@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
-   Copyright (C) 2005, 2006, 2007, 2012 Dag Andersen <danders@get2net.dk>
+   SPDX-FileCopyrightText: 2005, 2006, 2007, 2012 Dag Andersen <dag.andersen@kdemail.net>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 // clazy:excludeall=qstring-arg
@@ -36,8 +23,8 @@ namespace KPlato
 Account::Account()
     : m_name(),
       m_description(),
-      m_list(0),
-      m_parent(0),
+      m_list(nullptr),
+      m_parent(nullptr),
       m_accountList(),
       m_costPlaces() {
     
@@ -46,15 +33,14 @@ Account::Account()
 Account::Account(const QString& name, const QString& description)
     : m_name(name),
       m_description(description),
-      m_list(0),
-      m_parent(0),
+      m_list(nullptr),
+      m_parent(nullptr),
       m_accountList(),
       m_costPlaces() {
     
 }
 
 Account::~Account() {
-    //debugPlan<<m_name;
     if (m_list) {
         m_list->accountDeleted(this); // default account
     }
@@ -69,7 +55,7 @@ Account::~Account() {
     
 bool Account::isDefaultAccount() const
 {
-    return m_list == 0 ? false : m_list->defaultAccount() == this;
+    return m_list == nullptr ? false : m_list->defaultAccount() == this;
 }
 
 void Account::changed() {
@@ -104,7 +90,7 @@ void Account::insert(Account *account, int index) {
 }
 
 void Account::insertChildren() {
-    foreach (Account *a, m_accountList) {
+    for (Account *a : std::as_const(m_accountList)) {
         a->setList(m_list);
         a->setParent(this);
         insertId(a);
@@ -113,7 +99,7 @@ void Account::insertChildren() {
 }
 
 void Account::take(Account *account) {
-    if (account == 0) {
+    if (account == nullptr) {
         return;
     }
     if (account->parent()) {
@@ -139,7 +125,7 @@ void Account::take(Account *account) {
 
 bool Account::isChildOf(const Account *account) const
 {
-    if (m_parent == 0) {
+    if (m_parent == nullptr) {
         return false;
     }
     if (m_parent == account) {
@@ -150,7 +136,7 @@ bool Account::isChildOf(const Account *account) const
 
 bool Account::isBaselined(long id) const
 {
-    foreach (CostPlace *p, m_costPlaces) {
+    for (CostPlace *p : std::as_const(m_costPlaces)) {
         if (p->isBaselined(id)) {
             return true;
         }
@@ -159,22 +145,22 @@ bool Account::isBaselined(long id) const
 }
 
 bool Account::load(KoXmlElement &element, Project &project) {
-    m_name = element.attribute("name");
-    m_description = element.attribute("description");
+    m_name = element.attribute(QStringLiteral("name"));
+    m_description = element.attribute(QStringLiteral("description"));
     KoXmlNode n = element.firstChild();
     for (; ! n.isNull(); n = n.nextSibling()) {
         if (! n.isElement()) {
             continue;
         }
         KoXmlElement e = n.toElement();
-        if (e.tagName() == "costplace") {
+        if (e.tagName() == QStringLiteral("costplace")) {
             Account::CostPlace *child = new Account::CostPlace(this);
             if (child->load(e, project)) {
                 append(child);
             } else {
                 delete child;
             }
-        } else if (e.tagName() == "account") {
+        } else if (e.tagName() == QStringLiteral("account")) {
             Account *child = new Account();
             if (child->load(e, project)) {
                 m_accountList.append(child);
@@ -189,35 +175,35 @@ bool Account::load(KoXmlElement &element, Project &project) {
 }
 
 void Account::save(QDomElement &element) const {
-    QDomElement me = element.ownerDocument().createElement("account");
+    QDomElement me = element.ownerDocument().createElement(QStringLiteral("account"));
     element.appendChild(me);
-    me.setAttribute("name", m_name);
-    me.setAttribute("description", m_description);
-    foreach (Account::CostPlace *cp, m_costPlaces) {
+    me.setAttribute(QStringLiteral("name"), m_name);
+    me.setAttribute(QStringLiteral("description"), m_description);
+    for (Account::CostPlace *cp : std::as_const(m_costPlaces)) {
         cp->save(me);
     }
-    foreach (Account *a, m_accountList) {
+    for (Account *a : std::as_const(m_accountList)) {
         a->save(me);
     }
 }
 
 Account::CostPlace *Account::findCostPlace(const Resource &resource) const
 {
-    foreach (Account::CostPlace *cp, m_costPlaces) {
+    for (Account::CostPlace *cp : std::as_const(m_costPlaces)) {
         if (&resource == cp->resource()) {
             return cp;
         }
     }
-    return 0;
+    return nullptr;
 }
 
 Account::CostPlace *Account::findRunning(const Resource &resource) const {
-    foreach (Account::CostPlace *cp, m_costPlaces) {
+    for (Account::CostPlace *cp : std::as_const(m_costPlaces)) {
         if (&resource == cp->resource() && cp->running()) {
             return cp;
         }
     }
-    return 0;
+    return nullptr;
 }
 
 void Account::removeRunning(const Resource &resource) {
@@ -244,12 +230,12 @@ void Account::addRunning(Resource &resource) {
 
 Account::CostPlace *Account::findCostPlace(const Node &node) const
 {
-    foreach (Account::CostPlace *cp, m_costPlaces) {
+    for (Account::CostPlace *cp : std::as_const(m_costPlaces)) {
         if (&node == cp->node()) {
             return cp;
         }
     }
-    return 0;
+    return nullptr;
 }
 
 Account::CostPlace *Account::findRunning(const Node &node) const
@@ -259,7 +245,7 @@ Account::CostPlace *Account::findRunning(const Node &node) const
             return cp;
         }
     }
-    return 0;
+    return nullptr;
 }
 
 void Account::removeRunning(const Node &node) {
@@ -292,7 +278,7 @@ Account::CostPlace *Account::findStartup(const Node &node) const {
             return cp;
         }
     }
-    return 0;
+    return nullptr;
 }
 
 void Account::removeStartup(const Node &node) {
@@ -324,7 +310,7 @@ Account::CostPlace *Account::findShutdown(const Node &node) const {
             return cp;
         }
     }
-    return 0;
+    return nullptr;
 }
 
 void Account::removeShutdown(const Node &node) {
@@ -353,7 +339,7 @@ void Account::addShutdown(Node &node) {
 Account *Account::findAccount(const QString &id) const {
     if (m_list) 
         return m_list->findAccount(id);
-    return 0;
+    return nullptr;
 }
 
 bool Account::removeId(const QString &id) {
@@ -384,29 +370,29 @@ EffortCostMap Account::plannedCost(long id) const
 EffortCostMap Account::plannedCost(const QDate &start, const QDate &end, long id) const {
     EffortCostMap ec;
     if (! isElement()) {
-        foreach (Account *a, m_accountList) {
+        for (Account *a : std::as_const(m_accountList)) {
             ec += a->plannedCost(start, end, id);
         }
     }
-    foreach (Account::CostPlace *cp, m_costPlaces) {
+    for (Account::CostPlace *cp : std::as_const(m_costPlaces)) {
         ec += plannedCost(*cp, start, end, id);
     }
     if (isDefaultAccount()) {
-        QList<Node*> list = m_list == 0 ? QList<Node*>() : m_list->allNodes();
-        foreach (Node *n, list) {
+        const QList<Node*> list = m_list == nullptr ? QList<Node*>() : m_list->allNodes();
+        for (Node *n : list) {
             if (n->numChildren() > 0) {
                 continue;
             }
-            if (n->runningAccount() == 0) {
+            if (n->runningAccount() == nullptr) {
                 ec += n->plannedEffortCostPrDay(start, end, id);
             }
-            if (n->startupAccount() == 0) {
+            if (n->startupAccount() == nullptr) {
                 if ((! start.isValid() || n->startTime(id).date() >= start) &&
                      (! end.isValid() || n->startTime(id).date() <= end)) {
                     ec.add(n->startTime(id).date(), EffortCost(Duration::zeroDuration, n->startupCost()));
                 }
             }
-            if (n->shutdownAccount() == 0) {
+            if (n->shutdownAccount() == nullptr) {
                 if ((! start.isValid() || n->endTime(id).date() >= start) &&
                      (! end.isValid() || n->endTime(id).date() <= end)) {
                     ec.add(n->endTime(id).date(), EffortCost(Duration::zeroDuration, n->shutdownCost()));
@@ -455,33 +441,34 @@ EffortCostMap Account::actualCost(const QDate &start, const QDate &end, long id)
 {
     EffortCostMap ec;
     if (! isElement()) {
-        foreach (Account *a, m_accountList) {
+        for (Account *a : std::as_const(m_accountList)) {
             ec += a->actualCost(start, end, id);
         }
     }
-    foreach (Account::CostPlace *cp, costPlaces()) {
+    const auto costs = costPlaces();
+    for (Account::CostPlace *cp : costs) {
         ec += actualCost(*cp, start, end, id);
     }
     if (isDefaultAccount()) {
-        QList<Node*> list = m_list == 0 ? QList<Node*>() : m_list->allNodes();
-        foreach (Node *n, list) {
+        const QList<Node*> list = m_list == nullptr ? QList<Node*>() : m_list->allNodes();
+        for (Node *n : list) {
             if (n->numChildren() > 0) {
                 continue;
             }
-            if (n->runningAccount() == 0) {
+            if (n->runningAccount() == nullptr) {
                 //debugPlan<<"default, running:"<<n->name();
                 ec += n->actualEffortCostPrDay(start, end, id);
             }
             Task *t = dynamic_cast<Task*>(n); // only tasks have completion
             if (t) {
-                if (n->startupAccount() == 0 && t->completion().isStarted()) {
+                if (n->startupAccount() == nullptr && t->completion().isStarted()) {
                     const QDate startDate = t->completion().startTime().date();
                     if ((! start.isValid() || startDate >= start) &&
                         (! end.isValid() || startDate <= end)) {
                         ec.add(startDate, EffortCost(Duration::zeroDuration, n->startupCost()));
                     }
                 }
-                if (n->shutdownAccount() == 0 && t->completion().isFinished()) {
+                if (n->shutdownAccount() == nullptr && t->completion().isFinished()) {
                     //debugPlan<<"default, shutdown:"<<n->name();
                     const QDate finishDate = t->completion().finishTime().date();
                     if ((! start.isValid() || finishDate >= start) &&
@@ -521,7 +508,8 @@ EffortCostMap Account::actualCost(const Account::CostPlace &cp, const QDate &sta
             }
         }
     } else if (cp.resource() && m_list) {
-        foreach (Node *n, m_list->allNodes()) {
+        const auto nodes = m_list->allNodes();
+        for (Node *n : nodes) {
             if (n->type() == Node::Type_Task) {
                 ec += n->actualEffortCostPrDay(cp.resource(), start, end, id);
             }
@@ -536,7 +524,7 @@ Account::CostPlace::CostPlace(Account *acc, Node *node, bool running, bool strtu
     : m_account(acc), 
     m_objectId(node->id()),
     m_node(node),
-    m_resource(0),
+    m_resource(nullptr),
     m_running(false),
     m_startup(false),
     m_shutdown(false)
@@ -551,7 +539,7 @@ Account::CostPlace::CostPlace(Account *acc, Node *node, bool running, bool strtu
 Account::CostPlace::CostPlace(Account *acc, Resource *resource, bool running)
     : m_account(acc), 
     m_objectId(resource->id()),
-    m_node(0),
+    m_node(nullptr),
     m_resource(resource),
     m_running(false),
     m_startup(false),
@@ -567,21 +555,21 @@ Account::CostPlace::~CostPlace() {
     if (m_node) {
         if (m_running) {
             m_running = false;
-            m_node->setRunningAccount(0);
+            m_node->setRunningAccount(nullptr);
         }
         if (m_startup) {
             m_startup = false;
-            m_node->setStartupAccount(0);
+            m_node->setStartupAccount(nullptr);
         }
         if (m_shutdown) {
             m_shutdown = false;
-            m_node->setShutdownAccount(0);
+            m_node->setShutdownAccount(nullptr);
         }
     }
     if (m_resource) {
         if (m_running) {
             m_running = false;
-            m_resource->setAccount(0);
+            m_resource->setAccount(nullptr);
         }
     }
 }
@@ -634,9 +622,9 @@ void Account::CostPlace::setRunning(bool on)
     }
     m_running = on;
     if (m_node) {
-        m_node->setRunningAccount(on ? m_account : 0);
+        m_node->setRunningAccount(on ? m_account : nullptr);
     } else if (m_resource) {
-        m_resource->setAccount(on ? m_account : 0);
+        m_resource->setAccount(on ? m_account : nullptr);
     }
 }
 
@@ -647,7 +635,7 @@ void Account::CostPlace::setStartup(bool on)
     }
     m_startup = on;
     if (m_node)
-        m_node->setStartupAccount(on ? m_account : 0);
+        m_node->setStartupAccount(on ? m_account : nullptr);
 }
 
 void Account::CostPlace::setShutdown(bool on)
@@ -657,46 +645,46 @@ void Account::CostPlace::setShutdown(bool on)
     }
     m_shutdown = on;
     if (m_node)
-        m_node->setShutdownAccount(on ? m_account : 0);
+        m_node->setShutdownAccount(on ? m_account : nullptr);
 }
 
 //TODO
 bool Account::CostPlace::load(KoXmlElement &element, Project &project) {
     //debugPlan;
-    m_objectId = element.attribute("object-id");
+    m_objectId = element.attribute(QStringLiteral("object-id"));
     if (m_objectId.isEmpty()) {
         // check old format
-        m_objectId = element.attribute("node-id");
+        m_objectId = element.attribute(QStringLiteral("node-id"));
         if (m_objectId.isEmpty()) {
             errorPlan<<"No object id";
             return false;
         }
     }
     m_node = project.findNode(m_objectId);
-    if (m_node == 0) {
+    if (m_node == nullptr) {
         m_resource = project.findResource(m_objectId);
-        if (m_resource == 0) {
+        if (m_resource == nullptr) {
             errorPlan<<"Cannot find object with id: "<<m_objectId;
             return false;
         }
     }
-    bool on = (bool)(element.attribute("running-cost").toInt());
+    bool on = (bool)(element.attribute(QStringLiteral("running-cost")).toInt());
     if (on) setRunning(on);
-    on = (bool)(element.attribute("startup-cost").toInt());
+    on = (bool)(element.attribute(QStringLiteral("startup-cost")).toInt());
     if (on) setStartup(on);
-    on = (bool)(element.attribute("shutdown-cost").toInt());
+    on = (bool)(element.attribute(QStringLiteral("shutdown-cost")).toInt());
     if (on) setShutdown(on);
     return true;
 }
 
 void Account::CostPlace::save(QDomElement &element) const {
     //debugPlan;
-    QDomElement me = element.ownerDocument().createElement("costplace");
+    QDomElement me = element.ownerDocument().createElement(QStringLiteral("costplace"));
     element.appendChild(me);
-    me.setAttribute("object-id", m_objectId);
-    me.setAttribute("running-cost", QString::number(m_running));
-    me.setAttribute("startup-cost", QString::number(m_startup));
-    me.setAttribute("shutdown-cost", QString::number(m_shutdown));
+    me.setAttribute(QStringLiteral("object-id"), m_objectId);
+    me.setAttribute(QStringLiteral("running-cost"), QString::number(m_running));
+    me.setAttribute(QStringLiteral("startup-cost"), QString::number(m_startup));
+    me.setAttribute(QStringLiteral("shutdown-cost"), QString::number(m_shutdown));
     
 }
 
@@ -715,13 +703,13 @@ Accounts::Accounts(Project &project)
     : m_project(project),
       m_accountList(),
       m_idDict(),
-      m_defaultAccount(0) {
+      m_defaultAccount(nullptr) {
       
 }
 
 Accounts::~Accounts() {
     //debugPlan;
-    m_defaultAccount = 0;
+    m_defaultAccount = nullptr;
     while (!m_accountList.isEmpty()) {
         delete m_accountList.takeFirst();
     }
@@ -749,41 +737,41 @@ EffortCostMap Accounts::actualCost(const Account &account, const QDate &start, c
 
 void Accounts::insert(Account *account, Account *parent, int index) {
     Q_ASSERT(account);
-    if (parent == 0) {
+    if (parent == nullptr) {
         int i = index == -1 ? m_accountList.count() : index;
-        emit accountToBeAdded(parent, i);
+        Q_EMIT accountToBeAdded(parent, i);
         m_accountList.insert(i, account);
         account->setList(this);
-        account->setParent(0); // incase...
+        account->setParent(nullptr); // incase...
         insertId(account);
         account->insertChildren();
     } else {
         int i = index == -1 ? parent->accountList().count() : index;
-        emit accountToBeAdded(parent, i);
+        Q_EMIT accountToBeAdded(parent, i);
         parent->insert(account, i);
     }
     //debugPlan<<account->name();
-    emit accountAdded(account);
+    Q_EMIT accountAdded(account);
 }
 
 void Accounts::take(Account *account){
-    if (account == 0) {
+    if (account == nullptr) {
         return;
     }
-    account->m_list = 0;
+    account->m_list = nullptr;
     removeId(account->name());
     if (account->parent()) {
-        emit accountToBeRemoved(account);
+        Q_EMIT accountToBeRemoved(account);
         account->parent()->take(account);
-        emit accountRemoved(account);
+        Q_EMIT accountRemoved(account);
         //debugPlan<<account->name();
         return;
     }
     int i = m_accountList.indexOf(account);
     if (i != -1) {
-        emit accountToBeRemoved(account);
+        Q_EMIT accountToBeRemoved(account);
         m_accountList.removeAt(i);
-        emit accountRemoved(account);
+        Q_EMIT accountRemoved(account);
     }
     //debugPlan<<account->name();
 }
@@ -795,7 +783,7 @@ bool Accounts::load(KoXmlElement &element, Project &project) {
             continue;
         }
         KoXmlElement e = n.toElement();
-        if (e.tagName() == "account") {
+        if (e.tagName() == QStringLiteral("account")) {
             Account *child = new Account();
             if (child->load(e, project)) {
                 insert(child);
@@ -806,9 +794,9 @@ bool Accounts::load(KoXmlElement &element, Project &project) {
             }
         }
     }
-    if (element.hasAttribute("default-account")) {
-        m_defaultAccount = findAccount(element.attribute("default-account"));
-        if (m_defaultAccount == 0) {
+    if (element.hasAttribute(QStringLiteral("default-account"))) {
+        m_defaultAccount = findAccount(element.attribute(QStringLiteral("default-account")));
+        if (m_defaultAccount == nullptr) {
             warnPlan<<"Could not find default account.";
         }
     }
@@ -816,19 +804,20 @@ bool Accounts::load(KoXmlElement &element, Project &project) {
 }
 
 void Accounts::save(QDomElement &element) const {
-    QDomElement me = element.ownerDocument().createElement("accounts");
+    QDomElement me = element.ownerDocument().createElement(QStringLiteral("accounts"));
     element.appendChild(me);
     if (m_defaultAccount) {
-        me.setAttribute("default-account", m_defaultAccount->name());
+        me.setAttribute(QStringLiteral("default-account"), m_defaultAccount->name());
     }
-    foreach (Account *a, m_accountList) {
+    for (Account *a : std::as_const(m_accountList)) {
         a->save(me);
     }
 }
 
 QStringList Accounts::costElements() const {
     QStringList l;
-    foreach (const QString &key, m_idDict.uniqueKeys()) {
+    const auto keys = m_idDict.keys();
+    for (const QString &key : keys) {
         if (m_idDict[key]->isElement())
             l << key;
     }
@@ -837,40 +826,44 @@ QStringList Accounts::costElements() const {
     
 
 QStringList Accounts::nameList() const {
-    return m_idDict.uniqueKeys();
+    return m_idDict.keys();
 }
 
 Account *Accounts::findRunningAccount(const Resource &resource) const {
-    foreach (Account *a, m_idDict) {
+    const auto  accounts = m_idDict.values();
+    for (Account *a : accounts) {
         if (a->findRunning(resource)) {
             return a;
         }
     }
-    return 0;
+    return nullptr;
 }
 
 Account *Accounts::findRunningAccount(const Node &node) const {
-    foreach (Account *a, m_idDict) {
+    const auto  accounts = m_idDict.values();
+    for (Account *a : accounts) {
         if (a->findRunning(node))
             return a;
     }
-    return 0;
+    return nullptr;
 }
 
 Account *Accounts::findStartupAccount(const Node &node) const {
-    foreach (Account *a, m_idDict) {
+    const auto  accounts = m_idDict.values();
+    for (Account *a : accounts) {
         if (a->findStartup(node))
             return a;
     }
-    return 0;
+    return nullptr;
 }
 
 Account *Accounts::findShutdownAccount(const Node &node) const {
-    foreach (Account *a, m_idDict) {
+    const auto  accounts = m_idDict.values();
+    for (Account *a : accounts) {
         if (a->findShutdown(node))
             return a;
     }
-    return 0;
+    return nullptr;
 }
 
 Account *Accounts::findAccount(const QString &id) const {
@@ -880,7 +873,7 @@ Account *Accounts::findAccount(const QString &id) const {
 bool Accounts::insertId(Account *account) {
     Q_ASSERT(account);
     Account *a = findAccount(account->name());
-    if (a == 0) {
+    if (a == nullptr) {
         //debugPlan<<"'"<<account->name()<<"' inserted";
         m_idDict.insert(account->name(), account);
         return true;
@@ -903,7 +896,7 @@ bool Accounts::removeId(const QString &id) {
 
 QString Accounts::uniqueId(const QString &seed) const
 {
-    QString s = seed.isEmpty() ? i18n("Account") + ".%1" : seed + ".%1";
+    QString s = seed.isEmpty() ? i18n("Account") + QStringLiteral(".%1") : QString(seed + QStringLiteral(".%1"));
     int i = 1;
     QString n = s.arg(i);
     while (findAccount(n)) {
@@ -917,26 +910,26 @@ void Accounts::setDefaultAccount(Account *account)
     Account *a = m_defaultAccount;
     m_defaultAccount = account;
     if (a) {
-        emit changed(a);
+        Q_EMIT changed(a);
     }
     if (account) {
-        emit changed(account);
+        Q_EMIT changed(account);
     }
     if (a != account) {
-        emit defaultAccountChanged();
+        Q_EMIT defaultAccountChanged();
     }
 }
 
 void Accounts::accountDeleted(Account *account)
 {
     if (account == m_defaultAccount) {
-        m_defaultAccount = 0;
+        m_defaultAccount = nullptr;
     }
 }
 
 void Accounts::accountChanged(Account *account) 
 {
-    emit changed(account);
+    Q_EMIT changed(account);
 }
 
 QList<Node*> Accounts::allNodes() const
@@ -946,15 +939,15 @@ QList<Node*> Accounts::allNodes() const
 
 #ifndef NDEBUG
 void Accounts::printDebug(const QString& indent) {
-    debugPlan<<indent<<"Accounts:"<<m_accountList.count()<<" children";
-    foreach(Account *a, m_accountList) {
-        a->printDebug(indent + "    !");
+    debugPlan<<indent<<"Accounts:"<<this<<m_accountList.count()<<" children";
+    for(Account *a : std::as_const(m_accountList)) {
+        a->printDebug(indent + QStringLiteral("    !"));
     }
 }
 void Account::printDebug(const QString& indent) {
-    debugPlan<<indent<<"--- Account:"<<m_name<<":"<<m_accountList.count()<<" children";
-    foreach(Account *a, m_accountList) {
-        a->printDebug(indent + "    !");
+    debugPlan<<indent<<"--- Account:"<<this<<m_name<<":"<<m_accountList.count()<<" children";
+    for(Account *a : std::as_const(m_accountList)) {
+        a->printDebug(indent + QStringLiteral("    !"));
     }
 }
 #endif
