@@ -1,22 +1,9 @@
 /* This file is part of the KDE project
-   Copyright (C) 2005 - 2011 Dag Andersen <danders@get2net.dk>
-   Copyright (C) 2012 Dag Andersen <danders@get2net.dk>
-   Copyright (C) 2016 Dag Andersen <danders@get2net.dk>
+   SPDX-FileCopyrightText: 2005-2011 Dag Andersen <dag.andersen@kdemail.net>
+   SPDX-FileCopyrightText: 2012 Dag Andersen <dag.andersen@kdemail.net>
+   SPDX-FileCopyrightText: 2016 Dag Andersen <dag.andersen@kdemail.net>
    
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 // clazy:excludeall=qstring-arg
@@ -53,14 +40,12 @@ AppointmentInterval::AppointmentInterval(const AppointmentInterval &interval)
 AppointmentInterval::AppointmentInterval(const DateTime &start, const DateTime &end, double load)
     : d(new AppointmentIntervalData())
 {
+    if (start.isValid() && end.isValid()) {
+        Q_ASSERT(start.timeZone() == end.timeZone());
+    }
     setStartTime(start);
     setEndTime(end);
     setLoad(load);
-#ifndef NDEBUG
-    if (start.isValid() && end.isValid() && start.timeZone() != end.timeZone()) {
-        warnPlan<<"Timezones not equal:"<<start.timeZone()<<end.timeZone();
-    }
-#endif
 }
 
 AppointmentInterval::AppointmentInterval(QDate date, const TimeInterval& timeInterval, double load)
@@ -77,7 +62,7 @@ AppointmentInterval::AppointmentInterval(QDate date, const TimeInterval& timeInt
     setLoad(load);
 #ifndef NDEBUG
     if (s.isValid() && e.isValid()) {
-        debugPlan<<*this;
+//        debugPlan<<*this;
         Q_ASSERT(s.timeZone() == e.timeZone());
     }
 #endif
@@ -122,6 +107,22 @@ void AppointmentInterval::setLoad(double load)
     }
 }
 
+QTimeZone AppointmentInterval::timeZone() const
+{
+    return d->start.timeZone();
+}
+
+AppointmentInterval &AppointmentInterval::toTimeZone(const QTimeZone &tz)
+{
+    if (d->start.timeZone() != tz) {
+        d->start = d->start.toTimeZone(tz);
+    }
+    if (d->end.timeZone() != tz) {
+        d->end = d->end.toTimeZone(tz);
+    }
+    return *this;
+}
+
 Duration AppointmentInterval::effort() const
 {
     return (d->end - d->start) * d->load / 100;
@@ -178,7 +179,7 @@ bool AppointmentInterval::loadXML(KoXmlElement &element, XMLLoaderObject &status
 void AppointmentInterval::saveXML(QDomElement &element) const
 {
     Q_ASSERT(isValid());
-    QDomElement me = element.ownerDocument().createElement(QStringLiteral("interval"));
+    QDomElement me = element.ownerDocument().createElement(QStringLiteral("appointment-interval"));
     element.appendChild(me);
 
     me.setAttribute(QStringLiteral("start"), d->start.toString(Qt::ISODate));
@@ -208,9 +209,8 @@ AppointmentInterval AppointmentInterval::firstInterval(const AppointmentInterval
         if (s2 < f && f < e2) {
             s2 = f;
         }
-    } else {
-        f = s1 < s2 ? s1 : s2;
     }
+
     if (s1 < s2) {
         a.setStartTime(s1);
         if (e1 <= s2) {
@@ -239,11 +239,22 @@ AppointmentInterval AppointmentInterval::firstInterval(const AppointmentInterval
     return a;
 }
 
+AppointmentInterval &AppointmentInterval::operator=(const AppointmentInterval &interval)
+{
+    d = interval.d;
+    return *this;
+}
+
 bool AppointmentInterval::operator==(const AppointmentInterval &interval) const
 {
     return d->start == interval.d->start && d->end == interval.d->end && d->load == interval.d->load;
 }
 
+bool AppointmentInterval::operator!=(const AppointmentInterval &interval) const
+{
+    return !operator==(interval);
+}
+
 bool AppointmentInterval::operator<(const AppointmentInterval &other) const
 {
     if (d->start < other.d->start) {
@@ -265,7 +276,7 @@ bool AppointmentInterval::intersects(const AppointmentInterval &other) const
 
 AppointmentInterval AppointmentInterval::interval(const DateTime &start, const DateTime &end) const
 {
-    // TODO: Find and fix those that call with "wrong" timezone (should be local zone atm)
+    // TODO: Find and fix those that call with "wrong" timezone
     const DateTime s = start.toTimeZone(d->start.timeZone());
     const DateTime e = end.toTimeZone(d->end.timeZone());
     if (s <= d->start && e >= d->end) {
@@ -274,6 +285,27 @@ AppointmentInterval AppointmentInterval::interval(const DateTime &start, const D
     return AppointmentInterval(qMax(s, d->start), qMin(e, d->end), d->load);
 }
 
+bool AppointmentInterval::merge(const AppointmentInterval &interval)
+{
+    if (isConticuousTo(interval)) {
+        const DateTime s = interval.d->start.toTimeZone(d->start.timeZone());
+        const DateTime e = interval.d->end.toTimeZone(d->end.timeZone());
+        if (s < d->start) {
+            d->start = s;
+        }
+        if (e > d->end) {
+            d->end = e;
+        }
+        return true;
+    }
+    return false;
+}
+
+bool AppointmentInterval::isConticuousTo(const AppointmentInterval &other) const
+{
+    return operator!=(other) && !intersects(other) && (d->end == other.d->start || d->start == other.d->end);
+}
+
 QString AppointmentInterval::toString() const
 {
     return QStringLiteral("%1 - %2, %3%").arg(d->start.toString(Qt::ISODate)).arg(d->end.toString(Qt::ISODate)).arg(d->load);
@@ -291,12 +323,33 @@ AppointmentIntervalList::AppointmentIntervalList()
 
 }
 
+AppointmentIntervalList::AppointmentIntervalList(const AppointmentIntervalList &other)
+    : m_map(other.map())
+{
+}
+
 AppointmentIntervalList::AppointmentIntervalList(const QMultiMap<QDate, AppointmentInterval> &other)
     : m_map(other)
 {
 
 }
 
+QTimeZone AppointmentIntervalList::timeZone() const
+{
+    return m_map.isEmpty() ? QTimeZone::systemTimeZone() : m_map.first().timeZone();
+}
+
+AppointmentIntervalList &AppointmentIntervalList::toTimeZone(const QTimeZone &tz)
+{
+    AppointmentIntervalList m;
+    for (const auto &interval : std::as_const(m_map)) {
+        const AppointmentInterval i(interval.startTime().toTimeZone(tz), interval.endTime().toTimeZone(tz), interval.load());
+        m.add(i);
+    }
+    m_map = m.m_map;
+    return *this;
+}
+
 QMultiMap< QDate, AppointmentInterval > AppointmentIntervalList::map()
 {
     return m_map;
@@ -318,7 +371,8 @@ AppointmentIntervalList &AppointmentIntervalList::operator-=(const AppointmentIn
     if (lst.m_map.isEmpty()) {
         return *this;
     }
-    foreach (const AppointmentInterval &ai, lst.map()) {
+    const auto intervals = lst.map().values();
+    for (const AppointmentInterval &ai : intervals) {
         subtract(ai);
     }
     return *this;
@@ -342,15 +396,15 @@ void AppointmentIntervalList::subtract(const AppointmentInterval &interval)
     const DateTime et = interval.endTime();
     Q_ASSERT(st < et);
     const double load = interval.load();
-//     debugPlan<<"subtract:"<<*this<<endl<<"minus"<<interval;
+//     debugPlan<<"subtract:"<<*this<<'\n'<<"minus"<<interval;
     for (QDate date = st.date(); date <= et.date(); date = date.addDays(1)) {
         if (! m_map.contains(date)) {
             continue;
         }
         QList<AppointmentInterval> l;
-        QList<AppointmentInterval> v = m_map.values(date);
+        const QList<AppointmentInterval> v = m_map.values(date);
         m_map.remove(date);
-        foreach (const AppointmentInterval &vi, v) {
+        for (const AppointmentInterval &vi : v) {
             if (! vi.intersects(interval)) {
                 //debugPlan<<"subtract: not intersect:"<<vi<<interval;
                 l.insert(0, vi);
@@ -385,12 +439,12 @@ void AppointmentIntervalList::subtract(const AppointmentInterval &interval)
                 //if (! l.at(0).isValid()) { debugPlan<<vi<<interval<<l.at(0); qFatal("Invalid interval"); }
             }
         }
-        foreach (const AppointmentInterval &i, l) {
+        for (const AppointmentInterval &i : std::as_const(l)) {
             //if (! i.isValid()) { debugPlan<<interval<<i; qFatal("Invalid interval"); }
             m_map.insert(date, i);
         }
     }
-    //debugPlan<<"subtract:"<<interval<<" result="<<endl<<*this;
+    //debugPlan<<"subtract:"<<interval<<" result="<<'\n'<<*this;
 }
 
 AppointmentIntervalList &AppointmentIntervalList::operator+=(const AppointmentIntervalList &lst)
@@ -398,7 +452,8 @@ AppointmentIntervalList &AppointmentIntervalList::operator+=(const AppointmentIn
     if (lst.isEmpty()) {
         return *this;
     }
-    foreach (const AppointmentInterval &ai, lst.m_map) {
+    const auto intervals = lst.map().values();
+    for (const AppointmentInterval &ai : intervals) {
         add(ai);
     }
     return *this;
@@ -409,14 +464,19 @@ AppointmentIntervalList AppointmentIntervalList::extractIntervals(const DateTime
     if (isEmpty()) {
         return AppointmentIntervalList();
     }
-    QMultiMap<QDate, AppointmentInterval> lst;
+    QList<AppointmentInterval> ilst;
     QMultiMap<QDate, AppointmentInterval>::const_iterator it = m_map.lowerBound(start.date());
     for (; it != m_map.constEnd() && it.key() <= end.date(); ++it) {
         AppointmentInterval i = it.value().interval(start, end);
         if (i.isValid()) {
-            lst.insert(it.key(), it.value().interval(start, end));
+            ilst.append(i);
         }
     }
+    QMultiMap<QDate, AppointmentInterval> lst;
+    while (!ilst.isEmpty()) {
+        auto i = ilst.takeLast();
+        lst.insert(i.startTime().date(), i);
+    }
     return AppointmentIntervalList(lst);
 }
 
@@ -432,45 +492,54 @@ void AppointmentIntervalList::add(const AppointmentInterval &ai)
         Q_ASSERT(ai.isValid());
         return;
     }
-    QDate date = ai.startTime().date();
-    QDate ed =  ai.endTime().date();
-    int load = ai.load();
+    auto interval = ai;
+    if (!isEmpty()) {
+        interval.toTimeZone(m_map.first().timeZone());
+    }
+    QDate date = interval.startTime().date();
+    QDate ed =  interval.endTime().date();
+    int load = interval.load();
 
     QList<AppointmentInterval> lst;
     if (date == ed) {
-        lst << ai;
+        lst << interval;
     } else {
         // split intervals into separate dates
-        QTime t1 = ai.startTime().time();
+        const auto tz = interval.timeZone();
+        QTime t1 = interval.startTime().time();
         while (date < ed) {
-            lst << AppointmentInterval(DateTime(date, t1), DateTime(date.addDays(1)), load);
+            lst << AppointmentInterval(DateTime(date, t1, tz), DateTime(date.addDays(1), QTime(0, 0), tz), load);
             //debugPlan<<"split:"<<date<<lst.last();
             Q_ASSERT_X(lst.last().isValid(), "Split", "Invalid interval");
             date = date.addDays(1);
             t1 = QTime();
         }
-        if (ai.endTime().time() != QTime(0, 0, 0)) {
-            lst << AppointmentInterval(DateTime(ed), ai.endTime(), load);
+        if (interval.endTime().time() != QTime(0, 0, 0)) {
+            lst << AppointmentInterval(DateTime(ed, QTime(0, 0), tz), interval.endTime(), load);
             Q_ASSERT_X(lst.last().isValid(), "Split", "Invalid interval");
         }
     }
-    foreach (AppointmentInterval li, lst) {
+    for (AppointmentInterval li : std::as_const(lst)) {
         Q_ASSERT_X(lst.last().isValid(), "Add", "Invalid interval");
         date = li.startTime().date();
         if (! m_map.contains(date)) {
             m_map.insert(date, li);
             continue;
         }
-        QList<AppointmentInterval> v = m_map.values(date);
+        const QList<AppointmentInterval> v = m_map.values(date);
         m_map.remove(date);
         QList<AppointmentInterval> l;
-        foreach (const AppointmentInterval &vi, v) {
+        for (const AppointmentInterval &vi : v) {
             if (! li.isValid()) {
                 l.insert(0, vi);
                 Q_ASSERT_X(l.at(0).isValid(), "Original", "Invalid interval");
                 continue;
             }
-            if (! li.intersects(vi)) {
+            if (li.isConticuousTo(vi)) {
+                li.merge(vi);
+                continue;
+            }
+            if (!li.intersects(vi)) {
                 //debugPlan<<"not intersects:"<<li<<vi;
                 if (li < vi) {
                     if (! l.contains(li)) {
@@ -487,43 +556,43 @@ void AppointmentIntervalList::add(const AppointmentInterval &ai)
                     l.insert(0, vi);
                     Q_ASSERT_X(l.at(0).isValid(), "No intersects", "Add Invalid interval");
                 } else { Q_ASSERT(false); }
-            } else {
-                //debugPlan<<"intersects, merge"<<li<<vi;
-                if (li < vi) {
-                    //debugPlan<<"li < vi:";
-                    if (li.startTime() < vi.startTime()) {
-                        l.insert(0, AppointmentInterval(li.startTime(), vi.startTime(), li.load()));
-                        Q_ASSERT_X(l.at(0).isValid(), "Intersects, start", "Add Invalid interval");
-                    }
-                    l.insert(0, AppointmentInterval(vi.startTime(), qMin(vi.endTime(), li.endTime()), vi.load() + li.load()));
-                    Q_ASSERT_X(l.at(0).isValid(), "Intersects, middle", "Add Invalid interval");
-                    li.setStartTime(l.at(0).endTime()); // if more of li, it may overlap with next vi
-                    if (l.at(0).endTime() < vi.endTime()) {
-                        l.insert(0, AppointmentInterval(l.at(0).endTime(), vi.endTime(), vi.load()));
-                        //debugPlan<<"li < vi: vi rest:"<<l.at(0);
-                        Q_ASSERT_X(l.at(0).isValid(), "Intersects, end", "Add Invalid interval");
-                    }
-                } else if (vi < li) {
-                    //debugPlan<<"vi < li:";
-                    if (vi.startTime() < li.startTime()) {
-                        l.insert(0, AppointmentInterval(vi.startTime(), li.startTime(), vi.load()));
-                        Q_ASSERT_X(l.at(0).isValid(), "Intersects, start", "Add Invalid interval");
-                    }
-                    l.insert(0, AppointmentInterval(li.startTime(), qMin(vi.endTime(), li.endTime()), vi.load() + li.load()));
-                    Q_ASSERT_X(l.at(0).isValid(), "Intersects, middle", "Add Invalid interval");
-                    li.setStartTime(l.at(0).endTime()); // if more of li, it may overlap with next vi
-                    if (l.at(0).endTime() < vi.endTime()) {
-                        l.insert(0, AppointmentInterval(l.at(0).endTime(), vi.endTime(), vi.load()));
-                        //debugPlan<<"vi < li: vi rest:"<<l.at(0);
-                        Q_ASSERT_X(l.at(0).isValid(), "Intersects, end", "Add Invalid interval");
-                    }
-                } else {
-                    //debugPlan<<"vi == li:";
-                    li.setLoad(vi.load() + li.load());
-                    l.insert(0, li);
-                    Q_ASSERT_X(l.at(0).isValid(), "Equal", "Add Invalid interval");
-                    li = AppointmentInterval();
+                continue;
+            }
+            //debugPlan<<"intersects, merge"<<li<<vi;
+            if (li < vi) {
+                //debugPlan<<"li < vi:";
+                if (li.startTime() < vi.startTime()) {
+                    l.insert(0, AppointmentInterval(li.startTime(), vi.startTime(), li.load()));
+                    Q_ASSERT_X(l.at(0).isValid(), "Intersects, start", "Add Invalid interval");
                 }
+                l.insert(0, AppointmentInterval(vi.startTime(), qMin(vi.endTime(), li.endTime()), vi.load() + li.load()));
+                Q_ASSERT_X(l.at(0).isValid(), "Intersects, middle", "Add Invalid interval");
+                li.setStartTime(l.at(0).endTime()); // if more of li, it may overlap with next vi
+                if (l.at(0).endTime() < vi.endTime()) {
+                    l.insert(0, AppointmentInterval(l.at(0).endTime(), vi.endTime(), vi.load()));
+                    //debugPlan<<"li < vi: vi rest:"<<l.at(0);
+                    Q_ASSERT_X(l.at(0).isValid(), "Intersects, end", "Add Invalid interval");
+                }
+            } else if (vi < li) {
+                //debugPlan<<"vi < li:";
+                if (vi.startTime() < li.startTime()) {
+                    l.insert(0, AppointmentInterval(vi.startTime(), li.startTime(), vi.load()));
+                    Q_ASSERT_X(l.at(0).isValid(), "Intersects, start", "Add Invalid interval");
+                }
+                l.insert(0, AppointmentInterval(li.startTime(), qMin(vi.endTime(), li.endTime()), vi.load() + li.load()));
+                Q_ASSERT_X(l.at(0).isValid(), "Intersects, middle", "Add Invalid interval");
+                li.setStartTime(l.at(0).endTime()); // if more of li, it may overlap with next vi
+                if (l.at(0).endTime() < vi.endTime()) {
+                    l.insert(0, AppointmentInterval(l.at(0).endTime(), vi.endTime(), vi.load()));
+                    //debugPlan<<"vi < li: vi rest:"<<l.at(0);
+                    Q_ASSERT_X(l.at(0).isValid(), "Intersects, end", "Add Invalid interval");
+                }
+            } else {
+                //debugPlan<<"vi == li:";
+                li.setLoad(vi.load() + li.load());
+                l.insert(0, li);
+                Q_ASSERT_X(l.at(0).isValid(), "Equal", "Add Invalid interval");
+                li = AppointmentInterval();
             }
         }
         // If there is a rest of li, it must be inserted
@@ -531,7 +600,7 @@ void AppointmentIntervalList::add(const AppointmentInterval &ai)
             //debugPlan<<"rest:"<<li;
             l.insert(0, li);
         }
-        foreach(const AppointmentInterval &i, l) {
+        for(const AppointmentInterval &i : std::as_const(l)) {
             Q_ASSERT(i.isValid());
             m_map.insert(i.startTime().date(), i);
         }
@@ -542,7 +611,8 @@ void AppointmentIntervalList::add(const AppointmentInterval &ai)
 Duration AppointmentIntervalList::effort() const
 {
     Duration d;
-    foreach (const AppointmentInterval &i, m_map) {
+    const auto intervals = m_map.values();
+    for (const AppointmentInterval &i : intervals) {
         d += i.effort();
     }
     return d;
@@ -561,7 +631,8 @@ Duration AppointmentIntervalList::effort(const DateTime &start, const DateTime &
 
 void AppointmentIntervalList::saveXML(QDomElement &element) const
 {
-    foreach (const AppointmentInterval &i, m_map) {
+    const auto intervals = m_map.values();
+    for (const AppointmentInterval &i : intervals) {
         i.saveXML(element);
 #ifndef NDEBUG
         if (!i.isValid()) {
@@ -576,7 +647,7 @@ bool AppointmentIntervalList::loadXML(KoXmlElement &element, XMLLoaderObject &st
 {
     KoXmlElement e;
     forEachElement(e, element) {
-        if (e.tagName() == QLatin1String("interval")) {
+        if (e.tagName() == QStringLiteral("appointment-interval") || (status.version() < QStringLiteral("0.7.0") && e.tagName() == QStringLiteral("interval"))) {
             AppointmentInterval a;
             if (a.loadXML(e, status)) {
                 add(a);
@@ -592,7 +663,7 @@ QDebug operator<<(QDebug dbg, const KPlato::AppointmentIntervalList &i)
 {
     QMultiMap<QDate, AppointmentInterval>::const_iterator it = i.map().constBegin();
     for (; it != i.map().constEnd(); ++it) {
-        dbg<<endl<<it.key()<<":"<<it.value().startTime()<<it.value().endTime()<<it.value().load()<<"%";
+        dbg<<'\n'<<it.key()<<":"<<it.value().startTime()<<it.value().endTime()<<it.value().load()<<"%";
     }
     return dbg;
 }
@@ -601,8 +672,8 @@ QDebug operator<<(QDebug dbg, const KPlato::AppointmentIntervalList &i)
 Appointment::Appointment()
     : m_extraRepeats(), m_skipRepeats() {
     //debugPlan<<"("<<this<<")";
-    m_resource=0;
-    m_node=0;
+    m_resource=nullptr;
+    m_node=nullptr;
     m_calculationMode = Schedule::Scheduling;
     m_repeatInterval=Duration();
     m_repeatCount=0;
@@ -646,6 +717,12 @@ Appointment::~Appointment() {
     detach();
 }
 
+Appointment &Appointment::toTimeZone(const QTimeZone &tz)
+{
+    m_intervals.toTimeZone(tz);
+    return *this;
+}
+
 void Appointment::clear()
 {
     m_intervals.clear();
@@ -668,15 +745,17 @@ AppointmentIntervalList Appointment::intervals(const DateTime &start, const Date
 
 void Appointment::setIntervals(const AppointmentIntervalList &lst) {
     m_intervals.clear();
-    foreach(const AppointmentInterval &i, lst.map()) {
+    const auto intervals = lst.map().values();
+    for (const AppointmentInterval &i : intervals) {
         m_intervals.add(i);
     }
 }
 
 void Appointment::addInterval(const AppointmentInterval &a) {
     Q_ASSERT(a.isValid());
+    Q_ASSERT(a.startTime().timeZone() == a.endTime().timeZone());
     m_intervals.add(a);
-    //if (m_resource && m_resource->resource() && m_node && m_node->node()) debugPlan<<"Mode="<<m_calculationMode<<":"<<m_resource->resource()->name()<<" to"<<m_node->node()->name()<<""<<a.startTime()<<a.endTime();
+//     if (m_resource && m_resource->resource() && m_node && m_node->node()) debugPlan<<"Mode="<<m_calculationMode<<":"<<m_resource->resource()->name()<<" to"<<m_node->node()->name()<<""<<a.startTime()<<a.endTime();
 }
 void Appointment::addInterval(const DateTime &start, const DateTime &end, double load) {
     Q_ASSERT(start < end);
@@ -690,7 +769,8 @@ void Appointment::addInterval(const DateTime &start, KPlato::Duration duration,
 
 double Appointment::maxLoad() const {
     double v = 0.0;
-    foreach (const AppointmentInterval &i, m_intervals.map()) {
+    const auto intervals = m_intervals.map().values();
+    for (const AppointmentInterval &i : intervals) {
         if (v < i.load())
             v = i.load();
     }
@@ -717,45 +797,15 @@ bool Appointment::isBusy(const DateTime &/*start*/, const DateTime &/*end*/) {
     return false;
 }
 
-bool Appointment::loadXML(KoXmlElement &element, XMLLoaderObject &status, Schedule &sch) {
-    //debugPlan<<project.name();
-    Node *node = status.project().findNode(element.attribute(QStringLiteral("task-id")));
-    if (node == 0) {
-        errorPlan<<"The referenced task does not exists: "<<element.attribute(QStringLiteral("task-id"));
-        return false;
-    }
-    Resource *res = status.project().resource(element.attribute(QStringLiteral("resource-id")));
-    if (res == 0) {
-        errorPlan<<"The referenced resource does not exists: resource id="<<element.attribute(QStringLiteral("resource-id"));
-        return false;
-    }
-    if (!res->addAppointment(this, sch)) {
-        errorPlan<<"Failed to add appointment to resource: "<<res->name();
-        return false;
-    }
-    if (!node->addAppointment(this, sch)) {
-        errorPlan<<"Failed to add appointment to node: "<<node->name();
-        m_resource->takeAppointment(this);
-        return false;
-    }
-    //debugPlan<<"res="<<m_resource->resource()->name()<<" node="<<m_node->node()->name();
-    m_intervals.loadXML(element, status);
-    if (isEmpty()) {
-        errorPlan<<"Appointment is empty (added anyway): "<<node->name()<<res->name();
-        return false;
-    }
-    return true;
-}
-
 void Appointment::saveXML(QDomElement &element) const {
     if (isEmpty()) {
         errorPlan<<"Incomplete appointment data: No intervals";
     }
-    if (m_resource == 0 || m_resource->resource() == 0) {
+    if (m_resource == nullptr || m_resource->resource() == nullptr) {
         errorPlan<<"Incomplete appointment data: No resource";
         return;
     }
-    if (m_node == 0 || m_node->node() == 0) {
+    if (m_node == nullptr || m_node->node() == nullptr) {
         errorPlan<<"Incomplete appointment data: No node";
         return; // shouldn't happen
     }
@@ -780,8 +830,9 @@ Duration Appointment::plannedEffort(const Resource *resource, EffortCostCalculat
 // Returns the total planned effort for this appointment
 Duration Appointment::plannedEffort(EffortCostCalculationType type) const {
     Duration d;
-    if (type == ECCT_All || m_resource == 0 || m_resource->resource()->type() == Resource::Type_Work) {
-        foreach (const AppointmentInterval &i, m_intervals.map()) {
+    if (type == ECCT_All || m_resource == nullptr || m_resource->resource()->type() == Resource::Type_Work) {
+        const auto intervals = m_intervals.map().values();
+        for (const AppointmentInterval &i : intervals) {
             d += i.effort();
         }
     }
@@ -791,7 +842,7 @@ Duration Appointment::plannedEffort(EffortCostCalculationType type) const {
 // Returns the planned effort on the date
 Duration Appointment::plannedEffort(QDate date, EffortCostCalculationType type) const {
     Duration d;
-    if (type == ECCT_All || m_resource == 0 || m_resource->resource()->type() == Resource::Type_Work) {
+    if (type == ECCT_All || m_resource == nullptr || m_resource->resource()->type() == Resource::Type_Work) {
         QMultiMap<QDate, AppointmentInterval>::const_iterator it = m_intervals.map().constFind(date);
         for (; it != m_intervals.map().constEnd() && it.key() == date; ++it) {
             d += it.value().effort();
@@ -812,8 +863,9 @@ Duration Appointment::plannedEffort(const Resource *resource, QDate date, Effort
 Duration Appointment::plannedEffortTo(QDate date, EffortCostCalculationType type) const {
     Duration d;
     QDate e(date.addDays(1));
-    if (type == ECCT_All || m_resource == 0 || m_resource->resource()->type() == Resource::Type_Work) {
-        foreach (const AppointmentInterval &i, m_intervals.map()) {
+    if (type == ECCT_All || m_resource == nullptr || m_resource->resource()->type() == Resource::Type_Work) {
+        const auto intervals = m_intervals.map().values();
+        for (const AppointmentInterval &i : intervals) {
             d += i.effort(e, true); // upto e, not including
         }
     }
@@ -950,7 +1002,7 @@ void Appointment::detach() {
 // Returns the effort from start to end
 Duration Appointment::effort(const DateTime &start, const DateTime &end, EffortCostCalculationType type) const {
     Duration e;
-    if (type == ECCT_All || m_resource == 0 || m_resource->resource()->type() == Resource::Type_Work) {
+    if (type == ECCT_All || m_resource == nullptr || m_resource->resource()->type() == Resource::Type_Work) {
         e = m_intervals.effort(start, end);
     }
     return e;
@@ -958,8 +1010,9 @@ Duration Appointment::effort(const DateTime &start, const DateTime &end, EffortC
 // Returns the effort from start for the duration
 Duration Appointment::effort(const DateTime &start, KPlato::Duration duration, EffortCostCalculationType type) const {
     Duration d;
-    if (type == ECCT_All || m_resource == 0 || m_resource->resource()->type() == Resource::Type_Work) {
-        foreach (const AppointmentInterval &i, m_intervals.map()) {
+    if (type == ECCT_All || m_resource == nullptr || m_resource->resource()->type() == Resource::Type_Work) {
+        const auto intervals = m_intervals.map().values();
+        for (const AppointmentInterval &i : intervals) {
             d += i.effort(start, start+duration);
         }
     }
@@ -988,8 +1041,8 @@ Appointment &Appointment::operator-=(const Appointment &app) {
 }
 
 void Appointment::copy(const Appointment &app) {
-    m_resource = 0; //app.resource(); // NOTE: Don't copy, the new appointment
-    m_node = 0; //app.node();         // NOTE: doesn't belong to anyone yet.
+    m_resource = nullptr; //app.resource(); // NOTE: Don't copy, the new appointment
+    m_node = nullptr; //app.node();         // NOTE: doesn't belong to anyone yet.
     //TODO: incomplete but this is all we use atm
     m_calculationMode = app.calculationMode();
     
@@ -997,7 +1050,8 @@ void Appointment::copy(const Appointment &app) {
     //m_repeatCount = app.repeatCount();
 
     m_intervals.clear();
-    foreach (const AppointmentInterval &i, app.intervals().map()) {
+    const auto intervals = app.intervals().map().values();
+    for (const AppointmentInterval &i : intervals) {
         addInterval(i);
     }
 }
@@ -1057,7 +1111,7 @@ void Appointment::merge(const Appointment &app) {
         }
     }
     m_intervals.clear();
-    foreach (const AppointmentInterval &i, result) {
+    for (const AppointmentInterval &i : std::as_const(result)) {
         m_intervals.add(i);
     }
     //debugPlan<<this<<":"<<m_intervals.count();
@@ -1075,3 +1129,23 @@ Appointment Appointment::extractIntervals(const DateTimeInterval& interval) cons
 
 
 }  //KPlato namespace
+
+QDebug operator<<(QDebug dbg, const KPlato::Appointment *a)
+{
+    dbg << "Appointment("<<(void*)a<<')';
+    if (a) {
+        dbg<<'['<<a->node()<<a->resource()<<a->startTime()<<'-'<<a->endTime();
+        const auto lst = a->intervals().map();
+        for (const auto &i : lst) { // clazy:exclude=range-loop-reference
+            dbg<<'\n'<<'\t'<<i;
+        }
+        dbg<<']';
+    }
+    return dbg;
+}
+
+QDebug operator<<(QDebug dbg, const KPlato::Appointment &a)
+{
+    dbg << &a;
+    return dbg;
+}
