@@ -1,21 +1,8 @@
 /* This file is part of the KDE project
-   Copyright (C) 2003 - 2007 Dag Andersen <danders@get2net.dk>
-   Copyright (C) 2011 Dag Andersen <danders@get2net.dk>
+   SPDX-FileCopyrightText: 2003-2007 Dag Andersen <dag.andersen@kdemail.net>
+   SPDX-FileCopyrightText: 2011 Dag Andersen <dag.andersen@kdemail.net>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KPTCALENDAR_H
@@ -42,7 +29,6 @@ namespace KHolidays {
 class KUndo2Command;
 
 class QDomElement;
-class QStringList;
 
 
 /// The main namespace.
@@ -67,6 +53,9 @@ public:
     DateTimeInterval(const DateTime &t1, const DateTime &t2)
     : std::pair<DateTime, DateTime>(t1, t2)
     {}
+    DateTimeInterval(const DateTimeInterval &other)
+    : std::pair<DateTime, DateTime>(other.first, other.second)
+    {}
     DateTimeInterval &operator=(const DateTimeInterval &other) {
         first = other.first; second = other.second;
         return *this;
@@ -181,7 +170,7 @@ public:
     explicit CalendarDay(CalendarDay *day);
     ~CalendarDay();
 
-    bool load(KoXmlElement &element, XMLLoaderObject &status);
+    // NOTE: Saving is done here, loading is done using the XmlLoaderObject
     void save(QDomElement &element) const;
 
     QList<TimeInterval*> timeIntervals() const { return m_timeIntervals; }
@@ -218,26 +207,26 @@ public:
      * Returns the amount of 'worktime' that can be done on
      * this day between the times start and end.
      */
-    Duration effort(QTime start, int length, const QTimeZone &timeZone, Schedule *sch=0);
+    Duration effort(QTime start, int length, const QTimeZone &timeZone, Schedule *sch=nullptr);
     /**
      * Returns the amount of 'worktime' that can be done on
      * this day between the times start and end.
      */
-    Duration effort(QDate date, QTime start, int length, const QTimeZone &timeZone, Schedule *sch=0);
+    Duration effort(QDate date, QTime start, int length, const QTimeZone &timeZone, Schedule *sch=nullptr);
 
     /**
      * Returns the actual 'work interval' for the interval start to end.
      * If no 'work interval' exists, returns the interval start, end.
      * Use @ref hasInterval() to check if a 'work interval' exists.
      */
-    TimeInterval interval(QTime start, int length, const QTimeZone &timeZone,  Schedule *sch=0) const;
+    TimeInterval interval(QTime start, int length, const QTimeZone &timeZone,  Schedule *sch=nullptr) const;
     
     /**
      * Returns the actual 'work interval' for the interval start to end.
      * If no 'work interval' exists, returns the interval start, end.
      * Use @ref hasInterval() to check if a 'work interval' exists.
      */
-    TimeInterval interval(QDate date, QTime start, int length, const QTimeZone &timeZone, Schedule *sch=0) const;
+    TimeInterval interval(QDate date, QTime start, int length, const QTimeZone &timeZone, Schedule *sch=nullptr) const;
     
     bool hasInterval() const;
 
@@ -245,7 +234,7 @@ public:
      * Returns true if at least a part of a 'work interval' exists 
      * for the interval start to end.
      */
-    bool hasInterval(QTime start, int length, const QTimeZone &timeZone, Schedule *sch=0) const;
+    bool hasInterval(QTime start, int length, const QTimeZone &timeZone, Schedule *sch=nullptr) const;
     
     /**
      * Returns true if at least a part of a 'work interval' exists 
@@ -253,7 +242,7 @@ public:
      * Assumes this day is date. (Used by weekday hasInterval().)
      * If @p sch is not 0, the schedule is checked for availability.
      */
-    bool hasInterval(QDate date, QTime start, int length, const QTimeZone &timeZone, Schedule *sch=0) const;
+    bool hasInterval(QDate date, QTime start, int length, const QTimeZone &timeZone, Schedule *sch=nullptr) const;
     
     Duration duration() const;
     
@@ -281,7 +270,7 @@ public:
     explicit CalendarWeekdays(const CalendarWeekdays *weekdays);
     ~CalendarWeekdays();
 
-    bool load(KoXmlElement &element, XMLLoaderObject &status);
+    //bool load(KoXmlElement &element, XMLLoaderObject &status);
     void save(QDomElement &element) const;
 
     const QList<CalendarDay*> weekdays() const 
@@ -312,7 +301,7 @@ public:
     bool operator==(const CalendarWeekdays *weekdays) const;
     bool operator!=(const CalendarWeekdays *weekdays) const;
 
-    Duration effort(QDate date, QTime start, int length, const QTimeZone &timeZone, Schedule *sch=0);
+    Duration effort(QDate date, QTime start, int length, const QTimeZone &timeZone, Schedule *sch=nullptr);
     
     /**
      * Returns the actual 'work interval' on the weekday defined by date
@@ -364,7 +353,7 @@ public:
  *  4. Definitions for individual resources.
  *
  * A calendar can define a timezone different from the projects.
- * This enables planning with resources that does not recide in the same place.
+ * This enables planning with resources that does not reside in the same place.
  *
  */
 class PLANKERNEL_EXPORT Calendar : public QObject
@@ -372,11 +361,13 @@ class PLANKERNEL_EXPORT Calendar : public QObject
     Q_OBJECT
 public:
     Calendar();
-    explicit Calendar(const QString& name, Calendar *parent=0);
+    explicit Calendar(const QString& name, Calendar *parent=nullptr);
     //Calendar(const Calendar &c); QObject doesn't allow a copy constructor
     ~Calendar() override;
 
     const Calendar &operator=(const Calendar &calendar) { return copy(calendar); }
+    const Calendar &copy(const Calendar &calendar);
+    void copy(const Calendar *calendar);
 
     QString name() const { return m_name; }
     void setName(const QString& name);
@@ -406,7 +397,7 @@ public:
     /// Return child calendar at @p index, 0 if index out of bounds
     Calendar *childAt(int index) const { return m_calendars.value(index); }
     
-    bool load(KoXmlElement &element, XMLLoaderObject &status);
+    //bool load(KoXmlElement &element, XMLLoaderObject &status);
     void save(QDomElement &element) const;
 
     int state(QDate date) const;
@@ -457,7 +448,7 @@ public:
      * interval from @p start to @p end
      * If @p sch is not 0, the schedule is checked for availability.
      */
-    Duration effort(const DateTime &start, const DateTime &end, Schedule *sch=0) const;
+    Duration effort(const DateTime &start, const DateTime &end, Schedule *sch=nullptr) const;
 
     /**
      * Returns the first 'work interval' for the interval 
@@ -466,27 +457,27 @@ public:
      * You can also use @ref hasInterval() to check if a 'work interval' exists.
      * If @p sch is not 0, the schedule is checked for availability.
      */
-    DateTimeInterval firstInterval(const DateTime &start, const DateTime &end, Schedule *sch=0) const;
+    DateTimeInterval firstInterval(const DateTime &start, const DateTime &end, Schedule *sch=nullptr) const;
     
     /**
      * Returns true if at least a part of a 'work interval' exists 
      * for the interval starting at @p start and ending at @p end.
      * If @p sch is not 0, the schedule is checked for availability.
      */
-    bool hasInterval(const DateTime &start, const DateTime &end, Schedule *sch=0) const;
+    bool hasInterval(const DateTime &start, const DateTime &end, Schedule *sch=nullptr) const;
         
     /** 
      * Find the first available time after @p time before @p limit.
      * Return invalid datetime if not available.
      * If @p sch is not 0, the schedule is checked for availability.
      */
-    DateTime firstAvailableAfter(const DateTime &time, const DateTime &limit, Schedule *sch = 0);
+    DateTime firstAvailableAfter(const DateTime &time, const DateTime &limit, Schedule *sch = nullptr);
     /** 
      * Find the first available time backwards from @p time. Search until @p limit.
      * Return invalid datetime if not available.
      * If @p sch is not 0, the schedule is checked for availability.
      */
-    DateTime firstAvailableBefore(const DateTime &time, const DateTime &limit, Schedule *sch = 0);
+    DateTime firstAvailableBefore(const DateTime &time, const DateTime &limit, Schedule *sch = nullptr);
 
     Calendar *findCalendar() const { return findCalendar(m_id); }
     Calendar *findCalendar(const QString &id) const;
@@ -522,10 +513,12 @@ public:
     QStringList holidayRegionCodes() const;
 #endif
 
+    void setBlockVersion(bool block) { m_blockversion = block; }
+
 Q_SIGNALS:
-    void changed(KPlato::Calendar*);
-    void changed(KPlato::CalendarDay*);
-    void changed(KPlato::TimeInterval*);
+    void calendarChanged(KPlato::Calendar*);
+    void calendarDayChanged(KPlato::CalendarDay*);
+    void timeIntervalChanged(KPlato::TimeInterval*);
     
     void weekdayToBeAdded(KPlato::CalendarDay *day, int index);
     void weekdayAdded(KPlato::CalendarDay *day);
@@ -544,7 +537,6 @@ Q_SIGNALS:
 
 protected:
     void init();
-    const Calendar &copy(const Calendar &calendar);
     
     /**
      * Returns the amount of 'worktime' that can be done on
@@ -552,13 +544,13 @@ protected:
      * The date and times are in timespecification @p spec.
      * If @p sch is not 0, the schedule is checked for availability.
      */
-    Duration effort(QDate date, QTime start, int length, Schedule *sch=0) const;
+    Duration effort(QDate date, QTime start, int length, Schedule *sch=nullptr) const;
     /**
      * Returns the amount of 'worktime' that can be done in the
      * interval from @p start to @p end
      * If @p sch is not 0, the schedule is checked for availability.
      */
-    Duration effort(const QDateTime &start, const QDateTime &end, Schedule *sch=0) const;
+    Duration effort(const QDateTime &start, const QDateTime &end, Schedule *sch=nullptr) const;
     /**
      * Returns the first 'work interval' on date for the interval 
      * starting at @p start and ending at @p start + @p length.
@@ -567,20 +559,20 @@ protected:
      * The date and times are in timespecification spec.
      * If @p sch is not 0, the schedule is checked for availability.
      */
-    TimeInterval firstInterval(QDate date, QTime start, int length, Schedule *sch=0) const;
+    TimeInterval firstInterval(QDate date, QTime start, int length, Schedule *sch=nullptr) const;
     /**
      * Returns the first 'work interval' for the interval
      * starting at @p start and ending at @p end.
      * If no 'work interval' exists, returns an interval with invalid DateTime.
      */
-    DateTimeInterval firstInterval(const QDateTime &start, const QDateTime &end, Schedule *sch=0) const;
+    DateTimeInterval firstInterval(const QDateTime &start, const QDateTime &end, Schedule *sch=nullptr) const;
 
     /**
      * Returns true if at least a part of a 'work interval' exists 
      * for the interval on date, starting at @p start and ending at @p start + @p length.
      * If @p sch is not 0, the schedule is checked for availability.
      */
-    bool hasInterval(QDate date, QTime start, int length, Schedule *sch=0) const;
+    bool hasInterval(QDate date, QTime start, int length, Schedule *sch=nullptr) const;
 
     /**
      * Returns the work intervals in the interval from @p start to @p end
@@ -593,7 +585,7 @@ protected:
      * Return invalid datetime if not available.
      * If @p sch is not 0, the schedule is checked for availability.
      */
-    DateTime firstAvailableBefore(const QDateTime &time, const QDateTime &limit, Schedule *sch = 0);
+    DateTime firstAvailableBefore(const QDateTime &time, const QDateTime &limit, Schedule *sch = nullptr);
 
 private:
     QString m_name;
@@ -629,7 +621,7 @@ public:
 class PLANKERNEL_EXPORT StandardWorktime
 {
 public:
-    explicit StandardWorktime(Project *project = 0);
+    explicit StandardWorktime(Project *project = nullptr);
     explicit StandardWorktime(StandardWorktime* worktime);
     ~StandardWorktime();
 
@@ -673,7 +665,7 @@ public:
     
     QList<qint64> scales() const;
 
-    bool load(KoXmlElement &element, XMLLoaderObject &status);
+    //bool load(KoXmlElement &element, XMLLoaderObject &status);
     void save(QDomElement &element) const;
 
     void changed();
@@ -695,6 +687,7 @@ PLANKERNEL_EXPORT QDebug operator<<(QDebug dbg, KPlato::Calendar *c);
 PLANKERNEL_EXPORT QDebug operator<<(QDebug dbg, KPlato::CalendarWeekdays *w);
 PLANKERNEL_EXPORT QDebug operator<<(QDebug dbg, KPlato::CalendarDay *day);
 
+PLANKERNEL_EXPORT QDebug operator<<(QDebug dbg, KPlato::StandardWorktime &wt);
 PLANKERNEL_EXPORT QDebug operator<<(QDebug dbg, KPlato::StandardWorktime *wt);
 
 #endif
