@@ -1,21 +1,8 @@
 /* This file is part of the KDE project
-   Copyright (C) 2001 Thomas Zander zander@kde.org
-   Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012 Dag Andersen <danders@get2net.dk>
+   SPDX-FileCopyrightText: 2001 Thomas Zander zander @kde.org
+   SPDX-FileCopyrightText: 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012 Dag Andersen <dag.andersen@kdemail.net>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 // clazy:excludeall=qstring-arg
@@ -27,7 +14,7 @@
 #include <KLocalizedString>
 
 #include <QLocale>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QStringList>
 
 
@@ -72,7 +59,7 @@ Duration::Duration(const qint64 value, Duration::Unit unit) {
     else errorPlan<<"Unknown unit: "<<unit;
 }
 
-void Duration::add(KPlato::Duration delta) {
+void Duration::add(const Duration &delta) {
     m_ms += delta.m_ms;
 }
 
@@ -86,7 +73,7 @@ void Duration::add(qint64 delta) {
     m_ms = tmp;
 }
 
-void Duration::subtract(KPlato::Duration delta) {
+void Duration::subtract(const Duration &delta) {
     if (m_ms < delta.m_ms) {
         debugPlan<<"Underflow"<<delta.toString()<<" from"<<this->toString();
         m_ms = 0;
@@ -123,13 +110,13 @@ Duration Duration::operator*(const double value) const {
     return dur;
 }
 
-Duration Duration::operator*(const Duration value) const {
+Duration Duration::operator*(const Duration &value) const {
     Duration dur(*this);
     dur.m_ms = m_ms * value.m_ms;
     return dur;
 }
 
-double Duration::operator/(KPlato::Duration d) const {
+double Duration::operator/(const Duration &d) const {
     if (d == zeroDuration) {
         debugPlan<<"Divide by zero:"<<this->toString();
         return 0.0;
@@ -151,7 +138,7 @@ QString Duration::toString(Format format) const {
     unsigned minutes;
     unsigned seconds;
     QString result;
-
+    QLocale locale;
     switch (format) {
         case Format_Hour:
             ms = m_ms;
@@ -164,7 +151,7 @@ QString Duration::toString(Format format) const {
             days = m_ms / (1000 * 60 * 60 * 24.0);
             result = QStringLiteral("%1d").arg(QString::number(days, 'f', 4));
             break;
-        case Format_DayTime:
+        case Format_DayTime: {
             ms = m_ms;
             days = m_ms / (1000 * 60 * 60 * 24);
             ms -= (qint64)days * (1000 * 60 * 60 * 24);
@@ -174,8 +161,14 @@ QString Duration::toString(Format format) const {
             ms -= minutes * (1000 * 60);
             seconds = ms / (1000);
             ms -= seconds * (1000);
-            result.sprintf("%u %02u:%02u:%02u.%u", (unsigned)days, hours, minutes, seconds, (unsigned)ms);
+            const QString dayString = QString::number((unsigned)days);
+            const QString hourString = QString::number(hours);
+            const QString minString = QString::number(minutes);
+            const QString secString = QString::number(seconds);
+            const QString msString = QString::number(ms);
+            result = QStringLiteral("%1 %2:%3:%4.%5").arg(dayString, hourString, minString, secString, msString);
             break;
+        }
         case Format_HourFraction:
             result = QLocale().toString(toDouble(Unit_h), 'f', 2);
             break;
@@ -186,9 +179,9 @@ QString Duration::toString(Format format) const {
             ms -= (qint64)hours * (1000 * 60 * 60);
             minutes = ms / (1000 * 60);
             if (minutes > 0) {
-                result = i18nc("<hours>h:<minutes>m", "%1h:%2m", hours, minutes);
+                result = i18nc("<hours>h:<minutes>m", "%1h:%2m", locale.toString(hours), locale.toString(minutes));
             } else {
-                result = i18nc("<hours>h:<minutes>m", "%1h", hours);
+                result = i18nc("<hours>h:<minutes>m", "%1h", locale.toString(hours));
             }
             break;
         case Format_i18nDay:
@@ -213,18 +206,30 @@ QString Duration::toString(Format format) const {
             ms -= minutes * (1000 * 60);
             seconds = ms / (1000);
             ms -= seconds * (1000);
-            if (days == 0) {
+            if (days > 0) {
+                result = i18nc("<days>d <hours>h:<minutes>m", "%1d %2h:%3m", locale.toString(days), locale.toString(hours), locale.toString(minutes));
+            } else if (hours > 0) {
                 result = toString(Format_i18nHour);
             } else if (minutes > 0) {
-                result = i18nc("<days>d <hours>h:<minutes>m", "%1d %2h:%3m", days, hours, minutes);
-            } else if (hours > 0) {
-                result = i18nc("<days>d <hours>h:<minutes>m", "%1d %2h", days, hours);
-            } else {
-                result = i18nc("<days>d <hours>h:<minutes>m", "%1d", days);
+                if (ms > 0 ) {
+                    result = i18nc("<minutes>m:<seconds>s.<milliseconds>", "%1m:%2s.%3", locale.toString(minutes), locale.toString(seconds), locale.toString(ms));
+                } else if (seconds > 0) {
+                    result = i18nc("<minutes>m:<seconds>s", "%1m:%2s", locale.toString(minutes), locale.toString(seconds));
+                } else {
+                    result = i18nc("<minutes>m", "%1m", locale.toString(minutes));
+                }
+            } else if (seconds > 0) {
+                if (ms == 0 ) {
+                    result = i18nc("<seconds>s", "%1s", locale.toString(seconds));
+                } else {
+                    result = i18nc("<seconds>s.<milliseconds>", "%1s.%2", locale.toString(seconds), locale.toString(ms));
+                }
+            } else if (ms > 0) {
+                result = i18nc("<milliseconds>ms", "%1ms", locale.toString(ms));
             }
             break;
         case Format_i18nHourFraction:
-            result = QLocale().toString(toDouble(Unit_h), 'f', 2);
+            result = locale.toString(toDouble(Unit_h), 'f', 2);
             break;
         default:
             qFatal("Unknown format");
@@ -235,28 +240,27 @@ QString Duration::toString(Format format) const {
 
 Duration Duration::fromString(const QString &s, Format format, bool *ok) {
     if (ok) *ok = false;
-    QRegExp matcher;
     Duration tmp;
     switch (format) {
         case Format_Hour: {
-            matcher.setPattern(QStringLiteral("^(\\d*)h(\\d*)m$"));
-            int pos = matcher.indexIn(s);
-            if (pos > -1) {
-                tmp.addHours(matcher.cap(1).toUInt());
-                tmp.addMinutes(matcher.cap(2).toUInt());
+            QRegularExpression matcher(QStringLiteral("^(\\d*)h(\\d*)m$"));
+            auto match = matcher.match(s);
+            if (match.hasMatch()) {
+                tmp.addHours(match.captured(1).toUInt());
+                tmp.addMinutes(match.captured(2).toUInt());
                 if (ok) *ok = true;
             }
             break;
         }
         case Format_DayTime: {
-            matcher.setPattern(QStringLiteral("^(\\d*) (\\d*):(\\d*):(\\d*)\\.(\\d*)$"));
-            int pos = matcher.indexIn(s);
-            if (pos > -1) {
-                tmp.addDays(matcher.cap(1).toUInt());
-                tmp.addHours(matcher.cap(2).toUInt());
-                tmp.addMinutes(matcher.cap(3).toUInt());
-                tmp.addSeconds(matcher.cap(4).toUInt());
-                tmp.addMilliseconds(matcher.cap(5).toUInt());
+            QRegularExpression matcher(QStringLiteral("^(\\d*) (\\d*):(\\d*):(\\d*)\\.(\\d*)$"));
+            auto match = matcher.match(s);
+            if (match.hasMatch()) {
+                tmp.addDays(match.captured(1).toUInt());
+                tmp.addHours(match.captured(2).toUInt());
+                tmp.addMinutes(match.captured(3).toUInt());
+                tmp.addSeconds(match.captured(4).toUInt());
+                tmp.addMilliseconds(match.captured(5).toUInt());
                 if (ok) *ok = true;
             }
             break;
@@ -308,8 +312,8 @@ Duration::Unit Duration::unitFromString(const QString &u)
 }
 
 bool Duration::valueFromString(const QString &value, double &rv, Unit &unit) {
-    QStringList lst = Duration::unitList();
-    foreach (const QString &s, lst) {
+    const QStringList lst = Duration::unitList();
+    for (const QString &s : lst) {
         int pos = value.lastIndexOf(s);
         if (pos != -1) {
             unit = Duration::unitFromString(s);
@@ -317,11 +321,11 @@ bool Duration::valueFromString(const QString &value, double &rv, Unit &unit) {
             v.remove(s);
             bool ok;
             rv = v.toDouble(&ok);
-            errorPlan<<value<<" -> "<<v<<", "<<s<<" = "<<ok<<endl;
+            errorPlan<<value<<" -> "<<v<<", "<<s<<" = "<<ok<<'\n';
             return ok;
         }
     }
-    errorPlan<<"Illegal format, no unit: "<<value<<endl;
+    errorPlan<<"Illegal format, no unit: "<<value<<'\n';
     return false;
 }
 
