@@ -1,21 +1,8 @@
 /* This file is part of the KDE project
-   Copyright (C) 2001 Thomas Zander zander@kde.org
-   Copyright (C) 2004 - 2011 Dag Andersen <danders@get2net.dk>
+   SPDX-FileCopyrightText: 2001 Thomas Zander zander @kde.org
+   SPDX-FileCopyrightText: 2004-2011 Dag Andersen <dag.andersen@kdemail.net>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KPTDURATION_H
@@ -26,7 +13,6 @@
 #include <QtGlobal>
 
 class QString;
-class QStringList;
 
 /// The main namespace.
 namespace KPlato
@@ -95,42 +81,42 @@ public:
      */
     void addDays(qint64 delta) { addHours(delta * 24); }
 
-    bool   operator==(KPlato::Duration d) const { return m_ms == d.m_ms; }
+    bool   operator==(const KPlato::Duration &d) const { return m_ms == d.m_ms; }
     bool   operator==(qint64 d) const { return m_ms == d; }
-    bool   operator!=(KPlato::Duration d) const { return m_ms != d.m_ms; }
+    bool   operator!=(const KPlato::Duration &d) const { return m_ms != d.m_ms; }
     bool   operator!=(qint64 d) const { return m_ms != d; }
-    bool   operator<(KPlato::Duration d) const { return m_ms < d.m_ms; }
+    bool   operator<(const KPlato::Duration &d) const { return m_ms < d.m_ms; }
     bool   operator<(qint64 d) const { return m_ms < d; }
-    bool   operator<=(KPlato::Duration d) const { return m_ms <= d.m_ms; }
+    bool   operator<=(const KPlato::Duration &d) const { return m_ms <= d.m_ms; }
     bool   operator<=(qint64 d) const { return m_ms <= d; }
-    bool   operator>(KPlato::Duration d) const { return m_ms > d.m_ms; }
+    bool   operator>(const KPlato::Duration &d) const { return m_ms > d.m_ms; }
     bool   operator>(qint64 d) const { return m_ms > d; }
-    bool   operator>=(KPlato::Duration d) const { return m_ms >= d.m_ms; }
+    bool   operator>=(const KPlato::Duration &d) const { return m_ms >= d.m_ms; }
     bool   operator>=(qint64 d) const { return m_ms >= d; }
     Duration operator*(int value) const; 
     Duration operator*(const double value) const;
-    Duration operator*(const Duration value) const;
+    Duration operator*(const Duration &value) const;
     /// Divide duration with the integer @p value
     Duration operator/(int value) const;
     /// Divide duration with the duration @p d
-    double operator/(KPlato::Duration d) const;
+    double operator/(const KPlato::Duration &d) const;
     /// Add duration with duration @p d
-    Duration operator+(KPlato::Duration d) const
+    Duration operator+(const KPlato::Duration &d) const
         {Duration dur(*this); dur.add(d); return dur; }
     /// Add duration with duration @p d
-    Duration &operator+=(KPlato::Duration d) {add(d); return *this; }
+    Duration &operator+=(const KPlato::Duration &d) {add(d); return *this; }
     /// Subtract duration with duration @p d
-    Duration operator-(KPlato::Duration d) const
+    Duration operator-(const KPlato::Duration &d) const
         {Duration dur(*this); dur.subtract(d); return dur; }
     /// Subtract duration with duration @p d
-    Duration &operator-=(KPlato::Duration d) {subtract(d); return *this; }
+    Duration &operator-=(const KPlato::Duration &d) {subtract(d); return *this; }
 
     /// Format duration into a string with @p unit and @p precision.
     QString format(Unit unit = Unit_h, int precision = 1) const;
     /// Convert duration to a string with @p format
     QString toString(Format format = Format_DayTime) const;
     /// Create a duration from string @p s with @p format
-    static Duration fromString(const QString &s, Format format = Format_DayTime, bool *ok=0);
+    static Duration fromString(const QString &s, Format format = Format_DayTime, bool *ok=nullptr);
 
     /// Return the duration scaled to hours
     double toHours() const;
@@ -162,12 +148,12 @@ private:
     
 private:
     void add(qint64 delta);
-    void add(KPlato::Duration delta);
+    void add(const Duration &delta);
 
     /**
     * Subtracts @param delta from *this. If @param delta > *this, *this is set to zeroDuration.
     */
-    void subtract(KPlato::Duration delta);
+    void subtract(const Duration &delta);
 };
 
 }  //KPlato namespace
