@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
-   Copyright (C) 2010 Dag Andersen <danders@get2net.dk>
+   SPDX-FileCopyrightText: 2010 Dag Andersen <dag.andersen@kdemail.net>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation;
-   version 2 of the License.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 // clazy:excludeall=qstring-arg
@@ -94,6 +81,42 @@ void EffortCostMap::addBcwpCost(const QDate &date, double cost)
     m_days[ date ] = ec;
 }
 
+double EffortCostMap::costTo(QDate date) const {
+    double cost = 0.0;
+    EffortCostDayMap::const_iterator it;
+    for(it = m_days.constBegin(); it != m_days.constEnd(); ++it) {
+        if (it.key() > date) {
+            break;
+        }
+        cost += it.value().cost();
+    }
+    return cost;
+}
+
+Duration EffortCostMap::effortTo(QDate date) const {
+    Duration eff;
+    EffortCostDayMap::const_iterator it;
+    for(it = m_days.constBegin(); it != m_days.constEnd(); ++it) {
+        if (it.key() > date) {
+            break;
+        }
+        eff += it.value().effort();
+    }
+    return eff;
+}
+
+double EffortCostMap::hoursTo(QDate date) const {
+    double eff = 0.0;
+    EffortCostDayMap::const_iterator it;
+    for(it = m_days.constBegin(); it != m_days.constEnd(); ++it) {
+        if (it.key() > date) {
+            break;
+        }
+        eff += it.value().hours();
+    }
+    return eff;
+}
+
 double EffortCostMap::bcwpCost(const QDate &date) const
 {
     double v = 0.0;
@@ -130,10 +153,10 @@ QDebug EffortCostMap::debug(QDebug dbg) const
     if (! m_days.isEmpty()) {
         QMap<QDate, KPlato::EffortCost>::ConstIterator it = days().constBegin();
         for (; it != days().constEnd(); ++it) {
-            dbg<<endl;
+            dbg<<'\n';
             dbg<<"     "<<it.key().toString(Qt::ISODate)<<" "<<it.value();
         }
-        dbg<<endl;
+        dbg<<'\n';
     }
     return dbg;
 }
