@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
-  Copyright (C) 2006, 2007 Dag Andersen <danders@get2net.dk>
+  SPDX-FileCopyrightText: 2006, 2007 Dag Andersen <dag.andersen@kdemail.net>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version..
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-* Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KPTGLOBAL_H
@@ -23,12 +10,9 @@
 #include "plankernel_export.h"
 
 #include <Qt> // for things in Qt namespace
+#include <QLatin1String>
 
-// The Plan file syntax is used in parts of the KPlatoWork file, so:
-// * If you change PLAN_FILE_SYNTAX_VERSION, change PLANWORK_FILE_SYNTAX_VERSION too!
-// * You don't need to change PLAN_FILE_SYNTAX_VERSION when you change KPLATOWORK_FILE_SYNTAX_VERSION
-#define PLAN_FILE_SYNTAX_VERSION "0.6.7"
-#define PLANWORK_FILE_SYNTAX_VERSION "0.6.7"
+static const QLatin1String PLAN_FILE_SYNTAX_VERSION("0.7.0");
 
 #define CURRENTSCHEDULE     -1
 #define NOTSCHEDULED        -2
@@ -98,6 +82,7 @@ struct PLANKERNEL_EXPORT SchedulingState
     static QString constraintsNotMet(bool trans = true);
     static QString effortNotMet(bool trans = true);
     static QString schedulingError(bool trans = true);
+    static QString schedulingCanceled(bool trans = true);
 
 }; //namespace WhatsThis
 
