@@ -1,21 +1,8 @@
 /* This file is part of the KDE project
-   Copyright (C) 2001 Thomas Zander zander@kde.org
-   Copyright (C) 2004 - 2011 Dag Andersen <danders@get2net.dk>
+   SPDX-FileCopyrightText: 2001 Thomas Zander zander @kde.org
+   SPDX-FileCopyrightText: 2004-2011 Dag Andersen <dag.andersen@kdemail.net>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KPTNODE_H
@@ -70,19 +57,22 @@ public:
 
     enum State { 
         State_None = 0,
-        State_Started = 1,
-        State_StartedLate = 2,
-        State_StartedEarly = 4,
-        State_Finished = 8,
-        State_FinishedLate = 16,
-        State_FinishedEarly = 32,
-        State_Running = 64,
-        State_RunningLate = 128,
-        State_RunningEarly = 256,
-        State_ReadyToStart = 512, // all preceding tasks finished (if any)
-        State_NotReadyToStart = 1024, // all preceding tasks not finished (must be one or more)
-        State_NotScheduled = 2048,
-        State_Late = 4096
+        State_Started           = 1 << 0,
+        State_StartedLate       = 1 << 1,
+        State_StartedEarly      = 1 << 2,
+        State_Finished          = 1 << 3,
+        State_FinishedLate      = 1 << 4,
+        State_FinishedEarly     = 1 << 5,
+        State_Running           = 1 << 6,
+        State_RunningLate       = 1 << 7,
+        State_RunningEarly      = 1 << 8,
+        State_ReadyToStart      = 1 << 9,  // all preceding tasks finished (if any)
+        State_NotReadyToStart   = 1 << 10, // all preceding tasks not finished (must be one or more)
+        State_NotScheduled      = 1 << 11,
+        State_Late              = 1 << 12,
+        State_Baselined         = 1 << 13,
+        State_Scheduling        = 1 << 14,
+        State_Error             = 1 << 15
     };
     Q_ENUM(State);
 
@@ -118,8 +108,8 @@ public:
     };
     Q_ENUM(Properties);
 
-    explicit Node(Node *parent = 0);
-    Node(const Node &node, Node *parent = 0);
+    explicit Node(Node *parent = nullptr);
+    Node(const Node &node, Node *parent = nullptr);
 
 
     // Declare the class abstract
@@ -153,9 +143,8 @@ public:
      * Returns 0 if no project exists.
      */
     virtual const Node *projectNode() const;
-    
-    // The load and save methods
-    virtual bool load(KoXmlElement &, XMLLoaderObject &) { return true; }
+
+    // NOTE: Saving is done here, loading is done using the XmlLoaderObject
     virtual void save(QDomElement &element, const XmlSaveContext &context) const  = 0;
     /// Save me and my childrens relations.
     virtual void saveRelations(QDomElement &element, const XmlSaveContext &context) const;
@@ -171,7 +160,7 @@ public:
     void setParentNode(Node* newParent) { m_parent = newParent;}
     const QList<Node*> &childNodeIterator() const { return m_nodes; }
     int numChildren() const { return m_nodes.count(); }
-    virtual void addChildNode(Node *node, Node *after=0);
+    virtual void addChildNode(Node *node, Node *after=nullptr);
     virtual void insertChildNode(int index, Node *node);
     void takeChildNode(Node *node);
     void takeChildNode(int number);
@@ -224,7 +213,17 @@ public:
     QList<Relation*> dependParentNodes() const { return m_dependParentNodes; }
     QList<Node*> getParentNodes();
     bool isParentOf(const Node *node) const;
+    /// Checks if @p node is our predecessor.
+    /// Same as isSuccessorof(node, false, true).
     bool isDependChildOf(const Node *node) const;
+    /// Checks if @p node is our predecessor.
+    /// If @p checkProxis is true, proxy relations are also checked.
+    /// If @ checkSummarytasks is true, relations to summarytasks are included.
+    bool isSuccessorof(const Node *node, bool checkProxies = true, bool checkSummarytasks = false) const;
+    /// If @p checkProxis is true, proxy relations are also checked.
+    /// If @ checkSummarytasks is true, relations to summarytasks are included.
+    /// Checks if @p node is our successor
+    bool isPredecessorof(const Node *node, bool checkProxies = false, bool checkSummarytasks = false) const;
     virtual bool canMoveTo(const Node *newParent) const;
     
     Relation *findParentRelation(const Node *node) const;
@@ -289,10 +288,10 @@ public:
     virtual DateTime mustStartOn() const { return m_constraintStartTime; }
     virtual DateTime mustFinishOn() const { return m_constraintEndTime; }
 
-    virtual ResourceGroupRequest *resourceGroupRequest(const ResourceGroup * /*group*/) const { return 0; }
+    virtual ResourceGroupRequest *resourceGroupRequest(const ResourceGroup * /*group*/) const { return nullptr; }
     virtual QStringList requestNameList() const { return QStringList(); }
     virtual bool containsRequest(const QString &/*identity*/) const { return false; }
-    virtual ResourceRequest *resourceRequest(const QString &/*name*/) const { return 0; }
+    virtual ResourceRequest *resourceRequest(const QString &/*name*/) const { return nullptr; }
     
     /// Return the list of resources assigned to this task
     virtual QStringList assignedNameList(long /*id*/ = CURRENTSCHEDULE) const { return QStringList(); }
@@ -447,7 +446,7 @@ public:
     virtual Node *findNode() const { return findNode(m_id); }
     /// Find the node with identity id
     virtual Node *findNode(const QString &id) const
-        { return (m_parent ? m_parent->findNode(id) : 0); }
+        { return (m_parent ? m_parent->findNode(id) : nullptr); }
     /// Remove myself from the id register
     virtual bool removeId()  { return removeId(m_id); }
     /// Remove the registered identity @p id
@@ -512,6 +511,7 @@ public:
     bool isScheduled(long id = CURRENTSCHEDULE) const;
     /// Return the list of schedules for this node
     QHash<long, Schedule*> &schedules() { return m_schedules; }
+    QHash<long, Schedule*> schedules() const { return m_schedules; }
     /// Find schedule matching name and type. Does not return deleted schedule.
     Schedule *findSchedule(const QString &name, const Schedule::Type type);
     /// Find schedule matching name. Does not return deleted schedule.
@@ -538,7 +538,7 @@ public:
     const ResourceRequestCollection &requests() const { return m_requests; }
     ResourceRequestCollection &requests() { return m_requests; }
     
-    virtual uint state(long) const { return State_None; }
+    virtual uint state(long id = ANYSCHEDULED) const { Q_UNUSED(id) return State_None; }
     
     const Documents &documents() const { return m_documents; }
     Documents &documents() { return m_documents; }
@@ -552,6 +552,9 @@ public:
     /// @return priority
     int priority() const;
 
+    /// @return scheduling granularity
+    virtual ulong granularity() const;
+
 public:
     // These shouldn't be available to other than those who inherits
     /// Calculate the critical path
@@ -627,7 +630,9 @@ public:
     virtual void addChildProxyRelations(const QList<Relation*> &) {}
     virtual void addParentProxyRelation(Node *, const Relation *) {}
     virtual void addChildProxyRelation(Node *, const Relation *) {}
-    
+    const QList<Relation*> &parentProxyRelations() const { return m_parentProxyRelations; }
+    const QList<Relation*> &childProxyRelations() const { return m_childProxyRelations; }
+
     virtual void changed(int property = -1) { changed(this, property); }
     Duration getmDurationForward(){ return this->m_durationForward;}
 
@@ -637,6 +642,7 @@ public Q_SLOTS:
 
 protected:
     friend class KPlatoXmlLoaderBase;
+    friend class ProjectLoaderBase;
     /**
      * Calculates and returns the duration of the node.
      * Reimplement.
@@ -699,6 +705,9 @@ protected:
 
     int m_priority;
 
+    QList<Relation*> m_parentProxyRelations;
+    QList<Relation*> m_childProxyRelations;
+
 private:
     void init();
     bool m_blockChanged;
@@ -715,9 +724,9 @@ private:
 class PLANKERNEL_EXPORT Estimate {
 public:
     /// Constructor
-    explicit Estimate(Node *parent = 0);
+    explicit Estimate(Node *parent = nullptr);
     /// Copy constructor.
-    Estimate (const Estimate &estimate, Node *parent = 0);
+    Estimate (const Estimate &estimate, Node *parent = nullptr);
     /// Destructor
     ~Estimate();
 
