@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
-   Copyright (C) 2017 Dag Andersen <danders@get2net.dk>
+   SPDX-FileCopyrightText: 2017 Dag Andersen <dag.andersen@kdemail.net>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 // clazy:excludeall=qstring-arg
 #include "AccountsCommandTester.h"
@@ -54,14 +41,18 @@ void AccountsCommandTester::printDebug(long id) const {
     qDebug()<<"Resource start:"<<r->startTime(id).toString();
     qDebug()<<"Resource end  :"<<r->endTime(id).toString();
     qDebug()<<"Appointments:"<<r->numAppointments(id)<<"(internal)";
-    foreach (Appointment *a, r->appointments(id)) {
-        foreach (const AppointmentInterval &i, a->intervals().map()) {
+    const auto appointments = r->appointments(id);
+    for (Appointment *a : appointments) {
+        const auto intervals = a->intervals().map().values();
+        for (const AppointmentInterval &i : intervals) {
             qDebug()<<"  "<<i.startTime().toString()<<"-"<<i.endTime().toString()<<";"<<i.load();
         }
     }
     qDebug()<<"Appointments:"<<r->numExternalAppointments()<<"(external)";
-    foreach (Appointment *a, r->externalAppointmentList()) {
-        foreach (const AppointmentInterval &i, a->intervals().map()) {
+    const auto appointments2 = r->externalAppointmentList();
+    for (Appointment *a : appointments2) {
+        const auto intervals = a->intervals().map().values();
+        for (const AppointmentInterval &i : intervals) {
             qDebug()<<"  "<<i.startTime().toString()<<"-"<<i.endTime().toString()<<";"<<i.load();
         }
     }
@@ -70,7 +61,8 @@ void AccountsCommandTester::printDebug(long id) const {
 void AccountsCommandTester::printSchedulingLog(const ScheduleManager &sm) const
 {
     qDebug()<<"Scheduling log ---------------------------------";
-    foreach (const QString &s, sm.expected()->logMessages()) {
+    const auto logs = sm.expected()->logMessages();
+    for (const QString &s : logs) {
         qDebug()<<s;
     }
 }
@@ -78,7 +70,7 @@ void AccountsCommandTester::printSchedulingLog(const ScheduleManager &sm) const
 void AccountsCommandTester::init()
 {
     m_project = new Project();
-    m_project->setName("P1");
+    m_project->setName(QStringLiteral("P1"));
     m_project->setId(m_project->uniqueNodeId());
     m_project->registerNodeId(m_project);
     DateTime targetstart = DateTime(QDate::currentDate(), QTime(0,0,0));
@@ -89,7 +81,7 @@ void AccountsCommandTester::init()
     // standard worktime defines 8 hour day as default
     QVERIFY(m_project->standardWorktime());
     QCOMPARE(m_project->standardWorktime()->day(), 8.0);
-    m_calendar = new Calendar("Test");
+    m_calendar = new Calendar(QStringLiteral("Test"));
     m_calendar->setDefault(true);
     QTime t1(9, 0, 0);
     QTime t2 (17, 0, 0);
@@ -103,15 +95,16 @@ void AccountsCommandTester::init()
 
 
     ResourceGroup *g = new ResourceGroup();
-    g->setName("G1");
+    g->setName(QStringLiteral("G1"));
     m_project->addResourceGroup(g);
     m_resource = new Resource();
-    m_resource->setName("R1");
+    m_resource->setName(QStringLiteral("R1"));
     m_resource->setCalendar(m_calendar);
-    m_project->addResource(g, m_resource);
+    m_project->addResource(m_resource);
+    m_resource->addParentGroup(g);
 
     m_task = m_project->createTask();
-    m_task->setName("T1");
+    m_task->setName(QStringLiteral("T1"));
     m_project->addTask(m_task, m_project);
     m_task->estimate()->setUnit(Duration::Unit_h);
     m_task->estimate()->setExpectedEstimate(8.0);
@@ -126,7 +119,7 @@ void AccountsCommandTester::cleanup()
 void AccountsCommandTester::addAccount()
 {
     Account *a1 = new Account();
-    a1->setName("a1");
+    a1->setName(QStringLiteral("a1"));
     AddAccountCmd *cmd1 = new AddAccountCmd(*m_project, a1);
     cmd1->redo();
 
@@ -138,14 +131,14 @@ void AccountsCommandTester::addAccount()
     delete cmd1;
 
     a1 = new Account();
-    a1->setName("a1");
+    a1->setName(QStringLiteral("a1"));
     cmd1 = new AddAccountCmd(*m_project, a1);
     cmd1->redo();
 
     QCOMPARE(m_project->accounts().allAccounts().count(), 1);
 
     Account *a2 = new Account();
-    a2->setName("a2");
+    a2->setName(QStringLiteral("a2"));
     AddAccountCmd *cmd2 = new AddAccountCmd(*m_project, a2, a1);
     cmd2->redo();
 
@@ -163,7 +156,7 @@ void AccountsCommandTester::addAccount()
 void AccountsCommandTester::removeAccount()
 {
     Account *a1 = new Account();
-    a1->setName("a1");
+    a1->setName(QStringLiteral("a1"));
     m_project->accounts().insert(a1);
     QCOMPARE(m_project->accounts().allAccounts().count(), 1);
 
@@ -181,10 +174,10 @@ void AccountsCommandTester::removeAccount()
     QCOMPARE(m_project->accounts().allAccounts().count(), 0);
 
     a1 = new Account();
-    a1->setName("a1");
+    a1->setName(QStringLiteral("a1"));
     m_project->accounts().insert(a1);
     Account *a2 = new Account();
-    a2->setName("a2");
+    a2->setName(QStringLiteral("a2"));
     m_project->accounts().insert(a2, a1);
     QCOMPARE(m_project->accounts().allAccounts().count(), 2);
 
@@ -213,29 +206,29 @@ void AccountsCommandTester::costPlace()
 {
     KUndo2QStack cmds;
     Account *a1 = new Account();
-    a1->setName("a1");
+    a1->setName(QStringLiteral("a1"));
     cmds.push(new AddAccountCmd(*m_project, a1));
     QCOMPARE(m_project->accounts().allAccounts().count(), 1);
 
     Account *a2 = new Account();
-    a2->setName("a2");
+    a2->setName(QStringLiteral("a2"));
     cmds.push(new AddAccountCmd(*m_project, a2));
     QCOMPARE(m_project->accounts().allAccounts().count(), 2);
 
     Account *a3 = new Account();
-    a3->setName("a3");
+    a3->setName(QStringLiteral("a3"));
     cmds.push(new AddAccountCmd(*m_project, a3));
     QCOMPARE(m_project->accounts().allAccounts().count(), 3);
 
-    cmds.push(new NodeModifyRunningAccountCmd(*m_task, 0, a1));
+    cmds.push(new NodeModifyRunningAccountCmd(*m_task, nullptr, a1));
     QCOMPARE(m_task->runningAccount(), a1);
-    cmds.push(new NodeModifyStartupAccountCmd(*m_task, 0, a2));
+    cmds.push(new NodeModifyStartupAccountCmd(*m_task, nullptr, a2));
     QCOMPARE(m_task->startupAccount(), a2);
-    cmds.push(new NodeModifyShutdownAccountCmd(*m_task, 0, a3));
+    cmds.push(new NodeModifyShutdownAccountCmd(*m_task, nullptr, a3));
     QCOMPARE(m_task->shutdownAccount(), a3);
 
     cmds.push(new RemoveAccountCmd(*m_project, a1));
-    QVERIFY(m_task->runningAccount() == 0);
+    QVERIFY(m_task->runningAccount() == nullptr);
     QCOMPARE(m_task->startupAccount(), a2);
     QCOMPARE(m_task->shutdownAccount(), a3);
     cmds.undo();
@@ -244,7 +237,7 @@ void AccountsCommandTester::costPlace()
     QCOMPARE(m_task->shutdownAccount(), a3);
 
     cmds.push(new RemoveAccountCmd(*m_project, a2));
-    QVERIFY(m_task->startupAccount() == 0);
+    QVERIFY(m_task->startupAccount() == nullptr);
     QCOMPARE(m_task->runningAccount(), a1);
     QCOMPARE(m_task->shutdownAccount(), a3);
     cmds.undo();
@@ -253,7 +246,7 @@ void AccountsCommandTester::costPlace()
     QCOMPARE(m_task->shutdownAccount(), a3);
 
     cmds.push(new RemoveAccountCmd(*m_project, a3));
-    QVERIFY(m_task->shutdownAccount() == 0);
+    QVERIFY(m_task->shutdownAccount() == nullptr);
     QCOMPARE(m_task->runningAccount(), a1);
     QCOMPARE(m_task->startupAccount(), a2);
     cmds.undo();
@@ -261,12 +254,12 @@ void AccountsCommandTester::costPlace()
     QCOMPARE(m_task->startupAccount(), a2);
     QCOMPARE(m_task->shutdownAccount(), a3);
 
-    cmds.push(new ResourceModifyAccountCmd(*m_resource, 0, a1));
+    cmds.push(new ResourceModifyAccountCmd(*m_resource, nullptr, a1));
     QCOMPARE(m_resource->account(), a1);
 
     cmds.push(new RemoveAccountCmd(*m_project, a1));
-    QVERIFY(m_task->runningAccount() == 0);
-    QVERIFY(m_resource->account() == 0);
+    QVERIFY(m_task->runningAccount() == nullptr);
+    QVERIFY(m_resource->account() == nullptr);
     cmds.undo();
     QCOMPARE(m_task->runningAccount(), a1);
     QCOMPARE(m_resource->account(), a1);
@@ -276,41 +269,41 @@ void AccountsCommandTester::costPlace()
         cmds.undo();
     }
     a1 = new Account();
-    a1->setName("a1");
+    a1->setName(QStringLiteral("a1"));
     cmds.push(new AddAccountCmd(*m_project, a1));
     QCOMPARE(m_project->accounts().allAccounts().count(), 1);
 
-    cmds.push(new NodeModifyRunningAccountCmd(*m_task, 0, a1));
+    cmds.push(new NodeModifyRunningAccountCmd(*m_task, nullptr, a1));
     QCOMPARE(m_task->runningAccount(), a1);
-    cmds.push(new NodeModifyStartupAccountCmd(*m_task, 0, a1));
+    cmds.push(new NodeModifyStartupAccountCmd(*m_task, nullptr, a1));
     QCOMPARE(m_task->startupAccount(), a1);
-    cmds.push(new NodeModifyShutdownAccountCmd(*m_task, 0, a1));
+    cmds.push(new NodeModifyShutdownAccountCmd(*m_task, nullptr, a1));
     QCOMPARE(m_task->shutdownAccount(), a1);
 
     cmds.undo();
     QCOMPARE(m_task->runningAccount(), a1);
     QCOMPARE(m_task->startupAccount(), a1);
-    QVERIFY(m_task->shutdownAccount() == 0);
+    QVERIFY(m_task->shutdownAccount() == nullptr);
 
     cmds.undo();
     QCOMPARE(m_task->runningAccount(), a1);
-    QVERIFY(m_task->startupAccount() == 0);
-    QVERIFY(m_task->shutdownAccount() == 0);
+    QVERIFY(m_task->startupAccount() == nullptr);
+    QVERIFY(m_task->shutdownAccount() == nullptr);
 
     cmds.undo();
-    QVERIFY(m_task->runningAccount() == 0);
-    QVERIFY(m_task->startupAccount() == 0);
-    QVERIFY(m_task->shutdownAccount() == 0);
+    QVERIFY(m_task->runningAccount() == nullptr);
+    QVERIFY(m_task->startupAccount() == nullptr);
+    QVERIFY(m_task->shutdownAccount() == nullptr);
 
     cmds.redo();
     QCOMPARE(m_task->runningAccount(), a1);
-    QVERIFY(m_task->startupAccount() == 0);
-    QVERIFY(m_task->shutdownAccount() == 0);
+    QVERIFY(m_task->startupAccount() == nullptr);
+    QVERIFY(m_task->shutdownAccount() == nullptr);
 
     cmds.redo();
     QCOMPARE(m_task->runningAccount(), a1);
     QCOMPARE(m_task->startupAccount(), a1);
-    QVERIFY(m_task->shutdownAccount() == 0);
+    QVERIFY(m_task->shutdownAccount() == nullptr);
 
     cmds.redo();
     QCOMPARE(m_task->runningAccount(), a1);
