@@ -1,21 +1,8 @@
 /* This file is part of the KDE project
-   Copyright (C) 2008 Dag Andersen <danders@get2net.dk>
-   Copyright (C) 2016 Dag Andersen <danders@get2net.dk>
+   SPDX-FileCopyrightText: 2008 Dag Andersen <dag.andersen@kdemail.net>
+   SPDX-FileCopyrightText: 2016 Dag Andersen <dag.andersen@kdemail.net>
    
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 // clazy:excludeall=qstring-arg
 #include "AppointmentIntervalTester.h"
@@ -82,18 +69,18 @@ void AppointmentIntervalTester::addInterval()
     double load = 1;
     
     qDebug()<<"Add an interval"<<dt1<<dt2;
-    qDebug()<<endl<<lst;
+    qDebug()<<'\n'<<lst;
     lst.add(dt1, dt2, load);
-    qDebug()<<endl<<lst;
+    qDebug()<<'\n'<<lst;
 
     QCOMPARE(dt1, lst.map().values().first().startTime());
     QCOMPARE(dt2, lst.map().values().first().endTime());
     QCOMPARE(load, lst.map().values().first().load());
     
     qDebug()<<"add load";
-    qDebug()<<endl<<lst;
+    qDebug()<<'\n'<<lst;
     lst.add(dt1, dt2, load);
-    qDebug()<<endl<<lst;
+    qDebug()<<'\n'<<lst;
 
     QCOMPARE(dt1, lst.map().values().first().startTime());
     QCOMPARE(dt2, lst.map().values().first().endTime());
@@ -103,9 +90,9 @@ void AppointmentIntervalTester::addInterval()
     DateTime dt4 = dt3 + Duration(0, 1, 0);
     qDebug()<<"Add an interval after:"<<dt3<<dt4;
     
-    qDebug()<<endl<<lst;
+    qDebug()<<'\n'<<lst;
     lst.add(dt3, dt4, load);
-    qDebug()<<endl<<lst;
+    qDebug()<<'\n'<<lst;
 
     QCOMPARE(dt1, lst.map().values().first().startTime());
     QCOMPARE(dt2, lst.map().values().first().endTime());
@@ -119,11 +106,12 @@ void AppointmentIntervalTester::addInterval()
     DateTime dt6 = dt5 + Duration(0, 1, 0);
     qDebug()<<"Add an interval in between:"<<dt5<<dt6;
 
-    qDebug()<<endl<<lst;
+    qDebug()<<'\n'<<lst;
     lst.add(dt5, dt6, load);
-    qDebug()<<endl<<lst;
+    qDebug()<<'\n'<<lst;
 {
-    QMap<QDate, AppointmentInterval>::const_iterator i(lst.map().constBegin());
+    const auto map = lst.map();
+    QMultiMap<QDate, AppointmentInterval>::const_iterator i(map.constBegin());
 
     QCOMPARE(dt1, i.value().startTime());
     QCOMPARE(dt2, i.value().endTime());
@@ -141,11 +129,12 @@ void AppointmentIntervalTester::addInterval()
     DateTime dt8 = dt7 + Duration(0, 2, 0);
     qDebug()<<"Add an overlapping interval at start:"<<dt7<<dt8;
     
-    qDebug()<<endl<<lst;
+    qDebug()<<'\n'<<lst;
     lst.add(dt7, dt8, load);
-    qDebug()<<endl<<lst;
+    qDebug()<<'\n'<<lst;
 {
-    QMap<QDate, AppointmentInterval>::const_iterator i(lst.map().constBegin());
+    const auto map = lst.map();
+    QMultiMap<QDate, AppointmentInterval>::const_iterator i(map.constBegin());
 
     QCOMPARE(dt7, i.value().startTime());
     QCOMPARE(dt1, i.value().endTime());
@@ -167,11 +156,12 @@ void AppointmentIntervalTester::addInterval()
     DateTime dt10 = dt9 + Duration(0, 0, 30);
     qDebug()<<"Add an overlapping interval at start > start, end == end"<<dt9<<dt10;
     
-    qDebug()<<endl<<lst;
+    qDebug()<<'\n'<<lst;
     lst.add(dt9, dt10, load);
-    qDebug()<<endl<<lst;
+    qDebug()<<'\n'<<lst;
 {
-    QMap<QDate, AppointmentInterval>::const_iterator i(lst.map().constBegin());
+    const auto map = lst.map();
+    QMultiMap<QDate, AppointmentInterval>::const_iterator i(map.constBegin());
 
     QCOMPARE(dt7, i.value().startTime());
     QCOMPARE(dt9, i.value().endTime());
@@ -197,12 +187,13 @@ void AppointmentIntervalTester::addInterval()
     DateTime dt12 = dt11 + Duration(0, 0, 30);
     qDebug()<<"Add an overlapping interval at start > start, end < end:"<<dt11<<dt12;
     
-    qDebug()<<endl<<lst;
+    qDebug()<<'\n'<<lst;
     lst.add(dt11, dt12, load);
-    qDebug()<<endl<<lst;
+    qDebug()<<'\n'<<lst;
 {
     QCOMPARE(lst.map().count(), 7);
-    QMap<QDate, AppointmentInterval>::const_iterator i(lst.map().constBegin());
+    const auto map = lst.map();
+    QMultiMap<QDate, AppointmentInterval>::const_iterator i(map.constBegin());
 
     QCOMPARE(dt7, i.value().startTime());
     QCOMPARE(dt9, i.value().endTime());
@@ -235,16 +226,17 @@ void AppointmentIntervalTester::addInterval()
     qDebug()<<"Add an interval overlapping 2 intervals at start == start.1, end == end.2"<<dt1<<dt4;
     lst.clear();
     
-    qDebug()<<endl<<lst;
+    qDebug()<<'\n'<<lst;
     lst.add(dt1, dt2, load);
-    qDebug()<<endl<<lst;
+    qDebug()<<'\n'<<lst;
     lst.add(dt3, dt4, load);
-    qDebug()<<endl<<lst;
+    qDebug()<<'\n'<<lst;
     lst.add(dt1, dt4, load);
-    qDebug()<<endl<<lst;
+    qDebug()<<'\n'<<lst;
 {
     QCOMPARE(lst.map().count(), 3);
-    QMap<QDate, AppointmentInterval>::const_iterator i(lst.map().constBegin());
+    const auto map = lst.map();
+    QMultiMap<QDate, AppointmentInterval>::const_iterator i(map.constBegin());
 
     QCOMPARE(dt1, i.value().startTime());
     QCOMPARE(dt2, i.value().endTime());
@@ -262,16 +254,17 @@ void AppointmentIntervalTester::addInterval()
     dt5 = dt1 - Duration(0, 1, 0);
     qDebug()<<"Add an interval overlapping 2 intervals at start < start.1, end == end.2"<<dt5<<dt4;
 
-    qDebug()<<endl<<lst;
+    qDebug()<<'\n'<<lst;
     lst.add(dt1, dt2, load);
-    qDebug()<<endl<<lst;
+    qDebug()<<'\n'<<lst;
     lst.add(dt3, dt4, load);
-    qDebug()<<endl<<lst;
+    qDebug()<<'\n'<<lst;
     lst.add(dt5, dt4, load);
-    qDebug()<<endl<<lst;
+    qDebug()<<'\n'<<lst;
 {
     QCOMPARE(lst.map().count(), 4);
-    QMap<QDate, AppointmentInterval>::const_iterator i(lst.map().constBegin());
+    const auto map = lst.map();
+    QMultiMap<QDate, AppointmentInterval>::const_iterator i(map.constBegin());
 
     QCOMPARE(dt5, i.value().startTime());
     QCOMPARE(dt1, i.value().endTime());
@@ -297,7 +290,8 @@ void AppointmentIntervalTester::addInterval()
     lst.add(dt3, dt4, load);
     lst.add(dt5, dt6, load);
 {
-    QMap<QDate, AppointmentInterval>::const_iterator i(lst.map().constBegin());
+    const auto map = lst.map();
+    QMultiMap<QDate, AppointmentInterval>::const_iterator i(map.constBegin());
 
     QCOMPARE(dt5, i.value().startTime());
     QCOMPARE(dt1, i.value().endTime());
@@ -327,7 +321,8 @@ void AppointmentIntervalTester::addInterval()
     lst.add(dt3, dt4, load);
     lst.add(dt5, dt6, load);
 {
-    QMap<QDate, AppointmentInterval>::const_iterator i(lst.map().constBegin());
+    const auto map = lst.map();
+    QMultiMap<QDate, AppointmentInterval>::const_iterator i(map.constBegin());
 
     QCOMPARE(dt5, i.value().startTime());
     QCOMPARE(dt1, i.value().endTime());
@@ -357,7 +352,8 @@ void AppointmentIntervalTester::addInterval()
     lst.add(dt3, dt4, load);
     lst.add(dt5, dt6, load);
 {
-    QMap<QDate, AppointmentInterval>::const_iterator i(lst.map().constBegin());
+    const auto map = lst.map();
+    QMultiMap<QDate, AppointmentInterval>::const_iterator i(map.constBegin());
 
     QCOMPARE(dt1, i.value().startTime());
     QCOMPARE(dt5, i.value().endTime());
@@ -387,7 +383,8 @@ void AppointmentIntervalTester::addInterval()
     lst.add(dt3, dt4, load);
     lst.add(dt5, dt6, load);
 {
-    QMap<QDate, AppointmentInterval>::const_iterator i(lst.map().constBegin());
+    const auto map = lst.map();
+    QMultiMap<QDate, AppointmentInterval>::const_iterator i(map.constBegin());
 
     QCOMPARE(dt1, i.value().startTime());
     QCOMPARE(dt5, i.value().endTime());
@@ -413,7 +410,8 @@ void AppointmentIntervalTester::addInterval()
     lst.add(dt3, dt4, load);
     lst.add(dt5, dt6, load);
 {
-    QMap<QDate, AppointmentInterval>::const_iterator i(lst.map().constBegin());
+    const auto map = lst.map();
+    QMultiMap<QDate, AppointmentInterval>::const_iterator i(map.constBegin());
 
     QCOMPARE(dt1, i.value().startTime());
     QCOMPARE(dt5, i.value().endTime());
@@ -443,27 +441,45 @@ void AppointmentIntervalTester::addTangentIntervals()
     // Add an interval overlapping 2 intervals at start > start.1, end > end.2
     AppointmentIntervalList lst;
 
-    DateTime dt1(QDate(2010, 1, 1), QTime(0, 0, 0));
-    DateTime dt2(QDate(2010, 1, 1), QTime(12, 0, 0));
+    DateTime dt1(QDate(2010, 1, 1), QTime(4, 0, 0));
+    DateTime dt2(QDate(2010, 1, 1), QTime(8, 0, 0));
+    DateTime dt3(QDate(2010, 1, 1), QTime(8, 0, 0));
+    DateTime dt4(QDate(2010, 1, 1), QTime(12, 0, 0));
+    DateTime dt5(QDate(2010, 1, 1), QTime(12, 0, 0));
+    DateTime dt6(QDate(2010, 1, 1), QTime(16, 0, 0));
     double load = 1.;
 
-    qDebug()<<endl<<lst;
-    lst.add(dt2, dt1.addDays(1), load);
-    qDebug()<<endl<<lst;
-    QCOMPARE(lst.map().count(), 1);
-
+    qDebug()<<'\n'<<lst;
     lst.add(dt1, dt2, load);
+    qDebug()<<'\n'<<lst;
+    QCOMPARE(lst.map().count(), 1);
+    QCOMPARE(lst.map().values().at(0).startTime(), dt1);
+    QCOMPARE(lst.map().values().at(0).endTime(), dt2);
+
+    lst.add(dt5, dt6, load);
+    qDebug()<<lst;
     QCOMPARE(lst.map().count(), 2);
     QCOMPARE(lst.map().values().at(0).startTime(), dt1);
-    QCOMPARE(lst.map().values().at(1).endTime(), DateTime(dt1.addDays(1)));
-    
-    // add with a 12 hours hole
-    lst.add(dt2.addDays(1), dt1.addDays(2), load);
+    QCOMPARE(lst.map().values().at(0).endTime(), dt2);
+    QCOMPARE(lst.map().values().at(1).startTime(), dt5);
+    QCOMPARE(lst.map().values().at(1).endTime(), dt6);
+
+    lst.add(dt3, dt4, load);
+    qDebug()<<lst;
+    QCOMPARE(lst.map().count(), 1);
+    QCOMPARE(lst.map().values().at(0).startTime(), dt1);
+    QCOMPARE(lst.map().values().at(0).endTime(), dt6);
+
+    lst.add(dt3, dt4, load*2);
     QCOMPARE(lst.map().count(), 3);
-    
-    // fill the hole
-    lst.add(dt1.addDays(1), dt2.addDays(1), load);
-    QCOMPARE(lst.map().count(), 4);
+    QCOMPARE(lst.map().values().at(0).startTime(), dt1);
+    QCOMPARE(lst.map().values().at(0).endTime(), dt2);
+    QCOMPARE(lst.map().values().at(1).startTime(), dt3);
+    QCOMPARE(lst.map().values().at(1).endTime(), dt4);
+    QCOMPARE(lst.map().values().at(2).startTime(), dt5);
+    QCOMPARE(lst.map().values().at(2).endTime(), dt6);
+
+
 }
 
 void AppointmentIntervalTester::addAppointment()
@@ -524,9 +540,9 @@ void AppointmentIntervalTester::subtractList()
     lst1.add(dt3, dt4, load);
     qDebug()<<"Subtract non-overlapping intervals:";
 
-    qDebug()<<endl<<lst2<<endl<<"minus"<<endl<<lst1;
+    qDebug()<<'\n'<<lst2<<'\n'<<"minus"<<'\n'<<lst1;
     lst2 -= lst1;
-    qDebug()<<endl<<"result:"<<endl<<lst2;
+    qDebug()<<'\n'<<"result:"<<'\n'<<lst2;
     QCOMPARE(dt1, lst2.map().values().first().startTime());
     QCOMPARE(dt2, lst2.map().values().first().endTime());
     QCOMPARE(load, lst2.map().values().first().load());
@@ -537,23 +553,23 @@ void AppointmentIntervalTester::subtractList()
     lst1.add(dt5, dt6, load);
 
     qDebug()<<"-------- lst2 -= lst1";
-    qDebug()<<endl<<lst2<<endl<<lst1;
+    qDebug()<<'\n'<<lst2<<'\n'<<lst1;
     lst2 -= lst1;
-    qDebug()<<endl<<lst2;
+    qDebug()<<'\n'<<lst2;
     QCOMPARE(dt1, lst2.map().values().first().startTime());
     QCOMPARE(dt2, lst2.map().values().first().endTime());
     QCOMPARE(load, lst2.map().values().first().load());
     QCOMPARE(lst2.map().count(), 1);
 
-    s = "Subtract tangent intervals";
+    s = QStringLiteral("Subtract tangent intervals");
     qDebug()<<s;
     lst1.clear();
     lst1.add(dt1.addDays(-1), dt1, load); // before
-    Debug::print(lst2, "List2: " + s);
-    Debug::print(lst1, "List1: " + s);
+    Debug::print(lst2, QStringLiteral("List2: ") + s);
+    Debug::print(lst1, QStringLiteral("List1: ") + s);
 
     lst2 -= lst1;
-    Debug::print(lst2, "Result: " + s);
+    Debug::print(lst2, QStringLiteral("Result: ") + s);
     
     QCOMPARE(dt1, lst2.map().values().first().startTime());
     QCOMPARE(dt2, lst2.map().values().first().endTime());
@@ -575,10 +591,10 @@ void AppointmentIntervalTester::subtractList()
     // starts at start, end in the middle
     lst1.add(dt1, dt3, load / 2.);
 
-    s = "Subtract half the load of the first hour of the interval";
+    s = QStringLiteral("Subtract half the load of the first hour of the interval");
     qDebug()<<s;
-    Debug::print(lst2, "List2: " + s);
-    Debug::print(lst1, "List1: " + s);
+    Debug::print(lst2, QStringLiteral("List2: ") + s);
+    Debug::print(lst1, QStringLiteral("List1: ") + s);
 
     lst2 -= lst1;
     Debug::print(lst2, s);
@@ -592,7 +608,7 @@ void AppointmentIntervalTester::subtractList()
     QCOMPARE(dt2, lst2.map().values().at(1).endTime());
     QCOMPARE(load, lst2.map().values().at(1).load());
 
-    s = "Subtract all load from first interval";
+    s = QStringLiteral("Subtract all load from first interval");
     qDebug()<<s;
     lst2 -= lst1; // remove first interval
     QCOMPARE(lst2.map().count(), 1);
@@ -600,14 +616,14 @@ void AppointmentIntervalTester::subtractList()
     QCOMPARE(dt2, lst2.map().values().at(0).endTime());
     QCOMPARE(load, lst2.map().values().at(0).load());
 
-    s = "Subtract half the load from last hour of the interval";
+    s = QStringLiteral("Subtract half the load from last hour of the interval");
     qDebug()<<s;
     lst1.clear();
     dt4 = dt2 - Duration(0, 1, 0);
     lst1.add(dt4, dt2, 50.);
     
-    Debug::print(lst1, "List1: " + s);
-    Debug::print(lst2, "List2: " + s);
+    Debug::print(lst1, QStringLiteral("List1: ") + s);
+    Debug::print(lst2, QStringLiteral("List2: ") + s);
     lst2 -= lst1;
     
     QCOMPARE(lst2.map().count(), 2);
@@ -619,14 +635,14 @@ void AppointmentIntervalTester::subtractList()
     QCOMPARE(dt2, lst2.map().values().at(1).endTime());
     QCOMPARE(50., lst2.map().values().at(1).load());
 
-    s = "Subtract all load from last interval";
+    s = QStringLiteral("Subtract all load from last interval");
     qDebug()<<s;
-    Debug::print(lst1, "List1: " + s);
-    Debug::print(lst2, "List2: " + s);
+    Debug::print(lst1, QStringLiteral("List1: ") + s);
+    Debug::print(lst2, QStringLiteral("List2: ") + s);
 
     AppointmentInterval i = lst2.map().values().at(0);
     lst2 -= lst1;
-    Debug::print(lst2, "Result: " + s);
+    Debug::print(lst2, QStringLiteral("Result: ") + s);
 
     QCOMPARE(lst2.map().count(), 1);
     QCOMPARE(i.startTime(), lst2.map().values().at(0).startTime());
@@ -642,10 +658,10 @@ void AppointmentIntervalTester::subtractList()
     // starts before start, end in the middle
     lst1.add(dt1.addSecs(-10), dt3, load / 2.);
 
-    s = "Subtract half the load of the first hour of the interval";
+    s = QStringLiteral("Subtract half the load of the first hour of the interval");
     qDebug()<<s;
-    Debug::print(lst2, "List2: " + s);
-    Debug::print(lst1, "List1: " + s);
+    Debug::print(lst2, QStringLiteral("List2: ") + s);
+    Debug::print(lst1, QStringLiteral("List1: ") + s);
 
     lst2 -= lst1;
     Debug::print(lst2, s);
@@ -659,7 +675,7 @@ void AppointmentIntervalTester::subtractList()
     QCOMPARE(dt2, lst2.map().values().at(1).endTime());
     QCOMPARE(load, lst2.map().values().at(1).load());
 
-    s = "Subtract all load from first interval";
+    s = QStringLiteral("Subtract all load from first interval");
     qDebug()<<s;
     lst2 -= lst1; // remove first interval
     QCOMPARE(lst2.map().count(), 1);
@@ -667,17 +683,17 @@ void AppointmentIntervalTester::subtractList()
     QCOMPARE(dt2, lst2.map().values().at(0).endTime());
     QCOMPARE(load, lst2.map().values().at(0).load());
 
-    s = "Subtract half the load from last hour of the interval";
+    s = QStringLiteral("Subtract half the load from last hour of the interval");
     qDebug()<<s;
     lst1.clear();
     dt4 = dt2 - Duration(0, 1, 0);
     lst1.add(dt4, dt2.addSecs(10), 50.);
     
-    Debug::print(lst2, "List2: " + s);
-    Debug::print(lst1, "List1: " + s);
+    Debug::print(lst2, QStringLiteral("List2: ") + s);
+    Debug::print(lst1, QStringLiteral("List1: ") + s);
     lst2 -= lst1;
     
-    Debug::print(lst2, "Result: " + s);
+    Debug::print(lst2, QStringLiteral("Result: ") + s);
 
     QCOMPARE(lst2.map().count(), 2);
     QCOMPARE(dt3, lst2.map().values().at(0).startTime());
@@ -688,15 +704,15 @@ void AppointmentIntervalTester::subtractList()
     QCOMPARE(dt2, lst2.map().values().at(1).endTime());
     QCOMPARE(50., lst2.map().values().at(1).load());
 
-    s = "Subtract all load from last interval";
+    s = QStringLiteral("Subtract all load from last interval");
     qDebug()<<s;
-    Debug::print(lst1, "List1: " + s);
-    Debug::print(lst2, "List2: " + s);
+    Debug::print(lst1, QStringLiteral("List1: ") + s);
+    Debug::print(lst2, QStringLiteral("List2: ") + s);
 
     i = lst2.map().values().at(0);
     qDebug()<<"i:"<<i;
     lst2 -= lst1;
-    Debug::print(lst2, "Result: " + s);
+    Debug::print(lst2, QStringLiteral("Result: ") + s);
 
     QCOMPARE(lst2.map().count(), 1);
     QCOMPARE(i.startTime(), lst2.map().values().at(0).startTime());
@@ -745,9 +761,9 @@ void AppointmentIntervalTester::subtractListMidnight()
     lst1.add(dt3, dt4, load);
     qDebug()<<"Subtract non-overlapping intervals:";
 
-    qDebug()<<endl<<lst2<<endl<<"minus"<<endl<<lst1;
+    qDebug()<<'\n'<<lst2<<'\n'<<"minus"<<'\n'<<lst1;
     lst2 -= lst1;
-    qDebug()<<endl<<"result:"<<endl<<lst2;
+    qDebug()<<'\n'<<"result:"<<'\n'<<lst2;
     QCOMPARE(lst2.map().count(), 2);
     QCOMPARE(dt1, lst2.map().values().first().startTime());
     QCOMPARE(dt2, lst2.map().values().last().endTime());
@@ -759,24 +775,24 @@ void AppointmentIntervalTester::subtractListMidnight()
     lst1.add(dt5, dt6, load);
 
     qDebug()<<"-------- lst2 -= lst1";
-    qDebug()<<endl<<lst2<<endl<<lst1;
+    qDebug()<<'\n'<<lst2<<'\n'<<lst1;
     lst2 -= lst1;
-    qDebug()<<endl<<lst2;
+    qDebug()<<'\n'<<lst2;
     QCOMPARE(lst2.map().count(), 2);
     QCOMPARE(dt1, lst2.map().values().first().startTime());
     QCOMPARE(dt2, lst2.map().values().last().endTime());
     QCOMPARE(load, lst2.map().values().first().load());
     QCOMPARE(load, lst2.map().values().last().load());
 
-    s = "Subtract tangent intervals";
+    s = QStringLiteral("Subtract tangent intervals");
     qDebug()<<s;
     lst1.clear();
     lst1.add(dt1.addDays(-1), dt1, load); // before
-    Debug::print(lst2, "List2: " + s);
-    Debug::print(lst1, "List1: " + s);
+    Debug::print(lst2, QStringLiteral("List2: ") + s);
+    Debug::print(lst1, QStringLiteral("List1: ") + s);
 
     lst2 -= lst1;
-    Debug::print(lst2, "Result: " + s);
+    Debug::print(lst2, QStringLiteral("Result: ") + s);
     
     QCOMPARE(lst2.map().count(), 2);
     QCOMPARE(dt1, lst2.map().values().first().startTime());
@@ -800,10 +816,10 @@ void AppointmentIntervalTester::subtractListMidnight()
     // starts at start, end in the middle (at 23:00)
     lst1.add(dt1, dt3, load / 2.);
 
-    s = "Subtract half the load of the first hour of the interval";
+    s = QStringLiteral("Subtract half the load of the first hour of the interval");
     qDebug()<<s;
-    Debug::print(lst2, "List2: " + s);
-    Debug::print(lst1, "List1: " + s);
+    Debug::print(lst2, QStringLiteral("List2: ") + s);
+    Debug::print(lst1, QStringLiteral("List1: ") + s);
 
     lst2 -= lst1;
     Debug::print(lst2, s);
@@ -818,7 +834,7 @@ void AppointmentIntervalTester::subtractListMidnight()
     QCOMPARE(load, lst2.map().values().at(1).load());
     QCOMPARE(load, lst2.map().values().at(2).load());
 
-    s = "Subtract all load from first interval";
+    s = QStringLiteral("Subtract all load from first interval");
     qDebug()<<s;
     lst2 -= lst1; // remove first interval
     QCOMPARE(lst2.map().count(), 2);
@@ -827,14 +843,14 @@ void AppointmentIntervalTester::subtractListMidnight()
     QCOMPARE(load, lst2.map().values().at(0).load());
     QCOMPARE(load, lst2.map().values().at(1).load());
 
-    s = "Subtract half the load from last 30 min of the last interval";
+    s = QStringLiteral("Subtract half the load from last 30 min of the last interval");
     qDebug()<<s;
     lst1.clear();
     dt4 = dt2 - Duration(0, 0, 30);
     lst1.add(dt4, dt2, 50.);
     
-    Debug::print(lst1, "List1: " + s);
-    Debug::print(lst2, "List2: " + s);
+    Debug::print(lst1, QStringLiteral("List1: ") + s);
+    Debug::print(lst2, QStringLiteral("List2: ") + s);
     lst2 -= lst1;
     
     QCOMPARE(lst2.map().count(), 3);
@@ -847,13 +863,13 @@ void AppointmentIntervalTester::subtractListMidnight()
     QCOMPARE(dt2, lst2.map().values().at(2).endTime());
     QCOMPARE(50., lst2.map().values().at(2).load());
 
-    s = "Subtract all load from last interval";
+    s = QStringLiteral("Subtract all load from last interval");
     qDebug()<<s;
-    Debug::print(lst1, "List1: " + s);
-    Debug::print(lst2, "List2: " + s);
+    Debug::print(lst1, QStringLiteral("List1: ") + s);
+    Debug::print(lst2, QStringLiteral("List2: ") + s);
 
     lst2 -= lst1;
-    Debug::print(lst2, "Result: " + s);
+    Debug::print(lst2, QStringLiteral("Result: ") + s);
 
     QCOMPARE(lst2.map().count(), 2);
     QCOMPARE(dt3, lst2.map().values().at(0).startTime());
@@ -863,6 +879,81 @@ void AppointmentIntervalTester::subtractListMidnight()
 
 }
 
+void AppointmentIntervalTester::timeZones()
+{
+    QTimeZone tzCopenhagen("Europe/Copenhagen");
+    AppointmentIntervalList lst1;
+    DateTime dt1 = DateTime(QDate(2011, 02, 01), QTime(0, 0, 0), tzCopenhagen);
+    DateTime dt2 = dt1 + Duration(0, 3, 0);
+    double load = 100;
+    lst1.add(dt1, dt2, load);
+    QCOMPARE(lst1.map().count(), 1);
+    QCOMPARE(dt1, lst1.map().values().first().startTime());
+    QCOMPARE(dt2, lst1.map().values().last().endTime());
+
+    QTimeZone tzLondon("Europe/London");
+    lst1.toTimeZone(tzLondon);
+    Debug::print(lst1);
+    DateTime dt3 = dt1.toTimeZone(tzLondon);
+    DateTime dt4 = dt3.addSecs(3600);
+    DateTime dt5 = dt4.addSecs(2*3600);
+    QCOMPARE(lst1.map().count(), 2);
+    QCOMPARE(lst1.map().values().at(0).startTime(), dt3);
+    QCOMPARE(lst1.map().values().at(0).endTime(), dt4);
+    QCOMPARE(lst1.map().values().at(1).startTime(), dt4);
+    QCOMPARE(lst1.map().values().at(1).endTime(), dt5);
+
+    lst1.toTimeZone(tzCopenhagen);
+    Debug::print(lst1);
+    QCOMPARE(lst1.map().count(), 1);
+    QCOMPARE(lst1.map().values().first().startTime(), dt1);
+    QCOMPARE(lst1.map().values().last().endTime(), dt2);
+
+    DateTime dt10 = DateTime(QDate(2011, 01, 31), QTime(23, 0, 0), tzLondon);
+    DateTime dt11 = dt10 + Duration(0, 1, 0);
+    lst1.add(dt10, dt11, 100);
+    Debug::print(lst1);
+    QCOMPARE(lst1.map().count(), 2);
+    QCOMPARE(lst1.map().values().first().startTime(), dt10);
+    QCOMPARE(lst1.map().values().first().load(), 200);
+    QCOMPARE(lst1.map().values().first().endTime(), dt11);
+    QCOMPARE(lst1.map().values().last().endTime(), dt2);
+
+    DateTime dt20 = DateTime(QDate(2011, 01, 31), QTime(22, 0, 0), tzLondon);
+    DateTime dt21 = dt20 + Duration(0, 1, 0);
+    lst1.add(dt20, dt21, 100);
+    Debug::print(lst1);
+    auto date = dt20.toTimeZone(tzCopenhagen).date();
+    QCOMPARE(lst1.timeZone(), tzCopenhagen);
+    QCOMPARE(lst1.map().values(date).count(), 1);
+    QCOMPARE(lst1.map().values(date).first().startTime(), dt20.toTimeZone(tzCopenhagen));
+    QCOMPARE(lst1.map().values(date).first().load(), 100);
+    QCOMPARE(lst1.map().values(date).first().endTime(), DateTime(dt21.toTimeZone(tzCopenhagen)));
+
+    date = dt1.date();
+    QCOMPARE(lst1.map().values(date).count(), 2);
+    QCOMPARE(lst1.map().values(date).first().startTime(), dt1);
+    QCOMPARE(lst1.map().values(date).first().load(), 200);
+    QCOMPARE(lst1.map().values(date).first().endTime(), dt11);
+    QCOMPARE(lst1.map().values(date).last().startTime(), dt2 - Duration(0, 2, 0));
+    QCOMPARE(lst1.map().values(date).last().load(), 100);
+    QCOMPARE(lst1.map().values(date).last().endTime(), dt2);
+
+    QTimeZone tz2("Atlantic/South_Georgia");
+    DateTime dt30 = DateTime(QDate(2011, 02, 1), QTime(0, 0, 0), tz2);
+    DateTime dt31 = dt30 + Duration(0, 1, 0);
+    lst1.add(dt30, dt31, 100); // should be merged with last interval
+    Debug::print(lst1);
+    QCOMPARE(lst1.map().values(date).count(), 2);
+    QCOMPARE(lst1.map().values(date).first().startTime(), dt1);
+    QCOMPARE(lst1.map().values(date).first().load(), 200);
+    QCOMPARE(lst1.map().values(date).first().endTime(), dt11);
+    QCOMPARE(lst1.map().values(date).last().startTime(), dt2 - Duration(0, 2, 0));
+    QCOMPARE(lst1.map().values(date).last().load(), 100);
+    QCOMPARE(lst1.map().values(date).last().endTime(), DateTime(dt31.toTimeZone(tzCopenhagen)));
+
+}
+
 } //namespace KPlato
 
 QTEST_GUILESS_MAIN(KPlato::AppointmentIntervalTester)
