@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
-  Copyright (C) 2011 Pierre Stirnweiss <pstirnweiss@googlemail.com>
+  SPDX-FileCopyrightText: 2011 Pierre Stirnweiss <pstirnweiss@googlemail.com>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-* Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 // clazy:excludeall=qstring-arg
@@ -67,9 +54,9 @@ void CommandsTester::testCalendarAddCmd()
     Calendar *calendar1 = new Calendar();
     Calendar *calendar2 = new Calendar();
 
-    CalendarAddCmd *cmd1 = new CalendarAddCmd(m_project, calendar1, 0, 0);
+    CalendarAddCmd *cmd1 = new CalendarAddCmd(m_project, calendar1, 0, nullptr);
     cmd1->execute();
-    QVERIFY(m_project->calendarAt(0) == calendar1);
+    QVERIFY(m_project->calendarAt(0) == calendar1); //NOLINT(clang-analyzer-cplusplus.NewDeleteLeaks)
     CalendarAddCmd *cmd2 = new CalendarAddCmd(m_project, calendar2, 0, calendar1);
     cmd2->execute();
     QVERIFY(calendar1->childAt(0) == calendar2);
@@ -98,7 +85,8 @@ void CommandsTester::testCalendarRemoveCmd()
     m_project->addCalendar(calendar4);
     m_project->setDefaultCalendar(calendar3);
     m_project->addResourceGroup(group1);
-    m_project->addResource(group1, resource1);
+    m_project->addResource(resource1);
+    group1->addResource(-1, resource1, nullptr);
     resource1->setCalendar(calendar4);
     QVERIFY(m_project->calendarAt(0) == calendar1);
     QVERIFY(calendar1->childAt(0) == calendar2);
@@ -115,7 +103,7 @@ void CommandsTester::testCalendarRemoveCmd()
     CalendarRemoveCmd *cmd4 = new CalendarRemoveCmd(m_project, calendar4); //calendar used by a resource
 
     cmd3->execute();
-    QVERIFY(!m_project->calendars().contains(calendar3));
+    QVERIFY(!m_project->calendars().contains(calendar3)); //NOLINT(clang-analyzer-cplusplus.NewDeleteLeaks)
     QVERIFY(m_project->defaultCalendar() != calendar3);
 
     cmd4->execute();
@@ -147,7 +135,7 @@ void CommandsTester::testCalendarRemoveCmd()
     m_project->takeCalendar(calendar3);
     m_project->takeCalendar(calendar2);
     m_project->takeCalendar(calendar1);
-    m_project->takeResource(group1, resource1);
+    m_project->takeResource(resource1);
     m_project->takeResourceGroup(group1);
     delete cmd1;
     delete cmd2;
@@ -184,16 +172,16 @@ void CommandsTester::testCalendarMoveCmd()
 
 void CommandsTester::testCalendarModifyNameCmd()
 {
-    Calendar *calendar1 = new Calendar(QString("test1"));
+    Calendar *calendar1 = new Calendar(QStringLiteral("test1"));
     m_project->addCalendar(calendar1);
     QVERIFY(m_project->calendars().contains(calendar1));
-    QVERIFY(calendar1->name() == "test1");
+    QVERIFY(calendar1->name() == QStringLiteral("test1"));
 
-    CalendarModifyNameCmd *cmd1 = new CalendarModifyNameCmd(calendar1, QString("test2"));
+    CalendarModifyNameCmd *cmd1 = new CalendarModifyNameCmd(calendar1, QStringLiteral("test2"));
     cmd1->execute();
-    QVERIFY(calendar1->name() == "test2");
+    QVERIFY(calendar1->name() == QStringLiteral("test2"));
     cmd1->unexecute();
-    QVERIFY(calendar1->name() == "test1");
+    QVERIFY(calendar1->name() == QStringLiteral("test1"));
 
     m_project->takeCalendar(calendar1);
 
@@ -252,7 +240,7 @@ void CommandsTester::testCalendarAddDayCmd()
     Calendar *calendar1 = new Calendar();
     CalendarDay *day1 = new CalendarDay();
     m_project->addCalendar(calendar1);
-    QVERIFY(m_project->calendarCount() == 1);
+    QVERIFY(m_project->calendarCount() == 1); //NOLINT(clang-analyzer-cplusplus.NewDeleteLeaks)
     QVERIFY(calendar1->days().isEmpty());
 
     CalendarAddDayCmd *cmd1 = new CalendarAddDayCmd(calendar1, day1);
@@ -302,7 +290,7 @@ void CommandsTester::testCalendarModifyDayCmd()
     CalendarDay *day2 = new CalendarDay(QDate(2011,03,11));
     calendar1->addDay(day1);
     m_project->addCalendar(calendar1);
-    QVERIFY(m_project->calendarCount() == 1);
+    QVERIFY(m_project->calendarCount() == 1); //NOLINT(clang-analyzer-cplusplus.NewDeleteLeaks)
     QVERIFY(calendar1->days().contains(day1));
 
     CalendarModifyDayCmd *cmd1 = new CalendarModifyDayCmd(calendar1, day2);
@@ -461,18 +449,18 @@ void CommandsTester::testCalendarModifyWeekdayCmd()
     calendar1->setWeekday(1, *day1);
     QVERIFY(m_project->calendarCount() == 1);
     QVERIFY(calendar1->weekday(1)->state() == day1->state());
-    QVERIFY(calendar1->weekday(1)->timeIntervals().first()->startTime() == day1->timeIntervals().first()->startTime());
-    QVERIFY(calendar1->weekday(1)->timeIntervals().first()->hours() == day1->timeIntervals().first()->hours());
+    QVERIFY(calendar1->weekday(1)->timeIntervals().first()->startTime() == day1->timeIntervals().constFirst()->startTime());
+    QVERIFY(calendar1->weekday(1)->timeIntervals().first()->hours() == day1->timeIntervals().constFirst()->hours());
 
     CalendarModifyWeekdayCmd *cmd1 = new CalendarModifyWeekdayCmd(calendar1, 1, day2);
     cmd1->execute();
     QVERIFY(calendar1->weekday(1)->state() == day2->state());
-    QVERIFY(calendar1->weekday(1)->timeIntervals().first()->startTime() == day2->timeIntervals().first()->startTime());
-    QVERIFY(calendar1->weekday(1)->timeIntervals().first()->hours() == day2->timeIntervals().first()->hours());
+    QVERIFY(calendar1->weekday(1)->timeIntervals().first()->startTime() == day2->timeIntervals().constFirst()->startTime());
+    QVERIFY(calendar1->weekday(1)->timeIntervals().first()->hours() == day2->timeIntervals().constFirst()->hours());
     cmd1->unexecute();
     QVERIFY(calendar1->weekday(1)->state() == day1->state());
-    QVERIFY(calendar1->weekday(1)->timeIntervals().first()->startTime() == day1->timeIntervals().first()->startTime());
-    QVERIFY(calendar1->weekday(1)->timeIntervals().first()->hours() == day1->timeIntervals().first()->hours());
+    QVERIFY(calendar1->weekday(1)->timeIntervals().first()->startTime() == day1->timeIntervals().constFirst()->startTime());
+    QVERIFY(calendar1->weekday(1)->timeIntervals().first()->hours() == day1->timeIntervals().constFirst()->hours());
 
     m_project->takeCalendar(calendar1);
     day1->clearIntervals();
