@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
-   Copyright (C) 2006-2010 Dag Andersen <danders@get2net.dk>
+   SPDX-FileCopyrightText: 2006-2010 Dag Andersen <dag.andersen@kdemail.net>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 // clazy:excludeall=qstring-arg
 #include "ResourceTester.h"
@@ -22,6 +9,8 @@
 
 #include <kptresource.h>
 #include <kptcalendar.h>
+#include <AddResourceCmd.h>
+#include <AddParentGroupCmd.h>
 #include <kptcommand.h>
 #include <kptdatetime.h>
 #include <kptduration.h>
@@ -55,19 +44,19 @@ void ResourceTester::testAvailable()
     qDebug()<<"dt"<<dt;
     
     r.setAvailableFrom(qt);
-    Debug::print(&r, "Test setAvailableFrom with QDateTime");
+    Debug::print(&r, QStringLiteral("Test setAvailableFrom with QDateTime"));
     DateTime x = r.availableFrom();
     qDebug()<<"------"<<x;
     QCOMPARE(x, dt);
     qDebug()<<"----------------";
     r.setAvailableUntil(qt.addDays(1));
-    Debug::print(&r, "Test setAvailableUntil with QDateTime");
+    Debug::print(&r, QStringLiteral("Test setAvailableUntil with QDateTime"));
     QCOMPARE(r.availableUntil(), DateTime(dt.addDays(1)));
     qDebug()<<"----------------";
 }
 
 void ResourceTester::testSingleDay() {
-    Calendar t("Test");
+    Calendar t(QStringLiteral("Test"));
     QDate wdate(2006,1,2);
     DateTime before = DateTime(wdate.addDays(-1), QTime());
     DateTime after = DateTime(wdate.addDays(1), QTime());
@@ -86,7 +75,7 @@ void ResourceTester::testSingleDay() {
     r.setAvailableUntil(after);
     r.setCalendar(&t);
     
-    Debug::print(&r, "Test single resource, no group, no project", true);
+    Debug::print(&r, QStringLiteral("Test single resource, no group, no project"), true);
 
     QVERIFY(r.availableAfter(after, DateTime(after.addDays(1))).isValid() == false);
     QVERIFY(r.availableBefore(before, DateTime(before.addDays(-1))).isValid() == false);
@@ -106,62 +95,45 @@ void ResourceTester::testSingleDay() {
 
 void ResourceTester::team()
 {
-    Resource team;
-    team.setId("team");
-    Resource tm1, tm2;
-    tm1.setId("tm1");
-    tm2.setId("tm2");
-
-    QVERIFY(team.teamMemberIds().isEmpty());
-    team.addTeamMemberId(tm1.id());
-    QVERIFY(team.teamMemberIds().count() == 1);
-    team.removeTeamMemberId(tm1.id());
-    QVERIFY(team.teamMemberIds().isEmpty());
-    team.addTeamMemberId(tm1.id());
-    team.addTeamMemberId(tm2.id());
-    QVERIFY(team.teamMemberIds().count() == 2);
-    team.addTeamMemberId(tm2.id());
-    QVERIFY(team.teamMemberIds().count() == 2);
-    team.removeTeamMemberId(tm1.id());
-    team.removeTeamMemberId(tm2.id());
-    QVERIFY(team.teamMemberIds().isEmpty());
-
-    AddResourceTeamCmd ac(&team, tm1.id());
-    ac.execute();
-    QVERIFY(team.teamMemberIds().count() == 1);
-    ac.unexecute();
-    QVERIFY(team.teamMemberIds().isEmpty());
-    ac.execute();
-    RemoveResourceTeamCmd rc(&team, tm1.id());
-    rc.execute();
-    QVERIFY(team.teamMemberIds().isEmpty());
-    rc.unexecute();
-    QVERIFY(team.teamMemberIds().count() == 1);
-
     {
         Project p1;
 
         AddResourceGroupCmd *c1 = new AddResourceGroupCmd(&p1, new ResourceGroup());
         c1->redo();
+        QCOMPARE(p1.resourceGroups().count(), 1);
         ResourceGroup *g = p1.resourceGroups().at(0);
-        QVERIFY(g);
         delete c1;
 
-        AddResourceCmd *c2 = new AddResourceCmd(g, new Resource());
+        AddResourceCmd *c2 = new AddResourceCmd(&p1, new Resource());
         c2->redo();
-        Resource *r1 = g->resourceAt(0);
-        QVERIFY(r1);
+        QCOMPARE(p1.resourceList().count(), 1);
+        Resource *r1 = p1.resourceList().at(0);
+        AddParentGroupCmd *c21 = new AddParentGroupCmd(r1, g);
+        c21->redo();
+        QCOMPARE(g->resources().count(), 1);
+        QCOMPARE(g->resourceAt(0), r1);
         delete c2;
-        c2 = new AddResourceCmd(g, new Resource());
+        delete c21;
+        c2 = new AddResourceCmd(&p1, new Resource());
         c2->redo();
-        Resource *r2 = g->resourceAt(1);
-        QVERIFY(r2);
+        QCOMPARE(p1.resourceList().count(), 2);
+        Resource *r2 = p1.resourceList().at(1);
+        c21 = new AddParentGroupCmd(r2, g);
+        c21->redo();
+        QCOMPARE(g->resources().count(), 2);
+        QCOMPARE(g->resourceAt(1), r2);
         delete c2;
-        c2 = new AddResourceCmd(g, new Resource());
+        delete c21;
+        c2 = new AddResourceCmd(&p1, new Resource());
         c2->redo();
-        Resource *r3 = g->resourceAt(2);
-        QVERIFY(r3);
+        QCOMPARE(p1.resourceList().count(), 3);
+        Resource *r3 = p1.resourceList().at(2);
+        c21 = new AddParentGroupCmd(r3, g);
+        c21->redo();
+        QCOMPARE(g->resources().count(), 3);
+        QCOMPARE(g->resourceAt(2), r3);
         delete c2;
+        delete c21;
 
         AddResourceTeamCmd *c3 = new AddResourceTeamCmd(r1, r2->id());
         c3->redo();
@@ -187,7 +159,7 @@ void ResourceTester::team()
 
     {
         Project p1;
-        p1.setId("p1");
+        p1.setId(QStringLiteral("p1"));
 
         AddResourceGroupCmd *c1 = new AddResourceGroupCmd(&p1, new ResourceGroup());
         c1->redo();
@@ -197,21 +169,30 @@ void ResourceTester::team()
 
         Resource *r1 = new Resource();
         r1->setType(Resource::Type_Team);
-        AddResourceCmd *c2 = new AddResourceCmd(g, r1);
+        AddResourceCmd *c2 = new AddResourceCmd(&p1, r1);
         c2->redo();
+        AddParentGroupCmd *c21 = new AddParentGroupCmd(r1, g);
+        c21->redo();
         r1 = g->resourceAt(0);
         QVERIFY(r1);
         delete c2;
-        c2 = new AddResourceCmd(g, new Resource());
+        delete c21;
+        Resource *r2 = new Resource();
+        c2 = new AddResourceCmd(&p1, r2);
         c2->redo();
-        Resource *r2 = g->resourceAt(1);
-        QVERIFY(r2);
+        c21 = new AddParentGroupCmd(r2, g);
+        c21->redo();
+        QCOMPARE(g->resourceAt(1), r2);
         delete c2;
-        c2 = new AddResourceCmd(g, new Resource());
+        delete c21;
+        Resource *r3 = new Resource();
+        c2 = new AddResourceCmd(&p1, r3);
         c2->redo();
-        Resource *r3 = g->resourceAt(2);
-        QVERIFY(r3);
+        c21 = new AddParentGroupCmd(r3, g);
+        c21->redo();
+        QCOMPARE(g->resourceAt(2), r3);
         delete c2;
+        delete c21;
 
         AddResourceTeamCmd *c3 = new AddResourceTeamCmd(r1, r2->id());
         c3->redo();
@@ -236,42 +217,52 @@ void ResourceTester::team()
         QVERIFY(g2);
         delete c1;
 
-        c2 = new AddResourceCmd(g2, new Resource(r1));
+        c2 = new AddResourceCmd(&p2, new Resource(r1));
         c2->redo();
-        Resource *r11 = g2->resourceAt(0);
-        QVERIFY(r11);
+        QCOMPARE(p2.resourceList().count(), 1);
+        Resource *r11 = p2.resourceList().at(0);
+        c21 = new AddParentGroupCmd(r11, g2);
+        c21->redo();
+        QCOMPARE(g2->resources().count(), 1);
+        QCOMPARE(g2->resourceAt(0), r11);
         delete c2;
-        c2 = new AddResourceCmd(g2, new Resource(r2));
+        delete c21;
+        c2 = new AddResourceCmd(&p2, new Resource(r2));
         c2->redo();
-        Resource *r12 = g->resourceAt(1);
-        QVERIFY(r12);
+        QCOMPARE(p2.resourceList().count(), 2);
+        Resource *r12 = p2.resourceList().at(1);
+        c21 = new AddParentGroupCmd(r12, g2);
+        c21->redo();
+        QCOMPARE(g2->resources().count(), 2);
+        QCOMPARE(g2->resourceAt(1), r12);
         delete c2;
-        c2 = new AddResourceCmd(g2, new Resource(r3));
+        delete c21;
+        c2 = new AddResourceCmd(&p2, new Resource(r3));
         c2->redo();
-        Resource *r13 = g->resourceAt(2);
-        QVERIFY(r13);
+        QCOMPARE(p2.resourceList().count(), 3);
+        Resource *r13 = p2.resourceList().at(2);
+        c21 = new AddParentGroupCmd(r13, g2);
+        c21->redo();
+        QCOMPARE(g2->resources().count(), 3);
+        QCOMPARE(g2->resourceAt(2), r13);
         delete c2;
-
-        QCOMPARE(r1->teamMemberIds().count(), 2);
-        QCOMPARE(r1->teamMembers().count(), 2);
-        QCOMPARE(r1->teamMembers().at(0), r12);
-        QCOMPARE(r1->teamMembers().at(1), r13);
+        delete c21;
+        
+        QCOMPARE(r11->teamMemberIds().count(), 2);
+        QCOMPARE(r11->teamMembers().count(), 2);
+        QCOMPARE(r11->teamMembers().at(0), r12);
+        QCOMPARE(r11->teamMembers().at(1), r13);
 
         // xml
-        QDomDocument qdoc;
-        QDomElement e = qdoc.createElement("plan");
-        qdoc.appendChild(e);
-        p1.save(e, XmlSaveContext());
+        XmlSaveContext context(&p1);
+        context.save();
 
         KoXmlDocument xdoc;
-        xdoc.setContent(qdoc.toString());
+        xdoc.setContent(context.document.toByteArray());
         XMLLoaderObject sts;
 
         Project p3;
-        sts.setProject(&p3);
-        sts.setVersion(PLAN_FILE_SYNTAX_VERSION);
-        KoXmlElement xe = xdoc.documentElement().firstChildElement();
-        p3.load(xe, sts);
+        sts.loadProject(&p3, xdoc);
 
         QCOMPARE(p3.numResourceGroups(), 1);
         ResourceGroup *g3 = p3.resourceGroupAt(0);
@@ -286,7 +277,7 @@ void ResourceTester::team()
     {
         // team members in different group
         Project p1;
-        p1.setId("p1");
+        p1.setId(QStringLiteral("p1"));
 
         AddResourceGroupCmd *c1 = new AddResourceGroupCmd(&p1, new ResourceGroup());
         c1->redo();
@@ -301,21 +292,29 @@ void ResourceTester::team()
 
         Resource *r1 = new Resource();
         r1->setType(Resource::Type_Team);
-        AddResourceCmd *c2 = new AddResourceCmd(g, r1);
+        AddResourceCmd *c2 = new AddResourceCmd(&p1, r1);
         c2->redo();
+        AddParentGroupCmd *c21 = new AddParentGroupCmd(r1, g);
+        c21->redo();
         QCOMPARE(r1, g->resourceAt(0));
         delete c2;
+        delete c21;
         Resource *r2 = new Resource();
-        c2 = new AddResourceCmd(mg, r2);
+        c2 = new AddResourceCmd(&p1, r2);
         c2->redo();
+        c21 = new AddParentGroupCmd(r2, mg);
+        c21->redo();
         QCOMPARE(r2, mg->resourceAt(0));
         delete c2;
+        delete c21;
         Resource *r3 = new Resource();
-        c2 = new AddResourceCmd(mg, r3);
+        c2 = new AddResourceCmd(&p1, r3);
         c2->redo();
+        c21 = new AddParentGroupCmd(r3, mg);
+        c21->redo();
         QCOMPARE(r3, mg->resourceAt(1));
         delete c2;
-
+        delete c21;
         AddResourceTeamCmd *c3 = new AddResourceTeamCmd(r1, r2->id());
         c3->redo();
         delete c3;
@@ -346,44 +345,48 @@ void ResourceTester::team()
         QVERIFY(mg2);
         delete c1;
 
-        c2 = new AddResourceCmd(g2, new Resource(r1));
+        c2 = new AddResourceCmd(&p2, new Resource(r1));
         c2->redo();
-        Resource *r11 = g2->resourceAt(0);
-        QVERIFY(r11);
+        Resource *r11 = p2.resourceList().at(0);
+        c21 = new AddParentGroupCmd(r11, g2);
+        c21->redo();
+        QCOMPARE(r11, g2->resourceAt(0));
         delete c2;
-        c2 = new AddResourceCmd(mg2, new Resource(r2));
+        delete c21;
+        c2 = new AddResourceCmd(&p2, new Resource(r2));
         c2->redo();
-        Resource *r12 = mg2->resourceAt(0);
-        QVERIFY(r12);
+        Resource *r12 = p2.resourceList().at(1);
+        c21 = new AddParentGroupCmd(r12, mg2);
+        c21->redo();
+        QCOMPARE(r12, mg2->resourceAt(0));
         delete c2;
-        c2 = new AddResourceCmd(mg2, new Resource(r3));
+        delete c21;
+        c2 = new AddResourceCmd(&p2, new Resource(r3));
         c2->redo();
-        Resource *r13 = mg2->resourceAt(1);
-        QVERIFY(r13);
+        Resource *r13 = p2.resourceList().at(2);
+        c21 = new AddParentGroupCmd(r13, mg2);
+        c21->redo();
+        QCOMPARE(r13, mg2->resourceAt(1));
         delete c2;
-
+        delete c21;
+        
         QCOMPARE(r11->teamMemberIds().count(), 2);
         QCOMPARE(r11->teamMembers().count(), 2);
         QCOMPARE(r11->teamMembers().at(0), r12);
         QCOMPARE(r11->teamMembers().at(1), r13);
 
         // xml
-        QDomDocument qdoc;
-        QDomElement e = qdoc.createElement("plan");
-        qdoc.appendChild(e);
-        p1.save(e, XmlSaveContext());
+        XmlSaveContext context(&p1);
+        context.save();
 
         KoXmlDocument xdoc;
-        xdoc.setContent(qdoc.toString());
+        xdoc.setContent(context.document.toByteArray());
+
         XMLLoaderObject sts;
-
         Project p3;
-        sts.setProject(&p3);
-        sts.setVersion(PLAN_FILE_SYNTAX_VERSION);
-        KoXmlElement xe = xdoc.documentElement().firstChildElement();
-        p3.load(xe, sts);
+        sts.loadProject(&p3, xdoc);
 
-        QCOMPARE(p3.numResourceGroups(), 2);
+        QCOMPARE(p3.numResourceGroups(), p1.numResourceGroups());
         ResourceGroup *g3 = p3.resourceGroupAt(0);
         QCOMPARE(g3->numResources(), 1);
         ResourceGroup *mg3 = p3.resourceGroupAt(1);
@@ -408,26 +411,41 @@ void ResourceTester::required()
     QVERIFY(g);
     delete c1;
 
-    AddResourceCmd *c2 = new AddResourceCmd(g, new Resource());
+    AddResourceCmd *c2 = new AddResourceCmd(&p, new Resource());
     c2->redo();
-    Resource *r1 = g->resourceAt(0);
-    QVERIFY(r1);
+    QCOMPARE(p.resourceList().count(), 1);
+    Resource *r1 = p.resourceList().at(0);
+    AddParentGroupCmd *c21 = new AddParentGroupCmd(r1, g);
+    c21->redo();
+    QCOMPARE(g->resources().count(), 1);
+    QCOMPARE(g->resourceAt(0), r1);
     delete c2;
-    c2 = new AddResourceCmd(g, new Resource());
+    delete c21;
+    c2 = new AddResourceCmd(&p, new Resource());
     c2->redo();
-    Resource *r2 = g->resourceAt(1);
-    QVERIFY(r2);
+    QCOMPARE(p.resourceList().count(), 2);
+    Resource *r2 = p.resourceList().at(1);
+    c21 = new AddParentGroupCmd(r2, g);
+    c21->redo();
+    QCOMPARE(g->resources().count(), 2);
+    QCOMPARE(g->resourceAt(1), r2);
     delete c2;
-    c2 = new AddResourceCmd(g, new Resource());
+    delete c21;
+    c2 = new AddResourceCmd(&p, new Resource());
     c2->redo();
-    Resource *r3 = g->resourceAt(2);
-    QVERIFY(r3);
+    QCOMPARE(p.resourceList().count(), 3);
+    Resource *r3 = p.resourceList().at(2);
+    c21 = new AddParentGroupCmd(r3, g);
+    c21->redo();
+    QCOMPARE(g->resources().count(), 3);
+    QCOMPARE(g->resourceAt(2), r3);
     delete c2;
+    delete c21;
 
     QVERIFY(r1->requiredIds().isEmpty());
     QVERIFY(r1->requiredResources().isEmpty());
 
-    r1->addRequiredId(""); // not allowed to add empty id
+    r1->addRequiredId(QString()); // not allowed to add empty id
     QVERIFY(r1->requiredIds().isEmpty());
 
     r1->addRequiredId(r2->id());
@@ -466,21 +484,37 @@ void ResourceTester::required()
     delete c1;
 
     ResourceGroup *g1 = p2.resourceGroupAt(0);
-    c2 = new AddResourceCmd(g1, new Resource(r1));
+
+    c2 = new AddResourceCmd(&p2, new Resource(r1));
     c2->redo();
-    Resource *r4 = g1->resourceAt(0);
-    QVERIFY(r4);
+    QCOMPARE(p2.resourceList().count(), 1);
+    Resource *r4 = p2.resourceList().at(0);
+    c21 = new AddParentGroupCmd(r4, g1);
+    c21->redo();
+    QCOMPARE(g1->resources().count(), 1);
+    QCOMPARE(g1->resourceAt(0), r4);
     delete c2;
-    c2 = new AddResourceCmd(g1, new Resource(r2));
+    delete c21;
+    c2 = new AddResourceCmd(&p2, new Resource(r2));
     c2->redo();
-    Resource *r5 = g1->resourceAt(1);
-    QVERIFY(r5);
+    QCOMPARE(p2.resourceList().count(), 2);
+    Resource *r5 = p2.resourceList().at(1);
+    c21 = new AddParentGroupCmd(r5, g1);
+    c21->redo();
+    QCOMPARE(g1->resources().count(), 2);
+    QCOMPARE(g1->resourceAt(1), r5);
     delete c2;
-    c2 = new AddResourceCmd(g1, new Resource(r3));
+    delete c21;
+    c2 = new AddResourceCmd(&p2, new Resource(r3));
     c2->redo();
-    Resource *r6 = g1->resourceAt(2);
-    QVERIFY(r6);
+    QCOMPARE(p2.resourceList().count(), 3);
+    Resource *r6 = p2.resourceList().at(2);
+    c21 = new AddParentGroupCmd(r6, g1);
+    c21->redo();
+    QCOMPARE(g1->resources().count(), 3);
+    QCOMPARE(g1->resourceAt(2), r6);
     delete c2;
+    delete c21;
 
     QCOMPARE(r4->requiredIds().count(), 2);
     QCOMPARE(r4->requiredResources().count(), 2);
@@ -489,21 +523,19 @@ void ResourceTester::required()
 
     // using xml
     {
-        QDomDocument qdoc;
-        QDomElement e = qdoc.createElement("plan");
-        qdoc.appendChild(e);
-        p2.setId("p2");
-        p2.save(e, XmlSaveContext());
+        p2.setId(QStringLiteral("p2"));
+        XmlSaveContext context(&p2);
+        context.save();
 
         KoXmlDocument xdoc;
-        xdoc.setContent(qdoc.toString());
+        xdoc.setContent(context.document.toString());
         XMLLoaderObject sts;
         sts.setProject(&p);
         sts.setVersion(PLAN_FILE_SYNTAX_VERSION);
 
         Project p3;
         KoXmlElement xe = xdoc.documentElement().firstChildElement();
-        p3.load(xe, sts);
+        sts.loadProject(&p3, xdoc);
 
         ResourceGroup *g2 = p3.resourceGroupAt(0);
         QVERIFY(g2);
@@ -524,37 +556,55 @@ void ResourceTester::required()
     {
         // required in different group
         Project p4;
-        p4.setId("p4");
+        p4.setId(QStringLiteral("p4"));
 
         c1 = new AddResourceGroupCmd(&p4, new ResourceGroup());
         c1->redo();
         delete c1;
 
         ResourceGroup *m = new ResourceGroup();
-        m->setType(ResourceGroup::Type_Material);
+        m->setType(QStringLiteral("Material"));
         c1 = new AddResourceGroupCmd(&p4, m);
         c1->redo();
         delete c1;
 
         ResourceGroup *g3 = p4.resourceGroupAt(0);
-        c2 = new AddResourceCmd(g3, new Resource());
-        c2->redo();
-        Resource *r10 = g3->resourceAt(0);
-        QVERIFY(r4);
-        delete c2;
+        QVERIFY(g3);
 
-        Resource *r11 = new Resource();
+        c2 = new AddResourceCmd(&p4, new Resource());
+        c2->redo();
+        QCOMPARE(p4.resourceList().count(), 1);
+        Resource *r10 = p4.resourceList().at(0);
+        c21 = new AddParentGroupCmd(r10, g3);
+        c21->redo();
+        QCOMPARE(g3->resources().count(), 1);
+        QCOMPARE(g3->resourceAt(0), r10);
+        delete c2;
+        delete c21;
+
+        c2 = new AddResourceCmd(&p4, new Resource());
+        c2->redo();
+        QCOMPARE(p4.resourceList().count(), 2);
+        Resource *r11 = p4.resourceList().at(1);
         r11->setType(Resource::Type_Material);
-        c2 = new AddResourceCmd(m, r11);
-        c2->redo();
-        QVERIFY(m->resourceAt(0) == r11);
+        c21 = new AddParentGroupCmd(r11, m);
+        c21->redo();
+        QCOMPARE(m->resources().count(), 1);
+        QCOMPARE(m->resourceAt(0), r11);
         delete c2;
-        Resource *r12 = new Resource();
+        delete c21;
+
+        c2 = new AddResourceCmd(&p4, new Resource());
+        c2->redo();
+        QCOMPARE(p4.resourceList().count(), 3);
+        Resource *r12 = p4.resourceList().at(2);
         r12->setType(Resource::Type_Material);
-        c2 = new AddResourceCmd(m, r12);
-        c2->redo();
-        QVERIFY(m->resourceAt(1) == r12);
+        c21 = new AddParentGroupCmd(r12, m);
+        c21->redo();
+        QCOMPARE(m->resources().count(), 2);
+        QCOMPARE(m->resourceAt(1), r12);
         delete c2;
+        delete c21;
 
         r10->addRequiredId(r11->id());
         r10->addRequiredId(r12->id());
@@ -564,21 +614,18 @@ void ResourceTester::required()
         QCOMPARE(r10->requiredResources().at(1), r12);
 
         // using xml
-        QDomDocument qdoc;
-        QDomElement e = qdoc.createElement("plan");
-        qdoc.appendChild(e);
-        p4.save(e, XmlSaveContext());
+        XmlSaveContext context(&p4);
+        context.save();
 
         KoXmlDocument xdoc;
-        xdoc.setContent(qdoc.toString());
-        XMLLoaderObject sts;
-        sts.setProject(&p4);
-        sts.setVersion(PLAN_FILE_SYNTAX_VERSION);
+        xdoc.setContent(context.document.toByteArray());
 
         Project p5;
-        KoXmlElement xe = xdoc.documentElement().firstChildElement();
-        p5.load(xe, sts);
+        XMLLoaderObject sts;
+        sts.setProject(&p5);
+        sts.loadProject(&p5, xdoc);
 
+        QCOMPARE(p5.numResourceGroups(), p4.numResourceGroups());
         ResourceGroup *g4 = p5.resourceGroupAt(0);
         QVERIFY(g4);
         QCOMPARE(g4->numResources(), 1);
