@@ -1,21 +1,8 @@
 /* This file is part of the KDE project
-   Copyright (C) 20012 Dag Andersen <danders@get2net.dk>
-   Copyright (C) 2016 Dag Andersen <danders@get2net.dk>
+   SPDX-FileCopyrightText: 20012 Dag Andersen <dag.andersen@kdemail.net>
+   SPDX-FileCopyrightText: 2016 Dag Andersen <dag.andersen@kdemail.net>
    
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 // clazy:excludeall=qstring-arg
 #include "WorkInfoCacheTester.h"
@@ -44,11 +31,11 @@ QTimeZone createTimeZoneWithOffsetFromSystem(int hours, const QString & name, in
     if (offsetSeconds >= (12*3600)) {
         qDebug() << "reducing offset by 24h";
         offsetSeconds -= (24*3600);
-        *shiftDays = -1;
+        *shiftDays = 1;
     } else if (offsetSeconds <= -(12*3600)) {
         qDebug() << "increasing offset by 24h";
         offsetSeconds += (24*3600);
-        *shiftDays = 1;
+        *shiftDays = -1;
     } else {
         *shiftDays = 0;
     }
@@ -59,7 +46,7 @@ QTimeZone createTimeZoneWithOffsetFromSystem(int hours, const QString & name, in
 
 void WorkInfoCacheTester::basics()
 {
-    Calendar cal("Test");
+    Calendar cal(QStringLiteral("Test"));
     QDate wdate(2012,1,2);
     DateTime before = DateTime(wdate.addDays(-1), QTime());
     DateTime after = DateTime(wdate.addDays(1), QTime());
@@ -100,7 +87,7 @@ void WorkInfoCacheTester::basics()
 
 void WorkInfoCacheTester::addAfter()
 {
-    Calendar cal("Test");
+    Calendar cal(QStringLiteral("Test"));
     QDate wdate(2012,1,2);
     DateTime before = DateTime(wdate.addDays(-1), QTime());
     DateTime after = DateTime(wdate.addDays(1), QTime());
@@ -148,7 +135,7 @@ void WorkInfoCacheTester::addAfter()
 
 void WorkInfoCacheTester::addBefore()
 {
-    Calendar cal("Test");
+    Calendar cal(QStringLiteral("Test"));
     QDate wdate(2012,1,2);
     DateTime before = DateTime(wdate.addDays(-1), QTime());
     DateTime after = DateTime(wdate.addDays(1), QTime());
@@ -196,7 +183,7 @@ void WorkInfoCacheTester::addBefore()
 
 void WorkInfoCacheTester::addMiddle()
 {
-    Calendar cal("Test");
+    Calendar cal(QStringLiteral("Test"));
     QDate wdate(2012,1,2);
     DateTime before = DateTime(wdate.addDays(-1), QTime());
     DateTime after = DateTime(wdate.addDays(1), QTime());
@@ -242,7 +229,7 @@ void WorkInfoCacheTester::addMiddle()
 
 void WorkInfoCacheTester::fullDay()
 {
-    Calendar cal("Test");
+    Calendar cal(QStringLiteral("Test"));
     QDate wdate(2012,1,2);
 
     QTime t1(0,0,0);
@@ -274,76 +261,84 @@ void WorkInfoCacheTester::fullDay()
 
 void WorkInfoCacheTester::timeZone()
 {
-    QByteArray tz("TZ=Europe/Berlin");
-    putenv(tz.data());
+    //qputenv("TZ", QByteArray("America/Los_Angeles"));
     qDebug()<<"Local timezone: "<<QTimeZone::systemTimeZone();
     
-    Calendar cal("Test");
-    // local zone: Europe/Berlin (9 hours from America/Los_Angeles)
+    Calendar cal(QStringLiteral("Test"));
+    // Create a dummy timezone 9 hours from system timezone
     int laShiftDays;
-    QTimeZone la = createTimeZoneWithOffsetFromSystem(-9, "DummyLos_Angeles", &laShiftDays);
-    QVERIFY(la.isValid());
-    cal.setTimeZone(la);
+    QTimeZone dummytz = createTimeZoneWithOffsetFromSystem(-9, QStringLiteral("DummyTimeZone"), &laShiftDays);
+    QVERIFY(dummytz.isValid());
+    cal.setTimeZone(dummytz);
 
     QDate wdate(2012,1,2);
-    DateTime before = DateTime(wdate.addDays(-1), QTime());
-    DateTime after = DateTime(wdate.addDays(2), QTime());
+    DateTime before = DateTime(wdate.addDays(-1), QTime(), dummytz);
+    DateTime after = DateTime(wdate.addDays(2), QTime(), dummytz);
 //    qDebug() << "before, after" << before << after;
-    QTime t1(14,0,0); // 23 LA
-    QTime t2(16,0,0); // 01 LA next day
+    QTime t1(14,0,0); // 23 dummytz
+    QTime t2(16,0,0); // 01 dummytz next day
     DateTime wdt1(wdate, t1);
     DateTime wdt2(wdate, t2);
-    int length = t1.msecsTo(t2);
-    qDebug() << "wdt1, wdt2" << wdt1 << wdt2 << wdt1.toTimeZone(la) << wdt2.toTimeZone(la);
+    qint64 length = t1.msecsTo(t2);
+    qDebug() << "length:" << Duration(length).toString() << "wdt1, wdt2" << wdt1 << wdt2 << wdt1.toTimeZone(dummytz) << wdt2.toTimeZone(dummytz);
     CalendarDay *day = new CalendarDay(wdate, CalendarDay::Working);
     day->addInterval(TimeInterval(t1, length));
     cal.addDay(day);
     QVERIFY(cal.findDay(wdate) == day);
 
-    Debug::print(&cal, "DummyLos_Angeles");
+    Debug::print(&cal, QStringLiteral("DummyTimeZone"));
     Resource r;
     r.setCalendar(&cal);
     const Resource::WorkInfoCache &wic = r.workInfoCache();
     QVERIFY(! wic.isValid());
 
     r.calendarIntervals(before, after);
-    qDebug()<<wic.intervals.map();
-    QCOMPARE(wic.intervals.map().count(), 2);
+    QVERIFY(wic.isValid());
 
-    wdate = wdate.addDays(-laShiftDays);
-qDebug() << wdate;
-qDebug() << wic.intervals.map().value(wdate);
-qDebug() << wic.intervals.map().value(wdate).startTime();
-qDebug() << DateTime(wdate, QTime(23, 0, 0));
-    QCOMPARE(wic.intervals.map().value(wdate).startTime(), DateTime(wdate, QTime(23, 0, 0)));
-    QCOMPARE(wic.intervals.map().value(wdate).endTime(), DateTime(wdate.addDays(1), QTime(0, 0, 0)));
+    QCOMPARE(wic.intervals.map().count(), 1);
+    QCOMPARE(wic.intervals.map().values(wdate).count(), 1);
+    QMultiMap<QDate, AppointmentInterval>::const_iterator it = wic.intervals.map().constBegin();
+    QCOMPARE(it.value().startTime(), DateTime(wdate, QTime(14, 0, 0), dummytz));
+    QCOMPARE(it.value().endTime(), DateTime(wdate, QTime(16, 0, 0), dummytz));
+
+    // convert to localtime, moves the interval to around midnite (splits it into two)
+    auto localIntervals = wic.intervals;
+    qDebug()<<"before"<<localIntervals;
+    localIntervals.toTimeZone(QTimeZone::systemTimeZone());
+    qDebug()<<"after"<<localIntervals;
+    wdate = wdate.addDays(laShiftDays);
+    QCOMPARE(localIntervals.map().count(), 2);
+    QCOMPARE(localIntervals.map().values(wdate).count(), 1);
+    QCOMPARE(localIntervals.map().value(wdate).startTime(), DateTime(wdate, QTime(23, 0, 0), QTimeZone::systemTimeZone()));
+    QCOMPARE(localIntervals.map().value(wdate).endTime(), DateTime(wdate.addDays(1), QTime(0, 0, 0), QTimeZone::systemTimeZone()));
 
     wdate = wdate.addDays(1);
-    QCOMPARE(wic.intervals.map().value(wdate).startTime(), DateTime(wdate, QTime(0, 0, 0)));
-    QCOMPARE(wic.intervals.map().value(wdate).endTime(), DateTime(wdate, QTime(1, 0, 0)));
-
-    unsetenv("TZ");
+    QCOMPARE(localIntervals.map().values(wdate).count(), 1);
+    QCOMPARE(localIntervals.map().value(wdate).startTime(), DateTime(wdate, QTime(0, 0, 0)));
+    QCOMPARE(localIntervals.map().value(wdate).endTime(), DateTime(wdate, QTime(1, 0, 0)));
+    //qunsetenv("TZ");
 }
 
 void WorkInfoCacheTester::doubleTimeZones()
 {
-    QByteArray tz("TZ=Europe/Copenhagen");
-    putenv(tz.data());
-    qDebug()<<"Local timezone: "<<QTimeZone::systemTimeZone();
+    QTimeZone tz("Europe/Copenhagen");
+    qDebug()<<"Local timezone: "<<QTimeZone::systemTimeZone()<<"tz:"<<tz;
     
-    Calendar cal("LocalTime/Copenhagen");
-    QCOMPARE(cal.timeZone(),  QTimeZone::systemTimeZone());
-    
-    Calendar cal2("Helsinki");
-    cal2.setTimeZone(QTimeZone("Europe/Helsinki"));
+    Calendar cal(QStringLiteral("LocalTime/Copenhagen"));
+    cal.setTimeZone(tz);
+    QCOMPARE(cal.timeZone(),  tz);
+
+    QTimeZone htz("Europe/Helsinki");
+    Calendar cal2(QStringLiteral("Helsinki"));
+    cal2.setTimeZone(htz);
     QVERIFY(cal2.timeZone().isValid());
     
     QDate wdate(2012,1,2);
-    DateTime before = DateTime(wdate, QTime());
-    DateTime after = DateTime(wdate.addDays(1), QTime());
+    DateTime before = DateTime(wdate, QTime(), tz);
+    DateTime after = DateTime(wdate.addDays(1), QTime(), tz);
     //    qDebug() << "before, after" << before << after;
-    QTime t1(14,0,0); // 23 LA
-    QTime t2(16,0,0); // 01 LA next day
+    QTime t1(14,0,0);
+    QTime t2(16,0,0);
     DateTime wdt1(wdate, t1);
     DateTime wdt2(wdate, t2);
     int length = t1.msecsTo(t2);
@@ -353,7 +348,7 @@ void WorkInfoCacheTester::doubleTimeZones()
     cal.addDay(day);
     QVERIFY(cal.findDay(wdate) == day);
     
-    Debug::print(&cal, "");
+    Debug::print(&cal, QString());
     Resource r1;
     r1.setCalendar(&cal);
     const Resource::WorkInfoCache &wic = r1.workInfoCache();
@@ -363,15 +358,15 @@ void WorkInfoCacheTester::doubleTimeZones()
     Debug::print(wic.intervals);
     QCOMPARE(wic.intervals.map().count(), 1);
     
-    QCOMPARE(wic.intervals.map().value(wdate).startTime(), DateTime(wdate, QTime(14, 0, 0)));
-    QCOMPARE(wic.intervals.map().value(wdate).endTime(), DateTime(wdate, QTime(16, 0, 0)));
+    QCOMPARE(wic.intervals.map().value(wdate).startTime(), DateTime(wdate, QTime(14, 0, 0), tz));
+    QCOMPARE(wic.intervals.map().value(wdate).endTime(), DateTime(wdate, QTime(16, 0, 0), tz));
 
     day = new CalendarDay(wdate, CalendarDay::Working);
     day->addInterval(TimeInterval(t1, length));
     cal2.addDay(day);
     QVERIFY(cal2.findDay(wdate) == day);
     
-    Debug::print(&cal2, "");
+    Debug::print(&cal2, QString());
     Resource r2;
     r2.setCalendar(&cal2);
     const Resource::WorkInfoCache &wic2 = r2.workInfoCache();
@@ -381,10 +376,8 @@ void WorkInfoCacheTester::doubleTimeZones()
     Debug::print(wic2.intervals);
     QCOMPARE(wic2.intervals.map().count(), 1);
     
-    QCOMPARE(wic2.intervals.map().value(wdate).startTime(), DateTime(wdate, QTime(13, 0, 0)));
-    QCOMPARE(wic2.intervals.map().value(wdate).endTime(), DateTime(wdate, QTime(15, 0, 0)));
-    
-    unsetenv("TZ");
+    QCOMPARE(wic2.intervals.map().value(wdate).startTime(), DateTime(wdate, QTime(13, 0, 0), tz));
+    QCOMPARE(wic2.intervals.map().value(wdate).endTime(), DateTime(wdate, QTime(15, 0, 0), tz));
 }
 
 } //namespace KPlato
