@@ -1,24 +1,12 @@
 /*
- *  Copyright (c) 2014 Dmitry Kazakov <dimula73@gmail.com>
- *  Copyright (c) 2014 Mohit Goyal <mohit.bits2011@gmail.com>
+ *  SPDX-FileCopyrightText: 2014 Dmitry Kazakov <dimula73@gmail.com>
+ *  SPDX-FileCopyrightText: 2014 Mohit Goyal <mohit.bits2011@gmail.com>
  *
- *  This library is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU Lesser General Public License as published by
- *  the Free Software Foundation; either version 2.1 of the License, or
- *  (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Lesser General Public License for more details.
- *
- *  You should have received a copy of the GNU Lesser General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: LGPL-2.1-or-later
  */
 /****************************************************************************
 **
-** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** SPDX-FileCopyrightText: 2011 Nokia Corporation and /or its subsidiary(-ies).
 ** All rights reserved.
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -59,9 +47,9 @@
 
 // clazy:excludeall=qstring-arg
 #include <QDebug>
-#include <klocalizedstring.h>
-#include <kstandardaction.h>
-#include <kactioncollection.h>
+#include <KLocalizedString>
+#include <KStandardAction>
+#include <KActionCollection>
 #include "kundo2stack.h"
 #include "kundo2stack_p.h"
 #include "kundo2group.h"
@@ -133,16 +121,16 @@
 */
 
 KUndo2Command::KUndo2Command(const KUndo2MagicString &text, KUndo2Command *parent):
-    m_hasParent(parent != 0),
+    m_hasParent(parent != nullptr),
     m_timedID(0),
     m_endOfCommand(QTime::currentTime())
 {
     d = new KUndo2CommandPrivate;
-    if (parent != 0) {
+    if (parent != nullptr) {
         parent->d->child_list.append(this);
     }
     setText(text);
-    setTime();
+    m_timeOfCreation = QTime::currentTime();
 }
 
 /*!
@@ -156,10 +144,10 @@ KUndo2Command::KUndo2Command(const KUndo2MagicString &text, KUndo2Command *paren
 */
 
 KUndo2Command::KUndo2Command(KUndo2Command *parent):
-    m_hasParent(parent != 0),m_timedID(0)
+    m_hasParent(parent != nullptr),m_timedID(0)
 {
     d = new KUndo2CommandPrivate;
-    if (parent != 0)
+    if (parent != nullptr)
         parent->d->child_list.append(this);
     setTime();
 }
@@ -268,7 +256,7 @@ void KUndo2Command::undo()
 
 QString KUndo2Command::actionText() const
 {
-    if(d->actionText!=0)
+    if(!d->actionText.isEmpty())
         return d->actionText;
     else
         return QString();
@@ -328,7 +316,7 @@ int KUndo2Command::childCount() const
 const KUndo2Command *KUndo2Command::child(int index) const
 {
     if (index < 0 || index >= d->child_list.count())
-        return 0;
+        return nullptr;
     return d->child_list.at(index);
 }
 
@@ -539,11 +527,11 @@ void KUndo2QStack::setIndex(int idx, bool clean)
     }
     if (idx != m_index) {
         m_index = idx;
-        emit indexChanged(m_index);
-        emit canUndoChanged(canUndo());
-        emit undoTextChanged(undoText());
-        emit canRedoChanged(canRedo());
-        emit redoTextChanged(redoText());
+        Q_EMIT indexChanged(m_index);
+        Q_EMIT canUndoChanged(canUndo());
+        Q_EMIT undoTextChanged(undoText());
+        Q_EMIT canRedoChanged(canRedo());
+        Q_EMIT redoTextChanged(redoText());
     }
 
     if (clean)
@@ -551,7 +539,7 @@ void KUndo2QStack::setIndex(int idx, bool clean)
 
     bool is_clean = m_index == m_clean_index;
     if (is_clean != was_clean)
-        emit cleanChanged(is_clean);
+        Q_EMIT cleanChanged(is_clean);
 }
 
 void KUndo2QStack::purgeRedoState()
@@ -573,12 +561,12 @@ void KUndo2QStack::purgeRedoState()
     }
 
     if (redoStateChanged) {
-        emit canRedoChanged(canRedo());
-        emit redoTextChanged(redoText());
+        Q_EMIT canRedoChanged(canRedo());
+        Q_EMIT redoTextChanged(redoText());
     }
 
     if (cleanStateChanged) {
-        emit cleanChanged(isClean());
+        Q_EMIT cleanChanged(isClean());
     }
 }
 
@@ -618,7 +606,7 @@ bool KUndo2QStack::checkUndoLimit()
 */
 
 KUndo2QStack::KUndo2QStack(QObject *parent)
-    : QObject(parent), m_index(0), m_clean_index(0), m_group(0), m_undo_limit(0), m_useCumulativeUndoRedo(false), m_lastMergedSetCount(0), m_lastMergedIndex(0)
+    : QObject(parent), m_index(0), m_clean_index(0), m_group(nullptr), m_undo_limit(0), m_useCumulativeUndoRedo(false), m_lastMergedSetCount(0), m_lastMergedIndex(0)
 {
     setTimeT1(5);
     setTimeT2(1);
@@ -639,7 +627,7 @@ KUndo2QStack::KUndo2QStack(QObject *parent)
 KUndo2QStack::~KUndo2QStack()
 {
 #ifndef QT_NO_UNDOGROUP
-    if (m_group != 0)
+    if (m_group != nullptr)
         m_group->removeStack(this);
 #endif
     clear();
@@ -674,14 +662,14 @@ void KUndo2QStack::clear()
     m_index = 0;
     m_clean_index = 0;
 
-    emit indexChanged(0);
-    emit canUndoChanged(false);
-    emit undoTextChanged(QString());
-    emit canRedoChanged(false);
-    emit redoTextChanged(QString());
+    Q_EMIT indexChanged(0);
+    Q_EMIT canUndoChanged(false);
+    Q_EMIT undoTextChanged(QString());
+    Q_EMIT canRedoChanged(false);
+    Q_EMIT redoTextChanged(QString());
 
     if (!was_clean)
-        emit cleanChanged(true);
+        Q_EMIT cleanChanged(true);
 }
 
 /*!
@@ -715,7 +703,7 @@ bool KUndo2QStack::push(KUndo2Command *cmd)
 
     bool macro = !m_macro_stack.isEmpty();
 
-    KUndo2Command *cur = 0;
+    KUndo2Command *cur = nullptr;
     if (macro) {
         KUndo2Command *macro_cmd = m_macro_stack.last();
         if (!macro_cmd->d->child_list.isEmpty())
@@ -729,7 +717,7 @@ bool KUndo2QStack::push(KUndo2Command *cmd)
             m_clean_index = -1; // we've deleted the clean state
     }
 
-    bool try_merge = cur != 0
+    bool try_merge = cur != nullptr
                      && cur->id() != -1
                      && cur->id() == cmd->id()
                      && (macro || m_index != m_clean_index);
@@ -807,13 +795,13 @@ bool KUndo2QStack::push(KUndo2Command *cmd)
     }   
     if (try_merge && cur->mergeWith(cmd)) {
         delete cmd;
-        cmd = 0;
+        cmd = nullptr;
         if (!macro) {
-            emit indexChanged(m_index);
-            emit canUndoChanged(canUndo());
-            emit undoTextChanged(undoText());
-            emit canRedoChanged(canRedo());
-            emit redoTextChanged(redoText());
+            Q_EMIT indexChanged(m_index);
+            Q_EMIT canUndoChanged(canUndo());
+            Q_EMIT undoTextChanged(undoText());
+            Q_EMIT canRedoChanged(canRedo());
+            Q_EMIT redoTextChanged(redoText());
         }
     } else {
         if (macro) {
@@ -1042,7 +1030,7 @@ QString KUndo2QStack::undoText() const
 {
     if (!m_macro_stack.isEmpty())
         return QString();
-    if (m_index > 0 && m_command_list.at(m_index-1)!=0)
+    if (m_index > 0 && m_command_list.at(m_index-1)!=nullptr)
 
         return m_command_list.at(m_index - 1)->actionText();
     return QString();
@@ -1135,7 +1123,7 @@ QAction *KUndo2QStack::createRedoAction(QObject *parent) const
     \i canUndo() and canRedo() return false,
     \i calling undo() or redo() has no effect,
     \i the undo/redo actions are disabled.
-    \endlist
+    \'\n'ist
 
     The stack becomes enabled and appropriate signals are emitted when endMacro()
     is called for the outermost macro.
@@ -1166,10 +1154,10 @@ void KUndo2QStack::beginMacro(const KUndo2MagicString &text)
     m_macro_stack.append(cmd);
 
     if (m_macro_stack.count() == 1) {
-        emit canUndoChanged(false);
-        emit undoTextChanged(QString());
-        emit canRedoChanged(false);
-        emit redoTextChanged(QString());
+        Q_EMIT canUndoChanged(false);
+        Q_EMIT undoTextChanged(QString());
+        Q_EMIT canRedoChanged(false);
+        Q_EMIT redoTextChanged(QString());
     }
 }
 
@@ -1212,7 +1200,7 @@ void KUndo2QStack::endMacro()
 const KUndo2Command *KUndo2QStack::command(int index) const
 {
     if (index < 0 || index >= m_command_list.count())
-        return 0;
+        return nullptr;
     return m_command_list.at(index);
 }
 
@@ -1255,7 +1243,7 @@ void KUndo2QStack::setUndoLimit(int limit)
         return;
     m_undo_limit = limit;
     checkUndoLimit();
-    emit undoLimitChanged(m_undo_limit);
+    Q_EMIT undoLimitChanged(m_undo_limit);
 }
 
 int KUndo2QStack::undoLimit() const
@@ -1286,14 +1274,14 @@ void KUndo2QStack::setActive(bool active)
     Q_UNUSED(active);
 #else
     bool prev = isActive();
-    if (m_group != 0) {
+    if (m_group != nullptr) {
         if (active)
             m_group->setActiveStack(this);
         else if (m_group->activeStack() == this)
-            m_group->setActiveStack(0);
+            m_group->setActiveStack(nullptr);
     }
     if (isActive() != prev) {
-        emit activeChanged(!prev);
+        Q_EMIT activeChanged(!prev);
     }
 #endif
 }
@@ -1303,7 +1291,7 @@ bool KUndo2QStack::isActive() const
 #ifdef QT_NO_UNDOGROUP
     return true;
 #else
-    return m_group == 0 || m_group->activeStack() == this;
+    return m_group == nullptr || m_group->activeStack() == this;
 #endif
 }
 void KUndo2QStack::setUseCumulativeUndoRedo(bool value)
