@@ -1,21 +1,8 @@
 /* This file is part of the KDE project
-   Copyright (C) 2000 David Faure <faure@kde.org>
-   Copyright (C) 2006 Fredrik Edemar <f_edemar@linux.se>
+   SPDX-FileCopyrightText: 2000 David Faure <faure@kde.org>
+   SPDX-FileCopyrightText: 2006 Fredrik Edemar <f_edemar@linux.se>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #ifndef __KoApplicationAdaptor_h__
@@ -29,7 +16,6 @@ template<class T> class QList;
 template<class Key, class Value> class QMap;
 
 class QString;
-class QStringList;
 class KoApplication;
 
 /**
