@@ -1,20 +1,7 @@
 /* This file is part of the Calligra libraries
-   Copyright (C) 2001 Werner Trobin <trobin@kde.org>
+   SPDX-FileCopyrightText: 2001 Werner Trobin <trobin@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Library General Public
-License as published by the Free Software Foundation; either
-version 2 of the License, or (at your option) any later version.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Library General Public License for more details.
-
-You should have received a copy of the GNU Library General Public License
-along with this library; see the file COPYING.LIB.  If not, write to
-the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-Boston, MA 02110-1301, USA.
+SPDX-License-Identifier: LGPL-2.0-or-later
 */
 // clazy:excludeall=qstring-arg
 #include "KoFilterGraph.h"
@@ -23,7 +10,6 @@ Boston, MA 02110-1301, USA.
 #include "KoDocumentEntry.h"
 #include "KoFilterEntry.h"
 #include "KoDocument.h"
-#include <config.h> // CALLIGRA_OLD_PLUGIN_METADATA
 
 #include "PriorityQueue_p.h"
 #include "KoFilterEdge.h"
@@ -42,7 +28,7 @@ namespace CalligraFilter {
 Graph::Graph(const QByteArray& from)
         : m_from(from)
         , m_graphValid(false)
-        , d(0)
+        , d(nullptr)
 {
     buildGraph();
     shortestPaths();  // Will return after a single lookup if "from" is invalid (->no check here)
@@ -50,7 +36,7 @@ Graph::Graph(const QByteArray& from)
 
 Graph::~Graph()
 {
-    foreach(Vertex* vertex, m_vertices) {
+    for (Vertex* vertex : std::as_const(m_vertices)) {
         delete vertex;
     }
     m_vertices.clear();
@@ -64,7 +50,7 @@ void Graph::setSourceMimeType(const QByteArray& from)
     m_graphValid = false;
 
     // Initialize with "infinity" ...
-    foreach(Vertex* vertex, m_vertices) {
+    for (Vertex* vertex : std::as_const(m_vertices)) {
         vertex->reset();
     }
     // ...and re-run the shortest path search for the new source mime
@@ -105,7 +91,7 @@ void Graph::dump() const
 #ifndef NDEBUG
     debugFilter << "+++++++++ Graph::dump +++++++++";
     debugFilter << "From:" << m_from;
-    foreach(Vertex *vertex, m_vertices) {
+    for (Vertex *vertex : std::as_const(m_vertices)) {
         vertex->dump("   ");
     }
     debugFilter << "+++++++++ Graph::dump (done) +++++++++";
@@ -119,17 +105,13 @@ void Graph::buildGraph()
     // Make sure that all available parts are added to the graph
     const QList<KoDocumentEntry> parts(KoDocumentEntry::query());
 
-    foreach(const KoDocumentEntry& part, parts) {
+    for (const KoDocumentEntry& part : parts) {
 
         QJsonObject metaData = part.metaData();
-#ifdef CALLIGRA_OLD_PLUGIN_METADATA
-        QStringList nativeMimeTypes = metaData.value("X-KDE-ExtraNativeMimeTypes").toString().split(',');
-#else
-        QStringList nativeMimeTypes = metaData.value("X-KDE-ExtraNativeMimeTypes").toVariant().toStringList();
-#endif
-        nativeMimeTypes += metaData.value("X-KDE-NativeMimeType").toString();
+        QStringList nativeMimeTypes = metaData.value(QString::fromLatin1("X-KDE-ExtraNativeMimeTypes")).toVariant().toStringList();
+        nativeMimeTypes += metaData.value(QString::fromLatin1("X-KDE-NativeMimeType")).toString();
 
-        foreach(const QString& nativeMimeType, nativeMimeTypes) {
+        for (const QString& nativeMimeType : std::as_const(nativeMimeTypes)) {
             const QByteArray key = nativeMimeType.toLatin1();
             if (!m_vertices.contains(key))
                 m_vertices[key] = new Vertex(key);
@@ -139,11 +121,11 @@ void Graph::buildGraph()
     // no constraint here - we want *all* :)
     const QList<KoFilterEntry::Ptr> filters(KoFilterEntry::query());
 
-    foreach(KoFilterEntry::Ptr filter, filters) {
+    for (KoFilterEntry::Ptr filter : filters) {
 
         // First add the "starting points" to the dict
-        foreach (const QString& import, filter->import) {
-            const QByteArray key = import.toLatin1();    // latin1 is okay here (werner)
+        for (const QString& import_ : std::as_const(filter->import_)) {
+            const QByteArray key = import_.toLatin1();    // latin1 is okay here (werner)
             // already there?
             if (!m_vertices.contains(key))
                 m_vertices.insert(key, new Vertex(key));
@@ -152,7 +134,7 @@ void Graph::buildGraph()
         // Are we allowed to use this filter at all?
         if (KoFilterManager::filterAvailable(filter)) {
 
-            foreach(const QString& exportIt, filter->export_) {
+            for (const QString& exportIt : std::as_const(filter->export_)) {
 
                 // First make sure the export vertex is in place
                 const QByteArray key = exportIt.toLatin1();    // latin1 is okay here
@@ -162,8 +144,8 @@ void Graph::buildGraph()
                     m_vertices.insert(key, exp);
                 }
                 // Then create the appropriate edges
-                foreach(const QString& import, filter->import) {
-                    m_vertices[import.toLatin1()]->addEdge(new Edge(exp, filter));
+                for (const QString& import_ : std::as_const(filter->import_)) {
+                    m_vertices[import_.toLatin1()]->addEdge(new Edge(exp, filter));
                 }
             }
         } else
@@ -186,7 +168,7 @@ void Graph::shortestPaths()
     if (!from)
         return;
 
-    // Inititalize start vertex
+    // Initialize start vertex
     from->setKey(0);
 
     // Fill the priority queue with all the vertices
@@ -209,17 +191,13 @@ QByteArray Graph::findCalligraPart() const
     QList<KoDocumentEntry>::ConstIterator partIt(parts.constBegin());
     QList<KoDocumentEntry>::ConstIterator partEnd(parts.constEnd());
 
-    const Vertex *v = 0;
+    const Vertex *v = nullptr;
 
     // Be sure that v gets initialized correctly
     while (!v && partIt != partEnd) {
         QJsonObject metaData = (*partIt).metaData();
-#ifdef CALLIGRA_OLD_PLUGIN_METADATA
-        QStringList nativeMimeTypes = metaData.value("X-KDE-ExtraNativeMimeTypes").toString().split(',');
-#else
-        QStringList nativeMimeTypes = metaData.value("X-KDE-ExtraNativeMimeTypes").toVariant().toStringList();
-#endif
-        nativeMimeTypes += metaData.value("X-KDE-NativeMimeType").toString();
+        QStringList nativeMimeTypes = metaData.value(QString::fromLatin1("X-KDE-ExtraNativeMimeTypes")).toVariant().toStringList();
+        nativeMimeTypes += metaData.value(QString::fromLatin1("X-KDE-NativeMimeType")).toString();
         QStringList::ConstIterator it = nativeMimeTypes.constBegin();
         QStringList::ConstIterator end = nativeMimeTypes.constEnd();
         for (; !v && it != end; ++it)
@@ -233,12 +211,8 @@ QByteArray Graph::findCalligraPart() const
     // Now we try to find the "cheapest" Calligra vertex
     while (partIt != partEnd) {
         QJsonObject metaData = (*partIt).metaData();
-#ifdef CALLIGRA_OLD_PLUGIN_METADATA
-        QStringList nativeMimeTypes = metaData.value("X-KDE-ExtraNativeMimeTypes").toString().split(',');
-#else
-        QStringList nativeMimeTypes = metaData.value("X-KDE-ExtraNativeMimeTypes").toVariant().toStringList();
-#endif
-        nativeMimeTypes += metaData.value("X-KDE-NativeMimeType").toString();
+        QStringList nativeMimeTypes = metaData.value(QString::fromLatin1("X-KDE-ExtraNativeMimeTypes")).toVariant().toStringList();
+        nativeMimeTypes += metaData.value(QString::fromLatin1("X-KDE-NativeMimeType")).toString();
         QStringList::ConstIterator it = nativeMimeTypes.constBegin();
         QStringList::ConstIterator end = nativeMimeTypes.constEnd();
         for (; !v && it != end; ++it) {
