@@ -1,23 +1,10 @@
 /* This file is part of the KDE project
-   Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
+   SPDX-FileCopyrightText: 1998, 1999 Torben Weis <weis@kde.org>
                  2000, 2001 Werner Trobin <trobin@kde.org>
-   Copyright (C) 2004 Nicolas Goutte <goutte@kde.org>
-   Copyright (C) 2009 Thomas Zander <zander@kde.org>
+   SPDX-FileCopyrightText: 2004 Nicolas Goutte <goutte@kde.org>
+   SPDX-FileCopyrightText: 2009 Thomas Zander <zander@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Library General Public
-License as published by the Free Software Foundation; either
-version 2 of the License, or (at your option) any later version.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Library General Public License for more details.
-
-You should have received a copy of the GNU Library General Public License
-along with this library; see the file COPYING.LIB.  If not, write to
-the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-Boston, MA 02110-1301, USA.
+SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 // clazy:excludeall=qstring-arg
@@ -26,7 +13,6 @@ Boston, MA 02110-1301, USA.
 #include "KoDocument.h"
 #include "KoDocumentEntry.h"
 #include "KoProgressUpdater.h"
-#include <config.h> // CALLIGRA_OLD_PLUGIN_METADATA
 
 #include <QFile>
 #include <QLabel>
@@ -37,20 +23,18 @@ Boston, MA 02110-1301, USA.
 #include <QMimeDatabase>
 #include <QPluginLoader>
 
-#include <klocalizedstring.h>
-#include <kmessagebox.h>
+#include <KLocalizedString>
+#include <KMessageBox>
 #include <MainDebug.h>
 
 #include <queue>
 
-#include <unistd.h>
-
 // static cache for filter availability
 QMap<QString, bool> KoFilterManager::m_filterAvailable;
 
 KoFilterManager::KoFilterManager(KoDocument* document,
                                  KoProgressUpdater* progressUpdater) :
-        m_document(document), m_parentChain(0), m_graph(""),
+        m_document(document), m_parentChain(nullptr), m_graph(""),
         d(new Private())
 {
     Q_UNUSED(progressUpdater)
@@ -60,14 +44,14 @@ KoFilterManager::KoFilterManager(KoDocument* document,
 
 KoFilterManager::KoFilterManager(const QString& url, const QByteArray& mimetypeHint,
                                  KoFilterChain* const parentChain) :
-        m_document(0), m_parentChain(parentChain), m_importUrl(url), m_importUrlMimetypeHint(mimetypeHint),
+        m_document(nullptr), m_parentChain(parentChain), m_importUrl(url), m_importUrlMimetypeHint(mimetypeHint),
         m_graph(""), d(new Private)
 {
     d->batch = false;
 }
 
 KoFilterManager::KoFilterManager(const QByteArray& mimeType) :
-        m_document(0), m_parentChain(0), m_graph(""), d(new Private)
+        m_document(nullptr), m_parentChain(nullptr), m_graph(""), d(new Private)
 {
     d->batch = false;
     d->importMimeType = mimeType;
@@ -91,9 +75,25 @@ QString KoFilterManager::importDocument(const QString& url,
             typeName = t.name();
         }
     }
-    m_graph.setSourceMimeType(typeName.toLatin1()); // .latin1() is okay here (Werner)
-
-    if (!m_graph.isValid()) {
+    m_graph.setSourceMimeType(typeName.toLatin1());
+    bool validMimetype = m_graph.isValid();
+    if (!validMimetype) {
+        // Sometimes QMimeDatabase returns multiple mimetypes for the same file type.
+        // In case the default mimetype is not one we can handle,
+        // see if there is one in the list we *can* handle.
+        const auto mimetypes = QMimeDatabase().mimeTypesForFileName(u.path());
+        for (auto mt : mimetypes) { // clazy:exclude=range-loop-reference
+            if (mt.name() != typeName) {
+                m_graph.setSourceMimeType(mt.name().toLatin1()); // .latin1() is okay here (Werner)
+                validMimetype = m_graph.isValid();
+                if (validMimetype) {
+                    typeName = mt.name();
+                    break;
+                }
+            }
+        }
+    }
+    if (!validMimetype) {
         bool userCancelled = false;
 
         warnFilter << "Can't open " << typeName << ", trying filter chooser";
@@ -105,9 +105,9 @@ QString KoFilterManager::importDocument(const QString& url,
             QByteArray nativeFormat = m_document->nativeFormatMimeType();
 
             QApplication::setOverrideCursor(Qt::ArrowCursor);
-            KoFilterChooser chooser(0,
+            KoFilterChooser chooser(nullptr,
                     KoFilterManager::mimeFilter(nativeFormat, KoFilterManager::Import,
-                    m_document->extraNativeMimeTypes()), nativeFormat, u);
+                    m_document->extraNativeMimeTypes()), QString::fromLatin1(nativeFormat), u);
             if (chooser.exec()) {
                 QByteArray f = chooser.filterSelected().toLatin1();
                 if (f == nativeFormat) {
@@ -131,7 +131,7 @@ QString KoFilterManager::importDocument(const QString& url,
         }
     }
 
-    KoFilterChain::Ptr chain(0);
+    KoFilterChain::Ptr chain(nullptr);
     // Are we owned by a KoDocument?
     if (m_document) {
         QByteArray mimeType = m_document->nativeFormatMimeType();
@@ -142,7 +142,7 @@ QString KoFilterManager::importDocument(const QString& url,
         while (i < n) {
             QByteArray extraMime = extraMimes[i].toUtf8();
             // TODO check if its the same target mime then continue
-            KoFilterChain::Ptr newChain(0);
+            KoFilterChain::Ptr newChain(nullptr);
             newChain = m_graph.chain(this, extraMime);
             if (!chain || (newChain && newChain->weight() < chain->weight()))
                 chain = newChain;
@@ -151,13 +151,13 @@ QString KoFilterManager::importDocument(const QString& url,
     } else if (!d->importMimeType.isEmpty()) {
         chain = m_graph.chain(this, d->importMimeType);
     } else {
-        errorFilter << "You aren't supposed to use import() from a filter!" << endl;
+        errorFilter << "You aren't supposed to use import() from a filter!" << '\n';
         status = KoFilter::UsageError;
         return QString();
     }
 
     if (!chain) {
-        errorFilter << "Couldn't create a valid filter chain!" << endl;
+        errorFilter << "Couldn't create a valid filter chain!" << '\n';
         importErrorHelper(typeName);
         status = KoFilter::BadConversionGraph;
         return QString();
@@ -190,7 +190,7 @@ KoFilter::ConversionStatus KoFilterManager::exportDocument(const QString& url, Q
     if (m_document) {
         // We have to pick the right native mimetype as source.
         QStringList nativeMimeTypes;
-        nativeMimeTypes.append(m_document->nativeFormatMimeType());
+        nativeMimeTypes.append(QString::fromLatin1(m_document->nativeFormatMimeType()));
         nativeMimeTypes += m_document->extraNativeMimeTypes();
         QStringList::ConstIterator it = nativeMimeTypes.constBegin();
         const QStringList::ConstIterator end = nativeMimeTypes.constEnd();
@@ -216,7 +216,7 @@ KoFilter::ConversionStatus KoFilterManager::exportDocument(const QString& url, Q
             warnFilter << "Can't open" << t.name() << ", trying filter chooser";
 
             QApplication::setOverrideCursor(Qt::ArrowCursor);
-            KoFilterChooser chooser(0, KoFilterManager::mimeFilter(), QString(), u);
+            KoFilterChooser chooser(nullptr, KoFilterManager::mimeFilter(), QString(), u);
             if (chooser.exec())
                 m_graph.setSourceMimeType(chooser.filterSelected().toLatin1());
             else
@@ -228,7 +228,7 @@ KoFilter::ConversionStatus KoFilterManager::exportDocument(const QString& url, Q
 
     if (!m_graph.isValid()) {
         errorFilter << "Couldn't create a valid graph for this source mimetype.";
-        if (!d->batch && !userCancelled) KMessageBox::error(0, i18n("Could not export file."), i18n("Missing Export Filter"));
+        if (!d->batch && !userCancelled) KMessageBox::error(nullptr, i18n("Could not export file."), i18n("Missing Export Filter"));
         return KoFilter::BadConversionGraph;
     }
 
@@ -236,8 +236,8 @@ KoFilter::ConversionStatus KoFilterManager::exportDocument(const QString& url, Q
         chain = m_graph.chain(this, mimeType);
 
     if (!chain) {
-        errorFilter << "Couldn't create a valid filter chain to " << mimeType << " !" << endl;
-        if (!d->batch) KMessageBox::error(0, i18n("Could not export file."), i18n("Missing Export Filter"));
+        errorFilter << "Couldn't create a valid filter chain to " << mimeType << " !" << '\n';
+        if (!d->batch) KMessageBox::error(nullptr, i18n("Could not export file."), i18n("Missing Export Filter"));
         return KoFilter::BadConversionGraph;
     }
 
@@ -282,10 +282,10 @@ private:
 void buildGraph(QHash<QByteArray, Vertex*>& vertices, KoFilterManager::Direction direction)
 {
     QStringList stopList; // Lists of mimetypes that are considered end of chains
-    stopList << "text/plain";
-    stopList << "text/csv";
-    stopList << "text/x-tex";
-    stopList << "text/html";
+    stopList << QStringLiteral("text/plain");
+    stopList << QStringLiteral("text/csv");
+    stopList << QStringLiteral("text/x-tex");
+    stopList << QStringLiteral("text/html");
 
     // partly copied from build graph, but I don't see any other
     // way without crude hacks, as we have to obey the direction here
@@ -295,12 +295,8 @@ void buildGraph(QHash<QByteArray, Vertex*>& vertices, KoFilterManager::Direction
 
     while (partIt != partEnd) {
         QJsonObject metaData = (*partIt).metaData();
-#ifdef CALLIGRA_OLD_PLUGIN_METADATA
-        QStringList nativeMimeTypes = metaData.value("X-KDE-ExtraNativeMimeTypes").toString().split(',');
-#else
-        QStringList nativeMimeTypes = metaData.value("X-KDE-ExtraNativeMimeTypes").toVariant().toStringList();
-#endif
-        nativeMimeTypes += metaData.value("X-KDE-NativeMimeType").toString();
+        QStringList nativeMimeTypes = metaData.value(QStringLiteral("X-KDE-ExtraNativeMimeTypes")).toVariant().toStringList();
+        nativeMimeTypes += metaData.value(QStringLiteral("X-KDE-NativeMimeType")).toString();
         QStringList::ConstIterator it = nativeMimeTypes.constBegin();
         const QStringList::ConstIterator end = nativeMimeTypes.constEnd();
         for (; it != end; ++it)
@@ -311,75 +307,79 @@ void buildGraph(QHash<QByteArray, Vertex*>& vertices, KoFilterManager::Direction
             }
         ++partIt;
     }
-
-    QList<KoFilterEntry::Ptr> filters = KoFilterEntry::query(); // no constraint here - we want *all* :)
+    const QList<KoFilterEntry::Ptr> filters = KoFilterEntry::query(); // no constraint here - we want *all* :)
     QList<KoFilterEntry::Ptr>::ConstIterator it = filters.constBegin();
     QList<KoFilterEntry::Ptr>::ConstIterator end = filters.constEnd();
-    foreach(KoFilterEntry::Ptr filterEntry, filters)
-    for (; it != end; ++it) {
-        QStringList impList; // Import list
-        QStringList expList; // Export list
+    for (KoFilterEntry::Ptr filterEntry : filters) { // clazy:exclude=range-loop-reference
+        for (; it != end; ++it) {
+            QStringList impList; // Import list
+            QStringList expList; // Export list
 
-        // Now we have to exclude the "stop" mimetypes (in the right direction!)
-        if (direction == KoFilterManager::Import) {
-            // Import: "stop" mime type should not appear in export
-            foreach(const QString & testIt, (*it)->export_) {
-                if (!stopList.contains(testIt))
-                    expList.append(testIt);
-            }
-            impList = (*it)->import;
-        } else {
-            // Export: "stop" mime type should not appear in import
-            foreach(const QString & testIt, (*it)->import) {
-                if (!stopList.contains(testIt))
-                    impList.append(testIt);
-            }
-            expList = (*it)->export_;
-        }
-
-        if (impList.empty() || expList.empty()) {
-            // This filter cannot be used under these conditions
-            debugFilter << "Filter:" << (*it)->fileName() << " ruled out";
-            continue;
-        }
-
-        // First add the "starting points" to the dict
-        QStringList::ConstIterator importIt = impList.constBegin();
-        const QStringList::ConstIterator importEnd = impList.constEnd();
-        for (; importIt != importEnd; ++importIt) {
-            const QByteArray key = (*importIt).toLatin1();    // latin1 is okay here (werner)
-            // already there?
-            if (!vertices[ key ])
-                vertices.insert(key, new Vertex(key));
-        }
-
-        // Are we allowed to use this filter at all?
-        if (KoFilterManager::filterAvailable(*it)) {
-            QStringList::ConstIterator exportIt = expList.constBegin();
-            const QStringList::ConstIterator exportEnd = expList.constEnd();
-            for (; exportIt != exportEnd; ++exportIt) {
-                // First make sure the export vertex is in place
-                const QByteArray key = (*exportIt).toLatin1();    // latin1 is okay here
-                Vertex* exp = vertices[ key ];
-                if (!exp) {
-                    exp = new Vertex(key);
-                    vertices.insert(key, exp);
+            // Now we have to exclude the "stop" mimetypes (in the right direction!)
+            if (direction == KoFilterManager::Import) {
+                // Import: "stop" mime type should not appear in export
+                for (const QString & testIt : std::as_const((*it)->export_)) {
+                    if (!stopList.contains(testIt))
+                        expList.append(testIt);
                 }
-                // Then create the appropriate edges depending on the
-                // direction (import/export)
-                // This is the chunk of code which actually differs from the
-                // graph stuff (apart from the different vertex class)
-                importIt = impList.constBegin(); // ### TODO: why only the first one?
-                if (direction == KoFilterManager::Import) {
-                    for (; importIt != importEnd; ++importIt)
-                        exp->addEdge(vertices[(*importIt).toLatin1()]);
-                } else {
-                    for (; importIt != importEnd; ++importIt)
-                        vertices[(*importIt).toLatin1()]->addEdge(exp);
+                impList = (*it)->import_;
+            } else {
+                // Export: "stop" mime type should not appear in import
+                for (const QString & testIt : std::as_const((*it)->import_)) {
+                    if (!stopList.contains(testIt))
+                        impList.append(testIt);
+                }
+                expList = (*it)->export_;
+            }
+
+            if (impList.empty() || expList.empty()) {
+                // This filter cannot be used under these conditions
+                debugFilter << "Filter:" << (*it)->fileName() << " ruled out";
+                continue;
+            }
+
+            // First add the "starting points" to the dict
+            QStringList::ConstIterator importIt = impList.constBegin();
+            const QStringList::ConstIterator importEnd = impList.constEnd();
+            for (; importIt != importEnd; ++importIt) {
+                const QByteArray key = (*importIt).toLatin1();    // latin1 is okay here (werner)
+                // already there?
+                if (!vertices[ key ]) {
+                    debugFilter << "Filter: add start" <<key;
+                    vertices.insert(key, new Vertex(key));
                 }
             }
-        } else {
-            debugFilter << "Filter:" << (*it)->fileName() << " does not apply.";
+
+            // Are we allowed to use this filter at all?
+            if (KoFilterManager::filterAvailable(*it)) {
+                QStringList::ConstIterator exportIt = expList.constBegin();
+                const QStringList::ConstIterator exportEnd = expList.constEnd();
+                for (; exportIt != exportEnd; ++exportIt) {
+                    // First make sure the export vertex is in place
+                    const QByteArray key = (*exportIt).toLatin1();    // latin1 is okay here
+                    Vertex* exp = vertices[ key ];
+                    if (!exp) {
+                        exp = new Vertex(key);
+                        vertices.insert(key, exp);
+                    }
+                    // Then create the appropriate edges depending on the
+                    // direction (import/export)
+                    // This is the chunk of code which actually differs from the
+                    // graph stuff (apart from the different vertex class)
+                    importIt = impList.constBegin(); // ### TODO: why only the first one?
+                    if (direction == KoFilterManager::Import) {
+                        for (; importIt != importEnd; ++importIt) {
+                            debugFilter << "Filter: add edge" <<(*importIt);
+                            exp->addEdge(vertices[(*importIt).toLatin1()]);
+                        }
+                    } else {
+                        for (; importIt != importEnd; ++importIt)
+                            vertices[(*importIt).toLatin1()]->addEdge(exp);
+                    }
+                }
+            } else {
+                debugFilter << "Filter:" << (*it)->fileName() << " does not apply.";
+            }
         }
     }
 }
@@ -403,15 +403,15 @@ QStringList connected(const QHash<QByteArray, Vertex*>& vertices, const QByteArr
     while (!queue.empty()) {
         v = queue.front();
         queue.pop();
-        QList<Vertex*> edges = v->edges();
-        foreach(Vertex* current, edges) {
+        const QList<Vertex*> edges = v->edges();
+        for (Vertex* current : edges) {
             if (current->color() == Vertex::White) {
                 current->setColor(Vertex::Gray);
                 queue.push(current);
             }
         }
         v->setColor(Vertex::Black);
-        connected.append(v->mimeType());
+        connected.append(QString::fromLatin1(v->mimeType()));
     }
     return connected;
 }
@@ -424,26 +424,28 @@ QStringList KoFilterManager::mimeFilter(const QByteArray &mimetype, Direction di
     //debugFilter <<"mimetype=" << mimetype <<" extraNativeMimeTypes=" << extraNativeMimeTypes;
     QHash<QByteArray, Vertex*> vertices;
     buildGraph(vertices, direction);
-
     // TODO maybe use the fake vertex trick from the method below, to make the search faster?
 
     QStringList nativeMimeTypes;
-    nativeMimeTypes.append(QString::fromLatin1(mimetype));
+    if (!mimetype.isEmpty()) {
+        nativeMimeTypes.append(QString::fromLatin1(mimetype));
+    }
     nativeMimeTypes += extraNativeMimeTypes;
 
     // Add the native mimetypes first so that they are on top.
     QStringList lst = nativeMimeTypes;
 
     // Now look for filters which output each of those natives mimetypes
-    foreach(const QString &natit, nativeMimeTypes) {
+    for (const QString &natit : std::as_const(nativeMimeTypes)) {
         const QStringList outMimes = connected(vertices, natit.toLatin1());
-        //debugFilter <<"output formats connected to mime" << natit <<" :" << outMimes;
-        foreach(const QString &mit, outMimes) {
+        debugFilter <<"output formats connected to mime" << natit <<" :" << outMimes;
+        for (const QString &mit : outMimes) {
             if (!lst.contains(mit))     // append only if not there already. Qt4: QSet<QString>?
                 lst.append(mit);
         }
     }
-    foreach(Vertex* vertex, vertices) {
+    const auto list = vertices.values();
+    for (Vertex* vertex : list) {
         delete vertex;
     }
     vertices.clear();
@@ -471,12 +473,8 @@ QStringList KoFilterManager::mimeFilter()
     vertices.insert("supercalifragilistic/x-pialadocious", v);
     while (partIt != partEnd) {
         QJsonObject metaData = (*partIt).metaData();
-#ifdef CALLIGRA_OLD_PLUGIN_METADATA
-        QStringList nativeMimeTypes = metaData.value("X-KDE-ExtraNativeMimeTypes").toString().split(',');
-#else
-        QStringList nativeMimeTypes = metaData.value("X-KDE-ExtraNativeMimeTypes").toVariant().toStringList();
-#endif
-        nativeMimeTypes += metaData.value("X-KDE-NativeMimeType").toString();
+        QStringList nativeMimeTypes = metaData.value(QStringLiteral("X-KDE-ExtraNativeMimeTypes")).toVariant().toStringList();
+        nativeMimeTypes += metaData.value(QStringLiteral("X-KDE-NativeMimeType")).toString();
         QStringList::ConstIterator it = nativeMimeTypes.constBegin();
         const QStringList::ConstIterator end = nativeMimeTypes.constEnd();
         for (; it != end; ++it)
@@ -487,7 +485,7 @@ QStringList KoFilterManager::mimeFilter()
     QStringList result = connected(vertices, "supercalifragilistic/x-pialadocious");
 
     // Finally we have to get rid of our fake mimetype again
-    result.removeAll("supercalifragilistic/x-pialadocious");
+    result.removeAll(QStringLiteral("supercalifragilistic/x-pialadocious"));
     return result;
 }
 
@@ -497,7 +495,7 @@ bool KoFilterManager::filterAvailable(KoFilterEntry::Ptr entry)
 {
     if (!entry)
         return false;
-    if (entry->available != "check")
+    if (entry->available != QStringLiteral("check"))
         return true;
 
 // QT5TODO
@@ -525,7 +523,7 @@ bool KoFilterManager::filterAvailable(KoFilterEntry::Ptr entry)
         if (!sym) {
 //            warnFilter << "The library " << library.objectName()
 //                << " does not offer a check_" << library.objectName()
-//                << " function." << endl;
+//                << " function." << '\n';
             m_filterAvailable[key] = false;
         } else {
             typedef int (*t_func)();
@@ -541,7 +539,7 @@ void KoFilterManager::importErrorHelper(const QString& mimeType, const bool supp
 {
     QString tmp = i18n("Could not import file of type\n%1", mimeType);
     // ###### FIXME: use KLibLoader::lastErrorMessage() here
-    if (!suppressDialog) KMessageBox::error(0, tmp, i18n("Missing Import Filter"));
+    if (!suppressDialog) KMessageBox::error(nullptr, tmp, i18n("Missing Import Filter"));
 }
 
 void KoFilterManager::setBatchMode(const bool batch)
@@ -556,7 +554,7 @@ bool KoFilterManager::getBatchMode(void) const
 
 KoProgressUpdater* KoFilterManager::progressUpdater() const
 {
-    return 0;
+    return nullptr;
 //     if (d->progressUpdater.isNull()) {
 //         // somebody, probably its parent, deleted our progress updater for us
 //         return 0;
