@@ -1,21 +1,8 @@
 /* This file is part of the KDE project
-   Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
-   Copyright (C) 2000-2004 David Faure <faure@kde.org>
+   SPDX-FileCopyrightText: 1998, 1999 Torben Weis <weis@kde.org>
+   SPDX-FileCopyrightText: 2000-2004 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KOMAINWINDOW_H
@@ -23,7 +10,7 @@
 
 #include "komain_export.h"
 
-#include <kxmlguiwindow.h>
+#include <KXmlGuiWindow>
 //#include <KoCanvasObserverBase.h>
 //#include <KoCanvasSupervisor.h>
 
@@ -49,8 +36,6 @@ class QUrl;
  * This class is used to represent a main window
  * of a Calligra component. Each main window contains
  * a menubar and some toolbars.
- *
- * @note This class does NOT need to be subclassed in your application.
  */
 class KOMAIN_EXPORT KoMainWindow : public KXmlGuiWindow//, public KoCanvasSupervisor
 {
@@ -77,7 +62,7 @@ public:
      * Called when a document is assigned to this mainwindow.
      * This creates a view for this document, makes it the active part, etc.
      */
-    void setRootDocument(KoDocument *doc, KoPart *part = 0, bool deletePrevious = true);
+    virtual void setRootDocument(KoDocument *doc, KoPart *part = nullptr, bool deletePrevious = true);
 
     /**
      * This is used to handle the document used at start up before it actually
@@ -85,12 +70,6 @@ public:
      */
     void setPartToOpen(KoPart *part);
 
-    /**
-     * Update caption from document info - call when document info
-     * (title in the about page) changes.
-     */
-    void updateCaption();
-
     KoComponentData componentData() const;
     void setComponentData(const KoComponentData &componentData);
 
@@ -100,17 +79,6 @@ public:
     KoDocument *rootDocument() const;
     KoView *rootView() const;
 
-    /**
-     * The application should call this to show or hide a toolbar.
-     * It also takes care of the corresponding action in the settings menu.
-     */
-    void showToolbar(const char * tbName, bool shown);
-
-    /**
-     * @return TRUE if the toolbar @p tbName is visible
-     */
-    bool toolbarIsVisible(const char *tbName);
-
     /**
      * Sets the maximum number of recent documents entries.
      */
@@ -121,6 +89,9 @@ public:
      */
     void addRecentURL(const QString &projectName, const QUrl &url);
 
+    void setRecentFilesGroupName(const QString &name);
+    QString recentFilesGroupName() const;
+
     /**
      * Load the desired document and show it.
      * @param url the URL to open
@@ -140,6 +111,10 @@ public:
      * Reloads the recent documents list.
      */
     void reloadRecentFileList();
+    KRecentFilesAction *recentAction() const;
+
+
+    virtual bool isDocumentModified();
 
     /**
      * Updates the window caption based on the document info and path.
@@ -162,10 +137,7 @@ public:
 
 //    QList<KoCanvasObserverBase*> canvasObservers() const;
 
-    /**
-     * Create a new empty document.
-     */
-    KoPart* createPart() const;
+    void setBlockClose(bool value);
 
 Q_SIGNALS:
     /**
@@ -196,6 +168,10 @@ Q_SIGNALS:
     void configure(KoMainWindow *mw);
 
 public Q_SLOTS:
+    /**
+     * Update caption from document info.
+     */
+    void updateCaption();
 
     /**
      * Slot for eMailing the document using KMail
@@ -244,6 +220,7 @@ public Q_SLOTS:
      */
     void slotFilePrint();
     void slotFilePrintPreview();
+    KoPrintJob* printPreviewToPdf();
 
     KoPrintJob* exportToPdf(const QString &pdfFileName);
     KoPrintJob* exportToPdf();
@@ -326,6 +303,19 @@ public Q_SLOTS:
     void toggleDockersVisibility(bool visible);
 
     /**
+     * Saves the document by calling saveDocumentInternal()
+     *
+     * @see saveDocumentInternal()
+     */
+    bool saveDocument(bool saveas = false, bool silent = false, int specialOutputFlag = 0);
+
+    void slotConfigure();
+
+protected:
+    /**
+     * Re-implemnt if you need special handling.
+     *
+     * By default:
      * Saves the document, asking for a filename if necessary.
      *
      * @param saveas if set to TRUE the user is always prompted for a filename
@@ -338,23 +328,32 @@ public Q_SLOTS:
      *         (don't display anything in this case, the error dialog box is also implemented here
      *         but restore the original URL in slotFileSaveAs)
      */
-    bool saveDocument(bool saveas = false, bool silent = false, int specialOutputFlag = 0);
+    virtual bool saveDocumentInternal(bool saveas, bool silent, int specialOutputFlag);
 
-    void slotConfigure();
+public Q_SLOTS:
+    /**
+     * Save the list of recent files.
+     */
+    void saveRecentFiles();
 
-private:
+    void slotLoadCompleted();
+    void slotLoadCanceled(const QString &);
+    void slotSaveCompleted();
+    void slotSaveCanceled(const QString &);
+    void forceDockTabFonts();
 
     /**
-     * This setting indicates who is calling chooseNewDocument.
-     * Usually the app will want to
-     * - show the template dialog with 'everything' if InitDocAppStarting, InitDocFileClose or InitDocEmbedded
-     * - show the template dialog with 'templates only' if InitDocFileNew
-     * - create an empty document with default settings if InitDocEmpty
+     * Slot to create a new view for the currently activate @ref #koDocument.
      */
-    enum InitDocFlags { /*InitDocAppStarting, */ InitDocFileNew, InitDocFileClose /*, InitDocEmbedded, InitDocEmpty*/ };
+    virtual void newView();
 
-    /// Helper method for slotFileNew and slotFileClose
-    void chooseNewDocument(InitDocFlags initDocFlags);
+    void slotPrintPreviewPaintRequest(QPrinter *printer);
+
+private:
+    /**
+     * Create a new empty document.
+     */
+    KoPart* createPart() const;
 
     void closeEvent(QCloseEvent * e) override;
     void resizeEvent(QResizeEvent * e) override;
@@ -364,7 +363,10 @@ private:
      */
     bool queryClose() override;
 
-    bool openDocumentInternal(const QUrl &url, KoPart *newpart = 0, KoDocument *newdoc = 0);
+    enum InitDocFlags { InitOnFileNew, InitOnFileClose };
+    KoPart *chooseNewDocument(InitDocFlags init);
+
+    bool openDocumentInternal(const QUrl &url, KoPart *newpart = nullptr, KoDocument *newdoc = nullptr);
 
     /**
      * Returns whether or not the current slotFileSave[As]() or saveDocument()
@@ -386,27 +388,6 @@ private:
      */
     bool isImporting() const;
 
-    KRecentFilesAction *recentAction() const;
-
-private Q_SLOTS:
-    /**
-     * Save the list of recent files.
-     */
-    void saveRecentFiles();
-
-    void slotLoadCompleted();
-    void slotLoadCanceled(const QString &);
-    void slotSaveCompleted();
-    void slotSaveCanceled(const QString &);
-    void forceDockTabFonts();
-
-    /**
-     * Slot to create a new view for the currently activate @ref #koDocument.
-     */
-    virtual void newView();
-
-    void slotPrintPreviewPaintRequest(QPrinter *printer);
-
 // ---------------------  PartManager
 private:
 
