@@ -1,21 +1,8 @@
 /* This file is part of the KDE project
- * Copyright (C) 2007, 2009 Thomas Zander <zander@kde.org>
- * Copyright (C) 2011 Boudewijn Rempt <boud@kde.org>
+ * SPDX-FileCopyrightText: 2007, 2009 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2011 Boudewijn Rempt <boud@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 // clazy:excludeall=qstring-arg
 #include "KoPrintingDialog.h"
@@ -29,7 +16,7 @@
 
 #include <QApplication>
 #include <MainDebug.h>
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 #include <QPainter>
 #include <QPrinter>
 #include <QGridLayout>
@@ -95,7 +82,7 @@ void KoPrintingDialog::setPageRange(const QList<int> &pages)
 
 QPainter & KoPrintingDialog::painter() const
 {
-    if (d->painter == 0) {
+    if (d->painter == nullptr) {
         d->painter = new QPainter(d->printer);
         d->painter->save(); // state before page preparation (3)
     }
@@ -107,7 +94,7 @@ bool KoPrintingDialog::isStopped() const
     return d->stop;
 }
 
-// Define a printer friendly palette
+// Define a printer fri'\n'y palette
 #define VeryLightGray   "#f8f8f8"
 #define LightLightGray  "#f0f0f0"
 #define DarkDarkGray    "#b3b3b3"
@@ -121,7 +108,7 @@ public:
         palette.setColor(QPalette::Window, Qt::white);
         palette.setColor(QPalette::WindowText, Qt::black);
         palette.setColor(QPalette::Base, Qt::white);
-        palette.setColor(QPalette::AlternateBase, VeryLightGray);
+        palette.setColor(QPalette::AlternateBase, VeryLightGray); // clazy:exclude=qcolor-from-literal
         palette.setColor(QPalette::ToolTipBase, Qt::white);
         palette.setColor(QPalette::ToolTipText, Qt::black);
         palette.setColor(QPalette::Text, Qt::black);
@@ -131,10 +118,10 @@ public:
         palette.setColor(QPalette::Link, Qt::blue);
         palette.setColor(QPalette::Highlight, Qt::blue);
         palette.setColor(QPalette::HighlightedText, Qt::white);
-        palette.setColor(QPalette::Light, QColor(VeryLightGray));
-        palette.setColor(QPalette::Midlight, QColor(LightLightGray)); // used for freeDays in gantt chart
-        palette.setColor(QPalette::Dark, QColor(DarkDarkGray));
-        palette.setColor(QPalette::Mid, QColor(VeryDarkGray));
+        palette.setColor(QPalette::Light, QColor(VeryLightGray)); // clazy:exclude=qcolor-from-literal
+        palette.setColor(QPalette::Midlight, QColor(LightLightGray)); // used for freeDays in gantt chart // clazy:exclude=qcolor-from-literal
+        palette.setColor(QPalette::Dark, QColor(DarkDarkGray)); // clazy:exclude=qcolor-from-literal
+        palette.setColor(QPalette::Mid, QColor(VeryDarkGray)); // clazy:exclude=qcolor-from-literal
         palette.setColor(QPalette::Shadow, Qt::black);
         QApplication::setPalette(palette);
     }
@@ -178,7 +165,7 @@ void KoPrintingDialog::startPrinting(RemovePolicy removePolicy)
             d->dialog->show();
         d->stop = false;
         delete d->painter;
-        d->painter = 0;
+        d->painter = nullptr;
 //        d->zoomer.setZoom(1.0);
 //        d->zoomer.setDpi(d->printer->resolution(), d->printer->resolution());
 
@@ -187,15 +174,15 @@ void KoPrintingDialog::startPrinting(RemovePolicy removePolicy)
         }
         d->progress->start(100, i18n("Printing"));
 
-        if (d->printer->numCopies() > 1) {
-            QList<int> oldPages = d->pages;
+        if (d->printer->copyCount() > 1) {
+            const QList<int> oldPages = d->pages;
             if (d->printer->collateCopies()) { // means we print whole doc at once
-                for (int count = 1; count < d->printer->numCopies(); ++count)
+                for (int count = 1; count < d->printer->copyCount(); ++count)
                     d->pages.append(oldPages);
             } else {
                 d->pages.clear();
-                foreach (int page, oldPages) {
-                    for (int count = 1; count < d->printer->numCopies(); ++count)
+                for (int page : oldPages) {
+                    for (int count = 1; count < d->printer->copyCount(); ++count)
                         d->pages.append(page);
                 }
             }
@@ -213,7 +200,7 @@ void KoPrintingDialog::startPrinting(RemovePolicy removePolicy)
         PrintPalette p;
 
         d->resetValues();
-        foreach (int page, d->pages) {
+        for (int page : std::as_const(d->pages)) {
             d->index++;
             d->updaters.append(d->progress->startSubtask()); // one per page
             d->preparePage(page);
@@ -223,7 +210,6 @@ void KoPrintingDialog::startPrinting(RemovePolicy removePolicy)
             }
             
         }
-        d->painter->end();
         if (blocking) {
             printingDone();
         }
