@@ -1,28 +1,15 @@
 /* This file is part of the KDE project
-   Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
-   Copyright (C) 2007 Thomas Zander <zander@kde.org>
-   Copyright (C) 2010 Benjamin Port <port.benjamin@gmail.com>
+   SPDX-FileCopyrightText: 1998, 1999 Torben Weis <weis@kde.org>
+   SPDX-FileCopyrightText: 2007 Thomas Zander <zander@kde.org>
+   SPDX-FileCopyrightText: 2010 Benjamin Port <port.benjamin@gmail.com>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #ifndef __koView_h__
 #define __koView_h__
 
 #include <QWidget>
-#include <kxmlguiclient.h>
+#include <KXMLGUIClient>
 #include "komain_export.h"
 
 class KoPart;
@@ -56,12 +43,29 @@ public:
      *
      * The standard way to retrieve a KoView is to call KoPart::createView.
      *
+     * Note: Does not add global actions to this view.
+     *
      * @param part     KoPart
      * @param document is the document which should be displayed in this view. This pointer
      *                 must not be zero.
      * @param parent   parent widget for this view.
      */
-    KoView(KoPart *part, KoDocument *document, QWidget *parent = 0);
+    KoView(KoPart *part, KoDocument *document, QWidget *parent = nullptr);
+
+    /**
+     * Creates a new view for the document. Usually you don't create views yourself
+     * since the Calligra components come with their own view classes which inherit
+     * KoView.
+     *
+     * The standard way to retrieve a KoView is to call KoPart::createView.
+     *
+     * @param part     KoPart
+     * @param document is the document which should be displayed in this view. This pointer
+     *                 must not be zero.
+     * @param parent   parent widget for this view.
+     * @param setupGlobalActions If true global actions are added to this view.
+     */
+    KoView(KoPart *part, KoDocument *document, bool setupGlobalActions, QWidget *parent = nullptr);
 
     /**
      * Destroys the view and unregisters at the document.
