@@ -1,22 +1,9 @@
 /*  -*- C++ -*-
     This file is part of the KDE libraries
-    Copyright (C) 1997 Tim D. Gilman (tdgilman@best.org)
-              (C) 1998-2001 Mirko Boehm (mirko@kde.org)
-              (C) 2007 John Layt <john@layt.net>
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-FileCopyrightText: 1997 Tim D. Gilman (tdgilman@best.org)
+              SPDX-FileCopyrightText: 1998-2001 Mirko Boehm (mirko@kde.org)
+              SPDX-FileCopyrightText: 2007 John Layt <john@layt.net>
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 // clazy:excludeall=qstring-arg
@@ -25,10 +12,10 @@
 #include "kdatepicker.h"
 #include "kptdebug.h"
 
-#include <kconfig.h>
+#include <KConfig>
 #include <knotification.h>
-#include <kstandardshortcut.h>
-#include <kactioncollection.h>
+#include <KStandardShortcut>
+#include <KActionCollection>
 
 #include <QLocale>
 #include <QFontDatabase>
@@ -55,7 +42,7 @@ public:
         m_selectionmode = KDateTable::SingleSelection;
         m_paintweeknumbers = false;
         m_hoveredPos = -1;
-        m_model = 0;
+        m_model = nullptr;
         m_grid = false;
     }
 
@@ -254,27 +241,27 @@ void KDateTable::initAccels()
   KActionCollection* localCollection = new KActionCollection(this);
   localCollection->addAssociatedWidget(this);
 
-  QAction* next = localCollection->addAction(QLatin1String("next"));
+  QAction* next = localCollection->addAction(QStringLiteral("next"));
   next->setShortcuts(KStandardShortcut::next());
   connect(next, SIGNAL(triggered(bool)), SLOT(nextMonth()));
 
-  QAction* prior = localCollection->addAction(QLatin1String("prior"));
+  QAction* prior = localCollection->addAction(QStringLiteral("prior"));
   prior->setShortcuts(KStandardShortcut::prior());
   connect(prior, SIGNAL(triggered(bool)), SLOT(previousMonth()));
 
-  QAction* beginMonth = localCollection->addAction(QLatin1String("beginMonth"));
+  QAction* beginMonth = localCollection->addAction(QStringLiteral("beginMonth"));
   beginMonth->setShortcuts(KStandardShortcut::home());
   connect(beginMonth, SIGNAL(triggered(bool)), SLOT(beginningOfMonth()));
 
-  QAction* endMonth = localCollection->addAction(QLatin1String("endMonth"));
+  QAction* endMonth = localCollection->addAction(QStringLiteral("endMonth"));
   endMonth->setShortcuts(KStandardShortcut::end());
   connect(endMonth, SIGNAL(triggered(bool)), SLOT(endOfMonth()));
 
-  QAction* beginWeek = localCollection->addAction(QLatin1String("beginWeek"));
+  QAction* beginWeek = localCollection->addAction(QStringLiteral("beginWeek"));
   beginWeek->setShortcuts(KStandardShortcut::beginningOfLine());
   connect(beginWeek, SIGNAL(triggered(bool)), SLOT(beginningOfWeek()));
 
-  QAction* endWeek = localCollection->addAction("endWeek");
+  QAction* endWeek = localCollection->addAction(QStringLiteral("endWeek"));
   endWeek->setShortcuts(KStandardShortcut::endOfLine());
   connect(endWeek, SIGNAL(triggered(bool)), SLOT(endOfWeek()));
 
@@ -425,7 +412,7 @@ void KDateTable::paintCell(QPainter *painter, int row, int column)
                 }
             }
             KDateTableDateDelegate *del = d->customPaintingModes.value(pCellDate.toJulianDay());
-            if (del == 0) {
+            if (del == nullptr) {
                 del = d->m_dateDelegate;
             }
             if (del) {
@@ -518,7 +505,7 @@ void KDateTable::keyPressEvent(QKeyEvent *e)
         break;
     case Qt::Key_Return:
     case Qt::Key_Enter:
-        emit tableClicked();
+        Q_EMIT tableClicked();
         break;
     case Qt::Key_Control:
     case Qt::Key_Alt:
@@ -574,10 +561,10 @@ void KDateTable::keyPressEvent(QKeyEvent *e)
         {
             QMenu *menu = new QMenu();
             if (d->m_selectionmode == ExtendedSelection) {
-                emit aboutToShowContextMenu(menu, d->m_selectedDates);
+                Q_EMIT aboutToShowContextMenu(menu, d->m_selectedDates);
             } else {
                 menu->setTitle(QLocale().toString(d->m_date, QLocale::ShortFormat));
-                emit aboutToShowContextMenu(menu, d->m_date);
+                Q_EMIT aboutToShowContextMenu(menu, QList<QDate>()<<d->m_date);
             }
             if (menu->isEmpty()) {
                 delete menu;
@@ -621,7 +608,7 @@ void KDateTable::setFontSize(int size)
 
 void KDateTable::wheelEvent (QWheelEvent * e)
 {
-    setDate(d->m_date.addMonths(-(int)(e->delta()/120)));
+    setDate(d->m_date.addMonths(-(int)(e->angleDelta().y()/120)));
     e->accept();
 }
 
@@ -630,12 +617,12 @@ bool KDateTable::event(QEvent *ev)
     switch (ev->type()) {
     case QEvent::HoverMove: {
         QHoverEvent *e = static_cast<QHoverEvent *>(ev);
-        const int row = e->pos().y() * 7 / height();
+        const int row = e->position().toPoint().y() * 7 / height();
         int col;
         if (layoutDirection() == Qt::RightToLeft) {
-            col = (d->m_paintweeknumbers ? 8 : 7) - (e->pos().x() * (d->m_paintweeknumbers ? 8 : 7) / width()) - 1;
+            col = (d->m_paintweeknumbers ? 8 : 7) - (e->position().toPoint().x() * (d->m_paintweeknumbers ? 8 : 7) / width()) - 1;
         } else {
-            col = e->pos().x() * (d->m_paintweeknumbers ? 8 : 7) / width();
+            col = e->position().toPoint().x() * (d->m_paintweeknumbers ? 8 : 7) / width();
         }
 
         const int pos = row < 1 ? -1 : ((d->m_paintweeknumbers ? 8 : 7) * (row - 1)) + col;
@@ -797,7 +784,7 @@ void KDateTable::mousePressEvent(QMouseEvent *e)
                 d->m_selectedDates.clear();
                 d->m_selectedDates << clickedDate;
             }
-            emit selectionChanged(d->m_selectedDates);
+            Q_EMIT selectionChanged(d->m_selectedDates);
             break;
         default: break;
     }
@@ -812,17 +799,17 @@ void KDateTable::mousePressEvent(QMouseEvent *e)
     // much here
     update();
   }
-  emit tableClicked();
+  Q_EMIT tableClicked();
 
   if (e->button() == Qt::RightButton && d->m_popupMenuEnabled) {
         QMenu *menu = new QMenu();
         if (d->m_selectionmode == ExtendedSelection) {
-            emit aboutToShowContextMenu(menu, d->m_selectedDates);
+            Q_EMIT aboutToShowContextMenu(menu, d->m_selectedDates);
         } else {
             menu->setTitle(QLocale().toString(clickedDate, QLocale::ShortFormat));
-            emit aboutToShowContextMenu(menu, clickedDate);
+            Q_EMIT aboutToShowContextMenu(menu, QList<QDate>()<<clickedDate);
         }
-        menu->popup(e->globalPos());
+        menu->popup(e->globalPosition().toPoint());
   }
 }
 
@@ -840,15 +827,14 @@ bool KDateTable::setDate(const QDate& date_)
             QDate dt(date_.year(), date_.month(), 1);
             d->m_weekDayFirstOfMonth = dt.dayOfWeek();
         }
-        emit dateChanged(oldDate, date_);
-        emit dateChanged(date_);
+        Q_EMIT dateChanged(date_, oldDate);
     }
 
     if (d->m_selectionmode == KDateTable::SingleSelection)
     {
         d->m_selectedDates.clear();
         d->m_selectedDates << date_;
-        emit selectionChanged(d->m_selectedDates);
+        Q_EMIT selectionChanged(d->m_selectedDates);
     }
 
     update();
@@ -954,7 +940,7 @@ KDateTableDateDelegate::KDateTableDateDelegate(QObject *parent)
 QVariant KDateTableDateDelegate::data(const QDate &date, int role, KDateTableDataModel *model)
 {
     //debugPlan<<date<<role<<model;
-    if (model == 0) {
+    if (model == nullptr) {
         return QVariant();
     }
     return model->data(date, role);
@@ -1053,7 +1039,6 @@ QRectF KDateTableCustomDateDelegate::paint(QPainter *painter, const StyleOptionV
 
     QRectF r;
     bool paintRect=true;
-    QBrush bg(option.palette.base());
 
     if((option.state & QStyle::State_Active) == 0)
     { // we are either
@@ -1103,8 +1088,8 @@ QRectF KDateTableCustomDateDelegate::paint(QPainter *painter, const StyleOptionV
       }
       else
       {
-        painter->setBrush(option.palette.color(QPalette::Background));
-        painter->setPen(option.palette.color(QPalette::Background));
+        painter->setBrush(option.palette.color(QPalette::Window));
+        painter->setPen(option.palette.color(QPalette::Window));
       }
 
       if (date == QDate::currentDate())
@@ -1141,7 +1126,7 @@ KDateTableWeekDayDelegate::KDateTableWeekDayDelegate(QObject *parent)
 QVariant KDateTableWeekDayDelegate::data(int day, int role, KDateTableDataModel *model)
 {
     //debugPlan<<day<<role<<model;
-    if (model == 0) {
+    if (model == nullptr) {
         return QVariant();
     }
     return model->weekDayData(day, role);
@@ -1200,7 +1185,7 @@ KDateTableWeekNumberDelegate::KDateTableWeekNumberDelegate(QObject *parent)
 QVariant KDateTableWeekNumberDelegate::data(int week, int role, KDateTableDataModel *model)
 {
     //debugPlan<<week<<role<<model;
-    if (model == 0) {
+    if (model == nullptr) {
         return QVariant();
     }
     return model->weekNumberData(week, role);
@@ -1222,7 +1207,7 @@ QRectF KDateTableWeekNumberDelegate::paint(QPainter *painter, const StyleOptionH
     painter->drawRect(option.rectF);
     painter->setPen(textColor);
 
-    QString value = QString("%1").arg(week);
+    QString value = QStringLiteral("%1").arg(week);
     if (model) {
         QVariant v = model->weekNumberData(week, Qt::DisplayRole);
         if (v.isValid()) {
