@@ -1,27 +1,12 @@
 /* This file is part of the KDE project
-  Copyright (C) 2009, 2011 Dag Andersen <danders@get2net.dk>
+  SPDX-FileCopyrightText: 2009, 2011 Dag Andersen <dag.andersen@kdemail.net>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version..
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-* Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 // clazy:excludeall=qstring-arg
 #include "kptcommonstrings.h"
 
-#include <kundo2magicstring.h>
-
 #include <KLocalizedString>
 
 namespace KPlato
@@ -38,7 +23,7 @@ namespace KPlato
     QString ToolTip::nodeWBS() { return xi18nc("@info:tooltip", "Work Breakdown Structure Code"); }
     QString ToolTip::nodeLevel() { return xi18nc("@info:tooltip", "Node level"); }
     QString ToolTip::nodeRisk() { return xi18nc("@info:tooltip", "Risk controls the PERT distribution used when calculating the actual estimate for this task"); }
-    QString ToolTip::nodePriority() { return xi18nc("@info:tooltip", "Scheduling priority.<nl/><note>Atm. only the <emphasis>TJ Scheduler</emphasis> supports priority.</note>"); }
+    QString ToolTip::nodePriority() { return xi18nc("@info:tooltip", "Scheduling priority.<nl/>A higher number means higher priority."); }
     QString ToolTip::nodeRunningAccount() { return xi18nc("@info:tooltip", "Account for running costs"); }
     QString ToolTip::nodeStartupAccount() { return xi18nc("@info:tooltip", "Account for cost incurred at startup of the task"); }
     QString ToolTip::nodeStartupCost() { return xi18nc("@info:tooltip", "The cost incurred at startup of the task"); }
@@ -111,9 +96,9 @@ namespace KPlato
     QString ToolTip::nodeACWP() { return xi18nc("@info:tooltip", "Actual Cost of Work Performed"); }
     QString ToolTip::nodePerformanceIndex() { return i18n("Schedule performance index (BCWP/BCWS)"); }
 
-    QString ToolTip::resourceName() { return xi18nc("@info:tooltip", "The name of the resource or resource group"); }
-    QString ToolTip::resourceScope() { return xi18nc("@info:tooltip", "The scope of the resource or resource group"); }
-    QString ToolTip::resourceType() { return xi18nc("@info:tooltip", "The type of the resource or resource group"); }
+    QString ToolTip::resourceName() { return xi18nc("@info:tooltip", "The name of the resource"); }
+    QString ToolTip::resourceOrigin() { return xi18nc("@info:tooltip", "The origin of the resource"); }
+    QString ToolTip::resourceType() { return xi18nc("@info:tooltip", "The type of the resource"); }
     QString ToolTip::resourceInitials() { return xi18nc("@info:tooltip", "The initials of the resource"); }
     QString ToolTip::resourceEMail() { return xi18nc("@info:tooltip", "The e-mail address of the resource"); }
     QString ToolTip::resourceCalendar() { return xi18nc("@info:tooltip", "The calendar defines when the resource is working"); }
@@ -125,6 +110,12 @@ namespace KPlato
     QString ToolTip::resourceFixedCost() { return xi18nc("@info:tooltip", "The fixed cost"); }
     QString ToolTip::resourceAccount() { return xi18nc("@info:tooltip", "The account where the resource cost is accumulated"); }
 
+    QString ToolTip::resourceGroupName() { return xi18nc("@info:tooltip", "The name of the resource group"); }
+    QString ToolTip::resourceGroupOrigin() { return xi18nc("@info:tooltip", "The origin of the resource group"); }
+    QString ToolTip::resourceGroupType() { return xi18nc("@info:tooltip", "The type of the resource group"); }
+    QString ToolTip::resourceGroupUnits() { return xi18nc("@info:tooltip", "The aggregated units for the resources in the resource group"); }
+    QString ToolTip::resourceGroupCoordinator() { return xi18nc("@info:tooltip", "The coordinator of the resource group"); }
+
     QString ToolTip::accountName() { return xi18nc("@info:tooltip", "The name of the account"); }
     QString ToolTip::accountDescription() { return xi18nc("@info:tooltip", "The description of the account"); }
 
@@ -190,9 +181,5 @@ namespace KPlato
     QString ToolTip::relationType() { return xi18nc("@info:tooltip", "The type of relation"); }
     QString ToolTip::relationLag() { return xi18nc("@info:tooltip", "The relations time lag"); }
 
-
-    // Work around string freeze
-    KUndo2MagicString UndoText::removeDocument() { return kundo2_i18n("Remove document"); }
-
 } //namespace KPlato
 
