@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
-  Copyright (C) 2006 - 2007, 2012 Dag Andersen <danders@get2net.dk>
+  SPDX-FileCopyrightText: 2006-2007, 2012 Dag Andersen <dag.andersen@kdemail.net>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-* Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 // clazy:excludeall=qstring-arg
@@ -23,8 +10,7 @@
 #include "kptproject.h"
 #include "kptschedule.h"
 #include "kptdurationspinbox.h"
-#include "kptresourcemodel.h"
-#include "kptresourceallocationmodel.h"
+#include "kptnodeitemmodel.h"
 #include "kptdebug.h"
 
 #include <QApplication>
@@ -51,12 +37,11 @@
 #include <KoXmlWriter.h>
 #include <KoOdfWriteStore.h>
 
-#include <kcombobox.h>
-#include <klineedit.h>
+#include <KComboBox>
+#include <KLineEdit>
+#include <KLocalizedString>
 
-
-namespace KPlato
-{
+using namespace KPlato;
 
 //--------------------------------------
 bool ItemDelegate::eventFilter(QObject *object, QEvent *event)
@@ -72,23 +57,23 @@ bool ItemDelegate::eventFilter(QObject *object, QEvent *event)
             switch (e->key()) {
                 case Qt::Key_Left:
                     m_lastHint = Delegate::EditLeftItem;
-                    emit commitData(editor);
-                    emit closeEditor(editor, QAbstractItemDelegate::NoHint);
+                    Q_EMIT commitData(editor);
+                    Q_EMIT closeEditor(editor, QAbstractItemDelegate::NoHint);
                     return true;
                 case Qt::Key_Right:
                     m_lastHint = Delegate::EditRightItem;
-                    emit commitData(editor);
-                    emit closeEditor(editor, QAbstractItemDelegate::NoHint);
+                    Q_EMIT commitData(editor);
+                    Q_EMIT closeEditor(editor, QAbstractItemDelegate::NoHint);
                     return true;
                 case Qt::Key_Down:
                     m_lastHint = Delegate::EditDownItem;
-                    emit commitData(editor);
-                    emit closeEditor(editor, QAbstractItemDelegate::NoHint);
+                    Q_EMIT commitData(editor);
+                    Q_EMIT closeEditor(editor, QAbstractItemDelegate::NoHint);
                     return true;
                 case Qt::Key_Up:
                     m_lastHint = Delegate::EditUpItem;
-                    emit commitData(editor);
-                    emit closeEditor(editor, QAbstractItemDelegate::NoHint);
+                    Q_EMIT commitData(editor);
+                    Q_EMIT closeEditor(editor, QAbstractItemDelegate::NoHint);
                     return true;
                 default:
                     break;
@@ -100,7 +85,7 @@ bool ItemDelegate::eventFilter(QObject *object, QEvent *event)
 
 QSize ItemDelegate::sizeHint(const QStyleOptionViewItem & option, const QModelIndex & index) const
 {
-    // Decoration (like basline icon) increases height so check height of column 0 in case...
+    // Decoration (like baseline icon) increases height so check height of column 0 in case...
     QSize s = QStyledItemDelegate::sizeHint(option, index);
     return QSize(s.width(), qMax(s.height(), QStyledItemDelegate::sizeHint(option, index.sibling(index.row(), 0)).height()));
 }
@@ -134,7 +119,7 @@ bool CheckStateItemDelegate::editorEvent(QEvent *event, QAbstractItemModel *mode
     if ((event->type() == QEvent::MouseButtonRelease) || (event->type() == QEvent::MouseButtonDblClick) || (event->type() == QEvent::MouseButtonPress)) {
         QStyleOptionViewItem viewOpt(option);
         initStyleOption(&viewOpt, index);
-        QRect checkRect = style->subElementRect(QStyle::SE_ItemViewItemDecoration, &viewOpt, 0);
+        QRect checkRect = style->subElementRect(QStyle::SE_ItemViewItemDecoration, &viewOpt, nullptr);
         QMouseEvent *me = static_cast<QMouseEvent*>(event);
         if (me->button() != Qt::LeftButton || ! checkRect.contains(me->pos())) {
             return false;
@@ -205,58 +190,46 @@ ProgressBarDelegate::~ProgressBarDelegate()
 void ProgressBarDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option,
  const QModelIndex &index) const
 {
-    QStyle *style;
+    auto style = option.widget ? option.widget->style() : QApplication::style();
 
-    QStyleOptionViewItem opt = option;
-    initStyleOption(&opt, index);
+    // draw background
+    style->drawPrimitive(QStyle::PE_PanelItemViewItem, &option, painter);
 
-    style = opt.widget ? opt.widget->style() : QApplication::style();
-    style->drawPrimitive(QStyle::PE_PanelItemViewItem, &opt, painter);
-
-    if (!(opt.state & QStyle::State_Editing)) {
-        bool ok = false;
-        (void) index.data().toInt(&ok);
-        if (ok) {
+    bool ok;
+    index.data().toInt(&ok);
+    if (ok) {
+        // only draw progress bar if a valid int is returned and
+        const auto idx = index.siblingAtColumn(NodeModel::NodeStatus);
+        int state = idx.data(Qt::EditRole).toInt();
+        if (state & Node::State_NotReadyToStart || state & Node::State_NotScheduled) {
+            QStyleOptionViewItem opt = option;
+            initStyleOption(&opt, index);
+            opt.text = idx.data().toString();
+            style->drawControl(QStyle::CE_ItemViewItem, &opt, painter, opt.widget);
+        } else {
             QStyleOptionProgressBar pbOption;
             pbOption.QStyleOption::operator=(option);
             initStyleOptionProgressBar(&pbOption, index);
-
             style->drawControl(QStyle::CE_ProgressBar, &pbOption, painter);
-            // Draw focus, copied from qt
-            if (opt.state & QStyle::State_HasFocus) {
-                painter->save();
-                QStyleOptionFocusRect o;
-                o.QStyleOption::operator=(opt);
-                o.rect = style->subElementRect(QStyle::SE_ItemViewItemFocusRect, &opt, opt.widget);
-                o.state |= QStyle::State_KeyboardFocusChange;
-                o.state |= QStyle::State_Item;
-                QPalette::ColorGroup cg = (opt.state & QStyle::State_Enabled)
-                                ? QPalette::Normal : QPalette::Disabled;
-                o.backgroundColor = opt.palette.color(cg, (opt.state & QStyle::State_Selected)
-                                                ? QPalette::Highlight : QPalette::Window);
-                style->drawPrimitive(QStyle::PE_FrameFocusRect, &o, painter, opt.widget);
-                //debugPlan<<"Focus"<<o.rect<<opt.rect<<pbOption.rect;
-                painter->restore();
-            }
-        } else {
-            EnumDelegate del;
-            del.paint(painter, option, index);
         }
+    } else {
+        // draw the returned text (if any)
+        QStyleOptionViewItem opt = option;
+        initStyleOption(&opt, index);
+        opt.text = index.data().toString();
+        style->drawControl(QStyle::CE_ItemViewItem, &opt, painter, opt.widget);
     }
 }
 
 QSize ProgressBarDelegate::sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
-    QStyleOptionViewItem opt = option;
-    //  initStyleOption(&opt, index);
-
-    QStyle *style = opt.widget ? opt.widget->style() : QApplication::style();
+    QStyle *style = option.widget ? option.widget->style() : QApplication::style();
 
     QStyleOptionProgressBar pbOption;
     pbOption.QStyleOption::operator=(option);
     initStyleOptionProgressBar(&pbOption, index);
 
-    return style->sizeFromContents(QStyle::CT_ProgressBar, &pbOption, QSize(), opt.widget);
+    return style->sizeFromContents(QStyle::CT_ProgressBar, &pbOption, QSize(), option.widget);
 }
 
 void ProgressBarDelegate::initStyleOptionProgressBar(QStyleOptionProgressBar *option, const QModelIndex &index) const
@@ -266,14 +239,17 @@ void ProgressBarDelegate::initStyleOptionProgressBar(QStyleOptionProgressBar *op
     int max = index.data(Role::Maximum).toInt();
     option->maximum = max > option->minimum ? max : option->minimum + 100;
     option->progress = index.data().toInt();
-    option->text = QString::number((option->progress * 100) / (option->maximum - option->minimum)) + QLatin1Char('%');
-    option->textAlignment = Qt::AlignCenter;
+    option->text = i18nc("task progress", "%1%", (option->progress * 100) / (option->maximum - option->minimum));
+    option->textAlignment = Qt::AlignCenter; // TODO find out why this does not work
     option->textVisible = true;
+    option->state.setFlag(QStyle::State_Horizontal);
 }
 
 QWidget *ProgressBarDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem &, const QModelIndex &) const
 {
     Slider *slider = new Slider(parent);
+    slider->setAutoFillBackground(true);
+    slider->setBackgroundRole(QPalette::Highlight);
     slider->setRange(0, 100);
     slider->setOrientation(Qt::Horizontal);
     //debugPlan<<slider->minimumSizeHint()<<slider->minimumSize();
@@ -335,7 +311,7 @@ QWidget *SelectorDelegate::createEditor(QWidget *parent, const QStyleOptionViewI
             return editor;
         }
     }
-    return 0; // FIXME: What to do?
+    return nullptr; // FIXME: What to do?
 }
 
 void SelectorDelegate::setEditorData(QWidget *editor, const QModelIndex &index) const
@@ -421,68 +397,6 @@ void EnumDelegate::updateEditorGeometry(QWidget *editor, const QStyleOptionViewI
     editor->setGeometry(r);
 }
 
-//---------------------------
-RequieredResourceDelegate::RequieredResourceDelegate(QObject *parent)
-    : ItemDelegate(parent)
-{
-}
-
-QWidget *RequieredResourceDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem &/* option */, const QModelIndex &index) const
-{
-    if (index.data(Qt::CheckStateRole).toInt() == Qt::Unchecked) {
-        return 0;
-    }
-    TreeComboBox *editor = new TreeComboBox(parent);
-    editor->installEventFilter(const_cast<RequieredResourceDelegate*>(this));
-    ResourceItemSFModel *m = new ResourceItemSFModel(editor);
-    editor->setModel(m);
-    return editor;
-}
-
-void RequieredResourceDelegate::setEditorData(QWidget *editor, const QModelIndex &index) const
-{
-    TreeComboBox *box = static_cast<TreeComboBox*>(editor);
-    ResourceItemSFModel *pm = static_cast<ResourceItemSFModel*>(box->model());
-    ResourceItemModel *rm = qobject_cast<ResourceItemModel*>(pm->sourceModel());
-    Q_ASSERT(rm);
-    const ResourceAllocationItemModel *model = qobject_cast<const ResourceAllocationItemModel*>(index.model());
-    Q_ASSERT(model);
-    rm->setProject(model->project());
-    pm->addFilteredResource(model->resource(index));
-    QItemSelectionModel *sm = box->view()->selectionModel();
-    sm->clearSelection();
-    foreach (const Resource *r, model->required(index)) {
-        QModelIndex i = pm->mapFromSource(rm->index(r));
-        sm->select(i, QItemSelectionModel::Select | QItemSelectionModel::Rows);
-    }
-    box->setCurrentIndexes(sm->selectedRows());
-    box->view()->expandAll();
-}
-
-void RequieredResourceDelegate::setModelData(QWidget *editor, QAbstractItemModel *model,
-                                const QModelIndex &index) const
-{
-    TreeComboBox *box = static_cast<TreeComboBox*>(editor);
-
-    QAbstractProxyModel *pm = static_cast<QAbstractProxyModel*>(box->model());
-    ResourceItemModel *rm = qobject_cast<ResourceItemModel*>(pm->sourceModel());
-    QList<Resource*> lst;
-    foreach (const QModelIndex &i, box->currentIndexes()) {
-        lst << rm->resource(pm->mapToSource(i));
-    }
-    ResourceAllocationItemModel *mdl = qobject_cast<ResourceAllocationItemModel*>(model);
-    Q_ASSERT(mdl);
-    mdl->setRequired(index, lst);
-}
-
-void RequieredResourceDelegate::updateEditorGeometry(QWidget *editor, const QStyleOptionViewItem &option, const QModelIndex &/* index */) const
-{
-    debugPlan<<editor<<":"<<option.rect<<","<<editor->sizeHint();
-    QRect r = option.rect;
-    r.setWidth(qMax(100, r.width()));
-    editor->setGeometry(r);
-}
-
 //-------------------------------
 DurationSpinBoxDelegate::DurationSpinBoxDelegate(QObject *parent)
     : ItemDelegate(parent)
@@ -539,11 +453,20 @@ QWidget *SpinBoxDelegate::createEditor(QWidget *parent, const QStyleOptionViewIt
 void SpinBoxDelegate::setEditorData(QWidget *editor, const QModelIndex &index) const
 {
     int value = index.model()->data(index, Qt::EditRole).toInt();
-    int min = index.model()->data(index, Role::Minimum).toInt();
-    int max = index.model()->data(index, Role::Maximum).toInt();
+    auto min = index.model()->data(index, Role::Minimum);
+    auto max = index.model()->data(index, Role::Maximum);
 
     QSpinBox *box = static_cast<QSpinBox*>(editor);
-    box->setRange(min, max);
+    if (min.isValid()) {
+        box->setMinimum(min.toInt());
+    } else {
+        box->setMinimum(std::numeric_limits<int>::min());
+    }
+    if (max.isValid()) {
+        box->setMaximum(max.toInt());
+    } else {
+        box->setMaximum(std::numeric_limits<int>::max());
+    }
     box->setValue(value);
 }
 
@@ -673,8 +596,8 @@ void TimeDelegate::updateEditorGeometry(QWidget *editor, const QStyleOptionViewI
 //--------------------------
 ItemModelBase::ItemModelBase(QObject *parent)
     : QAbstractItemModel(parent),
-    m_project(0),
-    m_manager(0),
+    m_project(nullptr),
+    m_manager(nullptr),
     m_readWrite(false)//part->isReadWrite())
 {
 }
@@ -690,26 +613,31 @@ void ItemModelBase::setProject(Project *project)
 
 void ItemModelBase::setScheduleManager(ScheduleManager *sm)
 {
+    bool changed = m_manager != sm;
     m_manager = sm;
+    if (changed) {
+        Q_EMIT managerChanged(sm);
+    }
 }
 
 void ItemModelBase::slotLayoutChanged()
 {
     debugPlan;
-    emit layoutAboutToBeChanged();
-    emit layoutChanged();
+    Q_EMIT layoutAboutToBeChanged();
+    Q_EMIT layoutChanged();
 }
 
 void ItemModelBase::slotLayoutToBeChanged()
 {
     debugPlan;
-    emit layoutAboutToBeChanged();
+    Q_EMIT layoutAboutToBeChanged();
 }
 
 bool ItemModelBase::dropAllowed(const QModelIndex &index, int, const QMimeData *data)
 {
     if (flags(index) & Qt::ItemIsDropEnabled) {
-        foreach (const QString &s, data->formats()) {
+        const QList<QString> formats = data->formats();
+        for (const QString &s : formats) {
             if (mimeTypes().contains(s)) {
                 return true;
             }
@@ -721,7 +649,7 @@ bool ItemModelBase::dropAllowed(const QModelIndex &index, int, const QMimeData *
 QVariant ItemModelBase::data(const QModelIndex &index, int role) const
 {
     if (index.isValid() && role == Role::ColumnTag) {
-        return columnMap().key(index.column());
+        return QLatin1String(columnMap().key(index.column()));
     }
     return QVariant();
 }
@@ -730,7 +658,7 @@ QVariant ItemModelBase::headerData(int section, Qt::Orientation orientation, int
 {
     Q_UNUSED(orientation);
     if (role == Role::ColumnTag) {
-        return columnMap().key(section);
+        return QLatin1String(columnMap().key(section));
     }
     return QVariant();
 }
@@ -747,7 +675,7 @@ bool ItemModelBase::setData(const QModelIndex &index, const QVariant &value, int
 
 void ItemModelBase::projectDeleted()
 {
-    setProject(0);
+    setProject(nullptr);
 }
 
 int numColumns(const QModelIndexList &indexes)
@@ -782,43 +710,61 @@ int numRows(const QModelIndexList &indexes)
 
 void ItemModelBase::writeText(QMimeData *m, const QModelIndexList &indexes) const
 {
-    if (!mimeTypes().contains("text/html") && !mimeTypes().contains("text/plain")) {
+    if (indexes.isEmpty()) {
         return;
     }
     int cols = numColumns(indexes);
     int rows = numRows(indexes);
-    QTextDocument doc;
-    QTextCursor cursor(&doc);
-    cursor.insertTable(rows+1, cols);
-    QTextTableFormat tableFormat;
-    QVector<QTextLength> v;
-    for (int i = 0; i < cols; ++i) {
-        QTextLength l(QTextLength::PercentageLength, 100 / cols);
-        v << l;
+    if (mimeTypes().contains(QStringLiteral("text/html"))) {
+        QTextDocument doc;
+        QTextCursor cursor(&doc);
+        cursor.insertTable(rows+1, cols);
+        QTextTableFormat tableFormat;
+        QVector<QTextLength> v;
+        for (int i = 0; i < cols; ++i) {
+            QTextLength l(QTextLength::PercentageLength, 100 / cols);
+            v << l;
+        }
+        tableFormat.setColumnWidthConstraints(v);
+        cursor.currentTable()->setFormat(tableFormat);
+        // headers
+        for (int i = 0; i < cols; ++i) {
+            cursor.insertText(headerData(indexes.at(i).column(), Qt::Horizontal).toString());
+            cursor.movePosition(QTextCursor::NextCell);
+        }
+        // data
+        for (int i = 0; i < indexes.count(); ++i) {
+            cursor.insertText(indexes.at(i).data().toString());
+            cursor.movePosition(QTextCursor::NextCell);
+        }
+        m->setData(QStringLiteral("text/html"), doc.toHtml().toUtf8());
     }
-    tableFormat.setColumnWidthConstraints(v);
-    cursor.currentTable()->setFormat(tableFormat);
-    // headers
-    for (int i = 0; i < cols; ++i) {
-        cursor.insertText(headerData(indexes.at(i).column(), Qt::Horizontal).toString());
-        cursor.movePosition(QTextCursor::NextCell);
-    }
-    // data
-    for (int i = 0; i < indexes.count(); ++i) {
-        cursor.insertText(indexes.at(i).data().toString());
-        cursor.movePosition(QTextCursor::NextCell);
-    }
-    if (mimeTypes().contains("text/html")) {
-        m->setData("text/html", doc.toHtml("utf-8").toUtf8());
-    }
-    if (mimeTypes().contains("text/plain")) {
-        m->setData("text/plain", doc.toPlainText().toUtf8());
+    if (mimeTypes().contains(QStringLiteral("text/plain"))) {
+        QVector<QStringList> text(rows+1);
+        // headers
+        for (int c = 0; c < cols; ++c) {
+            text[0] << headerData(indexes.at(c).column(), Qt::Horizontal).toString();
+        }
+        // data
+        for (int i = 0; i < rows; ++i) {
+            for (int c = 0; c < cols; ++c) {
+                text[i+1] << indexes.at(i*cols+c).data().toString();
+            }
+        }
+        if (mimeTypes().contains(QStringLiteral("text/plain"))) {
+            QString s;
+            for (const auto &t : std::as_const(text)) {
+                s += t.join(QLatin1Char('\t'));
+                s += QLatin1Char('\n');
+            }
+            m->setData(QStringLiteral("text/plain"), s.toUtf8());
+        }
     }
 }
 
 QStringList ItemModelBase::mimeTypes() const
 {
-    return QStringList() << "text/html" << "text/plain";
+    return QStringList();
 }
 
 QMimeData *ItemModelBase::mimeData(const QModelIndexList &indexes) const
@@ -832,5 +778,3 @@ QMimeData *ItemModelBase::mimeData(const QModelIndexList &indexes) const
     writeText(m, indexes);
     return m;
 }
-
-} //namespace KPlato
