@@ -1,22 +1,9 @@
 /* This file is part of the KDE project
- * Copyright (C) 2007 - 2009, 2012 Dag Andersen <danders@get2net.dk>
- * Copyright (C) 2016 Dag Andersen <danders@get2net.dk>
- * Copyright (C) 2019 Dag Andersen <danders@get2net.dk>
+ * SPDX-FileCopyrightText: 2007-2009, 2012 Dag Andersen <dag.andersen@kdemail.net>
+ * SPDX-FileCopyrightText: 2016 Dag Andersen <dag.andersen@kdemail.net>
+ * SPDX-FileCopyrightText: 2019 Dag Andersen <dag.andersen@kdemail.net>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #ifndef NODEITEMMODEL_H
@@ -30,6 +17,7 @@
 #include <QMetaEnum>
 #include <QSortFilterProxyModel>
 #include <QUrl>
+#include <QTimer>
 
 class QMimeData;
 class KUndo2Command;
@@ -151,7 +139,7 @@ public:
     void setManager(ScheduleManager *sm);
     Project *project() const { return m_project; }
     ScheduleManager *manager() const { return m_manager; }
-    long id() const { return m_manager == 0 ? -1 : m_manager->scheduleId(); }
+    long id() const { return m_manager == nullptr ? -1 : m_manager->scheduleId(); }
     
     QVariant data(const Node *node, int property, int role = Qt::DisplayRole) const; 
     KUndo2Command *setData(Node *node, int property, const QVariant & value, int role = Qt::EditRole);
@@ -289,7 +277,7 @@ class PLANMODELS_EXPORT NodeItemModel : public ItemModelBase
 {
     Q_OBJECT
 public:
-    explicit NodeItemModel(QObject *parent = 0);
+    explicit NodeItemModel(QObject *parent = nullptr);
     ~NodeItemModel() override;
     
     /// Returns a column number/- name map for this model
@@ -384,7 +372,7 @@ class PLANMODELS_EXPORT GanttItemModel : public NodeItemModel
 public:
     enum GanttModelRoles { SpecialItemTypeRole = Qt::UserRole + 123 }; //FIXME
 
-    explicit GanttItemModel(QObject *parent = 0);
+    explicit GanttItemModel(QObject *parent = nullptr);
     ~GanttItemModel() override;
 
     int rowCount(const QModelIndex &parent) const override;
@@ -398,7 +386,7 @@ public:
 
 private:
     bool m_showSpecial;
-    QMap<Node*, void*> parentmap;
+    QMultiMap<Node*, void*> parentmap;
 };
 
 // TODO: Rename, this is now a flat node item model
@@ -406,7 +394,7 @@ class PLANMODELS_EXPORT MilestoneItemModel : public ItemModelBase
 {
     Q_OBJECT
 public:
-    explicit MilestoneItemModel(QObject *parent = 0);
+    explicit MilestoneItemModel(QObject *parent = nullptr);
     ~MilestoneItemModel() override;
 
     /// Returns a column number/- name map for this model
@@ -480,27 +468,65 @@ class PLANMODELS_EXPORT NodeSortFilterProxyModel : public QSortFilterProxyModel
 {
     Q_OBJECT
 public:
-    NodeSortFilterProxyModel(ItemModelBase* model, QObject *parent, bool filterUnscheduled = true);
+    NodeSortFilterProxyModel(ItemModelBase* model, QObject *parent);
 
     ItemModelBase *itemModel() const;
-    void setFilterUnscheduled(bool on);
-    bool filterUnscheduled() const { return m_filterUnscheduled; }
+    bool showSummarytasks() const;
+    bool tasksAndMilestonesGroupEnabled() const;
+    bool showProject() const;
+    bool showUnscheduled() const;
+    bool showTasks() const;
+    bool showMilestones() const;
+    bool periodGroupEnabled() const;
+    bool showRunning() const;
+    bool showFinished() const;
+    bool showNotStarted() const;
+    QDate periodStart() const;
+    QDate periodEnd() const;
 
     void sort(int column, Qt::SortOrder order = Qt::AscendingOrder) override;
 
+public Q_SLOTS:
+    void setShowSummarytasks(bool on);
+    void setTasksAndMilestonesGroupEnabled(bool on);
+    void setShowProject(bool on);
+    void setShowUnscheduled(bool on);
+    void setShowTasks(bool on);
+    void setShowMilestones(bool on);
+    void setPeriodGroupEnabled(bool on);
+    void setShowRunning(bool on);
+    void setShowFinished(bool on);
+    void setShowNotStarted(bool on);
+    void setPeriodStart(const QDate &dt);
+    void setPeriodEnd(const QDate &dt);
+
 protected:
     bool filterAcceptsRow (int source_row, const QModelIndex & source_parent) const override;
 
+private:
+    void setFilterInvalid();
+
 private:
     NodeItemModel *m_model;
-    bool m_filterUnscheduled;
+    bool m_showSummarytasks = false;
+    bool m_tasksAndMilestonesGroupEnabled = false;
+    bool m_showUnscheduled = false;
+    bool m_showTasks = true;
+    bool m_showMilestones = true;
+    bool m_periodGroupEnabled = false;
+    bool m_showRunning = true;
+    bool m_showFinished = true;
+    bool m_showNotStarted = true;
+    QDate m_periodStart;
+    QDate m_periodEnd;
+    QTimer m_invalidateFilter;
 };
 
 class PLANMODELS_EXPORT TaskModuleModel : public QAbstractItemModel
 {
     Q_OBJECT
 public:
-    explicit TaskModuleModel(QObject *parent = 0);
+    explicit TaskModuleModel(QObject *parent = nullptr);
 
     void addTaskModule(Project *project , const QUrl &url);
 
@@ -519,7 +545,7 @@ public:
     Project *loadProjectFromUrl(const QUrl &url) const;
 
 public Q_SLOTS:
-    void setProject(Project *project);
+    void setProject(KPlato::Project *project);
     void loadTaskModules(const QStringList &files);
     void slotTaskModulesChanged(const QList<QUrl> &modules);
 
