@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
-  Copyright (C) 2007 Dag Andersen <danders@get2net>
+  SPDX-FileCopyrightText: 2007 Dag Andersen <dag.andersen@kdemail.net>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-* Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KPTPERTCPMMODEL_H
@@ -42,7 +29,7 @@ class PLANMODELS_EXPORT CriticalPathItemModel : public ItemModelBase
 {
     Q_OBJECT
 public:
-    explicit CriticalPathItemModel(QObject *parent = 0);
+    explicit CriticalPathItemModel(QObject *parent = nullptr);
     ~CriticalPathItemModel() override;
     
     const QMetaEnum columnMap() const override { return m_nodemodel.columnMap(); }
@@ -97,7 +84,7 @@ class PLANMODELS_EXPORT PertResultItemModel : public ItemModelBase
 {
     Q_OBJECT
 public:
-    explicit PertResultItemModel(QObject *parent = 0);
+    explicit PertResultItemModel(QObject *parent = nullptr);
     ~PertResultItemModel() override;
     
     const QMetaEnum columnMap() const override { return m_nodemodel.columnMap(); }
