@@ -1,21 +1,8 @@
 /* This file is part of the KDE project
-  Copyright (C) 2007, 2012 Dag Andersen danders@get2net>
-  Copyright (C) 2016 Dag Andersen <danders@get2net.dk>
+  SPDX-FileCopyrightText: 2007, 2012 Dag Andersen <dag.andersen@kdemail.net>
+  SPDX-FileCopyrightText: 2016 Dag Andersen <dag.andersen@kdemail.net>
   
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 // clazy:excludeall=qstring-arg
@@ -75,7 +62,7 @@ int ScheduleModel::propertyCount() const
 
 ScheduleItemModel::ScheduleItemModel(QObject *parent)
     : ItemModelBase(parent),
-    m_manager(0),
+    m_manager(nullptr),
     m_flat(false)
 {
 }
@@ -90,7 +77,7 @@ void ScheduleItemModel::slotScheduleManagerToBeInserted(const ScheduleManager *p
     if (m_flat) {
         return; // handle in *Inserted();
     }
-    Q_ASSERT(m_manager == 0);
+    Q_ASSERT(m_manager == nullptr);
     m_manager = const_cast<ScheduleManager*>(parent);
     beginInsertRows(index(parent), row, row);
 }
@@ -104,13 +91,13 @@ void ScheduleItemModel::slotScheduleManagerInserted(const ScheduleManager *manag
         beginInsertRows(QModelIndex(), row, row);
         m_managerlist.insert(row, const_cast<ScheduleManager*>(manager));
         endInsertRows();
-        emit scheduleManagerAdded(const_cast<ScheduleManager*>(manager));
+        Q_EMIT scheduleManagerAdded(const_cast<ScheduleManager*>(manager));
         return;
     }
     Q_ASSERT(manager->parentManager() == m_manager);
     endInsertRows();
-    m_manager = 0;
-    emit scheduleManagerAdded(const_cast<ScheduleManager*>(manager));
+    m_manager = nullptr;
+    Q_EMIT scheduleManagerAdded(const_cast<ScheduleManager*>(manager));
 }
 
 void ScheduleItemModel::slotScheduleManagerToBeRemoved(const ScheduleManager *manager)
@@ -123,7 +110,7 @@ void ScheduleItemModel::slotScheduleManagerToBeRemoved(const ScheduleManager *ma
         return;
     }
 
-    Q_ASSERT(m_manager == 0);
+    Q_ASSERT(m_manager == nullptr);
     m_manager = const_cast<ScheduleManager*>(manager);
     QModelIndex i = index(manager);
     int row = i.row();
@@ -139,7 +126,7 @@ void ScheduleItemModel::slotScheduleManagerRemoved(const ScheduleManager *manage
     }
     Q_ASSERT(manager == m_manager); Q_UNUSED(manager);
     endRemoveRows();
-    m_manager = 0;
+    m_manager = nullptr;
 }
 
 void ScheduleItemModel::slotScheduleManagerToBeMoved(const ScheduleManager *manager)
@@ -238,13 +225,13 @@ void ScheduleItemModel::slotManagerChanged(ScheduleManager *sch)
 {
     if (m_flat) {
         int row = m_managerlist.indexOf(sch);
-        emit dataChanged(createIndex(row, 0, sch), createIndex(row, columnCount() - 1, sch));
+        Q_EMIT dataChanged(createIndex(row, 0, sch), createIndex(row, columnCount() - 1, sch));
         return;
     }
 
     int r = sch->parentManager() ? sch->parentManager()->indexOf(sch) : m_project->indexOf(sch);
     //debugPlan<<sch<<":"<<r;
-    emit dataChanged(createIndex(r, 0, sch), createIndex(r, columnCount() - 1, sch));
+    Q_EMIT dataChanged(createIndex(r, 0, sch), createIndex(r, columnCount() - 1, sch));
 }
 
 
@@ -262,11 +249,11 @@ Qt::ItemFlags ScheduleItemModel::flags(const QModelIndex &index) const
         return flags &= ~Qt::ItemIsEditable;
     }
     ScheduleManager *sm = manager(index);
-    if (sm == 0) {
+    if (sm == nullptr) {
         return flags;
     }
     SchedulerPlugin *pl = sm->schedulerPlugin();
-    if (pl == 0) {
+    if (pl == nullptr) {
         return flags;
     }
     int capabilities = pl->capabilities();
@@ -294,7 +281,7 @@ Qt::ItemFlags ScheduleItemModel::flags(const QModelIndex &index) const
                 }
                 break;
             case ScheduleModel::ScheduleDirection:
-                if (sm->parentManager() == 0 &&
+                if (sm->parentManager() == nullptr &&
                     capabilities & SchedulerPlugin::ScheduleForward &&
                     capabilities & SchedulerPlugin::ScheduleBackward)
                 {
@@ -317,12 +304,12 @@ Qt::ItemFlags ScheduleItemModel::flags(const QModelIndex &index) const
 
 QModelIndex ScheduleItemModel::parent(const QModelIndex &inx) const
 {
-    if (!inx.isValid() || m_project == 0 || m_flat) {
+    if (!inx.isValid() || m_project == nullptr || m_flat) {
         return QModelIndex();
     }
     //debugPlan<<inx.internalPointer()<<":"<<inx.row()<<","<<inx.column();
     ScheduleManager *sm = manager(inx);
-    if (sm == 0) {
+    if (sm == nullptr) {
         return QModelIndex();
     }
     return index(sm->parentManager());
@@ -331,7 +318,7 @@ QModelIndex ScheduleItemModel::parent(const QModelIndex &inx) const
 QModelIndex ScheduleItemModel::index(int row, int column, const QModelIndex &parent) const
 {
     //debugPlan<<m_project<<":"<<row<<","<<column;
-    if (m_project == 0 || column < 0 || column >= columnCount() || row < 0 || row >= rowCount(parent)) {
+    if (m_project == nullptr || column < 0 || column >= columnCount() || row < 0 || row >= rowCount(parent)) {
         //debugPlan<<row<<","<<column<<" out of bounce";
         return QModelIndex();
     }
@@ -347,14 +334,14 @@ QModelIndex ScheduleItemModel::index(int row, int column, const QModelIndex &par
 
 QModelIndex ScheduleItemModel::index(const ScheduleManager *manager) const
 {
-    if (m_project == 0 || manager == 0) {
+    if (m_project == nullptr || manager == nullptr) {
         return QModelIndex();
     }
     if (m_flat) {
         return createIndex(m_managerlist.indexOf(const_cast<ScheduleManager*>(manager)), 0, const_cast<ScheduleManager*>(manager));
     }
 
-    if (manager->parentManager() == 0) {
+    if (manager->parentManager() == nullptr) {
         return createIndex(m_project->indexOf(manager), 0, const_cast<ScheduleManager*>(manager));
     }
     return createIndex(manager->parentManager()->indexOf(manager), 0, const_cast<ScheduleManager*>(manager));
@@ -367,7 +354,7 @@ int ScheduleItemModel::columnCount(const QModelIndex &/*parent*/) const
 
 int ScheduleItemModel::rowCount(const QModelIndex &parent) const
 {
-    if (m_project == 0) {
+    if (m_project == nullptr) {
         return 0;
     }
     if (m_flat) {
@@ -387,7 +374,7 @@ int ScheduleItemModel::rowCount(const QModelIndex &parent) const
 QVariant ScheduleItemModel::name(const QModelIndex &index, int role) const
 {
     ScheduleManager *sm = manager (index);
-    if (sm == 0) {
+    if (sm == nullptr) {
         return QVariant();
     }
     switch (role) {
@@ -412,12 +399,12 @@ QVariant ScheduleItemModel::name(const QModelIndex &index, int role) const
 bool ScheduleItemModel::setName(const QModelIndex &index, const QVariant &value, int role)
 {
     ScheduleManager *sm = manager (index);
-    if (sm == 0) {
+    if (sm == nullptr) {
         return false;
     }
     switch (role) {
         case Qt::EditRole:
-            emit executeCommand(new ModifyScheduleManagerNameCmd(*sm, value.toString(), kundo2_i18n("Modify schedule name")));
+            Q_EMIT executeCommand(new ModifyScheduleManagerNameCmd(*sm, value.toString(), kundo2_i18n("Modify schedule name")));
             return true;
         default:
             break;
@@ -428,7 +415,7 @@ bool ScheduleItemModel::setName(const QModelIndex &index, const QVariant &value,
 QVariant ScheduleItemModel::schedulingMode(const QModelIndex &index, int role) const
 {
     ScheduleManager *sm = manager (index);
-    if (sm == 0) {
+    if (sm == nullptr) {
         return QVariant();
     }
     switch (role) {
@@ -458,12 +445,12 @@ QVariant ScheduleItemModel::schedulingMode(const QModelIndex &index, int role) c
 bool ScheduleItemModel::setSchedulingMode(const QModelIndex &index, const QVariant &value, int role)
 {
     ScheduleManager *sm = manager (index);
-    if (sm == 0) {
+    if (sm == nullptr) {
         return false;
     }
     switch (role) {
         case Qt::EditRole:
-            emit executeCommand(new ModifyScheduleManagerSchedulingModeCmd(*sm, value.toInt(), kundo2_i18n("Modify scheduling mode")));
+            Q_EMIT executeCommand(new ModifyScheduleManagerSchedulingModeCmd(*sm, value.toInt(), kundo2_i18n("Modify scheduling mode")));
             return true;
         default:
             break;
@@ -474,7 +461,7 @@ bool ScheduleItemModel::setSchedulingMode(const QModelIndex &index, const QVaria
 QVariant ScheduleItemModel::state(const QModelIndex &index, int role) const
 {
     ScheduleManager *sm = manager (index);
-    if (sm == 0) {
+    if (sm == nullptr) {
         return QVariant();
     }
     switch (role) {
@@ -485,7 +472,7 @@ QVariant ScheduleItemModel::state(const QModelIndex &index, int role) const
             }
             QStringList l = sm->state();
             if (l.isEmpty()) {
-                return "";
+                return QLatin1String("");
             }
             return l.first();
         }
@@ -493,12 +480,20 @@ QVariant ScheduleItemModel::state(const QModelIndex &index, int role) const
         {
             QStringList l = sm->state();
             if (l.isEmpty()) {
-                return "";
+                return QLatin1String("");
             }
             return l.first();
         }
-        case Qt::ToolTipRole:
-            return sm->state().join(", ");
+        case Qt::ToolTipRole: {
+            if (sm->owner() == ScheduleManager::OwnerPortfolio) {
+                return i18nc("@info:tooltip", "This schedule is created by the Portfolio Manager");
+            }
+            const auto states = sm->state();
+            if (states.count() > 1) {
+                return states.join(QStringLiteral(", "));
+            }
+            break;
+        }
         case Qt::TextAlignmentRole:
             return Qt::AlignCenter;
         case Qt::StatusTipRole:
@@ -513,7 +508,7 @@ QVariant ScheduleItemModel::state(const QModelIndex &index, int role) const
             if (!sm->isScheduled()) {
                 st = sm->state().value(0);
                 if (sm->progress() > 0) {
-                    st = QString("%1 %2%").arg(st).arg(sm->progress());
+                    st = QStringLiteral("%1 %2%").arg(st).arg(sm->progress());
                 }
             }
             return st;
@@ -534,11 +529,11 @@ bool ScheduleItemModel::setState(const QModelIndex &, const QVariant &, int role
 QVariant ScheduleItemModel::allowOverbooking(const QModelIndex &index, int role) const
 {
     ScheduleManager *sm = manager (index);
-    if (sm == 0) {
+    if (sm == nullptr) {
         return QVariant();
     }
     SchedulerPlugin *pl = sm->schedulerPlugin();
-    if (pl == 0) {
+    if (pl == nullptr) {
         return QVariant();
     }
     int capabilities = pl->capabilities();
@@ -593,12 +588,12 @@ QVariant ScheduleItemModel::allowOverbooking(const QModelIndex &index, int role)
 bool ScheduleItemModel::setAllowOverbooking(const QModelIndex &index, const QVariant &value, int role)
 {
     ScheduleManager *sm = manager (index);
-    if (sm == 0) {
+    if (sm == nullptr) {
         return false;
     }
     switch (role) {
         case Qt::EditRole:
-            emit executeCommand(new ModifyScheduleManagerAllowOverbookingCmd(*sm, value.toBool(), kundo2_i18n("Modify allow overbooking")));
+            Q_EMIT executeCommand(new ModifyScheduleManagerAllowOverbookingCmd(*sm, value.toBool(), kundo2_i18n("Modify allow overbooking")));
             return true;
     }
     return false;
@@ -608,7 +603,7 @@ bool ScheduleItemModel::setAllowOverbooking(const QModelIndex &index, const QVar
 QVariant ScheduleItemModel::usePert(const QModelIndex &index, int role) const
 {
     ScheduleManager *sm = manager (index);
-    if (sm == 0) {
+    if (sm == nullptr) {
         return QVariant();
     }
     switch (role) {
@@ -636,12 +631,12 @@ QVariant ScheduleItemModel::usePert(const QModelIndex &index, int role) const
 bool ScheduleItemModel::setUsePert(const QModelIndex &index, const QVariant &value, int role)
 {
     ScheduleManager *sm = manager (index);
-    if (sm == 0) {
+    if (sm == nullptr) {
         return false;
     }
     switch (role) {
         case Qt::EditRole:
-            emit executeCommand(new ModifyScheduleManagerDistributionCmd(*sm, value.toBool(), kundo2_i18n("Modify scheduling distribution")));
+            Q_EMIT executeCommand(new ModifyScheduleManagerDistributionCmd(*sm, value.toBool(), kundo2_i18n("Modify scheduling distribution")));
             slotManagerChanged(static_cast<ScheduleManager*>(sm));
             return true;
     }
@@ -650,11 +645,11 @@ bool ScheduleItemModel::setUsePert(const QModelIndex &index, const QVariant &val
 
 QVariant ScheduleItemModel::projectStart(const QModelIndex &index, int role) const
 {
-    if (m_project == 0) {
+    if (m_project == nullptr) {
         return QVariant();
     }
     ScheduleManager *sm = manager (index);
-    if (sm == 0) {
+    if (sm == nullptr) {
         return QVariant();
     }
     switch (role) {
@@ -686,11 +681,11 @@ QVariant ScheduleItemModel::projectStart(const QModelIndex &index, int role) con
 
 QVariant ScheduleItemModel::projectEnd(const QModelIndex &index, int role) const
 {
-    if (m_project == 0) {
+    if (m_project == nullptr) {
         return QVariant();
     }
     ScheduleManager *sm = manager (index);
-    if (sm == 0) {
+    if (sm == nullptr) {
         return QVariant();
     }
     switch (role) {
@@ -723,11 +718,11 @@ QVariant ScheduleItemModel::projectEnd(const QModelIndex &index, int role) const
 QVariant ScheduleItemModel::schedulingDirection(const QModelIndex &index, int role) const
 {
     ScheduleManager *sm = manager (index);
-    if (sm == 0) {
+    if (sm == nullptr) {
         return QVariant();
     }
     SchedulerPlugin *pl = sm->schedulerPlugin();
-    if (pl == 0) {
+    if (pl == nullptr) {
         return QVariant();
     }
     int capabilities = pl->capabilities();
@@ -782,12 +777,12 @@ QVariant ScheduleItemModel::schedulingDirection(const QModelIndex &index, int ro
 bool ScheduleItemModel::setSchedulingDirection(const QModelIndex &index, const QVariant &value, int role)
 {
     ScheduleManager *sm = manager (index);
-    if (sm == 0) {
+    if (sm == nullptr) {
         return false;
     }
     switch (role) {
         case Qt::EditRole:
-            emit executeCommand(new ModifyScheduleManagerSchedulingDirectionCmd(*sm, value.toBool(), kundo2_i18n("Modify scheduling direction")));
+            Q_EMIT executeCommand(new ModifyScheduleManagerSchedulingDirectionCmd(*sm, value.toBool(), kundo2_i18n("Modify scheduling direction")));
             slotManagerChanged(static_cast<ScheduleManager*>(sm));
             return true;
     }
@@ -797,7 +792,7 @@ bool ScheduleItemModel::setSchedulingDirection(const QModelIndex &index, const Q
 QVariant ScheduleItemModel::scheduler(const QModelIndex &index, int role) const
 {
     ScheduleManager *sm = manager(index);
-    if (sm == 0) {
+    if (sm == nullptr) {
         return QVariant();
     }
     SchedulerPlugin *pl = sm->schedulerPlugin();
@@ -829,10 +824,10 @@ QVariant ScheduleItemModel::scheduler(const QModelIndex &index, int role) const
 bool ScheduleItemModel::setScheduler(const QModelIndex &index, const QVariant &value, int role)
 {
     ScheduleManager *sm = manager(index);
-    if (sm != 0) {
+    if (sm != nullptr) {
         switch (role) {
             case Qt::EditRole: {
-                emit executeCommand(new ModifyScheduleManagerSchedulerCmd(*sm, value.toInt(), kundo2_i18n("Modify scheduler")));
+                Q_EMIT executeCommand(new ModifyScheduleManagerSchedulerCmd(*sm, value.toInt(), kundo2_i18n("Modify scheduler")));
                 return true;
             }
         }
@@ -843,7 +838,7 @@ bool ScheduleItemModel::setScheduler(const QModelIndex &index, const QVariant &v
 QVariant ScheduleItemModel::isScheduled(const QModelIndex &index, int role) const
 {
     ScheduleManager *sm = manager(index);
-    if (sm == 0) {
+    if (sm == nullptr) {
         return QVariant();
     }
     switch (role) {
@@ -865,28 +860,28 @@ QVariant ScheduleItemModel::isScheduled(const QModelIndex &index, int role) cons
 QVariant ScheduleItemModel::granularity(const QModelIndex &index, int role) const
 {
     ScheduleManager *sm = manager(index);
-    if (sm == 0) {
+    if (sm == nullptr) {
         return QVariant();
     }
     switch (role) {
         case Qt::EditRole:
         case Role::EnumListValue:
-            return qMin(sm->granularity(), sm->supportedGranularities().count() - 1);
+            return qMin(sm->granularityIndex(), sm->supportedGranularities().count() - 1);
         case Qt::DisplayRole: {
             QList<long unsigned int> lst = sm->supportedGranularities();
             if (lst.isEmpty()) {
                 return i18nc("Scheduling granularity not supported", "None");
             }
-            int idx = sm->granularity();
+            int idx = sm->granularityIndex();
             qulonglong g = idx < lst.count() ? lst[ idx ] : lst.last();
             return KFormat().formatDuration(g);
         }
         case Qt::ToolTipRole: {
             QList<long unsigned int> lst = sm->supportedGranularities();
             if (lst.isEmpty()) {
-                return xi18nc("@info:tooltip", "Scheduling granularity not supported");
+                return xi18nc("@info:tooltip", "Scheduling granularityIndex not supported");
             }
-            int idx = sm->granularity();
+            int idx = sm->granularityIndex();
             qulonglong g = idx < lst.count() ? lst[ idx ] : lst.last();
             return xi18nc("@info:tooltip", "Selected scheduling granularity: %1", KFormat().formatDuration(g));
         }
@@ -898,7 +893,8 @@ QVariant ScheduleItemModel::granularity(const QModelIndex &index, int role) cons
         case Role::EnumList: {
             QStringList sl;
             KFormat format;
-            foreach (long unsigned int v, sm->supportedGranularities()) {
+            const QList<long unsigned int> values = sm->supportedGranularities();
+            for (long unsigned int v : values) {
                 sl << format.formatDuration(v);
             }
             return sl;
@@ -910,10 +906,10 @@ QVariant ScheduleItemModel::granularity(const QModelIndex &index, int role) cons
 bool ScheduleItemModel::setGranularity(const QModelIndex &index, const QVariant &value, int role)
 {
     ScheduleManager *sm = manager(index);
-    if (sm != 0) {
+    if (sm != nullptr) {
         switch (role) {
             case Qt::EditRole: {
-                emit executeCommand(new ModifyScheduleManagerSchedulingGranularityCmd(*sm, value.toInt(), kundo2_i18n("Modify scheduling granularity")));
+                Q_EMIT executeCommand(new ModifyScheduleManagerSchedulingGranularityIndexCmd(*sm, value.toInt(), kundo2_i18n("Modify scheduling granularity")));
                 return true;
             }
         }
@@ -945,7 +941,7 @@ QVariant ScheduleItemModel::data(const QModelIndex &index, int role) const
             return QVariant();
     }
     if (result.isValid()) {
-        if (role == Qt::DisplayRole && result.type() == QVariant::String && result.toString().isEmpty()) {
+        if (role == Qt::DisplayRole && result.typeId() == QMetaType::QString && result.toString().isEmpty()) {
             // HACK to show focus in empty cells
             result = ' ';
         }
@@ -1003,18 +999,18 @@ QVariant ScheduleItemModel::headerData(int section, Qt::Orientation orientation,
             }
         } else if (role == Qt::EditRole) {
             switch (section) {
-                case ScheduleModel::ScheduleName: return "Name";
-                case ScheduleModel::ScheduleState: return "State";
-                case ScheduleModel::ScheduleMode: return "Mode";
-                case ScheduleModel::ScheduleDirection: return "Direction";
-                case ScheduleModel::ScheduleOverbooking: return "Overbooking";
-                case ScheduleModel::ScheduleDistribution: return "Distribution";
+                case ScheduleModel::ScheduleName: return QStringLiteral("Name");
+                case ScheduleModel::ScheduleState: return QStringLiteral("State");
+                case ScheduleModel::ScheduleMode: return QStringLiteral("Mode");
+                case ScheduleModel::ScheduleDirection: return QStringLiteral("Direction");
+                case ScheduleModel::ScheduleOverbooking: return QStringLiteral("Overbooking");
+                case ScheduleModel::ScheduleDistribution: return QStringLiteral("Distribution");
                 //                case ScheduleModel::ScheduleCalculate: return i18n("Calculate");
-                case ScheduleModel::SchedulePlannedStart: return "Planned Start";
-                case ScheduleModel::SchedulePlannedFinish: return "Planned Finish";
-                case ScheduleModel::ScheduleScheduler: return "Scheduler";
-                case ScheduleModel::ScheduleGranularity: return "Granularity";
-                case ScheduleModel::ScheduleScheduled: return "Scheduled";
+                case ScheduleModel::SchedulePlannedStart: return QStringLiteral("Planned Start");
+                case ScheduleModel::SchedulePlannedFinish: return QStringLiteral("Planned Finish");
+                case ScheduleModel::ScheduleScheduler: return QStringLiteral("Scheduler");
+                case ScheduleModel::ScheduleGranularity: return QStringLiteral("Granularity");
+                case ScheduleModel::ScheduleScheduled: return QStringLiteral("Scheduled");
                 default: return QVariant();
             }
         } else if (role == Qt::TextAlignmentRole) {
@@ -1061,7 +1057,7 @@ QAbstractItemDelegate *ScheduleItemModel::createDelegate(int column, QWidget *pa
         case ScheduleModel::ScheduleGranularity: return new EnumDelegate(parent);
         case ScheduleModel::ScheduleScheduler: return new EnumDelegate(parent);
     }
-    return 0;
+    return nullptr;
 }
 
 void ScheduleItemModel::sort(int column, Qt::SortOrder order)
@@ -1072,18 +1068,20 @@ void ScheduleItemModel::sort(int column, Qt::SortOrder order)
 
 QMimeData * ScheduleItemModel::mimeData(const QModelIndexList &) const
 {
-    return 0;
+    return nullptr;
 }
 
 QStringList ScheduleItemModel::mimeTypes () const
 {
-    return QStringList();
+    return QStringList()
+            << QStringLiteral("text/html")
+            << QStringLiteral("text/plain");
 }
 
 ScheduleManager *ScheduleItemModel::manager(const QModelIndex &index) const
 {
-    ScheduleManager *o = 0;
-    if (index.isValid() && m_project != 0 && index.internalPointer() != 0 && m_project->isScheduleManager(index.internalPointer())) {
+    ScheduleManager *o = nullptr;
+    if (index.isValid() && m_project != nullptr && index.internalPointer() != nullptr && m_project->isScheduleManager(index.internalPointer())) {
         o = static_cast<ScheduleManager*>(index.internalPointer());
         Q_ASSERT(o);
     }
@@ -1094,7 +1092,7 @@ void ScheduleItemModel::setFlat(bool flat)
 {
     m_flat = flat;
     m_managerlist.clear();
-    if (! flat || m_project == 0) {
+    if (! flat || m_project == nullptr) {
         return;
     }
     m_managerlist = m_project->allScheduleManagers();
@@ -1114,7 +1112,7 @@ ScheduleManager *ScheduleSortFilterModel::manager(const QModelIndex &index) cons
 {
     QModelIndex i = mapToSource(index);
     const ScheduleItemModel *m = qobject_cast<const ScheduleItemModel*>(i.model());
-    return m == 0 ? 0 : m->manager(i);
+    return m == nullptr ? nullptr : m->manager(i);
 }
 
 QVariant ScheduleSortFilterModel::data(const QModelIndex &index, int role) const
@@ -1122,10 +1120,10 @@ QVariant ScheduleSortFilterModel::data(const QModelIndex &index, int role) const
     QVariant v = QSortFilterProxyModel::data(index, role);
     if (role == Qt::DisplayRole && index.column() == ScheduleModel::ScheduleName) {
         QModelIndex state = index.sibling(index.row(), ScheduleModel::ScheduleState);
-        if (state.data(Qt::EditRole).toString() != "Scheduled") {
+        if (state.data(Qt::EditRole).toString() != QStringLiteral("Scheduled")) {
             QString s = state.data(SpecialScheduleDisplayRole).toString();
             if (!s.isEmpty()) {
-                return QString("%1 (%2)").arg(v.toString(), s); // TODO i18n
+                return QStringLiteral("%1 (%2)").arg(v.toString(), s); // TODO i18n
             }
         }
     }
@@ -1135,9 +1133,9 @@ QVariant ScheduleSortFilterModel::data(const QModelIndex &index, int role) const
 //--------------------------------------
 ScheduleLogItemModel::ScheduleLogItemModel(QObject *parent)
     : QStandardItemModel(parent),
-    m_project(0),
-    m_manager(0),
-    m_schedule(0)
+    m_project(nullptr),
+    m_manager(nullptr),
+    m_schedule(nullptr)
 {
 }
 
@@ -1148,7 +1146,7 @@ ScheduleLogItemModel::~ScheduleLogItemModel()
 void ScheduleLogItemModel::slotScheduleManagerToBeRemoved(const ScheduleManager *manager)
 {
     if (m_manager == manager) {
-        setManager(0);
+        setManager(nullptr);
     }
 }
 
@@ -1179,7 +1177,7 @@ void ScheduleLogItemModel::slotScheduleToBeRemoved(const MainSchedule *sch)
 {
     debugPlan<<m_schedule<<sch;
     if (m_schedule == sch) {
-        m_schedule = 0;
+        m_schedule = nullptr;
         clear();
     }
 }
@@ -1191,7 +1189,7 @@ void ScheduleLogItemModel::slotScheduleRemoved(const MainSchedule *sch)
 
 void ScheduleLogItemModel::projectDeleted()
 {
-    setProject(0);
+    setProject(nullptr);
 }
 
 void ScheduleLogItemModel::setProject(Project *project)
@@ -1246,7 +1244,7 @@ void ScheduleLogItemModel::setManager(ScheduleManager *manager)
             disconnect(m_manager, &ScheduleManager::logInserted, this, &ScheduleLogItemModel::slotLogInserted);
         }
         m_manager = manager;
-        m_schedule = 0;
+        m_schedule = nullptr;
         clear();
         if (m_manager) {
             m_schedule = m_manager->expected();
@@ -1273,14 +1271,14 @@ void ScheduleLogItemModel::addLogEntry(const Schedule::Log &log, int /*row*/)
     } else if (log.node) {
         lst.append(new QStandardItem(log.node->name()));
     } else {
-        lst.append( new QStandardItem(""));
+        lst.append(new QStandardItem());
     }
     lst.append(new QStandardItem(m_schedule->logPhase(log.phase)));
     QStandardItem *item = new QStandardItem(m_schedule->logSeverity(log.severity));
     item->setData(log.severity, SeverityRole);
     lst.append(item);
     lst.append(new QStandardItem(log.message));
-    foreach (QStandardItem *itm, lst) {
+    for (QStandardItem *itm : std::as_const(lst)) {
             if (log.resource) {
                 itm->setData(log.resource->id(), IdentityRole);
             } else if (log.node) {
@@ -1313,13 +1311,14 @@ void ScheduleLogItemModel::refresh()
     lst << i18n("Name") << i18n("Phase") << i18n("Severity") << i18n("Message");
     setHorizontalHeaderLabels(lst);
 
-    if (m_schedule == 0) {
+    if (m_schedule == nullptr) {
         debugPlan<<"No main schedule";
         return;
     }
 //     debugPlan<<m_schedule<<m_schedule->logs().count();
     int i = 1;
-    foreach (const Schedule::Log &l, m_schedule->logs()) {
+    const QVector<Schedule::Log> logs = m_schedule->logs();
+    for (const Schedule::Log &l : logs) {
         addLogEntry(l, i++);
     }
 }
