@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
-  Copyright (C) 2009 Dag Andersen <calligra-devel@kde.org>
+  SPDX-FileCopyrightText: 2009 Dag Andersen <calligra-devel@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 // clazy:excludeall=qstring-arg
@@ -44,6 +31,9 @@ TaskCompleteDelegate::~TaskCompleteDelegate()
 
 void TaskCompleteDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
+    if (!index.isValid()) {
+        return;
+    }
     QModelIndex typeidx = index.model()->index(index.row(), NodeModel::NodeType, index.parent());
     if (! typeidx.isValid()) {
         errorPlan<<"Cannot find nodetype for index:"<<index;
