@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
-  Copyright (C) 2009 Dag Andersen <danders@get2net.dk>
+  SPDX-FileCopyrightText: 2009 Dag Andersen <dag.andersen@kdemail.net>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KPTTREECOMBOBOX_H
@@ -22,7 +9,7 @@
 
 #include "planmodels_export.h"
 
-#include <kcombobox.h>
+#include <KComboBox>
 
 #include <QAbstractItemView>
 
@@ -39,10 +26,10 @@ class PLANMODELS_EXPORT TreeComboBox : public KComboBox
 {
     Q_OBJECT
 public:
-    explicit TreeComboBox(QWidget *parent = 0);
+    explicit TreeComboBox(QWidget *parent = nullptr);
 
     QTreeView *view() const;
-    void setModel(QAbstractItemModel *model);
+    void setModel(QAbstractItemModel *model) override;
     QAbstractItemModel *model() const;
 
     QList<QPersistentModelIndex> currentIndexes() const { return m_currentIndexes; }
