@@ -1,30 +1,19 @@
 /* This file is part of the KDE project
-  Copyright (C) 2017 Dag Andersen <danders@get2net.dk>
+  SPDX-FileCopyrightText: 2017 Dag Andersen <dag.andersen@kdemail.net>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version..
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef REPORTGENERATOR_H
 #define REPORTGENERATOR_H
 
+#include "planmodels_export.h"
+
 #include <QModelIndexList>
 
 #include <KoXmlReaderForward.h>
 
-#include <qdom.h>
+#include <QDomDocument>
 #include <QSortFilterProxyModel>
 
 class QIODevice;
@@ -35,13 +24,15 @@ class KoStore;
 class KoOdfWriteStore;
 class KoOdfReadStore;
 
+#define HeaderRole Qt::UserRole + 543
+
 namespace KPlato
 {
 
 class Project;
 class ScheduleManager;
 class ItemModelBase;
-
+class ChartItemModel;
 
 class PLANMODELS_EXPORT ReportGenerator
 {
@@ -56,13 +47,22 @@ public:
     void setProject(Project *project);
     void setScheduleManager(ScheduleManager *manager);
 
-    virtual bool open();
-    virtual void close();
-
-    virtual bool createReport();
+    bool initiate();
+    virtual bool createReport() = 0;
 
     QString lastError() const;
 
+protected:
+    /// Re-implement this to initiate your report generator
+    virtual bool initiateInternal();
+
+    QAbstractItemModel *projectsModel(ItemModelBase *base) const;
+    void addDataModel(const QString &name, QAbstractItemModel *model, int role);
+
+    static ChartItemModel *findChartItemModel(QSortFilterProxyModel &model);
+    static bool startsWith(const QStringList &keys, const QString &key);
+    static QStringList trimmed(const QStringList &lst);
+
 protected:
     QString m_lastError;
     QString m_reportType;
@@ -72,6 +72,14 @@ protected:
     ScheduleManager *m_manager;
 
     ReportGenerator *m_reportGenerator;
+
+    QStringList m_keys;
+    QStringList m_variables;
+
+    QMap<QString, QAbstractItemModel*> m_datamodels;
+    QMap<QString, int> m_headerrole;
+    QList<ItemModelBase*> m_basemodels;
+
 };
 
 } //namespace KPlato
