@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
-   Copyright (C) 2012 Dag Andersen <danders@get2net.dk>
+   SPDX-FileCopyrightText: 2012 Dag Andersen <dag.andersen@kdemail.net>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 // clazy:excludeall=qstring-arg
 #include "WorkPackageProxyModelTester.h"
@@ -37,11 +24,9 @@ Task *WorkPackageProxyModelTester::addTask(Node *parent, int after)
     Task *task = project.createTask();
     TaskAddCmd cmd(&project, task, parent->childNode(after));
     cmd.redo();
-    ResourceGroupRequest *gr = new ResourceGroupRequest(project.resourceGroupAt(0));
     ResourceRequest *rr = new ResourceRequest(project.resourceGroupAt(0)->resourceAt(0), 100);
-    gr->addResourceRequest(rr);
-    AddResourceGroupRequestCmd c(*task, gr);
-    c.redo();
+    AddResourceRequestCmd c2(&task->requests(), rr);
+    c2.redo();
     return task;
 }
 
@@ -84,7 +69,8 @@ void WorkPackageProxyModelTester::initTestCase()
     project.addResourceGroup(g);
     Resource *r = new Resource();
     r->setName("R1");
-    project.addResource(g, r);
+    project.addResource(r);
+    g->addResource(r);
 
     sm = project.createScheduleManager();
     m_model.setScheduleManager(sm);
