@@ -1,23 +1,10 @@
 /* This file is part of the KDE project
  *
- * Copyright (C) 2009 Inge Wallin <inge@lysator.liu.se>
- * Copyright (C) 2009 Thomas Zander <zander@kde.org>
- * Copyright (C) 2011 Pierre Ducroquet <pinaraf@pinaraf.info>
+ * SPDX-FileCopyrightText: 2009 Inge Wallin <inge@lysator.liu.se>
+ * SPDX-FileCopyrightText: 2009 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2011 Pierre Ducroquet <pinaraf@pinaraf.info>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 // clazy:excludeall=qstring-arg
@@ -150,35 +137,35 @@ KoBorder::BorderStyle KoBorder::odfBorderStyle(const QString &borderstyle, bool
     //       styles in the MS DOC that we may have to handle at some point.
     if (converted)
         *converted = true;
-    if (borderstyle == "none")
+    if (borderstyle == QStringLiteral("none"))
         return BorderNone;
-    if (borderstyle == "solid")
+    if (borderstyle == QStringLiteral("solid"))
         return BorderSolid;
-    if (borderstyle == "dashed")
+    if (borderstyle == QStringLiteral("dashed"))
         return BorderDashed;
-    if (borderstyle == "dotted")
+    if (borderstyle == QStringLiteral("dotted"))
         return BorderDotted;
-    if (borderstyle == "dot-dash")
+    if (borderstyle == QStringLiteral("dot-dash"))
         return BorderDashDot;
-    if (borderstyle == "dot-dot-dash")
+    if (borderstyle == QStringLiteral("dot-dot-dash"))
         return BorderDashDotDot;
-    if (borderstyle == "double")
+    if (borderstyle == QStringLiteral("double"))
         return BorderDouble;
-    if (borderstyle == "groove")   // Not odf compatible -- see above
+    if (borderstyle == QStringLiteral("groove"))  // Not odf compatible -- see above
         return BorderGroove;
-    if (borderstyle == "ridge")   // Not odf compatible -- see above
+    if (borderstyle == QStringLiteral("ridge"))   // Not odf compatible -- see above
         return BorderRidge;
-    if (borderstyle == "inset")   // Not odf compatible -- see above
+    if (borderstyle == QStringLiteral("inset"))   // Not odf compatible -- see above
         return BorderInset;
-    if (borderstyle == "outset")   // Not odf compatible -- see above
+    if (borderstyle == QStringLiteral("outset"))   // Not odf compatible -- see above
         return BorderOutset;
-    if (borderstyle == "dash-largegap")
+    if (borderstyle == QStringLiteral("dash-largegap"))
         return KoBorder::BorderDashedLong;
-    if (borderstyle == "slash") // not officially odf, but we support it anyway
+    if (borderstyle == QStringLiteral("slash")) // not officially odf, but we support it anyway
         return KoBorder::BorderSlash;
-    if (borderstyle == "wave") // not officially odf, but we support it anyway
+    if (borderstyle == QStringLiteral("wave")) // not officially odf, but we support it anyway
         return KoBorder::BorderWave;
-    if (borderstyle == "double-wave") // not officially odf, but we support it anyway
+    if (borderstyle == QStringLiteral("double-wave")) // not officially odf, but we support it anyway
         return KoBorder::BorderDoubleWave;
 
     if (converted)
@@ -191,31 +178,31 @@ QString KoBorder::odfBorderStyleString(BorderStyle borderstyle)
 {
     switch (borderstyle) {
     case BorderDashed:
-        return QString("dashed");
+        return QStringLiteral("dashed");
     case BorderDotted:
-        return QString("dotted");
+        return QStringLiteral("dotted");
     case BorderDashDot:
-        return QString("dot-dash");
+        return QStringLiteral("dot-dash");
     case BorderDashDotDot:
-        return QString("dot-dot-dash");
+        return QStringLiteral("dot-dot-dash");
     case BorderDouble:
-        return QString("double");
+        return QStringLiteral("double");
     case BorderGroove:
-        return QString("groove"); // not odf -- see above
+        return QStringLiteral("groove"); // not odf -- see above
     case BorderRidge:
-        return QString("ridge"); // not odf -- see above
+        return QStringLiteral("ridge"); // not odf -- see above
     case BorderInset:
-        return QString("inset"); // not odf -- see above
+        return QStringLiteral("inset"); // not odf -- see above
     case BorderOutset:
-        return QString("outset"); // not odf -- see above
+        return QStringLiteral("outset"); // not odf -- see above
     case BorderSolid:
-        return QString("solid");
+        return QStringLiteral("solid");
     case BorderNone:
-        return QString("none");
+        return QStringLiteral("none");
 
     default:
         // Handle unknown types as solid.
-        return QString("solid");
+        return QStringLiteral("solid");
     }
 }
 
@@ -223,13 +210,13 @@ QString KoBorder::msoBorderStyleString(BorderStyle borderstyle)
 {
     switch (borderstyle) {
     case KoBorder::BorderDashedLong:
-        return QString("dash-largegap");
+        return QStringLiteral("dash-largegap");
     case KoBorder::BorderSlash:
-        return QString("slash"); // not officially odf, but we support it anyway
+        return QStringLiteral("slash"); // not officially odf, but we support it anyway
     case KoBorder::BorderWave:
-        return QString("wave"); // not officially odf, but we support it anyway
+        return QStringLiteral("wave"); // not officially odf, but we support it anyway
     case KoBorder::BorderDoubleWave:
-        return QString("double-wave"); // not officially odf, but we support it anyway
+        return QStringLiteral("double-wave"); // not officially odf, but we support it anyway
 
     default:
         // Handle remaining styles as odf type style.
@@ -261,7 +248,6 @@ void KoBorder::setBorderStyle(BorderSide side, BorderStyle style)
     BorderData &edge = d->data[side];
     qreal width = edge.outerPen.widthF();
     qreal innerWidth = 0;
-    qreal middleWidth = 0;
     qreal space = 0;
     QVector<qreal> dashes;
     switch (style) {
@@ -287,7 +273,7 @@ void KoBorder::setBorderStyle(BorderSide side, BorderStyle style)
         break;
     }
     case KoBorder::BorderTriple:
-        innerWidth = middleWidth = space = width/6;
+        innerWidth = space = width/6;
         width -= (space + innerWidth);
         edge.outerPen.setStyle(Qt::SolidLine);
         break;
@@ -499,8 +485,8 @@ void KoBorder::paint(QPainter &painter, const QRectF &borderRect,
         start = borderRect.topLeft();
         end   = borderRect.bottomLeft();
         paintBorderSide(painter, start, end, &leftEdge, true,
-                        hasBorder(TopBorder) ? &topEdge : 0,
-                        hasBorder(BottomBorder) ? &bottomEdge : 0,
+                        hasBorder(TopBorder) ? &topEdge : nullptr,
+                        hasBorder(BottomBorder) ? &bottomEdge : nullptr,
                         1);
     }
 
@@ -509,8 +495,8 @@ void KoBorder::paint(QPainter &painter, const QRectF &borderRect,
         start = borderRect.topRight();
         end   = borderRect.bottomRight();
         paintBorderSide(painter, start, end, &rightEdge, true,
-                        hasBorder(TopBorder) ? &topEdge : 0,
-                        hasBorder(BottomBorder) ? &bottomEdge : 0,
+                        hasBorder(TopBorder) ? &topEdge : nullptr,
+                        hasBorder(BottomBorder) ? &bottomEdge : nullptr,
                         -1);
     }
 
@@ -519,8 +505,8 @@ void KoBorder::paint(QPainter &painter, const QRectF &borderRect,
         start = borderRect.topLeft();
         end   = borderRect.topRight();
         paintBorderSide(painter, start, end, &topEdge, false,
-                        hasBorder(LeftBorder) ? &leftEdge : 0,
-                        hasBorder(RightBorder) ? &rightEdge : 0,
+                        hasBorder(LeftBorder) ? &leftEdge : nullptr,
+                        hasBorder(RightBorder) ? &rightEdge : nullptr,
                         1);
     }
 
@@ -529,8 +515,8 @@ void KoBorder::paint(QPainter &painter, const QRectF &borderRect,
         start = borderRect.bottomLeft();
         end   = borderRect.bottomRight();
         paintBorderSide(painter, start, end, &bottomEdge, false,
-                        hasBorder(LeftBorder) ? &leftEdge : 0,
-                        hasBorder(RightBorder) ? &rightEdge : 0,
+                        hasBorder(LeftBorder) ? &leftEdge : nullptr,
+                        hasBorder(RightBorder) ? &rightEdge : nullptr,
                         -1);
     }
 
@@ -569,7 +555,7 @@ void KoBorder::paintBorderSide(QPainter &painter, QPointF lineStart, QPointF lin
             lineEnd.setY(lineEnd.y() + inwardsAcross * displacement);
         }
 
-        // Adjust for neigboring inner lines.
+        // Adjust for neighboring inner lines.
         if (neighbour1 && neighbour1->style == BorderDouble) {
             displacement = neighbour1->outerPen.widthF() + neighbour1->spacing;
             if (isVertical) {
@@ -607,8 +593,8 @@ void parseOdfBorder(const QString &border, QColor *color,
     *hasBorderStyle = false;
     *hasBorderWidth = false;
 
-    if (!border.isEmpty() && border != "none" && border != "hidden") {
-        QStringList borderData = border.split(' ', QString::SkipEmptyParts);
+    if (!border.isEmpty() && border != QStringLiteral("none") && border != QStringLiteral("hidden")) {
+        QStringList borderData = border.split(QLatin1Char(' '), Qt::SkipEmptyParts);
         if (borderData.length() > 0)
         {
             const QColor borderColor = QColor(borderData.last());
@@ -646,7 +632,7 @@ bool KoBorder::loadOdf(const KoXmlElement &style)
     QString specialBorderString;
     if (style.hasAttributeNS(KoXmlNS::fo, "border")) {
         borderString = style.attributeNS(KoXmlNS::fo, "border");
-        if (borderString == "none") {
+        if (borderString == QStringLiteral("none")) {
             // We use the "false" to indicate that there is no border
             // rather than that the parsing has failed.
             return false;
@@ -716,8 +702,8 @@ bool KoBorder::loadOdf(const KoXmlElement &style)
     if (style.hasAttributeNS(KoXmlNS::style, "border-line-width")) {
         result = true;
         QString borderLineWidth = style.attributeNS(KoXmlNS::style, "border-line-width");
-        if (!borderLineWidth.isEmpty() && borderLineWidth != "none" && borderLineWidth != "hidden") {
-            QStringList blw = borderLineWidth.split(' ', QString::SkipEmptyParts);
+        if (!borderLineWidth.isEmpty() && borderLineWidth != QStringLiteral("none") && borderLineWidth != QStringLiteral("hidden")) {
+            QStringList blw = borderLineWidth.split(QLatin1Char(' '), Qt::SkipEmptyParts);
             setInnerBorderWidth(LeftBorder, KoUnit::parseValue(blw[0], 0.1));
             setBorderSpacing(LeftBorder, KoUnit::parseValue(blw[1], 1.0));
             setOuterBorderWidth(LeftBorder, KoUnit::parseValue(blw[2], 0.1));
@@ -739,8 +725,8 @@ bool KoBorder::loadOdf(const KoXmlElement &style)
         if (style.hasAttributeNS(KoXmlNS::style, "border-line-width-left")) {
             result = true;
             QString borderLineWidth = style.attributeNS(KoXmlNS::style, "border-line-width-left");
-            if (!borderLineWidth.isEmpty() && borderLineWidth != "none" && borderLineWidth != "hidden") {
-                QStringList blw = borderLineWidth.split(' ', QString::SkipEmptyParts);
+            if (!borderLineWidth.isEmpty() && borderLineWidth != QStringLiteral("none") && borderLineWidth != QStringLiteral("hidden")) {
+                QStringList blw = borderLineWidth.split(QLatin1Char(' '), Qt::SkipEmptyParts);
                 setInnerBorderWidth(LeftBorder, KoUnit::parseValue(blw[0], 0.1));
                 setBorderSpacing(LeftBorder, KoUnit::parseValue(blw[1], 1.0));
                 setOuterBorderWidth(LeftBorder, KoUnit::parseValue(blw[2], 0.1));
@@ -749,8 +735,8 @@ bool KoBorder::loadOdf(const KoXmlElement &style)
         if (style.hasAttributeNS(KoXmlNS::style, "border-line-width-top")) {
             result = true;
             QString borderLineWidth = style.attributeNS(KoXmlNS::style, "border-line-width-top");
-            if (!borderLineWidth.isEmpty() && borderLineWidth != "none" && borderLineWidth != "hidden") {
-                QStringList blw = borderLineWidth.split(' ', QString::SkipEmptyParts);
+            if (!borderLineWidth.isEmpty() && borderLineWidth != QStringLiteral("none") && borderLineWidth != QStringLiteral("hidden")) {
+                QStringList blw = borderLineWidth.split(QLatin1Char(' '), Qt::SkipEmptyParts);
                 setInnerBorderWidth(TopBorder, KoUnit::parseValue(blw[0], 0.1));
                 setBorderSpacing(TopBorder, KoUnit::parseValue(blw[1], 1.0));
                 setOuterBorderWidth(TopBorder, KoUnit::parseValue(blw[2], 0.1));
@@ -759,8 +745,8 @@ bool KoBorder::loadOdf(const KoXmlElement &style)
         if (style.hasAttributeNS(KoXmlNS::style, "border-line-width-right")) {
             result = true;
             QString borderLineWidth = style.attributeNS(KoXmlNS::style, "border-line-width-right");
-            if (!borderLineWidth.isEmpty() && borderLineWidth != "none" && borderLineWidth != "hidden") {
-                QStringList blw = borderLineWidth.split(' ', QString::SkipEmptyParts);
+            if (!borderLineWidth.isEmpty() && borderLineWidth != QStringLiteral("none") && borderLineWidth != QStringLiteral("hidden")) {
+                QStringList blw = borderLineWidth.split(QLatin1Char(' '), Qt::SkipEmptyParts);
                 setInnerBorderWidth(RightBorder, KoUnit::parseValue(blw[0], 0.1));
                 setBorderSpacing(RightBorder, KoUnit::parseValue(blw[1], 1.0));
                 setOuterBorderWidth(RightBorder, KoUnit::parseValue(blw[2], 0.1));
@@ -769,8 +755,8 @@ bool KoBorder::loadOdf(const KoXmlElement &style)
         if (style.hasAttributeNS(KoXmlNS::style, "border-line-width-bottom")) {
             result = true;
             QString borderLineWidth = style.attributeNS(KoXmlNS::style, "border-line-width-bottom");
-            if (!borderLineWidth.isEmpty() && borderLineWidth != "none" && borderLineWidth != "hidden") {
-                QStringList blw = borderLineWidth.split(' ', QString::SkipEmptyParts);
+            if (!borderLineWidth.isEmpty() && borderLineWidth != QStringLiteral("none") && borderLineWidth != QStringLiteral("hidden")) {
+                QStringList blw = borderLineWidth.split(QLatin1Char(' '), Qt::SkipEmptyParts);
                 setInnerBorderWidth(BottomBorder, KoUnit::parseValue(blw[0], 0.1));
                 setBorderSpacing(BottomBorder, KoUnit::parseValue(blw[1], 1.0));
                 setOuterBorderWidth(BottomBorder, KoUnit::parseValue(blw[2], 0.1));
@@ -781,8 +767,8 @@ bool KoBorder::loadOdf(const KoXmlElement &style)
     if (style.hasAttributeNS(KoXmlNS::style, "diagonal-tl-br-widths")) {
         result = true;
         QString borderLineWidth = style.attributeNS(KoXmlNS::style, "diagonal-tl-br-widths");
-        if (!borderLineWidth.isEmpty() && borderLineWidth != "none" && borderLineWidth != "hidden") {
-            QStringList blw = borderLineWidth.split(' ', QString::SkipEmptyParts);
+        if (!borderLineWidth.isEmpty() && borderLineWidth != QStringLiteral("none") && borderLineWidth != QStringLiteral("hidden")) {
+            QStringList blw = borderLineWidth.split(QLatin1Char(' '), Qt::SkipEmptyParts);
             setInnerBorderWidth(TlbrBorder, KoUnit::parseValue(blw[0], 0.1));
             setBorderSpacing(TlbrBorder, KoUnit::parseValue(blw[1], 1.0));
             setOuterBorderWidth(TlbrBorder, KoUnit::parseValue(blw[2], 0.1));
@@ -791,8 +777,8 @@ bool KoBorder::loadOdf(const KoXmlElement &style)
     if (style.hasAttributeNS(KoXmlNS::style, "diagonal-bl-tr-widths")) {
         result = true;
         QString borderLineWidth = style.attributeNS(KoXmlNS::style, "diagonal-bl-tr-widths");
-        if (!borderLineWidth.isEmpty() && borderLineWidth != "none" && borderLineWidth != "hidden") {
-            QStringList blw = borderLineWidth.split(' ', QString::SkipEmptyParts);
+        if (!borderLineWidth.isEmpty() && borderLineWidth != QStringLiteral("none") && borderLineWidth != QStringLiteral("hidden")) {
+            QStringList blw = borderLineWidth.split(QLatin1Char(' '), Qt::SkipEmptyParts);
             setInnerBorderWidth(BltrBorder, KoUnit::parseValue(blw[0], 0.1));
             setBorderSpacing(BltrBorder, KoUnit::parseValue(blw[1], 1.0));
             setOuterBorderWidth(BltrBorder, KoUnit::parseValue(blw[2], 0.1));
@@ -876,8 +862,8 @@ bool KoBorder::loadOdf(const KoStyleStack &styleStack)
     if (styleStack.hasProperty(KoXmlNS::style, "border-line-width")) {
         result = true;
         QString borderLineWidth = styleStack.property(KoXmlNS::style, "border-line-width");
-        if (!borderLineWidth.isEmpty() && borderLineWidth != "none" && borderLineWidth != "hidden") {
-            QStringList blw = borderLineWidth.split(' ', QString::SkipEmptyParts);
+        if (!borderLineWidth.isEmpty() && borderLineWidth != QStringLiteral("none") && borderLineWidth != QStringLiteral("hidden")) {
+            QStringList blw = borderLineWidth.split(QLatin1Char(' '), Qt::SkipEmptyParts);
             setInnerBorderWidth(LeftBorder, KoUnit::parseValue(blw[0], 0.1));
             setBorderSpacing(LeftBorder, KoUnit::parseValue(blw[1], 1.0));
             setOuterBorderWidth(LeftBorder, KoUnit::parseValue(blw[2], 0.1));
@@ -901,8 +887,8 @@ bool KoBorder::loadOdf(const KoStyleStack &styleStack)
     if (styleStack.hasProperty(KoXmlNS::style, "border-line-width-left")) {
         result = true;
         QString borderLineWidth = styleStack.property(KoXmlNS::style, "border-line-width-left");
-        if (!borderLineWidth.isEmpty() && borderLineWidth != "none" && borderLineWidth != "hidden") {
-            QStringList blw = borderLineWidth.split(' ', QString::SkipEmptyParts);
+        if (!borderLineWidth.isEmpty() && borderLineWidth != QStringLiteral("none") && borderLineWidth != QStringLiteral("hidden")) {
+            QStringList blw = borderLineWidth.split(QLatin1Char(' '), Qt::SkipEmptyParts);
             setInnerBorderWidth(LeftBorder, KoUnit::parseValue(blw[0], 0.1));
             setBorderSpacing(LeftBorder, KoUnit::parseValue(blw[1], 1.0));
             setOuterBorderWidth(LeftBorder, KoUnit::parseValue(blw[2], 0.1));
@@ -911,8 +897,8 @@ bool KoBorder::loadOdf(const KoStyleStack &styleStack)
     if (styleStack.hasProperty(KoXmlNS::style, "border-line-width-top")) {
         result = true;
         QString borderLineWidth = styleStack.property(KoXmlNS::style, "border-line-width-top");
-        if (!borderLineWidth.isEmpty() && borderLineWidth != "none" && borderLineWidth != "hidden") {
-            QStringList blw = borderLineWidth.split(' ', QString::SkipEmptyParts);
+        if (!borderLineWidth.isEmpty() && borderLineWidth != QStringLiteral("none") && borderLineWidth != QStringLiteral("hidden")) {
+            QStringList blw = borderLineWidth.split(QLatin1Char(' '), Qt::SkipEmptyParts);
             setInnerBorderWidth(TopBorder, KoUnit::parseValue(blw[0], 0.1));
             setBorderSpacing(TopBorder, KoUnit::parseValue(blw[1], 1.0));
             setOuterBorderWidth(TopBorder, KoUnit::parseValue(blw[2], 0.1));
@@ -921,8 +907,8 @@ bool KoBorder::loadOdf(const KoStyleStack &styleStack)
     if (styleStack.hasProperty(KoXmlNS::style, "border-line-width-right")) {
         result = true;
         QString borderLineWidth = styleStack.property(KoXmlNS::style, "border-line-width-right");
-        if (!borderLineWidth.isEmpty() && borderLineWidth != "none" && borderLineWidth != "hidden") {
-            QStringList blw = borderLineWidth.split(' ', QString::SkipEmptyParts);
+        if (!borderLineWidth.isEmpty() && borderLineWidth != QStringLiteral("none") && borderLineWidth != QStringLiteral("hidden")) {
+            QStringList blw = borderLineWidth.split(QLatin1Char(' '), Qt::SkipEmptyParts);
             setInnerBorderWidth(RightBorder, KoUnit::parseValue(blw[0], 0.1));
             setBorderSpacing(RightBorder, KoUnit::parseValue(blw[1], 1.0));
             setOuterBorderWidth(RightBorder, KoUnit::parseValue(blw[2], 0.1));
@@ -931,8 +917,8 @@ bool KoBorder::loadOdf(const KoStyleStack &styleStack)
     if (styleStack.hasProperty(KoXmlNS::style, "border-line-width-bottom")) {
         result = true;
         QString borderLineWidth = styleStack.property(KoXmlNS::style, "border-line-width-bottom");
-        if (!borderLineWidth.isEmpty() && borderLineWidth != "none" && borderLineWidth != "hidden") {
-            QStringList blw = borderLineWidth.split(' ', QString::SkipEmptyParts);
+        if (!borderLineWidth.isEmpty() && borderLineWidth != QStringLiteral("none") && borderLineWidth != QStringLiteral("hidden")) {
+            QStringList blw = borderLineWidth.split(QLatin1Char(' '), Qt::SkipEmptyParts);
             setInnerBorderWidth(BottomBorder, KoUnit::parseValue(blw[0], 0.1));
             setBorderSpacing(BottomBorder, KoUnit::parseValue(blw[1], 1.0));
             setOuterBorderWidth(BottomBorder, KoUnit::parseValue(blw[2], 0.1));
@@ -943,8 +929,8 @@ bool KoBorder::loadOdf(const KoStyleStack &styleStack)
     if (styleStack.hasProperty(KoXmlNS::style, "diagonal-tl-br-widths")) {
         result = true;
         QString borderLineWidth = styleStack.property(KoXmlNS::style, "diagonal-tl-br-widths");
-        if (!borderLineWidth.isEmpty() && borderLineWidth != "none" && borderLineWidth != "hidden") {
-            QStringList blw = borderLineWidth.split(' ', QString::SkipEmptyParts);
+        if (!borderLineWidth.isEmpty() && borderLineWidth != QStringLiteral("none") && borderLineWidth != QStringLiteral("hidden")) {
+            QStringList blw = borderLineWidth.split(QLatin1Char(' '), Qt::SkipEmptyParts);
             setInnerBorderWidth(TlbrBorder, KoUnit::parseValue(blw[0], 0.1));
             setBorderSpacing(TlbrBorder, KoUnit::parseValue(blw[1], 1.0));
             setOuterBorderWidth(TlbrBorder, KoUnit::parseValue(blw[2], 0.1));
@@ -953,8 +939,8 @@ bool KoBorder::loadOdf(const KoStyleStack &styleStack)
     if (styleStack.hasProperty(KoXmlNS::style, "diagonal-bl-tr-widths")) {
         result = true;
         QString borderLineWidth = styleStack.property(KoXmlNS::style, "diagonal-bl-tr-widths");
-        if (!borderLineWidth.isEmpty() && borderLineWidth != "none" && borderLineWidth != "hidden") {
-            QStringList blw = borderLineWidth.split(' ', QString::SkipEmptyParts);
+        if (!borderLineWidth.isEmpty() && borderLineWidth != QStringLiteral("none") && borderLineWidth != QStringLiteral("hidden")) {
+            QStringList blw = borderLineWidth.split(QLatin1Char(' '), Qt::SkipEmptyParts);
             setInnerBorderWidth(BltrBorder, KoUnit::parseValue(blw[0], 0.1));
             setBorderSpacing(BltrBorder, KoUnit::parseValue(blw[1], 1.0));
             setOuterBorderWidth(BltrBorder, KoUnit::parseValue(blw[2], 0.1));
@@ -969,7 +955,7 @@ bool KoBorder::loadOdf(const KoStyleStack &styleStack)
 void KoBorder::parseAndSetBorder(const QString &borderString,
                                  bool hasSpecialBorder, const QString &specialBorderString)
 {
-    if (borderString == "none") {
+    if (borderString == QStringLiteral("none")) {
         return;
     }
 
@@ -1035,28 +1021,28 @@ void KoBorder::parseAndSetBorder(const BorderSide borderSide, const QString &bor
 void KoBorder::saveOdf(KoGenStyle &style, KoGenStyle::PropertyType type) const
 {
     // Get the strings that describe respective borders.
-    QString leftBorderString = QString("%1pt %2 %3")
+    QString leftBorderString = QStringLiteral("%1pt %2 %3")
                                  .arg(QString::number(borderWidth(LeftBorder)),
                                       odfBorderStyleString(borderStyle(LeftBorder)),
                                       borderColor(LeftBorder).name());
-    QString rightBorderString =  QString("%1pt %2 %3")
+    QString rightBorderString =  QStringLiteral("%1pt %2 %3")
                                   .arg(QString::number(borderWidth(RightBorder)),
                                        odfBorderStyleString(borderStyle(RightBorder)),
                                        borderColor(RightBorder).name());
-    QString topBorderString = QString("%1pt %2 %3")
+    QString topBorderString = QStringLiteral("%1pt %2 %3")
                                 .arg(QString::number(borderWidth(TopBorder)),
                                      odfBorderStyleString(borderStyle(TopBorder)),
                                      borderColor(TopBorder).name());
-    QString bottomBorderString = QString("%1pt %2 %3")
+    QString bottomBorderString = QStringLiteral("%1pt %2 %3")
                                    .arg(QString::number(borderWidth(BottomBorder)),
                                         odfBorderStyleString(borderStyle(BottomBorder)),
                                         borderColor(BottomBorder).name());
 
-    QString tlbrBorderString = QString("%1pt %2 %3")
+    QString tlbrBorderString = QStringLiteral("%1pt %2 %3")
                                 .arg(QString::number(borderWidth(TlbrBorder)),
                                      odfBorderStyleString(borderStyle(TlbrBorder)),
                                      borderColor(TlbrBorder).name());
-    QString trblBorderString = QString("%1pt %2 %3")
+    QString trblBorderString = QStringLiteral("%1pt %2 %3")
                                    .arg(QString::number(borderWidth(BltrBorder)),
                                         odfBorderStyleString(borderStyle(BltrBorder)),
                                         borderColor(BltrBorder).name());
@@ -1107,28 +1093,28 @@ void KoBorder::saveOdf(KoGenStyle &style, KoGenStyle::PropertyType type) const
     }
 
     // Handle double borders
-    QString leftBorderLineWidth = QString("%1pt %2pt %3pt")
+    QString leftBorderLineWidth = QStringLiteral("%1pt %2pt %3pt")
                                     .arg(QString::number(innerBorderWidth(LeftBorder)),
                                          QString::number(borderSpacing(LeftBorder)),
                                          QString::number(outerBorderWidth(LeftBorder)));
-    QString rightBorderLineWidth = QString("%1pt %2pt %3pt")
+    QString rightBorderLineWidth = QStringLiteral("%1pt %2pt %3pt")
                                      .arg(QString::number(innerBorderWidth(RightBorder)),
                                           QString::number(borderSpacing(RightBorder)),
                                           QString::number(outerBorderWidth(RightBorder)));
-    QString topBorderLineWidth = QString("%1pt %2pt %3pt")
+    QString topBorderLineWidth = QStringLiteral("%1pt %2pt %3pt")
                                    .arg(QString::number(innerBorderWidth(TopBorder)),
                                         QString::number(borderSpacing(TopBorder)),
                                         QString::number(outerBorderWidth(TopBorder)));
-    QString bottomBorderLineWidth = QString("%1pt %2pt %3pt")
+    QString bottomBorderLineWidth = QStringLiteral("%1pt %2pt %3pt")
                                       .arg(QString::number(innerBorderWidth(BottomBorder)),
                                            QString::number(borderSpacing(BottomBorder)),
                                            QString::number(outerBorderWidth(BottomBorder)));
 
-    QString tlbrBorderLineWidth = QString("%1pt %2pt %3pt")
+    QString tlbrBorderLineWidth = QStringLiteral("%1pt %2pt %3pt")
                                    .arg(QString::number(innerBorderWidth(TlbrBorder)),
                                         QString::number(borderSpacing(TlbrBorder)),
                                         QString::number(outerBorderWidth(TlbrBorder)));
-    QString trblBorderLineWidth = QString("%1pt %2pt %3pt")
+    QString trblBorderLineWidth = QStringLiteral("%1pt %2pt %3pt")
                                       .arg(QString::number(innerBorderWidth(BltrBorder)),
                                            QString::number(borderSpacing(BltrBorder)),
                                            QString::number(outerBorderWidth(BltrBorder)));
