@@ -1,21 +1,8 @@
 /* This file is part of the KDE project
-   Copyright (C) 2005 David Faure <faure@kde.org>
-   Copyright (C) 2007 Thorsten Zachmann <zachmann@kde.org>
+   SPDX-FileCopyrightText: 2005 David Faure <faure@kde.org>
+   SPDX-FileCopyrightText: 2007 Thorsten Zachmann <zachmann@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #ifndef KOODFREADSTORE_H
 #define KOODFREADSTORE_H
@@ -79,14 +66,14 @@ public:
      * Load and parse
      *
      * This function loads and parses the content.xml, styles.xml and the settings.xml
-     * file in the store. The sytles are already parsed.
+     * file in the store. The styles are already parsed.
      *
      * After this function is called you can access the data via
      * styles()
      * contentDoc()
      * settingsDoc()
      *
-     * @param errorMessage The errorMessage is set in case an error is encounted.
+     * @param errorMessage The errorMessage is set in case an error is encountered.
      * @return true if loading and parsing was successful, false otherwise. In case of an error
      * the errorMessage is updated accordingly.
      */
@@ -96,6 +83,7 @@ public:
      * Load a file from an odf store
      */
     bool loadAndParse(const QString &fileName, KoXmlDocument &doc, QString &errorMessage);
+    bool loadAndParse(const char *fileName, KoXmlDocument &doc, QString &errorMessage);
 
     /**
      * Load a file and parse from a QIODevice
