@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
- * Copyright (C) 2019 Dag Andersen <danders@get2net.dk>
+ * SPDX-FileCopyrightText: 2019 Dag Andersen <dag.andersen@kdemail.net>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 // clazy:excludeall=qstring-arg
@@ -25,7 +12,6 @@
 #include "kptcommand.h"
 #include "kptitemmodelbase.h"
 #include "kptdurationspinbox.h"
-#include "Help.h"
 #include "KoIcon.h"
 
 #include <KLocalizedString>
@@ -90,7 +76,7 @@ BaseDelegate::BaseDelegate(QObject *parent)
 
 void BaseDelegate::slotEditorDestroyed(QObject*)
 {
-    emit const_cast<BaseDelegate*>(this)->editModeChanged(false);
+    Q_EMIT const_cast<BaseDelegate*>(this)->editModeChanged(false);
 }
 
 PredeccessorDelegate::PredeccessorDelegate(Project *project, Node *task, QObject *parent)
@@ -105,7 +91,7 @@ QWidget *PredeccessorDelegate::createEditor(QWidget *parent, const QStyleOptionV
     QComboBox *editor = new QComboBox(parent);
     editor->installEventFilter(const_cast<PredeccessorDelegate*>(this));
     connect(editor, &QComboBox::destroyed, this, &BaseDelegate::slotEditorDestroyed);
-    emit const_cast<PredeccessorDelegate*>(this)->editModeChanged(true);
+    Q_EMIT const_cast<PredeccessorDelegate*>(this)->editModeChanged(true);
     return editor;
 }
 
@@ -113,7 +99,7 @@ void PredeccessorDelegate::setEditorData(QWidget *editor, const QModelIndex &ind
 {
     QComboBox *e = static_cast<QComboBox*>(editor);
     if (m_task && m_project) {
-        QList<Task*> tasks = sortedTasks(m_project, static_cast<Task*>(m_task), index);
+        const QList<Task*> tasks = sortedTasks(m_project, static_cast<Task*>(m_task), index);
         for (Task *t : tasks) {
             e->addItem(t->name(), t->id());
         }
@@ -150,7 +136,7 @@ QWidget *TypeDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem
     QComboBox *editor = new QComboBox(parent);
     editor->installEventFilter(const_cast<TypeDelegate*>(this));
     connect(editor, &QComboBox::destroyed, this, &BaseDelegate::slotEditorDestroyed);
-    emit const_cast<TypeDelegate*>(this)->editModeChanged(true);
+    Q_EMIT const_cast<TypeDelegate*>(this)->editModeChanged(true);
     return editor;
 }
 
@@ -185,7 +171,7 @@ QWidget *LagDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem &
     DurationSpinBox *editor = new DurationSpinBox(parent);
     editor->installEventFilter(const_cast<LagDelegate*>(this));
     connect(editor, &QComboBox::destroyed, this, &BaseDelegate::slotEditorDestroyed);
-    emit const_cast<LagDelegate*>(this)->editModeChanged(true);
+    Q_EMIT const_cast<LagDelegate*>(this)->editModeChanged(true);
     return editor;
 }
 
@@ -277,15 +263,15 @@ RelationEditorDialog::RelationEditorDialog(Project *project, Node *task, QWidget
 
     BaseDelegate *del = new PredeccessorDelegate(project, task, ui.view);
     connect(del, &BaseDelegate::editModeChanged, this, &RelationEditorDialog::slotDisableInsert);
-    connect(del, &BaseDelegate::editModeChanged, ui.removeBtn, &QAbstractButton::setDisabled);
+    connect(del, &BaseDelegate::editModeChanged, this, &RelationEditorDialog::slotDisableRemove);
     ui.view->setItemDelegateForColumn(0, del);
     del = new TypeDelegate(ui.view);
     connect(del, &BaseDelegate::editModeChanged, ui.addBtn, &QAbstractButton::setDisabled);
-    connect(del, &BaseDelegate::editModeChanged, ui.removeBtn, &QAbstractButton::setDisabled);
+    connect(del, &BaseDelegate::editModeChanged, this, &RelationEditorDialog::slotDisableRemove);
     ui.view->setItemDelegateForColumn(1, del);
     del = new LagDelegate(ui.view);
     connect(del, &BaseDelegate::editModeChanged, ui.addBtn, &QAbstractButton::setDisabled);
-    connect(del, &BaseDelegate::editModeChanged, ui.removeBtn, &QAbstractButton::setDisabled);
+    connect(del, &BaseDelegate::editModeChanged, this, &RelationEditorDialog::slotDisableRemove);
     ui.view->setItemDelegateForColumn(2, del);
     ui.view->setColumnWidth(0, 280);
 
@@ -299,8 +285,9 @@ RelationEditorDialog::RelationEditorDialog(Project *project, Node *task, QWidget
     }
     slotDisableInsert(false);
     connect(ui.view->selectionModel(), &QItemSelectionModel::currentChanged, this, &RelationEditorDialog::slotCurrentChanged);
+    slotCurrentChanged(ui.view->selectionModel()->currentIndex());
 
-    Help::add(this, xi18nc("@info:whatsthis",
+    setWhatsThis( xi18nc("@info:whatsthis",
                            "<title>Task Dependency Dialog</title>"
                            "<para>"
                            "The task dependency dialog enables you to easily add a predecessor to the selected task."
@@ -315,6 +302,13 @@ void RelationEditorDialog::slotCurrentChanged(const QModelIndex &idx)
 {
     QStandardItemModel *m = static_cast<QStandardItemModel*>(ui.view->model());
     QStandardItem *item = m->itemFromIndex(idx);
+    if (!item) {
+        ui.removeBtn->setEnabled(false);
+        return;
+    } else {
+        ui.removeBtn->setEnabled(true);
+    }
+
     if (item->data().toBool()) {
         ui.removeBtn->defaultAction()->setIcon(koIcon("edit-undo"));
         ui.removeBtn->defaultAction()->setText(i18n("Un-Delete"));
@@ -324,9 +318,8 @@ void RelationEditorDialog::slotCurrentChanged(const QModelIndex &idx)
     }
 }
 
-void RelationEditorDialog::slotDisableInsert(bool _disable)
+void RelationEditorDialog::slotDisableInsert(bool disable)
 {
-    bool disable = _disable;
     if (!disable) {
         QList<Task*> tasks = m_project->allTasks();
         tasks.removeAll(m_task);
@@ -346,6 +339,12 @@ void RelationEditorDialog::slotDisableInsert(bool _disable)
     ui.addBtn->setDisabled(disable);
 }
 
+void RelationEditorDialog::slotDisableRemove(bool disable)
+{
+    QModelIndex cidx = ui.view->selectionModel()->currentIndex();
+    ui.removeBtn->setDisabled(disable || !cidx.isValid());
+}
+
 void RelationEditorDialog::addRelation()
 {
     QStandardItemModel *m = static_cast<QStandardItemModel*>(ui.view->model());
@@ -368,6 +367,8 @@ void RelationEditorDialog::addRelation()
 void RelationEditorDialog::removeRelation()
 {
     QModelIndex cidx = ui.view->selectionModel()->currentIndex();
+    if (!cidx.isValid()) return;
+
     cidx = cidx.sibling(cidx.row(), 0);
     if (cidx.isValid()) {
         QModelIndex idx = cidx;
@@ -376,14 +377,14 @@ void RelationEditorDialog::removeRelation()
         if (item->data().toBool()) {
             // undelete
             item->setIcon(QIcon());
-            item->setData(false); // deleted
+            item->setData(false, TASKDELETED_ROLE); // deleted
             idx = idx.sibling(idx.row(), 1);
             m->itemFromIndex(idx)->setEnabled(true);
             idx = idx.sibling(idx.row(), 2);
             m->itemFromIndex(idx)->setEnabled(true);
         } else {
             item->setIcon(koIcon("edit-delete"));
-            item->setData(true); // deleted
+            item->setData(true, TASKDELETED_ROLE); // deleted
             idx = idx.sibling(idx.row(), 1);
             m->itemFromIndex(idx)->setEnabled(false);
             idx = idx.sibling(idx.row(), 2);
@@ -420,10 +421,10 @@ MacroCommand *RelationEditorDialog::buildCommand() {
             Relation *r = it.key();
             if (pred == r->parent()) {
                 it.setValue(Skip);
-                if (type == r->type()) {
+                if (type != r->type()) {
                     c->addCommand(new ModifyRelationTypeCmd(r, type));
                 }
-                if (lag == r->lag()) {
+                if (lag != r->lag()) {
                     c->addCommand(new ModifyRelationLagCmd(r, lag));
                 }
                 found = true;
