@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
-   Copyright (C) 2017 Dag Andersen <danders@get2net.dk>
+   SPDX-FileCopyrightText: 2017 Dag Andersen <dag.andersen@kdemail.net>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef TASKSEDITDIALOGWIDGET_H
@@ -22,7 +9,7 @@
 
 #include "planui_export.h"
 
-#include <kpagedialog.h>
+#include <KPageDialog>
 
 
 namespace KPlato
@@ -51,7 +38,7 @@ public:
      * @param tasks the list of tasks to be edited
      * @param parent parent widget
      */
-    TasksEditDialog(Project &project, const QList<Task*> &tasks, QWidget *parent=0);
+    TasksEditDialog(Project &project, const QList<Task*> &tasks, QWidget *parent=nullptr);
 
     virtual MacroCommand *buildCommand();
 
