@@ -1,22 +1,9 @@
 /* This file is part of the KDE project
- * Copyright (C) 2007, 2012 Dag Andersen <danders@get2net>
- * Copyright (C) 2017 Dag Andersen <danders@get2net>
- * Copyright (C) 2019 Dag Andersen <danders@get2net>
+ * SPDX-FileCopyrightText: 2007, 2012 Dag Andersen <dag.andersen@kdemail.net>
+ * SPDX-FileCopyrightText: 2017 Dag Andersen <dag.andersen@kdemail.net>
+ * SPDX-FileCopyrightText: 2019 Dag Andersen <dag.andersen@kdemail.net>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 // clazy:excludeall=qstring-arg
@@ -35,7 +22,6 @@
 #include "kptdatetime.h"
 #include "kptintervaledit.h"
 #include "kptitemviewsettup.h"
-#include "Help.h"
 #include "kptdebug.h"
 
 #include <KoIcon.h>
@@ -49,7 +35,7 @@
 #include <QMenu>
 
 #include <KLocalizedString>
-#include <kactioncollection.h>
+#include <KActionCollection>
 
 #include <KoDocument.h>
 
@@ -63,13 +49,13 @@ CalendarTreeView::CalendarTreeView(QWidget *parent)
     : TreeViewBase(parent)
 {
     header()->setContextMenuPolicy(Qt::CustomContextMenu);
-    setModel(new CalendarItemModel());
+    setModel(new CalendarItemModel(this));
 
     setSelectionBehavior(QAbstractItemView::SelectRows);
     setSelectionMode(QAbstractItemView::SingleSelection);
-    setSelectionModel(new QItemSelectionModel(model()));
+    setSelectionModel(new QItemSelectionModel(model(), this));
 
-    setItemDelegateForColumn(CalendarItemModel::Scope, new EnumDelegate(this));
+    setItemDelegateForColumn(CalendarItemModel::Origin, new EnumDelegate(this));
     setItemDelegateForColumn(CalendarItemModel::TimeZone, new EnumDelegate(this)); // timezone
 #ifdef HAVE_KHOLIDAYS
     setItemDelegateForColumn(CalendarItemModel::HolidayRegion, new EnumDelegate(this));
@@ -79,34 +65,34 @@ CalendarTreeView::CalendarTreeView(QWidget *parent)
 
 void CalendarTreeView::slotHeaderContextMenuRequested(const QPoint &pos)
 {
-    emit contextMenuRequested(QModelIndex(), mapToGlobal(pos));
+    Q_EMIT contextMenuRequested(QModelIndex(), mapToGlobal(pos), QModelIndexList());
 }
 
 void CalendarTreeView::contextMenuEvent (QContextMenuEvent *event)
 {
-    emit contextMenuRequested(indexAt(event->pos()), event->globalPos());
+    Q_EMIT contextMenuRequested(indexAt(event->pos()), event->globalPos(), QModelIndexList());
 }
 
 void CalendarTreeView::focusInEvent (QFocusEvent *event)
 {
     //debugPlan;
     TreeViewBase::focusInEvent(event);
-    emit focusChanged();
+    Q_EMIT focusChanged();
 }
 
 void CalendarTreeView::focusOutEvent (QFocusEvent * event)
 {
     //debugPlan;
     TreeViewBase::focusInEvent(event);
-    emit focusChanged();
+    Q_EMIT focusChanged();
 }
 
 void CalendarTreeView::selectionChanged(const QItemSelection &sel, const QItemSelection &desel)
 {
     //debugPlan<<sel.indexes().count();
-    //foreach(const QModelIndex &i, selectionModel()->selectedIndexes()) { debugPlan<<i.row()<<","<<i.column(); }
+    //for (const QModelIndex &i : std::as_const(selectionModel()->selectedIndexes())) { debugPlan<<i.row()<<","<<i.column(); }
     TreeViewBase::selectionChanged(sel, desel);
-    emit sigSelectionChanged(selectionModel()->selectedIndexes());
+    Q_EMIT selectedIndexesChanged(selectionModel()->selectedIndexes());
 }
 
 void CalendarTreeView::currentChanged(const QModelIndex & current, const QModelIndex & previous)
@@ -115,7 +101,7 @@ void CalendarTreeView::currentChanged(const QModelIndex & current, const QModelI
     TreeViewBase::currentChanged(current, previous);
     // possible bug in qt: in QAbstractItemView::SingleSelection you can select multiple items/rows
     selectionModel()->select(current, QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows);
-    emit currentChanged(current);
+    Q_EMIT currentIndexChanged(current);
 }
 
 Calendar *CalendarTreeView::currentCalendar() const
@@ -129,13 +115,14 @@ Calendar *CalendarTreeView::selectedCalendar() const
     if (lst.count() == 1) {
         return model()->calendar(lst.first());
     }
-    return 0;
+    return nullptr;
 }
 
 QList<Calendar*> CalendarTreeView::selectedCalendars() const
 {
     QList<Calendar *> lst;
-    foreach (const QModelIndex &i, selectionModel()->selectedRows()) {
+    const QModelIndexList indexes = selectionModel()->selectedRows();
+    for (const QModelIndex &i : indexes) {
         Calendar *a = model()->calendar(i);
         if (a) {
             lst << a;
@@ -155,15 +142,15 @@ void CalendarTreeView::dragMoveEvent(QDragMoveEvent *event)
     }
     // QTreeView thinks it's ok to drop, but it might not be...
     event->ignore();
-    QModelIndex index = indexAt(event->pos());
+    QModelIndex index = indexAt(event->position().toPoint());
     if (! index.isValid()) {
-        if (model()->dropAllowed(0, event->mimeData())) {
+        if (model()->dropAllowed(nullptr, event->mimeData())) {
             event->accept();
         }
         return;
     }
     Calendar *c = model()->calendar(index);
-    if (c == 0) {
+    if (c == nullptr) {
         errorPlan<<"no calendar to drop on!";
         return; // hmmm
     }
@@ -221,7 +208,7 @@ void CalendarDayView::slotSetWork()
         return;
     }
     Calendar *cal = model()->calendar();
-    if (cal == 0) {
+    if (cal == nullptr) {
         return;
     }
     QModelIndexList lst = selectionModel()->selectedIndexes();
@@ -232,9 +219,9 @@ void CalendarDayView::slotSetWork()
         return;
     }
     QList<CalendarDay*> days;
-    foreach (const QModelIndex &i, lst) {
+    for (const QModelIndex &i : std::as_const(lst)) {
         CalendarDay *day = model()->day(i);
-        if (day == 0) {
+        if (day == nullptr) {
             continue;
         }
         days << day;
@@ -247,13 +234,13 @@ void CalendarDayView::slotSetWork()
 void CalendarDayView::slotIntervalEditDialogFinished(int result)
 {
     IntervalEditDialog *dlg = qobject_cast<IntervalEditDialog*>(sender());
-    if (dlg == 0) {
+    if (dlg == nullptr) {
         return;
     }
     if (result == QDialog::Accepted) {
         MacroCommand *cmd = dlg->buildCommand();
         if (cmd) {
-            emit executeCommand(cmd);
+            Q_EMIT executeCommand(cmd);
         }
     }
     dlg->deleteLater();
@@ -274,16 +261,16 @@ void CalendarDayView::slotSetVacation()
     }
     bool mod = false;
     MacroCommand *m = new MacroCommand(kundo2_i18n("Modify Weekday State"));
-    foreach (const QModelIndex &i, lst) {
+    for (const QModelIndex &i : std::as_const(lst)) {
         CalendarDay *day = model()->day(i);
-        if (day == 0 || day->state() == CalendarDay::NonWorking) {
+        if (day == nullptr || day->state() == CalendarDay::NonWorking) {
             continue;
         }
         mod = true;
         m->addCommand(new CalendarModifyStateCmd(model()->calendar(), day, CalendarDay::NonWorking));
     }
     if (mod) {
-        emit executeCommand(m);
+        Q_EMIT executeCommand(m);
     } else {
         delete m;
     }
@@ -304,16 +291,16 @@ void CalendarDayView::slotSetUndefined()
     }
     bool mod = false;
     MacroCommand *m = new MacroCommand(kundo2_i18n("Modify Weekday State"));
-    foreach (const QModelIndex &i, lst) {
+    for (const QModelIndex &i : std::as_const(lst)) {
         CalendarDay *day = model()->day(i);
-        if (day == 0 || day->state() == CalendarDay::Undefined) {
+        if (day == nullptr || day->state() == CalendarDay::Undefined) {
             continue;
         }
         mod = true;
         m->addCommand(new CalendarModifyStateCmd(model()->calendar(), day, CalendarDay::Undefined));
     }
     if (mod) {
-        emit executeCommand(m);
+        Q_EMIT executeCommand(m);
     } else {
         delete m;
     }
@@ -327,7 +314,7 @@ void CalendarDayView::setCurrentCalendar(Calendar *calendar)
 void CalendarDayView::contextMenuEvent (QContextMenuEvent *event)
 {
     //debugPlan;
-    if (!isReadWrite() || !model()->calendar() || model()->calendar()->isShared()) {
+    if (!model()->calendar() || model()->calendar()->isShared()) {
         return;
     }
     QMenu menu;
@@ -337,29 +324,28 @@ void CalendarDayView::contextMenuEvent (QContextMenuEvent *event)
 
     menu.exec(event->globalPos(), actionSetWork);
 
-    //emit contextMenuRequested(indexAt(event->pos()), event->globalPos());
+    //Q_EMIT contextMenuRequested(indexAt(event->pos()), event->globalPos());
 }
 
 void CalendarDayView::focusInEvent (QFocusEvent *event)
 {
     //debugPlan;
     QTableView::focusInEvent(event);
-    emit focusChanged();
+    Q_EMIT focusChanged();
 }
 
 void CalendarDayView::focusOutEvent (QFocusEvent * event)
 {
     //debugPlan;
     QTableView::focusInEvent(event);
-    emit focusChanged();
+    Q_EMIT focusChanged();
 }
 
 void CalendarDayView::selectionChanged(const QItemSelection &sel, const QItemSelection &desel)
 {
     //debugPlan<<sel.indexes().count();
-    //foreach(QModelIndex i, selectionModel()->selectedIndexes()) { debugPlan<<i.row()<<","<<i.column(); }
     QTableView::selectionChanged(sel, desel);
-    emit sigSelectionChanged(selectionModel()->selectedIndexes());
+    Q_EMIT selectedIndexesChanged(selectionModel()->selectedIndexes());
 }
 
 void CalendarDayView::currentChanged(const QModelIndex & current, const QModelIndex & previous)
@@ -367,7 +353,7 @@ void CalendarDayView::currentChanged(const QModelIndex & current, const QModelIn
     //debugPlan;
     QTableView::currentChanged(current, previous);
 //    selectionModel()->select(current, QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows);
-    emit currentChanged(current);
+    Q_EMIT currentIndexChanged(current);
 }
 
 CalendarDay *CalendarDayView::selectedDay() const
@@ -376,7 +362,7 @@ CalendarDay *CalendarDayView::selectedDay() const
     if (lst.count() == 1) {
         return model()->day(lst.first());
     }
-    return 0;
+    return nullptr;
 }
 
 //-----------------------------------
@@ -384,13 +370,9 @@ CalendarEditor::CalendarEditor(KoPart *part, KoDocument *doc, QWidget *parent)
     : ViewBase(part, doc, parent),
     m_model(new DateTableDataModel(this))
 {
-    if (doc && doc->isReadWrite()) {
-        setXMLFile("CalendarEditorUi.rc");
-    } else {
-        setXMLFile("CalendarEditorUi_readonly.rc");
-    }
+    setXMLFile(QStringLiteral("CalendarEditorUi.rc"));
 
-    Help::add(this,
+    setWhatsThis(
               xi18nc("@info:whatsthis",
                       "<title>Work & Vacation Editor</title>"
                       "<para>"
@@ -405,12 +387,12 @@ CalendarEditor::CalendarEditor(KoPart *part, KoDocument *doc, QWidget *parent)
                       "A calendar can be defined as the <emphasis>Default calendar</emphasis>. "
                       "The default calendar is used by a working resource, when the resources calendar is not explicitly set."
                       "<nl/><link url='%1'>More...</link>"
-                      "</para>", Help::page("Work_and_Vacation_Editor")));
+                      "</para>", QStringLiteral("plan:work-and-vacation-editor")));
 
     setupGui();
 
     QVBoxLayout *l = new QVBoxLayout(this);
-    l->setMargin(0);
+    l->setContentsMargins(0, 0, 0, 0);
     QSplitter *sp = new QSplitter(this);
     l->addWidget(sp);
 
@@ -420,7 +402,7 @@ CalendarEditor::CalendarEditor(KoPart *part, KoDocument *doc, QWidget *parent)
 
     QFrame *f = new QFrame(sp);
     l = new QVBoxLayout(f);
-    l->setMargin(0);
+    l->setContentsMargins(0, 0, 0, 0);
 
     m_dayview = new CalendarDayView(f);
     l->addWidget(m_dayview);
@@ -442,7 +424,6 @@ CalendarEditor::CalendarEditor(KoPart *part, KoDocument *doc, QWidget *parent)
     m_calendarview->setAcceptDrops(true);
     m_calendarview->setAcceptDropsOnView(true);
 
-    connect(m_datePicker->dateTable(), SIGNAL(aboutToShowContextMenu(QMenu*,QDate)), SLOT(slotContextMenuDate(QMenu*,QDate)));
     connect(m_datePicker->dateTable(), SIGNAL(aboutToShowContextMenu(QMenu*,QList<QDate>)), SLOT(slotContextMenuDate(QMenu*,QList<QDate>)));
 
 /*    const QDate date(2007,7,19);
@@ -465,12 +446,12 @@ CalendarEditor::CalendarEditor(KoPart *part, KoDocument *doc, QWidget *parent)
     connect(m_dayview->model(), &ItemModelBase::executeCommand, doc, &KoDocument::addCommand);
     connect(m_dayview, &CalendarDayView::executeCommand, doc, &KoDocument::addCommand);
 
-    connect(m_calendarview, SIGNAL(currentChanged(QModelIndex)), this, SLOT(slotCurrentCalendarChanged(QModelIndex)));
-    connect(m_calendarview, &CalendarTreeView::sigSelectionChanged, this, &CalendarEditor::slotCalendarSelectionChanged);
-    connect(m_calendarview, SIGNAL(contextMenuRequested(QModelIndex,QPoint)), this, SLOT(slotContextMenuCalendar(QModelIndex,QPoint)));
+    connect(m_calendarview, &CalendarTreeView::currentIndexChanged, this, &CalendarEditor::slotCurrentCalendarChanged);
+    connect(m_calendarview, &CalendarTreeView::selectedIndexesChanged, this, &CalendarEditor::slotCalendarSelectionChanged);
+    connect(m_calendarview, &CalendarTreeView::contextMenuRequested, this, &CalendarEditor::slotContextMenuCalendar);
 
-    connect(m_dayview, SIGNAL(currentChanged(QModelIndex)), this, SLOT(slotCurrentDayChanged(QModelIndex)));
-    connect(m_dayview, &CalendarDayView::sigSelectionChanged, this, &CalendarEditor::slotDaySelectionChanged);
+    connect(m_dayview, &CalendarDayView::currentIndexChanged, this, &CalendarEditor::slotCurrentDayChanged);
+    connect(m_dayview, &CalendarDayView::selectedIndexesChanged, this, &CalendarEditor::slotDaySelectionChanged);
     connect(m_dayview, &CalendarDayView::contextMenuRequested, this, &CalendarEditor::slotContextMenuDay);
 
     connect(m_dayview->model(), &QAbstractItemModel::dataChanged, this, &CalendarEditor::slotEnableActions);
@@ -505,9 +486,6 @@ void CalendarEditor::setGuiActive(bool activate)
 
 void CalendarEditor::slotContextMenuDate(QMenu *menu, const QList<QDate> &dates)
 {
-    if (! isReadWrite()) {
-        return;
-    }
     if (!currentCalendar() || currentCalendar()->isShared()) {
         return;
     }
@@ -521,54 +499,15 @@ void CalendarEditor::slotContextMenuDate(QMenu *menu, const QList<QDate> &dates)
     menu->addAction(actionSetUndefined);
 }
 
-void CalendarEditor::slotContextMenuDate(QMenu *menu, const QDate &date)
-{
-    debugPlan<<menu<<date;
-    if (! isReadWrite() || ! date.isValid()) {
-        return;
-    }
-    if (!currentCalendar() || currentCalendar()->isShared()) {
-        return;
-    }
-    m_currentMenuDateList << date;
-    menu->addAction(actionSetWork);
-    menu->addAction(actionSetVacation);
-    menu->addAction(actionSetUndefined);
-}
-
 void CalendarEditor::slotContextMenuCalendar(const QModelIndex &index, const QPoint& pos)
 {
-    if (!index.isValid()) {
-        slotHeaderContextMenuRequested(pos);
-        return;
-    }
-    if (! isReadWrite() || !currentCalendar()) {
-        return;
-    }
-    //debugPlan<<index.row()<<","<<index.column()<<":"<<pos;
-    QString name;
-/*    if (index.isValid()) {
-        Calendar *a = m_calendarview->model()->calendar(index);
-        if (a) {
-            name = "calendareditor_calendar_popup";
-        }
-    }*/
-    //debugPlan<<name;
-    m_calendarview->setContextMenuIndex(index);
-    if (name.isEmpty()) {
-        slotHeaderContextMenuRequested(pos);
-        m_calendarview->setContextMenuIndex(QModelIndex());
-        return;
-    }
-    emit requestPopupMenu(name, pos);
-    m_calendarview->setContextMenuIndex(QModelIndex());
+    Q_UNUSED(index)
+    Q_UNUSED(pos)
+    slotHeaderContextMenuRequested(pos);
 }
 
 void CalendarEditor::slotContextMenuDay(const QModelIndex &index, const QPoint& pos)
 {
-    if (! isReadWrite()) {
-        return;
-    }
     debugPlan<<index.row()<<","<<index.column()<<":"<<pos;
 /*    QString name;
     if (index.isValid()) {
@@ -580,7 +519,7 @@ void CalendarEditor::slotContextMenuDay(const QModelIndex &index, const QPoint&
     if (name.isEmpty()) {
         return;
     }
-    emit requestPopupMenu(name, pos);*/
+    Q_EMIT requestPopupMenu(name, pos);*/
 }
 
 bool CalendarEditor::loadContext(const KoXmlElement &context)
@@ -644,17 +583,17 @@ void CalendarEditor::setupGui()
     KActionCollection *coll = actionCollection();
 
     actionAddCalendar = new QAction(koIcon("resource-calendar-insert"), i18n("Add Calendar"), this);
-    coll->addAction("add_calendar", actionAddCalendar);
-    coll->setDefaultShortcut(actionAddCalendar, Qt::CTRL + Qt::Key_I);
+    coll->addAction(QStringLiteral("add_calendar"), actionAddCalendar);
+    coll->setDefaultShortcut(actionAddCalendar, Qt::CTRL | Qt::Key_I);
     connect(actionAddCalendar , &QAction::triggered, this, &CalendarEditor::slotAddCalendar);
 
     actionAddSubCalendar = new QAction(koIcon("resource-calendar-child-insert"), i18n("Add Subcalendar"), this);
-    coll->addAction("add_subcalendar", actionAddSubCalendar);
-    coll->setDefaultShortcut(actionAddSubCalendar, Qt::SHIFT + Qt::CTRL + Qt::Key_I);
+    coll->addAction(QStringLiteral("add_subcalendar"), actionAddSubCalendar);
+    coll->setDefaultShortcut(actionAddSubCalendar, Qt::SHIFT | Qt::CTRL | Qt::Key_I);
     connect(actionAddSubCalendar , &QAction::triggered, this, &CalendarEditor::slotAddSubCalendar);
 
     actionDeleteSelection = new QAction(koIcon("edit-delete"), xi18nc("@action", "Delete"), this);
-    coll->addAction("delete_selection", actionDeleteSelection);
+    coll->addAction(QStringLiteral("delete_selection"), actionDeleteSelection);
     coll->setDefaultShortcut(actionDeleteSelection, Qt::Key_Delete);
     connect(actionDeleteSelection, &QAction::triggered, this, &CalendarEditor::slotDeleteCalendar);
 
@@ -687,7 +626,7 @@ void CalendarEditor::slotAddCalendar ()
     //debugPlan;
     // get parent through sibling
     Calendar *cal = m_calendarview->selectedCalendar();
-    Calendar *parent = cal ? cal->parentCal() : 0;
+    Calendar *parent = cal ? cal->parentCal() : nullptr;
     int pos = parent ? parent->indexOf(cal) : project()->indexOf(cal);
     if (pos >= 0) {
         ++pos; // after selected calendar
@@ -780,7 +719,7 @@ void CalendarEditor::slotAddDay ()
 void CalendarEditor::slotSetWork()
 {
     debugPlan<<currentCalendar()<<m_currentMenuDateList;
-    if (currentCalendar() == 0 || m_currentMenuDateList.isEmpty()) {
+    if (currentCalendar() == nullptr || m_currentMenuDateList.isEmpty()) {
         return;
     }
     IntervalEditDialog *dlg = new IntervalEditDialog(currentCalendar(), m_currentMenuDateList, this);
@@ -792,7 +731,7 @@ void CalendarEditor::slotSetWork()
 void CalendarEditor::slotIntervalEditDialogFinished(int result)
 {
     IntervalEditDialog *dlg = qobject_cast<IntervalEditDialog*>(sender());
-    if (dlg == 0) {
+    if (dlg == nullptr) {
         return;
     }
     if (result == QDialog::Accepted) {
@@ -807,15 +746,15 @@ void CalendarEditor::slotIntervalEditDialogFinished(int result)
 void CalendarEditor::slotSetVacation()
 {
     debugPlan<<m_currentMenuDateList;
-    if (m_currentMenuDateList.isEmpty() || currentCalendar() == 0) {
+    if (m_currentMenuDateList.isEmpty() || currentCalendar() == nullptr) {
         return;
     }
     bool mod = false;
     MacroCommand *m = new MacroCommand(kundo2_i18n("Modify Calendar"));
-    foreach (const QDate &date, m_currentMenuDateList) {
+    for (const QDate &date : std::as_const(m_currentMenuDateList)) {
         debugPlan<<"handle:"<<date;
         CalendarDay *day = currentCalendar()->findDay(date);
-        if (day == 0) {
+        if (day == nullptr) {
             mod = true;
             day = new CalendarDay(date, CalendarDay::NonWorking);
             m->addCommand(new CalendarAddDayCmd(currentCalendar(), day));
@@ -841,12 +780,12 @@ void CalendarEditor::slotSetVacation()
 void CalendarEditor::slotSetUndefined()
 {
     debugPlan;
-    if (m_currentMenuDateList.isEmpty() || currentCalendar() == 0) {
+    if (m_currentMenuDateList.isEmpty() || currentCalendar() == nullptr) {
         return;
     }
     bool mod = false;
     MacroCommand *m = new MacroCommand(kundo2_i18n("Modify Calendar"));
-    foreach (const QDate &date, m_currentMenuDateList) {
+    for (const QDate &date : std::as_const(m_currentMenuDateList)) {
         CalendarDay *day = currentCalendar()->findDay(date);
         if (day && day->state() != CalendarDay::Undefined) {
             mod = true;
