@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
-  Copyright (C) 2007 Dag Andersen <danders@get2net.dk>
+  SPDX-FileCopyrightText: 2007 Dag Andersen <dag.andersen@kdemail.net>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-* Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KPTITEMVIEWSETTUP_H
@@ -26,7 +13,7 @@
 
 #include <QListWidgetItem>
 
-#include <kpagedialog.h>
+#include <KPageDialog>
 
 class KoPageLayoutWidget;
 
@@ -42,7 +29,7 @@ class PLANUI_EXPORT ItemViewSettup : public QWidget, public Ui::ItemViewSettings
 {
     Q_OBJECT
 public:
-    explicit ItemViewSettup(TreeViewBase *view, bool includeColumn0, QWidget *parent = 0);
+    explicit ItemViewSettup(TreeViewBase *view, bool includeColumn0, QWidget *parent = nullptr);
     
     class Item : public QListWidgetItem
     {
@@ -71,7 +58,7 @@ class PLANUI_EXPORT ItemViewSettupDialog : public KPageDialog
 {
     Q_OBJECT
 public:
-    explicit ItemViewSettupDialog(ViewBase *view, TreeViewBase *treeview, bool includeColumn0 = false, QWidget *parent = 0);
+    explicit ItemViewSettupDialog(ViewBase *view, TreeViewBase *treeview, bool includeColumn0 = false, QWidget *parent = nullptr);
 
     KPageWidgetItem *insertWidget(int before, QWidget *widget, const QString &name, const QString &header);
     void addPrintingOptions(bool setAsCurrent = false);
@@ -92,7 +79,7 @@ class PLANUI_EXPORT SplitItemViewSettupDialog : public KPageDialog
 {
     Q_OBJECT
 public:
-    explicit SplitItemViewSettupDialog(ViewBase *view, DoubleTreeViewBase *treeview, QWidget *parent = 0);
+    explicit SplitItemViewSettupDialog(ViewBase *view, DoubleTreeViewBase *treeview, QWidget *parent = nullptr);
 
     KPageWidgetItem *insertWidget(int before, QWidget *widget, const QString &name, const QString &header);
     void addPrintingOptions(bool setAsCurrent = false);
