@@ -1,22 +1,9 @@
 /* This file is part of the KDE project
-  Copyright (C) 2007 Florian Piquemal <flotueur@yahoo.fr>
-  Copyright (C) 2007 Alexis Ménard <darktears31@gmail.com>
-  Copyright (C) 2007, 2012 Dag Andersen <danders@get2net>
+  SPDX-FileCopyrightText: 2007 Florian Piquemal <flotueur@yahoo.fr>
+  SPDX-FileCopyrightText: 2007 Alexis Ménard <darktears31@gmail.com>
+  SPDX-FileCopyrightText: 2007, 2012 Dag Andersen <dag.andersen@kdemail.net>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-* Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 // clazy:excludeall=qstring-arg
 #include "kptpertresult.h"
@@ -26,8 +13,12 @@
 #include "kptschedule.h"
 #include "kptitemviewsettup.h"
 #include "kptdebug.h"
+#include <kptcommand.h>
+#include "kpttaskdialog.h"
+#include "kptsummarytaskdialog.h"
 
 #include <KoDocument.h>
+#include <KoIcon.h>
 
 #include <KActionCollection>
 
@@ -83,12 +74,12 @@ static const double dist[][2] = {
 //-----------------------------------
 PertResult::PertResult(KoPart *part, KoDocument *doc, QWidget *parent)
     : ViewBase(part, doc, parent),
-    m_node(0),
-    m_project(0),
-    current_schedule(0)
+    m_node(nullptr),
+    m_project(nullptr),
+    current_schedule(nullptr)
 {
     debugPlan << " ---------------- KPlato: Creating PertResult ----------------";
-    setXMLFile("PertResultUi.rc");
+    setXMLFile(QStringLiteral("PertResultUi.rc"));
     widget.setupUi(this);
     PertResultItemModel *m = new PertResultItemModel(widget.treeWidgetTaskResult);
     widget.treeWidgetTaskResult->setModel(m);
@@ -145,7 +136,8 @@ void PertResult::draw()
         }
         widget.scheduleName->setText(model()->manager()->name());
         Duration f;
-        foreach (Node *n, m_project->allNodes()) {
+        const QList<Node*> nodes = m_project->allNodes();
+        for (Node *n : nodes) {
             if (n->type() == Node::Type_Task || n->type() == Node::Type_Milestone) {
                 f += static_cast<Task*>(n)->positiveFloat(id);
             }
@@ -156,6 +148,10 @@ void PertResult::draw()
 
 void PertResult::setupGui()
 {
+    auto actionOpenNode  = new QAction(koIcon("document-edit"), i18n("Edit..."), this);
+    actionCollection()->addAction(QStringLiteral("node_properties"), actionOpenNode);
+    connect(actionOpenNode, &QAction::triggered, this, &PertResult::slotOpenCurrentNode);
+
     // Add the context menu actions for the view options
     actionCollection()->addAction(widget.treeWidgetTaskResult->actionSplitView()->objectName(), widget.treeWidgetTaskResult->actionSplitView());
     connect(widget.treeWidgetTaskResult->actionSplitView(), &QAction::triggered, this, &PertResult::slotSplitView);
@@ -168,7 +164,7 @@ void PertResult::slotSplitView()
 {
     debugPlan;
     widget.treeWidgetTaskResult->setViewSplitMode(! widget.treeWidgetTaskResult->isViewSplit());
-    emit optionsModified();
+    Q_EMIT optionsModified();
 }
 
 Node *PertResult::currentNode() const
@@ -180,7 +176,7 @@ void PertResult::slotContextMenuRequested(const QModelIndex& index, const QPoint
 {
     debugPlan<<index<<pos;
     Node *node = model()->node(index);
-    if (node == 0) {
+    if (node == nullptr) {
         slotHeaderContextMenuRequested(pos);
         return;
     }
@@ -188,26 +184,19 @@ void PertResult::slotContextMenuRequested(const QModelIndex& index, const QPoint
     QString name;
     switch (node->type()) {
         case Node::Type_Task:
-            name = "task_popup";
+            name = QStringLiteral("task_edit_popup");
             break;
         case Node::Type_Milestone:
-            name = "taskeditor_milestone_popup";
-            break;
-        case Node::Type_Summarytask:
-            name = "summarytask_popup";
-            break;
-        case Node::Type_Project:
+            name = QStringLiteral("taskeditor_milestone_popup");
             break;
         default:
-            name = "node_popup";
             break;
     }
     if (name.isEmpty()) {
         slotHeaderContextMenuRequested(pos);
-        return;
+    } else {
+        openPopupMenu(name, pos);
     }
-    debugPlan<<name;
-    emit requestPopupMenu(name, pos);
 }
 
 void PertResult::slotHeaderContextMenuRequested(const QPoint &pos)
@@ -252,8 +241,8 @@ void PertResult::slotProjectCalculated(KPlato::ScheduleManager *sm)
 void PertResult::slotScheduleManagerToBeRemoved(const ScheduleManager *sm)
 {
     if (sm == model()->manager()) {
-        current_schedule = 0;
-        model()->setManager(0);
+        current_schedule = nullptr;
+        model()->setManager(nullptr);
     }
 }
 
@@ -301,11 +290,77 @@ KoPrintJob *PertResult::createPrintJob()
     return widget.treeWidgetTaskResult->createPrintJob(this);
 }
 
+void PertResult::slotOpenCurrentNode()
+{
+    //debugPlan;
+    slotOpenNode(currentNode());
+}
+
+void PertResult::slotOpenNode(Node *node)
+{
+    //debugPlan;
+    if (!node) {
+        return ;
+    }
+    switch (node->type()) {
+        case Node::Type_Task: {
+                Task *task = static_cast<Task *>(node);
+                TaskDialog *dia = new TaskDialog(*project(), *task, project()->accounts(), this);
+                connect(dia, &QDialog::finished, this, &PertResult::slotTaskEditFinished);
+                dia->open();
+                break;
+            }
+        case Node::Type_Milestone: {
+                // Use the normal task dialog for now.
+                // Maybe milestone should have it's own dialog, but we need to be able to
+                // enter a duration in case we accidentally set a tasks duration to zero
+                // and hence, create a milestone
+                Task *task = static_cast<Task *>(node);
+                TaskDialog *dia = new TaskDialog(*project(), *task, project()->accounts(), this);
+                connect(dia, &QDialog::finished, this, &PertResult::slotTaskEditFinished);
+                dia->open();
+                break;
+            }
+        default:
+            break;
+    }
+}
+
+void PertResult::slotTaskEditFinished(int result)
+{
+    TaskDialog *dia = qobject_cast<TaskDialog*>(sender());
+    if (dia == nullptr) {
+        return;
+    }
+    if (result == QDialog::Accepted) {
+        KUndo2Command *cmd = dia->buildCommand();
+        if (cmd) {
+            koDocument()->addCommand(cmd);
+        }
+    }
+    dia->deleteLater();
+}
+
+void PertResult::slotSummaryTaskEditFinished(int result)
+{
+    SummaryTaskDialog *dia = qobject_cast<SummaryTaskDialog*>(sender());
+    if (dia == nullptr) {
+        return;
+    }
+    if (result == QDialog::Accepted) {
+        KUndo2Command * cmd = dia->buildCommand();
+        if (cmd) {
+            koDocument()->addCommand(cmd);
+        }
+    }
+    dia->deleteLater();
+}
+
 //--------------------
 PertCpmView::PertCpmView(KoPart *part, KoDocument *doc, QWidget *parent)
     : ViewBase(part, doc, parent),
-    m_project(0),
-    current_schedule(0),
+    m_project(nullptr),
+    current_schedule(nullptr),
     block(false)
 {
     debugPlan << " ---------------- KPlato: Creating PertCpmView ----------------";
@@ -368,7 +423,7 @@ void PertCpmView::slotSplitView()
 {
     debugPlan;
     widget.cpmTable->setViewSplitMode(! widget.cpmTable->isViewSplit());
-    emit optionsModified();
+    Q_EMIT optionsModified();
 }
 
 Node *PertCpmView::currentNode() const
@@ -380,7 +435,7 @@ void PertCpmView::slotContextMenuRequested(const QModelIndex& index, const QPoin
 {
     debugPlan<<index<<pos;
     Node *node = model()->node(index);
-    if (node == 0) {
+    if (node == nullptr) {
         slotHeaderContextMenuRequested(pos);
         return;
     }
@@ -388,18 +443,18 @@ void PertCpmView::slotContextMenuRequested(const QModelIndex& index, const QPoin
     QString name;
     switch (node->type()) {
         case Node::Type_Task:
-            name = "task_popup";
+            name = QStringLiteral("task_popup");
             break;
         case Node::Type_Milestone:
-            name = "taskeditor_milestone_popup";
+            name = QStringLiteral("taskeditor_milestone_popup");
             break;
         case Node::Type_Summarytask:
-            name = "summarytask_popup";
+            name = QStringLiteral("summarytask_popup");
             break;
         case Node::Type_Project:
             break;
         default:
-            name = "node_popup";
+            name = QStringLiteral("node_popup");
             break;
     }
     if (name.isEmpty()) {
@@ -407,7 +462,7 @@ void PertCpmView::slotContextMenuRequested(const QModelIndex& index, const QPoin
         return;
     }
     debugPlan<<name;
-    emit requestPopupMenu(name, pos);
+    Q_EMIT requestPopupMenu(name, pos);
 }
 
 void PertCpmView::slotHeaderContextMenuRequested(const QPoint &pos)
@@ -456,8 +511,8 @@ void PertCpmView::slotScheduleManagerChanged(ScheduleManager *sm)
 void PertCpmView::slotScheduleManagerToBeRemoved(const ScheduleManager *sm)
 {
     if (sm == current_schedule) {
-        current_schedule = 0;
-        model()->setManager(0);
+        current_schedule = nullptr;
+        model()->setManager(nullptr);
         widget.probabilityFrame->setVisible(false);
     }
 }
@@ -511,7 +566,7 @@ void PertCpmView::draw()
 void PertCpmView::slotFinishTimeChanged(const QDateTime &dt)
 {
     debugPlan<<dt;
-    if (block || m_project == 0 || current_schedule == 0) {
+    if (block || m_project == nullptr || current_schedule == nullptr) {
         return;
     }
     block = true;
@@ -531,7 +586,7 @@ void PertCpmView::slotFinishTimeChanged(const QDateTime &dt)
 void PertCpmView::slotProbabilityChanged(int value)
 {
     debugPlan<<value;
-    if (value == 0 || block || m_project == 0 || current_schedule == 0) {
+    if (value == 0 || block || m_project == nullptr || current_schedule == nullptr) {
         return;
     }
     block = true;
