@@ -1,20 +1,7 @@
  /* This file is part of the KDE project
-   Copyright (C) 2005 - 2010 Dag Andersen <danders@get2net.dk>
+   SPDX-FileCopyrightText: 2005-2010 Dag Andersen <dag.andersen@kdemail.net>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KPTRESOURCEAPPOINTMENTSVIEW_H
@@ -22,12 +9,10 @@
 
 #include "planui_export.h"
 
-#include "ui_kptresourceappointmentsdisplayoptions.h"
-
 #include "kptviewbase.h"
 #include "kptresourceappointmentsmodel.h"
 
-#include <kpagedialog.h>
+#include <KPageDialog>
 
 #include <QDomDocument>
 
@@ -45,43 +30,21 @@ class Resource;
 class ResourceGroup;
 class ScheduleManager;
 class ResourceAppointmentsItemModel;
+class ResourceAppointmentsTreeView;
 
-//-------------------------------------------------
-class ResourceAppointmentsDisplayOptionsPanel : public QWidget, public Ui::ResourceAppointmentsDisplayOptions
+class ResourceAppointmentsConfigDialog : public KPageDialog
 {
-    Q_OBJECT
 public:
-    explicit ResourceAppointmentsDisplayOptionsPanel(ResourceAppointmentsItemModel *model, QWidget *parent = 0);
-
-    void setValues(const ResourceAppointmentsItemModel &del);
-
-public Q_SLOTS:
-    void slotOk();
-    void setDefault();
-
-Q_SIGNALS:
-    void changed();
-
-private:
-    ResourceAppointmentsItemModel *m_model;
-};
-
-class ResourceAppointmentsSettingsDialog : public KPageDialog
-{
-    Q_OBJECT
-public:
-    explicit ResourceAppointmentsSettingsDialog(ViewBase *view, ResourceAppointmentsItemModel *model, QWidget *parent = 0, bool selectPrint = false);
-
-public Q_SLOTS:
-    void slotOk();
+    ResourceAppointmentsConfigDialog(ViewBase *view, ResourceAppointmentsTreeView *treeview, QWidget *p, bool selectPrint = false);
 
 private:
     ViewBase *m_view;
+    ResourceAppointmentsTreeView *m_treeview;
     KoPageLayoutWidget *m_pagelayout;
     PrintingHeaderFooter *m_headerfooter;
+
 };
 
-//------------------------
 class PLANUI_EXPORT ResourceAppointmentsTreeView : public DoubleTreeViewBase
 {
     Q_OBJECT
@@ -123,8 +86,6 @@ public:
     void draw() override;
 
     ResourceAppointmentsItemModel *model() const { return m_view->model(); }
-    
-    void updateReadWrite(bool /*readwrite*/) override {};
 
     Node *currentNode() const override;
     Resource *currentResource() const override;
@@ -164,6 +125,15 @@ private Q_SLOTS:
     void slotAddGroup();
     void slotDeleteSelection();
 
+    void slotTaskProgress();
+    void slotTaskDescription();
+    void slotOpenTaskDescription(bool);
+    void slotDocuments();
+
+    void slotTaskProgressFinished(int result);
+    void slotTaskDescriptionFinished(int result);
+    void slotDocumentsFinished(int result);
+
 private:
     ResourceAppointmentsTreeView *m_view;
 
