@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
-   Copyright (C) 2004 - 2007, 2012 Dag Andersen <danders@get2net.dk>
+   SPDX-FileCopyrightText: 2004-2007, 2012 Dag Andersen <dag.andersen@kdemail.net>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 // clazy:excludeall=qstring-arg
@@ -53,7 +40,7 @@ public:
         delete day;
     }
     void setHours() {
-        setText(1, "-");
+        setText(1, QStringLiteral("-"));
         day->clearIntervals();
     }
     void setIntervals(QList<TimeInterval*> intervals) {
@@ -65,11 +52,11 @@ public:
     }
     
     MacroCommand *save() {
-        MacroCommand *cmd=0;
+        MacroCommand *cmd=nullptr;
         if (*original != *day) {
             cmd = new MacroCommand();
             cmd->addCommand(new CalendarModifyWeekdayCmd(calendar, weekday, day));
-            day = 0;
+            day = nullptr;
         }
         return cmd;
     }
@@ -102,21 +89,21 @@ StandardWorktimeDialog::StandardWorktimeDialog(Project &p, QWidget *parent)
 MacroCommand *StandardWorktimeDialog::buildCommand() {
     //debugPlan;
     KUndo2MagicString n = kundo2_i18n("Modify Estimate Conversions");
-    MacroCommand *cmd = 0;
+    MacroCommand *cmd = nullptr;
     if (m_original->year() != dia->inYear()) {
-        if (cmd == 0) cmd = new MacroCommand(n);
+        if (cmd == nullptr) cmd = new MacroCommand(n);
         cmd->addCommand(new ModifyStandardWorktimeYearCmd(m_original, m_original->year(), dia->inYear()));
     }
     if (m_original->month() != dia->inMonth()) {
-        if (cmd == 0) cmd = new MacroCommand(n);
+        if (cmd == nullptr) cmd = new MacroCommand(n);
         cmd->addCommand(new ModifyStandardWorktimeMonthCmd(m_original, m_original->month(), dia->inMonth()));
     }
     if (m_original->week() != dia->inWeek()) {
-        if (cmd == 0) cmd = new MacroCommand(n);
+        if (cmd == nullptr) cmd = new MacroCommand(n);
         cmd->addCommand(new ModifyStandardWorktimeWeekCmd(m_original, m_original->week(), dia->inWeek()));
     }
     if (m_original->day() != dia->inDay()) {
-        if (cmd == 0) cmd = new MacroCommand(n);
+        if (cmd == nullptr) cmd = new MacroCommand(n);
         cmd->addCommand(new ModifyStandardWorktimeDayCmd(m_original, m_original->day(), dia->inDay()));
     }
     return cmd;
@@ -156,11 +143,11 @@ StandardWorktimeDialogImpl::StandardWorktimeDialogImpl(StandardWorktime *std, QW
 
 
 void StandardWorktimeDialogImpl::slotEnableButtonOk(bool on) {
-    emit enableButtonOk(on);
+    Q_EMIT enableButtonOk(on);
 }
 
 void StandardWorktimeDialogImpl::slotCheckAllFieldsFilled() {
-    emit obligatedFieldsFilled(true);
+    Q_EMIT obligatedFieldsFilled(true);
 }
 
 void StandardWorktimeDialogImpl::slotYearChanged(double value) {
