@@ -1,21 +1,8 @@
 /* This file is part of the KDE project
-   Copyright (C) 2002 Bo Thorsen  bo@sonofthor.dk
-   Copyright (C) 2004 -2010 Dag Andersen <danders@get2net.dk>
+   SPDX-FileCopyrightText: 2002 Bo Thorsen bo @sonofthor.dk
+   SPDX-FileCopyrightText: 2004-2010 Dag Andersen <dag.andersen@kdemail.net>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KPTTASKDIALOG_H
@@ -23,7 +10,7 @@
 
 #include "planui_export.h"
 
-#include <kpagedialog.h>
+#include <KPageDialog>
 
 
 namespace KPlato
@@ -53,7 +40,7 @@ public:
      * @param accounts all defined accounts
      * @param parent parent widget
      */
-    TaskDialog(Project &project, Task &task, Accounts &accounts, QWidget *parent=0);
+    TaskDialog(Project &project, Task &task, Accounts &accounts, QWidget *parent=nullptr);
 
     virtual MacroCommand *buildCommand();
 
@@ -78,7 +65,7 @@ protected:
 class PLANUI_EXPORT TaskAddDialog : public TaskDialog {
     Q_OBJECT
 public:
-    TaskAddDialog(Project &project, Task &task, Node *currentNode, Accounts &accounts, QWidget *parent=0);
+    TaskAddDialog(Project &project, Task &task, Node *currentNode, Accounts &accounts, QWidget *parent=nullptr);
     ~TaskAddDialog() override;
 
     MacroCommand *buildCommand() override;
@@ -93,7 +80,7 @@ private:
 class PLANUI_EXPORT SubTaskAddDialog : public TaskDialog {
     Q_OBJECT
 public:
-    SubTaskAddDialog(Project &project, Task &task, Node *currentNode, Accounts &accounts, QWidget *parent=0);
+    SubTaskAddDialog(Project &project, Task &task, Node *currentNode, Accounts &accounts, QWidget *parent=nullptr);
     ~SubTaskAddDialog() override;
 
     MacroCommand *buildCommand() override;
