@@ -1,21 +1,8 @@
 /* This file is part of the KDE project
-  Copyright (C) 2006 -20010 Dag Andersen <danders@get2net.dk>
-  Copyright (C) 2019 Dag Andersen <danders@get2net.dk>
+  SPDX-FileCopyrightText: 2006-20010 Dag Andersen <dag.andersen@kdemail.net>
+  SPDX-FileCopyrightText: 2019 Dag Andersen <dag.andersen@kdemail.net>
   
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version..
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-* Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KPTTASKEDITOR_H
@@ -27,6 +14,8 @@
 #include "kptnodeitemmodel.h"
 #include "kptviewbase.h"
 
+#include <kptnode.h>
+
 class KoDocument;
 
 class KActionMenu;
@@ -36,6 +25,7 @@ namespace KPlato
 
 class Project;
 class Node;
+class Task;
 class NodeItemModel;
 class MacroCommand;
 
@@ -43,7 +33,7 @@ class PLANUI_EXPORT TaskEditorItemModel : public NodeItemModel
 {
     Q_OBJECT
 public:
-    explicit TaskEditorItemModel(QObject *parent = 0);
+    explicit TaskEditorItemModel(QObject *parent = nullptr);
     
     Qt::ItemFlags flags(const QModelIndex & index) const override;
     QVariant headerData(int section, Qt::Orientation orientation, int role) const override;
@@ -112,11 +102,11 @@ public:
     void setupGui();
     void setProject(Project *project) override;
     Project *project() const override { return m_view->project(); }
-    void createDockers() override;
 
     Node *currentNode() const override;
     QList<Node*> selectedNodes() const ;
     Node *selectedNode() const;
+    QList<Task*> selectedTasks(Node::NodeTypes type = Node::Type_Task) const;
 
     void updateReadWrite(bool readwrite) override;
 
@@ -138,7 +128,7 @@ Q_SIGNALS:
     void addMilestone();
     void addSubtask();
     void addSubMilestone();
-    void deleteTaskList(const QList<KPlato::Node*>&);
+//     void deleteTaskList(const QList<KPlato::Node*>&);
     void moveTaskUp();
     void moveTaskDown();
     void indentTask();
@@ -161,6 +151,7 @@ protected:
     int selectedRowCount() const;
     QModelIndexList selectedRows() const;
     void editTasks(const QList<Task*> &tasks, const QPoint &pos);
+    void createDockers();
 
 protected Q_SLOTS:
     void slotOptions() override;
@@ -183,14 +174,32 @@ private Q_SLOTS:
     void slotUnindentTask();
     void slotMoveTaskUp();
     void slotMoveTaskDown();
+    void slotTaskSplit();
 
     void slotSplitView();
     void slotProjectShown(bool);
 
     void taskModuleDoubleClicked(QModelIndex idx);
 
+    void slotOpenCurrentSelection();
+    void slotOpenNode(KPlato::Node *node);
+    void slotTaskProgress();
+    void slotOpenProjectDescription();
+    void slotTaskDescription();
+    void slotOpenTaskDescription(bool);
+    void slotDocuments();
+
+    void slotTaskEditFinished(int result);
+    void slotSummaryTaskEditFinished(int result);
+    void slotTaskProgressFinished(int result);
+    void slotMilestoneProgressFinished(int result);
+    void slotTaskDescriptionFinished(int result);
+    void slotDocumentsFinished(int result);
+
 private:
     void edit(const QModelIndex &index);
+    Node *newIndentParent(const QList<Node*> nodes) const;
+    void deleteTaskList(QList<Node*> lst);
 
 private:
     TaskEditorTreeView *m_view;
@@ -266,6 +275,21 @@ private Q_SLOTS:
 
     void slotSplitView();
 
+    void slotOpenCurrentNode();
+    void slotOpenNode(KPlato::Node *node);
+    void slotTaskProgress();
+    void slotOpenProjectDescription();
+    void slotTaskDescription();
+    void slotOpenTaskDescription(bool);
+    void slotDocuments();
+
+    void slotTaskEditFinished(int result);
+    void slotSummaryTaskEditFinished(int result);
+    void slotTaskProgressFinished(int result);
+    void slotMilestoneProgressFinished(int result);
+    void slotTaskDescriptionFinished(int result);
+    void slotDocumentsFinished(int result);
+
 private:
     NodeTreeView *m_view;
     QAction *actionShowProject;
@@ -325,7 +349,6 @@ public:
     KoPrintJob *createPrintJob() override;
 
 Q_SIGNALS:
-    void mailWorkpackage(KPlato::Node *n, KPlato::Resource *r = 0);
     void publishWorkpackages(const QList<KPlato::Node*> &nodes, KPlato::Resource *r, bool mailTo);
     void openWorkpackages();
     void checkForWorkPackages(bool);
@@ -359,6 +382,17 @@ private Q_SLOTS:
 
     void slotSplitView();
 
+    void slotTaskProgress();
+    void slotOpenProjectDescription();
+    void slotTaskDescription();
+    void slotOpenTaskDescription(bool);
+    void slotDocuments();
+
+    void slotTaskProgressFinished(int result);
+    void slotMilestoneProgressFinished(int result);
+    void slotTaskDescriptionFinished(int result);
+    void slotDocumentsFinished(int result);
+
 private:
     WorkPackageTreeView *m_view;
     MacroCommand *m_cmd;
