@@ -1,21 +1,8 @@
 /* This file is part of the KDE project
- * Copyright (C) 2019 Dag Andersen <danders@get2net.dk>
- * Copyright (C) 2007 - 2010, 2012 Dag Andersen <danders@get2net.dk>
+ * SPDX-FileCopyrightText: 2019 Dag Andersen <dag.andersen@kdemail.net>
+ * SPDX-FileCopyrightText: 2007-2010, 2012 Dag Andersen <dag.andersen@kdemail.net>
  * 
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- * 
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- * 
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 // clazy:excludeall=qstring-arg
@@ -29,8 +16,10 @@
 #include "kptproject.h"
 #include "kptschedule.h"
 #include "kpteffortcostmap.h"
-#include "Help.h"
 #include "kpttaskdescriptiondialog.h"
+#include "kpttaskprogressdialog.h"
+#include "kptmilestoneprogressdialog.h"
+#include "kptdocumentsdialog.h"
 #include "kptdebug.h"
 
 #include <KoXmlReader.h>
@@ -73,11 +62,10 @@ TaskStatusTreeView::TaskStatusTreeView(QWidget *parent)
     setContextMenuPolicy(Qt::CustomContextMenu);
     TaskStatusItemModel *m = new TaskStatusItemModel(this);
     setModel(m);
-    //setSelectionBehavior(QAbstractItemView::SelectItems);
+
     setSelectionMode(QAbstractItemView::ExtendedSelection);
     setSelectionBehavior(QAbstractItemView::SelectRows);
     setStretchLastSection(false);
-
     createItemDelegates(m);
 
     QList<int> lst1; lst1 << 1 << -1; // only display column 0 (NodeName) in left view
@@ -105,6 +93,21 @@ TaskStatusTreeView::TaskStatusTreeView(QWidget *parent)
     for (int i = 0; i < show.count(); ++i) {
         slaveView()->mapToSection(show.at(i), i);
     }
+
+    connect(masterView()->selectionModel(), &QItemSelectionModel::currentChanged, this, &TaskStatusTreeView::slotCurrentItemChanged);
+    connect(m, &TaskStatusItemModel::stateChanged, this, &TaskStatusTreeView::slotStateChanged);
+}
+
+void KPlato::TaskStatusTreeView::slotCurrentItemChanged(const QModelIndex& idx)
+{
+    masterView()->selectionModel()->select(idx, QItemSelectionModel::ClearAndSelect);
+}
+
+void KPlato::TaskStatusTreeView::slotStateChanged(KPlato::Node* node)
+{
+    const auto idx = model()->index(node).siblingAtColumn(NodeModel::NodeCompleted);
+    masterView()->expand(idx.parent());
+    masterView()->selectionModel()->setCurrentIndex(idx, QItemSelectionModel::ClearAndSelect);
 }
 
 int TaskStatusTreeView::weekday() const
@@ -163,14 +166,15 @@ void TaskStatusTreeView::setProject(Project *project)
 
 //-----------------------------------
 TaskStatusView::TaskStatusView(KoPart *part, KoDocument *doc, QWidget *parent)
-    : ViewBase(part, doc, parent),
-    m_id(-1)
+    : ViewBase(part, doc, parent)
+    , m_id(-1)
+    , m_commandDocument(doc)
 {
     debugPlan<<"-------------------- creating TaskStatusView -------------------";
-    setXMLFile("TaskStatusViewUi.rc");
+    setXMLFile(QStringLiteral("TaskStatusViewUi.rc"));
 
     QVBoxLayout * l = new QVBoxLayout(this);
-    l->setMargin(0);
+    l->setContentsMargins(0, 0, 0, 0);
     m_view = new TaskStatusTreeView(this);
     m_doubleTreeView = m_view;
     connect(this, &ViewBase::expandAll, m_view, &DoubleTreeViewBase::slotExpand);
@@ -195,8 +199,9 @@ TaskStatusView::TaskStatusView(KoPart *part, KoDocument *doc, QWidget *parent)
     m_view->masterView()->setExpandsOnDoubleClick(false);
     connect(m_view->masterView(), &TreeViewBase::doubleClicked, this, &TaskStatusView::itemDoubleClicked);
     connect(m_view->slaveView(), &TreeViewBase::doubleClicked, this, &TaskStatusView::itemDoubleClicked);
+    connect(m_view->selectionModel(), &QItemSelectionModel::selectionChanged, this, &TaskStatusView::slotSelectionChanged);
 
-    Help::add(this,
+    setWhatsThis(
               xi18nc("@info:whatsthis", 
                      "<title>Task Status View</title>"
                      "<para>"
@@ -212,20 +217,37 @@ TaskStatusView::TaskStatusView(KoPart *part, KoDocument *doc, QWidget *parent)
                      "</para><para>"
                      "This view supports configuration and printing using the context menu."
                      "<nl/><link url='%1'>More...</link>"
-                     "</para>", Help::page("Task_Status_View")));
-    
+                     "</para>", QStringLiteral("plan:task-status-view")));
+
+}
+
+void TaskStatusView::slotEditCopy()
+{
+    m_view->editCopy();
 }
 
 void TaskStatusView::itemDoubleClicked(const QPersistentModelIndex &idx)
 {
     if (idx.column() == NodeModel::NodeDescription) {
-        emit openTaskDescription(isReadWrite() && (idx.flags() & Qt::ItemIsEditable));
+        Node *node = m_view->model()->node(idx);
+        if (node) {
+            auto action = actionCollection()->action(QStringLiteral("task_description"));
+            if (action) {
+                if (node->type() == Node::Type_Project) {
+                    slotOpenProjectDescription();
+                } else {
+                    action->trigger();
+                }
+            }
+        }
     }
 }
 
 void TaskStatusView::updateReadWrite(bool rw)
 {
     m_view->setReadWrite(rw);
+    ViewBase::updateReadWrite(rw);
+    updateActionsEnabled(isReadWrite());
 }
 
 void TaskStatusView::setScheduleManager(ScheduleManager *sm)
@@ -235,7 +257,7 @@ void TaskStatusView::setScheduleManager(ScheduleManager *sm)
         // we should only get here if the only schedule manager is scheduled,
         // or when last schedule manager is deleted
         m_domdoc.clear();
-        QDomElement element = m_domdoc.createElement("expanded");
+        QDomElement element = m_domdoc.createElement(QStringLiteral("expanded"));
         m_domdoc.appendChild(element);
         m_view->masterView()->saveExpanded(element);
     }
@@ -243,7 +265,7 @@ void TaskStatusView::setScheduleManager(ScheduleManager *sm)
     bool expand = sm && scheduleManager() && sm != scheduleManager();
     QDomDocument doc;
     if (expand) {
-        QDomElement element = doc.createElement("expanded");
+        QDomElement element = doc.createElement(QStringLiteral("expanded"));
         doc.appendChild(element);
         m_view->masterView()->saveExpanded(element);
     }
@@ -262,6 +284,17 @@ Node *TaskStatusView::currentNode() const
     return m_view->model()->node(m_view->selectionModel()->currentIndex());
 }
 
+void KPlato::TaskStatusView::setCommandDocument(KoDocument* doc)
+{
+    if (m_commandDocument) {
+        disconnect(model(), &ItemModelBase::executeCommand, m_commandDocument, &KoDocument::addCommand);
+    }
+    m_commandDocument = doc;
+    if (doc) {
+        connect(model(), &ItemModelBase::executeCommand, doc, &KoDocument::addCommand);
+    }
+}
+
 void TaskStatusView::setProject(Project *project)
 {
     m_project = project;
@@ -276,7 +309,7 @@ void TaskStatusView::draw(Project &project)
 void TaskStatusView::setGuiActive(bool activate)
 {
     debugPlan<<activate;
-//    updateActionsEnabled(true);
+    slotSelectionChanged();
     ViewBase::setGuiActive(activate);
 }
 
@@ -289,7 +322,7 @@ void TaskStatusView::slotContextMenuRequested(const QModelIndex &index, const QP
     }
     m_view->setContextMenuIndex(index);
     Node *node = m_view->model()->node(index);
-    if (node == 0) {
+    if (node == nullptr) {
         slotHeaderContextMenuRequested(pos);
         m_view->setContextMenuIndex(QModelIndex());
         return;
@@ -302,15 +335,16 @@ void TaskStatusView::slotContextMenuRequested(Node *node, const QPoint& pos)
 {
     debugPlan<<node->name()<<" :"<<pos;
     QString name;
+    auto sid = scheduleManager() ? scheduleManager()->scheduleId() : -1;
     switch (node->type()) {
         case Node::Type_Task:
-            name = "taskstatus_popup";
+            name = node->isScheduled(sid) ? QStringLiteral("taskstatus_popup") : QStringLiteral("task_unscheduled_popup");
             break;
         case Node::Type_Milestone:
-            name = "taskview_milestone_popup";
+            name = node->isScheduled(sid) ? QStringLiteral("taskview_milestone_popup") : QStringLiteral("task_unscheduled_popup");
             break;
         case Node::Type_Summarytask:
-            name = "taskview_summary_popup";
+            name = QStringLiteral("taskview_summary_popup");
             break;
         default:
             break;
@@ -318,13 +352,25 @@ void TaskStatusView::slotContextMenuRequested(Node *node, const QPoint& pos)
     debugPlan<<name;
     if (name.isEmpty()) {
         slotHeaderContextMenuRequested(pos);
-        return;
+    } else {
+        openContextMenu(name, pos);
     }
-    emit requestPopupMenu(name, pos);
 }
 
 void TaskStatusView::setupGui()
 {
+    auto actionTaskProgress  = new QAction(koIcon("document-edit"), i18n("Progress..."), this);
+    actionCollection()->addAction(QStringLiteral("task_progress"), actionTaskProgress);
+    connect(actionTaskProgress, &QAction::triggered, this, &TaskStatusView::slotTaskProgress);
+
+    auto actionTaskDescription  = new QAction(koIcon("document-edit"), i18n("Description..."), this);
+    actionCollection()->addAction(QStringLiteral("task_description"), actionTaskDescription);
+    connect(actionTaskDescription, &QAction::triggered, this, &TaskStatusView::slotTaskDescription);
+
+    auto actionDocuments  = new QAction(koIcon("document-edit"), i18n("Documents..."), this);
+    actionCollection()->addAction(QStringLiteral("task_documents"), actionDocuments);
+    connect(actionDocuments, &QAction::triggered, this, &TaskStatusView::slotDocuments);
+
     // Add the context menu actions for the view options
     actionCollection()->addAction(m_view->actionSplitView()->objectName(), m_view->actionSplitView());
     connect(m_view->actionSplitView(), &QAction::triggered, this, &TaskStatusView::slotSplitView);
@@ -337,7 +383,7 @@ void TaskStatusView::slotSplitView()
 {
     debugPlan;
     m_view->setViewSplitMode(! m_view->isViewSplit());
-    emit optionsModified();
+    Q_EMIT optionsModified();
 }
 
 void TaskStatusView::slotRefreshView()
@@ -349,7 +395,7 @@ void TaskStatusView::slotOptions()
 {
     debugPlan;
     TaskStatusViewSettingsDialog *dlg = new TaskStatusViewSettingsDialog(this, m_view, this);
-    dlg->addPrintingOptions(sender()->objectName() == "print_options");
+    dlg->addPrintingOptions(sender()->objectName() == QStringLiteral("print_options"));
     connect(dlg, SIGNAL(finished(int)), SLOT(slotOptionsFinished(int)));
     dlg->open();
 }
@@ -358,20 +404,20 @@ bool TaskStatusView::loadContext(const KoXmlElement &context)
 {
     debugPlan;
     ViewBase::loadContext(context);
-    m_view->setPeriod(context.attribute("period", QString("%1").arg(m_view->defaultPeriod())).toInt());
+    m_view->setPeriod(context.attribute("period", QStringLiteral("%1").arg(m_view->defaultPeriod())).toInt());
 
-    m_view->setPeriodType(context.attribute("periodtype", QString("%1").arg(m_view->defaultPeriodType())).toInt());
+    m_view->setPeriodType(context.attribute("periodtype", QStringLiteral("%1").arg(m_view->defaultPeriodType())).toInt());
 
-    m_view->setWeekday(context.attribute("weekday", QString("%1").arg(m_view->defaultWeekday())).toInt());
+    m_view->setWeekday(context.attribute("weekday", QStringLiteral("%1").arg(m_view->defaultWeekday())).toInt());
     return m_view->loadContext(model()->columnMap(), context);
 }
 
 void TaskStatusView::saveContext(QDomElement &context) const
 {
     ViewBase::saveContext(context);
-    context.setAttribute("period", QString::number(m_view->period()));
-    context.setAttribute("periodtype", QString::number(m_view->periodType()));
-    context.setAttribute("weekday", QString::number(m_view->weekday()));
+    context.setAttribute(QStringLiteral("period"), QString::number(m_view->period()));
+    context.setAttribute(QStringLiteral("periodtype"), QString::number(m_view->periodType()));
+    context.setAttribute(QStringLiteral("weekday"), QString::number(m_view->weekday()));
     m_view->saveContext(model()->columnMap(), context);
 }
 
@@ -380,6 +426,187 @@ KoPrintJob *TaskStatusView::createPrintJob()
     return m_view->createPrintJob(this);
 }
 
+void TaskStatusView::slotSelectionChanged()
+{
+    updateActionsEnabled(m_view->selectionModel()->currentIndex().isValid());
+}
+
+void TaskStatusView::updateActionsEnabled(bool on)
+{
+    const auto node  = currentNode();
+    bool enable = on && node;
+
+    const auto c = actionCollection();
+    if (auto a = c->action(QStringLiteral("task_progress"))) { a->setEnabled(false); }
+    if (auto a = c->action(QStringLiteral("task_description"))) { a->setEnabled(enable); }
+    if (auto a = c->action(QStringLiteral("task_documents"))) { a->setEnabled(enable); }
+
+    if (enable) {
+        auto sid = scheduleManager() ? scheduleManager()->scheduleId() : -1;
+        switch (node->type()) {
+            case Node::Type_Task:
+            case Node::Type_Milestone:
+                if (auto a = c->action(QStringLiteral("task_progress"))) { a->setEnabled(enable && node->isScheduled(sid)); }
+                break;
+            default:
+                if (auto a = c->action(QStringLiteral("task_progress"))) { a->setEnabled(false); }
+                break;
+        }
+    }
+}
+
+void TaskStatusView::slotTaskProgress()
+{
+    //debugPlan;
+    Node * node = currentNode();
+    if (!node)
+        return ;
+
+    switch (node->type()) {
+        case Node::Type_Project: {
+                break;
+            }
+        case Node::Type_Subproject:
+            //TODO
+            break;
+        case Node::Type_Task: {
+                Task *task = dynamic_cast<Task *>(node);
+                Q_ASSERT(task);
+                TaskProgressDialog *dia = new TaskProgressDialog(*task, scheduleManager(),  project()->standardWorktime(), this);
+                connect(dia, &QDialog::finished, this, &TaskStatusView::slotTaskProgressFinished);
+                dia->open();
+                break;
+            }
+        case Node::Type_Milestone: {
+                Task *task = dynamic_cast<Task *>(node);
+                Q_ASSERT(task);
+                MilestoneProgressDialog *dia = new MilestoneProgressDialog(*task, this);
+                connect(dia, &QDialog::finished, this, &TaskStatusView::slotMilestoneProgressFinished);
+                dia->open();
+                break;
+            }
+        case Node::Type_Summarytask: {
+                // TODO
+                break;
+            }
+        default:
+            break; // avoid warnings
+    }
+}
+
+void TaskStatusView::slotTaskProgressFinished(int result)
+{
+    TaskProgressDialog *dia = qobject_cast<TaskProgressDialog*>(sender());
+    if (dia == nullptr) {
+        return;
+    }
+    if (result == QDialog::Accepted) {
+        KUndo2Command * m = dia->buildCommand();
+        if (m) {
+            m_commandDocument->addCommand(m);
+        }
+    }
+    dia->deleteLater();
+}
+
+void TaskStatusView::slotMilestoneProgressFinished(int result)
+{
+    MilestoneProgressDialog *dia = qobject_cast<MilestoneProgressDialog*>(sender());
+    if (dia == nullptr) {
+        return;
+    }
+    if (result == QDialog::Accepted) {
+        KUndo2Command * m = dia->buildCommand();
+        if (m) {
+            m_commandDocument->addCommand(m);
+        }
+    }
+    dia->deleteLater();
+}
+
+void TaskStatusView::slotOpenProjectDescription()
+{
+    TaskDescriptionDialog *dia = new TaskDescriptionDialog(*project(), this, !isReadWrite());
+    connect(dia, &QDialog::finished, this, &TaskStatusView::slotTaskDescriptionFinished);
+    dia->open();
+}
+
+void TaskStatusView::slotTaskDescription()
+{
+    slotOpenTaskDescription(!isReadWrite());
+}
+
+void TaskStatusView::slotOpenTaskDescription(bool ro)
+{
+    //debugPlan;
+    Node * node = currentNode();
+    if (!node)
+        return ;
+
+    switch (node->type()) {
+        case Node::Type_Task:
+        case Node::Type_Milestone:
+        case Node::Type_Summarytask: {
+                TaskDescriptionDialog *dia = new TaskDescriptionDialog(*node, this, ro);
+                connect(dia, &QDialog::finished, this, &TaskStatusView::slotTaskDescriptionFinished);
+                dia->open();
+                break;
+            }
+        default:
+            break;
+    }
+}
+
+void TaskStatusView::slotTaskDescriptionFinished(int result)
+{
+    TaskDescriptionDialog *dia = qobject_cast<TaskDescriptionDialog*>(sender());
+    if (dia == nullptr) {
+        return;
+    }
+    if (result == QDialog::Accepted) {
+        KUndo2Command * m = dia->buildCommand();
+        if (m) {
+            m_commandDocument->addCommand(m);
+        }
+    }
+    dia->deleteLater();
+}
+
+void TaskStatusView::slotDocuments()
+{
+    //debugPlan;
+    Node * node = currentNode();
+    if (!node) {
+        return ;
+    }
+    switch (node->type()) {
+        case Node::Type_Summarytask:
+        case Node::Type_Task:
+        case Node::Type_Milestone: {
+            DocumentsDialog *dia = new DocumentsDialog(*node, this);
+            connect(dia, &QDialog::finished, this, &TaskStatusView::slotDocumentsFinished);
+            dia->open();
+            break;
+        }
+        default:
+            break;
+    }
+}
+
+void TaskStatusView::slotDocumentsFinished(int result)
+{
+    DocumentsDialog *dia = qobject_cast<DocumentsDialog*>(sender());
+    if (dia == nullptr) {
+        return;
+    }
+    if (result == QDialog::Accepted) {
+        KUndo2Command * m = dia->buildCommand();
+        if (m) {
+            m_commandDocument->addCommand(m);
+        }
+    }
+    dia->deleteLater();
+}
 
 //------------------------------------------------
 TaskStatusViewSettingsPanel::TaskStatusViewSettingsPanel(TaskStatusTreeView *view, QWidget *parent)
