@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
-   Copyright (C) 2007, 2011, 2012 Dag Andersen <danders@get2net.dk>
+   SPDX-FileCopyrightText: 2007, 2011, 2012 Dag Andersen <dag.andersen@kdemail.net>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 // clazy:excludeall=qstring-arg
@@ -39,7 +26,7 @@ namespace KPlato
 
 UsedEffortItemModel::UsedEffortItemModel (QWidget *parent)
     : QAbstractItemModel(parent),
-    m_completion(0),
+    m_completion(nullptr),
     m_readonly(false)
 {
     m_headers << i18n("Resource");
@@ -84,14 +71,14 @@ QVariant UsedEffortItemModel::data (const QModelIndex &index, int role) const
                 break;
             }
             Completion::UsedEffort *ue = usedEffort(index);
-            if (ue == 0) {
+            if (ue == nullptr) {
                 return QVariant();
             }
             if (index.column() == 8) {
                 // Total
-                //debugPlan<<index.row()<<","<<index.column()<<" total"<<endl;
+                //debugPlan<<index.row()<<","<<index.column()<<" total"<<'\n';
                 double res = 0.0;
-                foreach (const QDate &d, m_dates) {
+                for (const QDate &d: std::as_const(m_dates)) {
                     Completion::UsedEffort::ActualEffort e = ue->effort(d);
                     res += e.normalEffort().toDouble(Duration::Unit_h);
                 }
@@ -107,13 +94,13 @@ QVariant UsedEffortItemModel::data (const QModelIndex &index, int role) const
             }
             if (index.column() == 0) {
                 const Resource *r = resource(index);
-                //debugPlan<<index.row()<<","<<index.column()<<" "<<r<<endl;
+                //debugPlan<<index.row()<<","<<index.column()<<" "<<r<<'\n';
                 if (r) {
                     return r->name();
                 }
             } else {
                 Completion::UsedEffort *ue = usedEffort(index);
-                if (ue == 0) {
+                if (ue == nullptr) {
                     return QVariant();
                 }
                 Completion::UsedEffort::ActualEffort e = ue->effort(m_dates.value(index.column() - 1));
@@ -150,31 +137,31 @@ bool UsedEffortItemModel::setData (const QModelIndex &idx, const QVariant &value
             }
             if (idx.column() == 0) {
                 const Resource *er = resource(idx);
-                Q_ASSERT(er != 0);
+                Q_ASSERT(er != nullptr);
 
                 Q_ASSERT (m_editlist.count() > value.toInt());
 
                 const Resource *v = m_editlist.values().value(value.toInt()); // clazy:exclude=container-anti-pattern
-                Q_ASSERT(v != 0);
+                Q_ASSERT(v != nullptr);
 
                 int x = m_resourcelist.indexOf(er);
                 Q_ASSERT(x != -1);
                 m_resourcelist.replace(x, v);
                 m_completion->addUsedEffort(v);
-                emit dataChanged(createIndex(idx.row(), 1), createIndex(idx.row(), columnCount() - 1));
-                emit rowInserted(createIndex(idx.row(), 0));
+                Q_EMIT dataChanged(createIndex(idx.row(), 1), createIndex(idx.row(), columnCount() - 1));
+                Q_EMIT rowInserted(createIndex(idx.row(), 0));
                 return true;
             }
             Completion::UsedEffort *ue = usedEffort(idx);
-            if (ue == 0) {
+            if (ue == nullptr) {
                 return false;
             }
             QDate d = m_dates.value(idx.column() - 1);
             Completion::UsedEffort::ActualEffort e = ue->effort(d);
             e.setNormalEffort(Duration(value.toDouble(), Duration::Unit_h));
             ue->setEffort(d, e);
-            emit effortChanged(d);
-            emit dataChanged(idx, idx);
+            Q_EMIT effortChanged(d);
+            Q_EMIT dataChanged(idx, idx);
             return true;
         }
         default: break;
@@ -191,8 +178,8 @@ bool UsedEffortItemModel::submit()
 void UsedEffortItemModel::revert()
 {
     debugPlan;
-    QList<const Resource*> lst = m_resourcelist;
-    foreach (const Resource *r, lst) {
+    const QList<const Resource*> lst = m_resourcelist;
+    for (const Resource *r : lst) {
         if (! m_completion->usedEffortMap().contains(r)) {
             int row = m_resourcelist.indexOf(r);
             if (row != -1) {
@@ -262,11 +249,11 @@ void UsedEffortItemModel::setCompletion(Completion *completion)
     beginResetModel();
     m_completion = completion;
     m_resourcelist.clear();
-    QMap<QString, const Resource*> lst;
+    QMultiMap<QString, const Resource*> lst;
     const Completion::ResourceUsedEffortMap &map = completion->usedEffortMap();
     Completion::ResourceUsedEffortMap::const_iterator it;
     for (it = map.constBegin(); it != map.constEnd(); ++it) {
-        lst.insertMulti(it.key()->name(), it.key());
+        lst.insert(it.key()->name(), it.key());
     }
     m_resourcelist = lst.values();
     endResetModel();
@@ -275,8 +262,8 @@ void UsedEffortItemModel::setCompletion(Completion *completion)
 const Resource *UsedEffortItemModel::resource(const QModelIndex &index) const
 {
     int row = index.row();
-    if (m_completion == 0 || row < 0 || row >= m_resourcelist.count()) {
-        return 0;
+    if (m_completion == nullptr || row < 0 || row >= m_resourcelist.count()) {
+        return nullptr;
     }
     return m_resourcelist.value(row);
 }
@@ -284,8 +271,8 @@ const Resource *UsedEffortItemModel::resource(const QModelIndex &index) const
 Completion::UsedEffort *UsedEffortItemModel::usedEffort(const QModelIndex &index) const
 {
     const Resource *r = resource(index);
-    if (r == 0) {
-        return 0;
+    if (r == nullptr) {
+        return nullptr;
     }
     return m_completion->usedEffort(r);
 }
@@ -298,12 +285,12 @@ void UsedEffortItemModel::setCurrentMonday(const QDate &date)
         m_dates << date.addDays(i);
     }
     endResetModel();
-    emit headerDataChanged (Qt::Horizontal, 1, 7);
+    Q_EMIT headerDataChanged (Qt::Horizontal, 1, 7);
 }
 
 QModelIndex UsedEffortItemModel::addRow()
 {
-    if (m_project == 0) {
+    if (m_project == nullptr) {
         return QModelIndex();
     }
     m_editlist.clear();
@@ -333,12 +320,13 @@ void UsedEffortItemModel::addResource(const QString &name)
     setData(createIndex(row, 0, const_cast<Resource*>(resource)), 0, Qt::EditRole);
 }
 
-QMap<QString, const Resource*> UsedEffortItemModel::freeResources() const
+QMultiMap<QString, const Resource*> UsedEffortItemModel::freeResources() const
 {
-    QMap<QString, const Resource*> map;
-    foreach (Resource *r, m_project->resourceList()) {
+    QMultiMap<QString, const Resource*> map;
+    const QList<Resource*> resources = m_project->resourceList();
+    for (Resource *r : resources) {
         if (! m_resourcelist.contains(r)) {
-            map.insertMulti(r->name(), r);
+            map.insert(r->name(), r);
         }
     }
     return map;
@@ -399,10 +387,10 @@ void UsedEffortEditor::addResource()
 //----------------------------------------
 CompletionEntryItemModel::CompletionEntryItemModel (QObject *parent)
     : QAbstractItemModel(parent),
-    m_node(0),
-    m_project(0),
-    m_manager(0),
-    m_completion(0)
+    m_node(nullptr),
+    m_project(nullptr),
+    m_manager(nullptr),
+    m_completion(nullptr)
 {
     m_headers << i18n("Date")
             // xgettext: no-c-format
@@ -421,7 +409,7 @@ CompletionEntryItemModel::CompletionEntryItemModel (QObject *parent)
 void CompletionEntryItemModel::setTask(Task *t)
 {
     m_node = t;
-    m_project = 0;
+    m_project = nullptr;
     if (m_node && m_node->projectNode()) {
         m_project = static_cast<Project*>(m_node->projectNode());
     }
@@ -460,7 +448,7 @@ QVariant CompletionEntryItemModel::date (int row, int role) const
 QVariant CompletionEntryItemModel::percentFinished (int row, int role) const
 {
     Completion::Entry *e = m_completion->entry(date(row).toDate());
-    if (e == 0) {
+    if (e == nullptr) {
         return QVariant();
     }
     switch (role) {
@@ -475,7 +463,7 @@ QVariant CompletionEntryItemModel::percentFinished (int row, int role) const
 QVariant CompletionEntryItemModel::remainingEffort (int row, int role) const
 {
     Completion::Entry *e = m_completion->entry(date(row).toDate());
-    if (e == 0) {
+    if (e == nullptr) {
         return QVariant();
     }
     switch (role) {
@@ -514,7 +502,7 @@ QVariant CompletionEntryItemModel::remainingEffort (int row, int role) const
 QVariant CompletionEntryItemModel::actualEffort (int row, int role) const
 {
     Completion::Entry *e = m_completion->entry(date(row).toDate());
-    if (e == 0) {
+    if (e == nullptr) {
         return QVariant();
     }
     switch (role) {
@@ -525,7 +513,7 @@ QVariant CompletionEntryItemModel::actualEffort (int row, int role) const
             } else {
                 v = e->totalPerformed;
             }
-            //debugPlan<<m_node->name()<<": "<<v<<" "<<unit<<" : "<<scales<<endl;
+            //debugPlan<<m_node->name()<<": "<<v<<" "<<unit<<" : "<<scales<<'\n';
             return v.format();
         }
         case Qt::EditRole:
@@ -560,7 +548,7 @@ QVariant CompletionEntryItemModel::actualEffort (int row, int role) const
 
 QVariant CompletionEntryItemModel::plannedEffort (int /*row*/, int role) const
 {
-    if (m_node == 0) {
+    if (m_node == nullptr) {
         return QVariant();
     }
     switch (role) {
@@ -637,14 +625,28 @@ bool CompletionEntryItemModel::setData (const QModelIndex &idx, const QVariant &
         case Qt::EditRole: {
             if (idx.column() == Property_Date) {
                 QDate od = date(idx.row()).toDate();
-                removeEntry(od);
-                addEntry(value.toDate());
-                // emit dataChanged(idx, idx);
-                return true;
+                QDate nd = value.toDate();
+                if (od == nd) {
+                    // new unedited entry
+                    addEntry(nd);
+                    // Q_EMIT dataChanged(idx, idx);
+                    return true;
+                }
+                if (!m_datelist.contains(nd)) {
+                    // date is edited so remove original
+                    removeEntry(od);
+                    // add new edited entry
+                    addEntry(nd);
+                    // Q_EMIT dataChanged(idx, idx);
+                    return true;
+                }
+                // probably a duplicate of an existing date
+                removeEntry(od); // just remove the new entry date to avoid duplicates for now
+                return false;
             }
             if (idx.column() == Property_Completion) {
                 Completion::Entry *e = m_completion->entry(date(idx.row()).toDate());
-                if (e == 0) {
+                if (e == nullptr) {
                     return false;
                 }
                 e->percentFinished = value.toInt();
@@ -654,12 +656,12 @@ bool CompletionEntryItemModel::setData (const QModelIndex &idx, const QVariant &
                     e->totalPerformed = est * e->percentFinished / 100;
                     e->remainingEffort = est - e->totalPerformed;
                 }
-                emit dataChanged(idx, createIndex(idx.row(), 3));
+                Q_EMIT dataChanged(idx, createIndex(idx.row(), 3));
                 return true;
             }
             if (idx.column() == Property_UsedEffort) {
                 Completion::Entry *e = m_completion->entry(date(idx.row()).toDate());
-                if (e == 0) {
+                if (e == nullptr) {
                     return false;
                 }
                 double v(value.toList()[0].toDouble());
@@ -669,12 +671,12 @@ bool CompletionEntryItemModel::setData (const QModelIndex &idx, const QVariant &
                     return false;
                 }
                 e->totalPerformed = d;
-                emit dataChanged(idx, idx);
+                Q_EMIT dataChanged(idx, idx);
                 return true;
             }
             if (idx.column() == Property_RemainingEffort) {
                 Completion::Entry *e = m_completion->entry(date(idx.row()).toDate());
-                if (e == 0) {
+                if (e == nullptr) {
                     return false;
                 }
                 double v(value.toList()[0].toDouble());
@@ -684,7 +686,7 @@ bool CompletionEntryItemModel::setData (const QModelIndex &idx, const QVariant &
                     return false;
                 }
                 e->remainingEffort = d;
-                emit dataChanged(idx, idx);
+                Q_EMIT dataChanged(idx, idx);
                 return true;
             }
         }
@@ -695,13 +697,13 @@ bool CompletionEntryItemModel::setData (const QModelIndex &idx, const QVariant &
 
 bool CompletionEntryItemModel::submit()
 {
-    debugPlan<<endl;
+    debugPlan<<'\n';
     return QAbstractItemModel::submit();
 }
 
 void CompletionEntryItemModel::revert()
 {
-    debugPlan<<endl;
+    debugPlan<<'\n';
     refresh();
 }
 
@@ -741,7 +743,7 @@ int CompletionEntryItemModel::columnCount(const QModelIndex & /*parent */) const
 
 int CompletionEntryItemModel::rowCount(const QModelIndex &idx) const
 {
-    if (m_completion == 0 || idx.isValid()) {
+    if (m_completion == nullptr || idx.isValid()) {
         return 0;
     }
     return m_datelist.count();
@@ -778,7 +780,7 @@ void CompletionEntryItemModel::refresh()
 
 QModelIndex CompletionEntryItemModel::addRow()
 {
-    if (m_completion == 0) {
+    if (m_completion == nullptr) {
         return QModelIndex();
     }
     int row = rowCount();
@@ -800,7 +802,7 @@ void CompletionEntryItemModel::removeEntry(const QDate& date)
 void CompletionEntryItemModel::removeRow(int row)
 {
     debugPlan<<row;
-    if (row < 0 && row >= rowCount()) {
+    if (row < 0 || row >= rowCount()) {
         return;
     }
     QDate date = m_datelist.value(row);
@@ -809,13 +811,13 @@ void CompletionEntryItemModel::removeRow(int row)
     endRemoveRows();
     debugPlan<<date<<" removed row"<<row;
     m_completion->takeEntry(date);
-    emit rowRemoved(date);
-    emit changed();
+    Q_EMIT rowRemoved(date);
+    Q_EMIT changed();
 }
 
 void CompletionEntryItemModel::addEntry(const QDate& date)
 {
-    debugPlan<<date<<endl;
+    debugPlan<<date<<'\n';
     Completion::Entry *e = new Completion::Entry();
     if (m_completion->entries().isEmpty()) {
         if (m_node) {
@@ -830,9 +832,9 @@ void CompletionEntryItemModel::addEntry(const QDate& date)
     refresh();
     int i = m_datelist.indexOf(date);
     if (i != -1) {
-        emit rowInserted(date);
-        emit dataChanged(createIndex(i, 1), createIndex(i, rowCount() - 1));
-    } else  errorPlan<<"Failed to find added entry: "<<date<<endl;
+        Q_EMIT rowInserted(date);
+        Q_EMIT dataChanged(createIndex(i, 1), createIndex(i, rowCount() - 1));
+    } else  errorPlan<<"Failed to find added entry: "<<date<<'\n';
 }
 
 void CompletionEntryItemModel::addRow(const QDate &date)
@@ -841,7 +843,7 @@ void CompletionEntryItemModel::addRow(const QDate &date)
         if (this->date(i).toDate() == date) {
             const QModelIndex idx1 = index(i, Property_UsedEffort);
             const QModelIndex idx2 = index(rowCount()-1, Property_UsedEffort);
-            emit dataChanged(idx1, idx2);
+            Q_EMIT dataChanged(idx1, idx2);
             return;
         }
     }
@@ -896,12 +898,12 @@ void CompletionEntryEditor::insertEntry(const QDate &date)
 
 void CompletionEntryEditor::addEntry()
 {
-    debugPlan<<endl;
+    debugPlan<<'\n';
     QModelIndex i = model()->addRow();
     if (i.isValid()) {
         model()->setFlags(i.column(), Qt::ItemIsEditable);
         setCurrentIndex(i);
-        emit selectedItemsChanged(QItemSelection(), QItemSelection()); //hmmm, control removeEntryBtn
+        Q_EMIT selectedItemsChanged(QItemSelection(), QItemSelection()); //hmmm, control removeEntryBtn
         scrollTo(i);
         edit(i);
         model()->setFlags(i.column(), Qt::NoItemFlags);
@@ -918,9 +920,14 @@ void CompletionEntryEditor::removeEntry()
         QModelIndex idx = lst.takeFirst();
         rows[ idx.row() ] = 0;
     }
-    QList<int> r = rows.uniqueKeys();
+    const auto r = rows.keys();
+    QList<int> removed;
     debugPlan<<rows<<r;
     for (int i = r.count() - 1; i >= 0; --i) {
+        if (removed.contains(r.at(i))) {
+            continue;
+        }
+        removed << r.at(i);
         model()->removeRow(r.at(i));
     }
 }
