@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
-  Copyright (C) 2006 -2010 Dag Andersen <danders@get2net.dk>
+  SPDX-FileCopyrightText: 2006-2010 Dag Andersen <dag.andersen@kdemail.net>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KPTVIEWBASE_H
@@ -64,6 +51,7 @@ class ViewBase;
 class TreeViewBase;
 class DoubleTreeViewBase;
 
+class CommonActionsController;
 //------------------
 
 class PLANUI_EXPORT DockWidget : public QDockWidget
@@ -130,7 +118,7 @@ class PLANUI_EXPORT PrintingHeaderFooter : public QWidget, public Ui::PrintingHe
 {
     Q_OBJECT
 public:
-    explicit PrintingHeaderFooter(const PrintingOptions &opt, QWidget *parent = 0);
+    explicit PrintingHeaderFooter(const PrintingOptions &opt, QWidget *parent = nullptr);
     ~PrintingHeaderFooter() override;
 
     void setOptions(const PrintingOptions &options);
@@ -168,7 +156,6 @@ public:
 
 Q_SIGNALS:
     void changed(const KPlato::PrintingOptions &opt);
-    void changed();
 
 public Q_SLOTS:
     void setPrintingOptions(const KPlato::PrintingOptions &opt);
@@ -190,11 +177,13 @@ protected:
 class PLANUI_EXPORT ViewActionLists
 {
 public:
-    ViewActionLists() : actionOptions(0) {}
+    ViewActionLists() : actionOptions(nullptr) {}
     virtual ~ViewActionLists() {}
 
     QList<QAction*> contextActionList() const { return m_contextActionList; }
-    void addContextAction(QAction *action, int pos = INT_MAX);
+    void addContextAction(QAction *action, qsizetype pos = INT_MAX) {
+        m_contextActionList.insert(std::min(pos, m_contextActionList.count()), action);
+    }
 
 protected:
     /// List of actions that will be shown in the views header context menu
@@ -233,13 +222,11 @@ public:
     KoPageLayout pageLayout() const override;
 
     /// Return the type of view this is (class name)
-    QString viewType() const { return metaObject()->className(); }
+    QString viewType() const { return QLatin1String(metaObject()->className()); }
 
     /// Returns true if this view or any child widget has focus
     bool isActive() const;
 
-    /// Set the project this view shall handle.
-    virtual void setProject(Project *project);
     /// Return the project
     virtual Project *project() const { return m_proj; }
     /// Return the schedule manager
@@ -255,15 +242,15 @@ public:
     bool isReadWrite() const { return m_readWrite; }
 
     /// Reimplement if your view handles nodes
-    virtual Node* currentNode() const { return 0; }
+    virtual Node* currentNode() const { return nullptr; }
     /// Reimplement if your view handles resources
-    virtual Resource* currentResource() const { return 0; }
+    virtual Resource* currentResource() const { return nullptr; }
     /// Reimplement if your view handles resource groups
-    virtual ResourceGroup* currentResourceGroup() const { return 0; }
+    virtual ResourceGroup* currentResourceGroup() const { return nullptr; }
     /// Reimplement if your view handles calendars
-    virtual Calendar* currentCalendar() const { return 0; }
+    virtual Calendar* currentCalendar() const { return nullptr; }
     /// Reimplement if your view handles relations
-    virtual Relation *currentRelation() const { return 0; }
+    virtual Relation *currentRelation() const { return nullptr; }
     /// Reimplement if your view handles zoom
 //    virtual KoZoomController *zoomController() const { return 0; }
 
@@ -277,7 +264,6 @@ public:
     static QWidget *createPageLayoutWidget(ViewBase *view);
     static PrintingHeaderFooter *createHeaderFooterWidget(ViewBase *view);
 
-    virtual void createDockers() {}
     void addDocker(DockWidget *ds);
     QList<DockWidget*> dockers() const;
     DockWidget *findDocker(const QString &id) const;
@@ -292,11 +278,16 @@ public:
     void openPopupMenu(const QString& name, const QPoint &pos);
     QMenu *popupMenu(const QString& name);
 
+    void openContextMenu(const QString& name, const QPoint &pos);
+
 public Q_SLOTS:
     void setPrintingOptions(const KPlato::PrintingOptions &opt) { m_printingOptions = opt; }
     /// Activate/deactivate the gui
     virtual void setGuiActive(bool activate);
-    virtual void setScheduleManager(KPlato::ScheduleManager *sm) { m_schedulemanager = sm; }
+    /// Set the project this view shall handle.
+    virtual void setProject(KPlato::Project *project);
+    /// Set the schedule manager this view shall handle.
+    virtual void setScheduleManager(KPlato::ScheduleManager *sm);
     void slotUpdateReadWrite(bool);
     virtual void slotHeaderContextMenuRequested(const QPoint &pos);
 
@@ -351,7 +342,7 @@ class PLANUI_EXPORT TreeViewPrintingDialog : public PrintingDialog
 {
     Q_OBJECT
 public:
-    TreeViewPrintingDialog(ViewBase *view, TreeViewBase *treeview, Project *project = 0);
+    TreeViewPrintingDialog(ViewBase *view, TreeViewBase *treeview, Project *project = nullptr);
     ~TreeViewPrintingDialog() override {}
 
     int documentFirstPage() const override { return 1; }
@@ -375,7 +366,7 @@ class PLANUI_EXPORT TreeViewBase : public QTreeView
 {
     Q_OBJECT
 public:
-    explicit TreeViewBase(QWidget *parent = 0);
+    explicit TreeViewBase(QWidget *parent = nullptr);
 
     void setReadWrite(bool rw);
     virtual void createItemDelegates(ItemModelBase *model);
@@ -603,7 +594,7 @@ public:
     }
 
     void showColumn(int col) {
-        if (col == 0 || m_rightview == 0) m_leftview->showColumn(col);
+        if (col == 0 || m_rightview == nullptr) m_leftview->showColumn(col);
         else m_rightview->showColumn(col);
     }
     bool isColumnHidden(int col) const {
