@@ -1,21 +1,8 @@
 /* This file is part of the KDE project
- * Copyright (C) 2019 Dag Andersen <danders@get2net.dk>
- * Copyright (C) 2007 - 2010, 2012 Dag Andersen <danders@get2net.dk>
+ * SPDX-FileCopyrightText: 2019 Dag Andersen <dag.andersen@kdemail.net>
+ * SPDX-FileCopyrightText: 2007-2010, 2012 Dag Andersen <dag.andersen@kdemail.net>
  * 
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- * 
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- * 
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 // clazy:excludeall=qstring-arg
@@ -28,7 +15,6 @@
 #include "kptproject.h"
 #include "kptschedule.h"
 #include "kpteffortcostmap.h"
-#include "Help.h"
 #include "kptdebug.h"
 
 #include <KoXmlReader.h>
@@ -73,9 +59,9 @@ QList<QWidget*> PerformanceStatusPrintingDialog::createOptionWidgets() const
 
 void PerformanceStatusPrintingDialog::printPage(int page, QPainter &painter)
 {
-    //debugPlan<<page<<printer().pageRect()<<printer().paperRect()<<printer().margins()<<printer().fullPage();
+    //debugPlan<<page<<printer().pageLayout().paintrectpixels(resolution)<<printer().paperRect()<<printer().margins()<<printer().fullPage();
     painter.save();
-    QRect rect = printer().pageRect();
+    QRect rect = printer().pageLayout().paintRectPixels(printer().resolution());
     rect.moveTo(0, 0); // the printer already has margins set
     QRect header = headerRect();
     QRect footer = footerRect();
@@ -100,8 +86,8 @@ void PerformanceStatusPrintingDialog::printPage(int page, QPainter &painter)
 //-----------------------------------
 PerformanceStatusBase::PerformanceStatusBase(QWidget *parent)
     : QWidget(parent),
-    m_project(0),
-    m_manager(0)
+    m_project(nullptr),
+    m_manager(nullptr)
 {
     setupUi(this);
 
@@ -114,7 +100,7 @@ PerformanceStatusBase::PerformanceStatusBase(QWidget *parent)
 
     m_legend = new Legend(ui_chart);
     ui_chart->replaceLegend(m_legend);
-    m_legend->setObjectName("Chart legend");
+    m_legend->setObjectName(QStringLiteral("Chart legend"));
 
     backgroundAttrs = m_legend->backgroundAttributes();
     m_legend->setBackgroundAttributes(backgroundAttrs);
@@ -124,7 +110,7 @@ PerformanceStatusBase::PerformanceStatusBase(QWidget *parent)
     m_legend->setPosition(Position::East);
     //m_legend->setAlignment((Qt::Alignment)(Qt::AlignTop | Qt::AlignCenter));
     m_legenddiagram.setModel(&m_chartmodel);
-    m_legenddiagram.setObjectName("Legend diagram");
+    m_legenddiagram.setObjectName(QStringLiteral("Legend diagram"));
     m_legend->setDiagram(&m_legenddiagram);
 
     // get rid of the default coordinate plane
@@ -142,12 +128,15 @@ PerformanceStatusBase::PerformanceStatusBase(QWidget *parent)
     connect(&m_chartmodel, &QAbstractItemModel::modelReset, this, &PerformanceStatusBase::slotUpdate);
     connect(ui_chart, &KPlato::Chart::customContextMenuRequested, this, &PerformanceStatusBase::customContextMenuRequested);
     ui_performancetable->setContextMenuPolicy(Qt::CustomContextMenu);
-    connect(ui_performancetable, &PerformanceTableView::customContextMenuRequested, this, &PerformanceStatusBase::slotContextMenuRequested);
+    connect(ui_performancetable, &PerformanceTableView::contextMenuRequested, this, &PerformanceStatusBase::slotContextMenuRequested);
+    connect(ui_stack, &QStackedWidget::customContextMenuRequested, this, [this](const QPoint &pos){
+        Q_EMIT customContextMenuRequested(ui_stack->mapToGlobal(pos));
+    });
 }
 
 void PerformanceStatusBase::slotContextMenuRequested(const QPoint &pos)
 {
-    emit customContextMenuRequested(mapToGlobal(pos));
+    Q_EMIT customContextMenuRequested(ui_performancetable->mapToGlobal(pos));
 }
 
 void PerformanceStatusBase::editCopy()
@@ -181,13 +170,13 @@ void PerformanceStatusBase::createBarChart()
 {
     m_barchart.effortplane = new CartesianCoordinatePlane(ui_chart);
     m_barchart.effortplane->setRubberBandZoomingEnabled(true);
-    m_barchart.effortplane->setObjectName("Bar chart, Effort");
+    m_barchart.effortplane->setObjectName(QStringLiteral("Bar chart, Effort"));
     m_barchart.costplane = new CartesianCoordinatePlane(ui_chart);
     m_barchart.costplane->setRubberBandZoomingEnabled(true);
-    m_barchart.costplane->setObjectName("Bar chart, Cost");
+    m_barchart.costplane->setObjectName(QStringLiteral("Bar chart, Cost"));
 
     BarDiagram *effortdiagram = new BarDiagram(ui_chart, m_barchart.effortplane);
-    effortdiagram->setObjectName("Effort diagram");
+    effortdiagram->setObjectName(QStringLiteral("Effort diagram"));
 
     m_barchart.dateaxis = new CartesianAxis();
     m_barchart.dateaxis->setPosition(CartesianAxis::Bottom);
@@ -207,7 +196,7 @@ void PerformanceStatusBase::createBarChart()
     effortdiagram->setModel(&(m_barchart.effortproxy));
 
     BarDiagram *costdiagram = new BarDiagram(ui_chart, m_barchart.costplane);
-    costdiagram->setObjectName("Cost diagram");
+    costdiagram->setObjectName(QStringLiteral("Cost diagram"));
 
     m_barchart.costaxis = new CartesianAxis(costdiagram);
     m_barchart.costaxis->setPosition(CartesianAxis::Left);
@@ -220,7 +209,7 @@ void PerformanceStatusBase::createBarChart()
     costdiagram->setHidden(5, true);
     m_barchart.costproxy.setZeroColumns(QList<int>() << 3 << 4 << 5);
 
-    m_barchart.costproxy.setObjectName("Bar: Cost");
+    m_barchart.costproxy.setObjectName(QStringLiteral("Bar: Cost"));
     m_barchart.costproxy.setSourceModel(&m_chartmodel);
     costdiagram->setModel(&(m_barchart.costproxy));
 
@@ -228,9 +217,9 @@ void PerformanceStatusBase::createBarChart()
     m_barchart.costdiagram = costdiagram;
 
     m_barchart.piplane = new CartesianCoordinatePlane(ui_chart);
-    m_barchart.piplane->setObjectName("Performance Indices");
+    m_barchart.piplane->setObjectName(QStringLiteral("Performance Indices"));
     BarDiagram *pidiagram = new BarDiagram(ui_chart, m_barchart.piplane);
-    pidiagram->setObjectName("PI diagram");
+    pidiagram->setObjectName(QStringLiteral("PI diagram"));
     m_barchart.piaxis = new CartesianAxis(pidiagram);
     pidiagram->addAxis(m_barchart.piaxis);
     m_barchart.piplane->addDiagram(pidiagram);
@@ -241,14 +230,14 @@ void PerformanceStatusBase::createBarChart()
 void PerformanceStatusBase::createLineChart()
 {
     m_linechart.effortplane = new CartesianCoordinatePlane(ui_chart);
-    m_linechart.effortplane->setObjectName("Line chart, Effort");
+    m_linechart.effortplane->setObjectName(QStringLiteral("Line chart, Effort"));
     m_linechart.effortplane->setRubberBandZoomingEnabled(true);
     m_linechart.costplane = new CartesianCoordinatePlane(ui_chart);
-    m_linechart.costplane->setObjectName("Line chart, Cost");
+    m_linechart.costplane->setObjectName(QStringLiteral("Line chart, Cost"));
     m_linechart.costplane->setRubberBandZoomingEnabled(true);
 
     LineDiagram *effortdiagram = new LineDiagram(ui_chart, m_linechart.effortplane);
-    effortdiagram->setObjectName("Effort diagram");
+    effortdiagram->setObjectName(QStringLiteral("Effort diagram"));
 
     m_linechart.dateaxis = new CartesianAxis();
     m_linechart.dateaxis->setPosition(CartesianAxis::Bottom);
@@ -264,12 +253,12 @@ void PerformanceStatusBase::createLineChart()
     effortdiagram->setHidden(2, true);
     m_linechart.effortproxy.setZeroColumns(QList<int>() << 0 << 1 << 2);
 
-    m_linechart.effortproxy.setObjectName("Line: Effort");
+    m_linechart.effortproxy.setObjectName(QStringLiteral("Line: Effort"));
     m_linechart.effortproxy.setSourceModel(&m_chartmodel);
     effortdiagram->setModel(&(m_linechart.effortproxy));
 
     LineDiagram *costdiagram = new LineDiagram(ui_chart, m_linechart.costplane);
-    costdiagram->setObjectName("Cost diagram");
+    costdiagram->setObjectName(QStringLiteral("Cost diagram"));
 
     m_linechart.costaxis = new CartesianAxis(costdiagram);
     m_linechart.costaxis->setPosition(CartesianAxis::Left);
@@ -280,7 +269,7 @@ void PerformanceStatusBase::createLineChart()
     costdiagram->setHidden(4, true);
     costdiagram->setHidden(5, true);
 
-    m_linechart.costproxy.setObjectName("Line: Cost");
+    m_linechart.costproxy.setObjectName(QStringLiteral("Line: Cost"));
     m_linechart.costproxy.setZeroColumns(QList<int>() << 3 << 4 << 5);
     m_linechart.costproxy.setSourceModel(&m_chartmodel);
     costdiagram->setModel(&(m_linechart.costproxy));
@@ -289,10 +278,10 @@ void PerformanceStatusBase::createLineChart()
     m_linechart.costdiagram = costdiagram;
 
     m_linechart.piplane = new CartesianCoordinatePlane(ui_chart);
-    m_linechart.piplane->setObjectName("Performance Indices");
+    m_linechart.piplane->setObjectName(QStringLiteral("Performance Indices"));
     m_linechart.piplane->setRubberBandZoomingEnabled(true);
     LineDiagram *pidiagram = new LineDiagram(ui_chart, m_linechart.piplane);
-    pidiagram->setObjectName("PI diagram");
+    pidiagram->setObjectName(QStringLiteral("PI diagram"));
     m_linechart.piaxis = new CartesianAxis(pidiagram);
     pidiagram->addAxis(m_linechart.piaxis);
     m_linechart.piplane->addDiagram(pidiagram);
@@ -321,11 +310,12 @@ void PerformanceStatusBase::setupChart()
     }
     ui_stack->setCurrentIndex(0);
     debugPlan<<"Planes:"<<ui_chart->coordinatePlanes();
-    foreach (AbstractCoordinatePlane *pl, ui_chart->coordinatePlanes()) {
+    const QList<AbstractCoordinatePlane*> planes = ui_chart->coordinatePlanes();
+    for (AbstractCoordinatePlane *pl : planes) {
         CartesianCoordinatePlane *p = dynamic_cast<CartesianCoordinatePlane*>(pl);
-        if (p == 0) continue;
+        if (p == nullptr) continue;
         GridAttributes ga = p->globalGridAttributes();
-        ga.setGridVisible(p->referenceCoordinatePlane() == 0);
+        ga.setGridVisible(p->referenceCoordinatePlane() == nullptr);
         p->setGlobalGridAttributes(ga);
     }
     m_legend->setDatasetHidden(0, ! (m_chartinfo.showBaseValues && m_chartinfo.showCost && m_chartinfo.showBCWSCost));
@@ -367,7 +357,7 @@ void PerformanceStatusBase::setupChart(ChartContents &cc)
     static_cast<AbstractCartesianDiagram*>(cc.effortplane->diagram())->takeAxis(cc.dateaxis);
     static_cast<AbstractCartesianDiagram*>(cc.costplane->diagram())->takeAxis(cc.dateaxis);
     static_cast<AbstractCartesianDiagram*>(cc.piplane->diagram())->takeAxis(cc.dateaxis);
-    cc.costplane->setReferenceCoordinatePlane(0);
+    cc.costplane->setReferenceCoordinatePlane(nullptr);
     if (info.showBaseValues) {
         if (info.showEffort) {
             // filter cost columns if cost is *not* shown, else hide them and zero out
@@ -406,7 +396,7 @@ void PerformanceStatusBase::setupChart(ChartContents &cc)
             erc << 6 << 7 << 8 << 9;
             ezc << 6 << 7 << 8 << 9;
 
-            cc.costplane->setReferenceCoordinatePlane(info.showEffort ? cc.effortplane : 0);
+            cc.costplane->setReferenceCoordinatePlane(info.showEffort ? cc.effortplane : nullptr);
             ui_chart->addCoordinatePlane(cc.costplane);
 
             static_cast<AbstractCartesianDiagram*>(cc.costplane->diagram())->addAxis(cc.dateaxis);
@@ -477,9 +467,9 @@ void PerformanceStatusBase::setupChart(ChartContents &cc)
         }
     }
 
-    foreach(AbstractCoordinatePlane *p, ui_chart->coordinatePlanes()) {
+    for (AbstractCoordinatePlane *p : std::as_const(ui_chart->coordinatePlanes())) {
         debugPlan<<p<<"references:"<<p->referenceCoordinatePlane();
-        foreach (AbstractDiagram *d, p->diagrams()) {
+        for (AbstractDiagram *d : std::as_const(p->diagrams())) {
             debugPlan<<p<<"diagram:"<<d;
         }
     }
@@ -490,7 +480,7 @@ void PerformanceStatusBase::contextMenuEvent(QContextMenuEvent *event)
 {
     debugPlan<<event->globalPos();
     if (event->modifiers() == Qt::NoModifier) {
-        emit customContextMenuRequested(event->globalPos());
+        Q_EMIT customContextMenuRequested(event->globalPos());
     }
 }
 
@@ -508,7 +498,7 @@ void PerformanceStatusBase::setScheduleManager(ScheduleManager *sm)
     }
     m_manager = sm;
     m_chartmodel.setScheduleManager(sm);
-    static_cast<PerformanceDataCurrentDateModel*>(ui_performancetable->model())->setScheduleManager(sm);
+    qobject_cast<PerformanceDataCurrentDateModel*>(ui_performancetable->model())->setScheduleManager(sm);
 }
 
 void PerformanceStatusBase::setProject(Project *project)
@@ -521,7 +511,7 @@ void PerformanceStatusBase::setProject(Project *project)
         connect(m_project, &Project::localeChanged, this, &PerformanceStatusBase::slotLocaleChanged);
     }
     m_chartmodel.setProject(project);
-    static_cast<PerformanceDataCurrentDateModel*>(ui_performancetable->model())->setProject(project);
+    qobject_cast<PerformanceDataCurrentDateModel*>(ui_performancetable->model())->setProject(project);
 
     slotLocaleChanged();
 }
@@ -543,27 +533,27 @@ void PerformanceStatusBase::slotLocaleChanged()
 bool PerformanceStatusBase::loadContext(const KoXmlElement &context)
 {
     debugPlan;
-    m_chartinfo.showBarChart = context.attribute("show-bar-chart", "0").toInt();
-    m_chartinfo.showLineChart = context.attribute("show-line-chart", "1").toInt();
-    m_chartinfo.showTableView = context.attribute("show-table-view", "0").toInt();
+    m_chartinfo.showBarChart = context.attribute("show-bar-chart", QString::number(0)).toInt();
+    m_chartinfo.showLineChart = context.attribute("show-line-chart", QString::number(1)).toInt();
+    m_chartinfo.showTableView = context.attribute("show-table-view", QString::number(0)).toInt();
 
-    m_chartinfo.showBaseValues = context.attribute("show-base-values", "1").toInt();
-    m_chartinfo.showIndices = context.attribute("show-indeces", "0").toInt();
+    m_chartinfo.showBaseValues = context.attribute("show-base-values", QString::number(1)).toInt();
+    m_chartinfo.showIndices = context.attribute("show-indeces", QString::number(0)).toInt();
 
-    m_chartinfo.showCost = context.attribute("show-cost", "1").toInt();
-    m_chartinfo.showBCWSCost = context.attribute("show-bcws-cost", "1").toInt();
-    m_chartinfo.showBCWPCost = context.attribute("show-bcwp-cost", "1").toInt();
-    m_chartinfo.showACWPCost = context.attribute("show-acwp-cost", "1").toInt();
+    m_chartinfo.showCost = context.attribute("show-cost", QString::number(1)).toInt();
+    m_chartinfo.showBCWSCost = context.attribute("show-bcws-cost", QString::number(1)).toInt();
+    m_chartinfo.showBCWPCost = context.attribute("show-bcwp-cost", QString::number(1)).toInt();
+    m_chartinfo.showACWPCost = context.attribute("show-acwp-cost", QString::number(1)).toInt();
 
-    m_chartinfo.showEffort = context.attribute("show-effort", "1").toInt();
-    m_chartinfo.showBCWSEffort = context.attribute("show-bcws-effort", "1").toInt();
-    m_chartinfo.showBCWPEffort = context.attribute("show-bcwp-effort", "1").toInt();
-    m_chartinfo.showACWPEffort = context.attribute("show-acwp-effort", "1").toInt();
+    m_chartinfo.showEffort = context.attribute("show-effort", QString::number(1)).toInt();
+    m_chartinfo.showBCWSEffort = context.attribute("show-bcws-effort", QString::number(1)).toInt();
+    m_chartinfo.showBCWPEffort = context.attribute("show-bcwp-effort", QString::number(1)).toInt();
+    m_chartinfo.showACWPEffort = context.attribute("show-acwp-effort", QString::number(1)).toInt();
 
-    m_chartinfo.showSpiCost = context.attribute("show-spi-cost", "1").toInt();
-    m_chartinfo.showCpiCost = context.attribute("show-cpi-cost", "1").toInt();
-    m_chartinfo.showSpiEffort = context.attribute("show-spi-effort", "1").toInt();
-    m_chartinfo.showCpiEffort = context.attribute("show-cpi-effort", "1").toInt();
+    m_chartinfo.showSpiCost = context.attribute("show-spi-cost", QString::number(1)).toInt();
+    m_chartinfo.showCpiCost = context.attribute("show-cpi-cost", QString::number(1)).toInt();
+    m_chartinfo.showSpiEffort = context.attribute("show-spi-effort", QString::number(1)).toInt();
+    m_chartinfo.showCpiEffort = context.attribute("show-cpi-effort", QString::number(1)).toInt();
 
     debugPlan<<"Cost:"<<m_chartinfo.showCost<<"bcws="<<m_chartinfo.showBCWSCost<<"bcwp="<<m_chartinfo.showBCWPCost<<"acwp="<<m_chartinfo.showACWPCost;
     debugPlan<<"Effort:"<<m_chartinfo.showCost<<"bcws="<<m_chartinfo.showBCWSCost<<"bcwp="<<m_chartinfo.showBCWPCost<<"acwp="<<m_chartinfo.showACWPCost;
@@ -573,40 +563,40 @@ bool PerformanceStatusBase::loadContext(const KoXmlElement &context)
 
 void PerformanceStatusBase::saveContext(QDomElement &context) const
 {
-    context.setAttribute("show-bar-chart", QString::number(m_chartinfo.showBarChart));
-    context.setAttribute("show-line-chart", QString::number(m_chartinfo.showLineChart));
-    context.setAttribute("show-table-view", QString::number(m_chartinfo.showTableView));
+    context.setAttribute(QStringLiteral("show-bar-chart"), QString::number(m_chartinfo.showBarChart));
+    context.setAttribute(QStringLiteral("show-line-chart"), QString::number(m_chartinfo.showLineChart));
+    context.setAttribute(QStringLiteral("show-table-view"), QString::number(m_chartinfo.showTableView));
 
-    context.setAttribute("show-base-values", QString::number(m_chartinfo.showBaseValues));
-    context.setAttribute("show-indeces", QString::number(m_chartinfo.showIndices));
+    context.setAttribute(QStringLiteral("show-base-values"), QString::number(m_chartinfo.showBaseValues));
+    context.setAttribute(QStringLiteral("show-indeces"), QString::number(m_chartinfo.showIndices));
 
-    context.setAttribute("show-cost", QString::number(m_chartinfo.showCost));
-    context.setAttribute("show-bcws-cost", QString::number(m_chartinfo.showBCWSCost));
-    context.setAttribute("show-bcwp-cost", QString::number(m_chartinfo.showBCWPCost));
-    context.setAttribute("show-acwp-cost", QString::number(m_chartinfo.showACWPCost));
+    context.setAttribute(QStringLiteral("show-cost"), QString::number(m_chartinfo.showCost));
+    context.setAttribute(QStringLiteral("show-bcws-cost"), QString::number(m_chartinfo.showBCWSCost));
+    context.setAttribute(QStringLiteral("show-bcwp-cost"), QString::number(m_chartinfo.showBCWPCost));
+    context.setAttribute(QStringLiteral("show-acwp-cost"), QString::number(m_chartinfo.showACWPCost));
 
-    context.setAttribute("show-effort",  QString::number(m_chartinfo.showEffort));
-    context.setAttribute("show-bcws-effort", QString::number(m_chartinfo.showBCWSEffort));
-    context.setAttribute("show-bcwp-effort", QString::number(m_chartinfo.showBCWPEffort));
-    context.setAttribute("show-acwp-effort", QString::number(m_chartinfo.showACWPEffort));
+    context.setAttribute(QStringLiteral("show-effort"),  QString::number(m_chartinfo.showEffort));
+    context.setAttribute(QStringLiteral("show-bcws-effort"), QString::number(m_chartinfo.showBCWSEffort));
+    context.setAttribute(QStringLiteral("show-bcwp-effort"), QString::number(m_chartinfo.showBCWPEffort));
+    context.setAttribute(QStringLiteral("show-acwp-effort"), QString::number(m_chartinfo.showACWPEffort));
 
-    context.setAttribute("show-spi-cost", QString::number(m_chartinfo.showSpiCost));
-    context.setAttribute("show-cpi-cost", QString::number(m_chartinfo.showCpiCost));
-    context.setAttribute("show-spi-effort", QString::number(m_chartinfo.showSpiEffort));
-    context.setAttribute("show-cpi-effort", QString::number(m_chartinfo.showCpiEffort));
+    context.setAttribute(QStringLiteral("show-spi-cost"), QString::number(m_chartinfo.showSpiCost));
+    context.setAttribute(QStringLiteral("show-cpi-cost"), QString::number(m_chartinfo.showCpiCost));
+    context.setAttribute(QStringLiteral("show-spi-effort"), QString::number(m_chartinfo.showSpiEffort));
+    context.setAttribute(QStringLiteral("show-cpi-effort"), QString::number(m_chartinfo.showCpiEffort));
 }
 
 KoPrintJob *PerformanceStatusBase::createPrintJob(ViewBase *parent)
 {
     PerformanceStatusPrintingDialog *dia = new PerformanceStatusPrintingDialog(parent, this, parent->project());
-    dia->printer().setCreator("Plan");
+    dia->printer().setCreator(QStringLiteral("Plan"));
     return dia;
 }
 
 void PerformanceStatusBase::setNodes(const QList<Node *> &nodes)
 {
     m_chartmodel.setNodes(nodes);
-    static_cast<PerformanceDataCurrentDateModel*>(ui_performancetable->model())->setNodes(nodes);
+    qobject_cast<PerformanceDataCurrentDateModel*>(ui_performancetable->model())->setNodes(nodes);
 }
 
 
