@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
-  Copyright (C) 2017 Dag Andersen <danders@get2net.dk>
+  SPDX-FileCopyrightText: 2017 Dag Andersen <dag.andersen@kdemail.net>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 // clazy:excludeall=qstring-arg
@@ -40,7 +27,7 @@ ProjectView::ProjectView(KoPart *part, KoDocument *doc, QWidget *parent)
 {
     debugPlan<<"----------------- Create ProjectView ----------------------";
     QVBoxLayout * l = new QVBoxLayout(this);
-    l->setMargin(0);
+    l->setContentsMargins(0, 0, 0, 0);
     m_view = new QTableView(this);
     l->addWidget(m_view);
     if (createConnection()) {
@@ -124,7 +111,7 @@ int ProjectView::selectedRowCount() const
 void ProjectView::slotContextMenuRequested(const QPoint& pos)
 {
     debugPlan;
-    emit requestPopupMenu("reportsgeneratorview_popup", m_view->mapToGlobal(pos));
+    Q_EMIT requestPopupMenu("reportsgeneratorview_popup", m_view->mapToGlobal(pos));
 }
 
 void ProjectView::slotEnableActions()
