@@ -1,37 +1,30 @@
 /* This file is part of the KDE project
-  Copyright (C) 2017 Dag Andersen <danders@get2net.dk>
+  SPDX-FileCopyrightText: 2017 Dag Andersen <dag.andersen@kdemail.net>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 // clazy:excludeall=qstring-arg
 #include "ReportsGeneratorView.h"
 
 #include "reportgenerator/ReportGenerator.h"
-#include "Help.h"
+#include <reportgenerator/ReportGeneratorFactory.h>
 #include "kptdebug.h"
 
 #include <KoIcon.h>
 #include <KoXmlReader.h>
 #include <KoDocument.h>
+#include <KoPart.h>
+#include <KoComponentData.h>
 
 #include <KActionCollection>
 #include <KUrlRequester>
 #include <KFile>
-#include <KRun>
+#include <KIO/OpenUrlJob>
+#include <KIO/JobUiDelegate>
+#include <KIO/JobUiDelegateFactory>
+#include <KMessageBox>
+#include <KConfigGroup>
 
 #include <QAction>
 #include <QHeaderView>
@@ -46,27 +39,36 @@
 #include <QDir>
 #include <QUrl>
 #include <QMap>
-#include <QMessageBox>
 
-namespace KPlato
+
+const QLoggingCategory &PLANREPORT_LOG()
 {
+    static const QLoggingCategory category("calligra.plan.report");
+    return category;
+}
+#define debugPlanReport qCDebug(PLANREPORT_LOG)<<Q_FUNC_INFO
+
+using namespace KPlato;
 
 #define FULLPATHROLE Qt::UserRole + 123
 
 class TemplateFileDelegate : public QStyledItemDelegate
 {
 public:
-    TemplateFileDelegate(QObject *parent);
+    TemplateFileDelegate(KoPart *part, QObject *parent);
 
     QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
     void setEditorData(QWidget *editor, const QModelIndex &index) const override;
     void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const override;
 
-    QMap<QString, QUrl> files;
+private:
+    KoPart *m_part;
+    mutable QMap<QString, QUrl> m_files;
 };
 
-TemplateFileDelegate::TemplateFileDelegate(QObject *parent)
+TemplateFileDelegate::TemplateFileDelegate(KoPart *part, QObject *parent)
     : QStyledItemDelegate(parent)
+    , m_part(part)
 {
 }
 
@@ -79,13 +81,38 @@ QWidget *TemplateFileDelegate::createEditor(QWidget *parent, const QStyleOptionV
 
 void TemplateFileDelegate::setEditorData(QWidget *editor, const QModelIndex &index) const
 {
+    m_files.clear();
     QComboBox *cb = qobject_cast<QComboBox*>(editor);
-    debugPlan<<cb;
+    debugPlanReport<<cb;
     if (!cb) {
         return;
     }
+    QString path = QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("reports"), QStandardPaths::LocateDirectory);
+    debugPlanReport<<"standardpath:"<<path;
+    if (!path.isEmpty()) {
+        QDir dir(path);
+        const auto entries = dir.entryList(QDir::Files|QDir::QDir::NoDotAndDotDot);
+        for(auto &file : entries) {
+            QUrl url;
+            url.setUrl(path + QLatin1Char('/') + file);
+            m_files.insert(url.fileName(), url);
+        }
+    }
+    KConfigGroup cfgGrp(m_part->componentData().config(), QStringLiteral("Report Templates"));
+    if (cfgGrp.exists()) {
+        const auto templates = cfgGrp.readEntry(QStringLiteral("ReportTemplatePaths")).split(QLatin1Char(','));
+        for (auto &path : templates) {
+            QDir dir(path);
+            const auto entries = dir.entryList(QDir::Files|QDir::QDir::NoDotAndDotDot);
+            for(auto &file : entries) {
+                QUrl url;
+                url.setUrl(path + QLatin1Char('/') + file);
+                m_files.insert(url.fileName(), url);
+            }
+        }
+    }
     cb->setEditable(true);
-    cb->addItems(files.keys());
+    cb->addItems(m_files.keys());
     QString file = index.data().toString();
     cb->setCurrentText(file);
 }
@@ -93,20 +120,20 @@ void TemplateFileDelegate::setEditorData(QWidget *editor, const QModelIndex &ind
 void TemplateFileDelegate::setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const
 {
     QComboBox *cb = qobject_cast<QComboBox*>(editor);
-    debugPlan<<cb;
+    debugPlanReport<<cb;
     if (cb) {
         QString cfile = index.data().toString();
         QString nfile = cb->currentText();
-        debugPlan<<"template file:"<<nfile<<files;
+        debugPlanReport<<"template file:"<<nfile<<m_files;
         if (cfile != nfile) {
             model->setData(index, nfile);
-            if (files.contains(nfile)) {
-                nfile = files[nfile].url();
+            if (m_files.contains(nfile)) {
+                nfile = m_files[nfile].url();
             }
             model->setData(index, nfile, FULLPATHROLE);
             model->setData(index, nfile, Qt::ToolTipRole);
         }
-    } else debugPlan<<"  No combo box editor!!";
+    } else debugPlanReport<<"  No combo box editor!!";
 }
 
 class FileItemDelegate : public QStyledItemDelegate
@@ -204,64 +231,60 @@ QStringList ReportsGeneratorView::addOptions()
 
 QStringList ReportsGeneratorView::addTags()
 {
-    return QStringList() << "Nothing" << "Date" << "Number";
+    return QStringList() << QStringLiteral("Nothing") << QStringLiteral("Date") << QStringLiteral("Number");
 
 }
 
+#define COLUMN_NAME 0
+#define COLUMN_TEMPLATE 1
+#define COLUMN_ADD 2
+#define COLUMN_FILE 3
+
 ReportsGeneratorView::ReportsGeneratorView(KoPart *part, KoDocument *doc, QWidget *parent)
     : ViewBase(part, doc, parent)
 {
     debugPlan<<"----------------- Create ReportsGeneratorView ----------------------";
-    if (doc && doc->isReadWrite()) {
-        setXMLFile("ReportsGeneratorViewUi.rc");
-    } else {
-        setXMLFile("ReportsGeneratorViewUi_readonly.rc");
-    }
+    setXMLFile(QStringLiteral("ReportsGeneratorViewUi.rc"));
 
     QVBoxLayout * l = new QVBoxLayout(this);
-    l->setMargin(0);
+    l->setContentsMargins(0, 0, 0, 0);
     m_view = new QTreeView(this);
     QStandardItemModel *m = new QStandardItemModel(m_view);
-    m->setHorizontalHeaderLabels(QStringList() << i18n("Name") << i18n("Report Template") << i18n("Report File") << i18n("Add"));
-    m->setHeaderData(0, Qt::Horizontal, xi18nc("@info:tooltip", "Report name"), Qt::ToolTipRole);
-    m->setHeaderData(1, Qt::Horizontal, xi18nc("@info:tooltip", "Report template file name"), Qt::ToolTipRole);
-    m->setHeaderData(2, Qt::Horizontal, xi18nc("@info:tooltip", "Name of the generated report file"), Qt::ToolTipRole);
-    m->setHeaderData(3, Qt::Horizontal, xi18nc("@info:tooltip", "Information added to filename"), Qt::ToolTipRole);
+    static const QMap<int, QString> headers = {
+        { COLUMN_NAME, i18nc("@title:column", "Name") },
+        { COLUMN_TEMPLATE, i18nc("@title:column", "Report Template") },
+        { COLUMN_ADD, i18nc("@title:column", "Add") },
+        { COLUMN_FILE, i18nc("@title:column", "Report File") }
+    };
+    m->setHorizontalHeaderLabels(headers.values());
+    m->setHeaderData(COLUMN_NAME, Qt::Horizontal, xi18nc("@info:tooltip", "Report name"), Qt::ToolTipRole);
+    m->setHeaderData(COLUMN_TEMPLATE, Qt::Horizontal, xi18nc("@info:tooltip", "Report template file name"), Qt::ToolTipRole);
+    m->setHeaderData(COLUMN_ADD, Qt::Horizontal, xi18nc("@info:tooltip", "Information added to filename"), Qt::ToolTipRole);
+    m->setHeaderData(COLUMN_FILE, Qt::Horizontal, xi18nc("@info:tooltip", "Name of the generated report file"), Qt::ToolTipRole);
+    connect(m, &QStandardItemModel::dataChanged, this, [this](const QModelIndex&, const QModelIndex&) {
+        slotEnableActions();
+        Q_EMIT optionsModified(); // FIXME need undo/redo
+    });
+
     m_view->setModel(m);
     m_view->setContextMenuPolicy(Qt::CustomContextMenu);
     m_view->setRootIsDecorated(false);
     m_view->setAlternatingRowColors(true);
 
-    updateReadWrite(doc && doc->isReadWrite());
-
     connect(m_view, &QWidget::customContextMenuRequested, this, &ReportsGeneratorView::slotContextMenuRequested);
     l->addWidget(m_view);
 
-    TemplateFileDelegate *del = new TemplateFileDelegate(m_view);
-    QString path = QStandardPaths::locate(QStandardPaths::AppDataLocation, "reports", QStandardPaths::LocateDirectory);
-    debugPlan<<"standardpath:"<<path;
-    if (!path.isEmpty()) {
-        QDir dir(path);
-        debugPlan<<dir.entryList(QDir::Files|QDir::QDir::NoDotAndDotDot);
-        foreach(const QString &file, dir.entryList(QDir::Files|QDir::QDir::NoDotAndDotDot)) {
-            QUrl url;
-            url.setUrl(path + '/' + file);
-            debugPlan<<"templates:"<<url<<path<<file;
-            del->files.insert(url.fileName(), url);
-        }
-    }
-    m_view->setItemDelegateForColumn(1, del);
+    TemplateFileDelegate *del = new TemplateFileDelegate(part, m_view);
+    m_view->setItemDelegateForColumn(COLUMN_TEMPLATE, del);
 
-    m_view->setItemDelegateForColumn(2, new FileItemDelegate(m_view));
+    m_view->setItemDelegateForColumn(COLUMN_FILE, new FileItemDelegate(m_view));
 
-    m_view->setItemDelegateForColumn(3, new FileNameExtensionDelegate(m_view));
-    m_view->header()->setSectionResizeMode(3, QHeaderView::Fixed);
-    m_view->header()->resizeSection(3, 12);
+    m_view->setItemDelegateForColumn(COLUMN_ADD, new FileNameExtensionDelegate(m_view));
 
     connect(m_view->selectionModel(), &QItemSelectionModel::selectionChanged, this, &ReportsGeneratorView::slotSelectionChanged);
     setupGui();
 
-    Help::add(this,
+    setWhatsThis(
                    xi18nc("@info:whatsthis",
                           "<title>Add and generate reports</title>"
                           "<para>"
@@ -269,7 +292,7 @@ ReportsGeneratorView::ReportsGeneratorView(KoPart *part, KoDocument *doc, QWidge
                           "</para><para>"
                           "You can create a report template using any Open Document text editor."
                           "<nl/><link url='%1'>More...</link>"
-                          "</para>", Help::page("Reports_Generator_View")));
+                          "</para>", QStringLiteral("plan:reports-generator-view")));
 }
 
 void ReportsGeneratorView::updateReadWrite(bool rw)
@@ -286,11 +309,12 @@ void ReportsGeneratorView::updateReadWrite(bool rw)
         }
     }
     ViewBase::updateReadWrite(rw);
+    updateActionsEnabled(isReadWrite());
 }
 
 void ReportsGeneratorView::setGuiActive(bool activate)
 {
-    debugPlan<<activate;
+    debugPlanReport<<activate;
     updateActionsEnabled(true);
     ViewBase::setGuiActive(activate);
 }
@@ -317,8 +341,13 @@ int ReportsGeneratorView::selectedRowCount() const
 
 void ReportsGeneratorView::slotContextMenuRequested(const QPoint& pos)
 {
-    debugPlan;
-    emit requestPopupMenu("reportsgeneratorview_popup", m_view->mapToGlobal(pos));
+    const auto idx = m_view->currentIndex();
+    if (idx.column() == COLUMN_FILE) {
+        const auto fname = idx.data().toString();
+        if (!fname.isEmpty()) {
+            openPopupMenu(QStringLiteral("generatereports_popup"), m_view->viewport()->mapToGlobal(pos));
+        }
+    }
 }
 
 void ReportsGeneratorView::slotEnableActions()
@@ -329,8 +358,19 @@ void ReportsGeneratorView::slotEnableActions()
 void ReportsGeneratorView::updateActionsEnabled(bool on)
 {
     actionAddReport->setEnabled(on);
-    actionRemoveReport->setEnabled(on && selectedRowCount() > 0);
-    actionGenerateReport->setEnabled(on && selectedRowCount() > 0);
+    const auto lst = selectedRows();
+    bool enable = on && lst.count() > 0;
+    actionRemoveReport->setEnabled(enable);
+    if (enable) {
+        for (const auto idx : lst) {
+            enable &= !idx.siblingAtColumn(COLUMN_TEMPLATE).data().toString().isEmpty();
+            enable &= !idx.siblingAtColumn(COLUMN_FILE).data().toString().isEmpty();
+            if (!enable) {
+                break;
+            }
+        }
+    }
+    actionGenerateReport->setEnabled(enable);
 }
 
 void ReportsGeneratorView::setupGui()
@@ -338,22 +378,33 @@ void ReportsGeneratorView::setupGui()
     KActionCollection *coll = actionCollection();
 
     actionAddReport = new QAction(koIcon("list-add"), i18n("Add Report"), this);
-    coll->addAction("add_report", actionAddReport);
-    coll->setDefaultShortcut(actionAddReport, Qt::CTRL + Qt::Key_I);
+    coll->addAction(QStringLiteral("add_report"), actionAddReport);
+    coll->setDefaultShortcut(actionAddReport, Qt::CTRL | Qt::Key_I);
     connect(actionAddReport, &QAction::triggered, this, &ReportsGeneratorView::slotAddReport);
-    addContextAction(actionAddReport);
 
     actionRemoveReport = new QAction(koIcon("list-remove"), i18n("Remove Report"), this);
-    coll->addAction("remove_report", actionRemoveReport);
-    coll->setDefaultShortcut(actionRemoveReport, Qt::CTRL + Qt::Key_D);
+    coll->addAction(QStringLiteral("remove_report"), actionRemoveReport);
+    coll->setDefaultShortcut(actionRemoveReport, Qt::CTRL | Qt::Key_D);
     connect(actionRemoveReport, &QAction::triggered, this, &ReportsGeneratorView::slotRemoveReport);
-    addContextAction(actionRemoveReport);
 
     actionGenerateReport = new QAction(koIcon("document-export"), i18n("Generate Report"), this);
-    coll->addAction("generate_report", actionGenerateReport);
-    coll->setDefaultShortcut(actionGenerateReport, Qt::CTRL + Qt::Key_G);
+    coll->addAction(QStringLiteral("generate_report"), actionGenerateReport);
+    coll->setDefaultShortcut(actionGenerateReport, Qt::CTRL | Qt::Key_G);
     connect(actionGenerateReport, &QAction::triggered, this, &ReportsGeneratorView::slotGenerateReport);
-    addContextAction(actionGenerateReport);
+
+    auto a = new QAction(koIcon("document-open"), i18n("Open..."), this);
+    coll->addAction(QStringLiteral("open_report"), a);
+    connect(a, &QAction::triggered, this, [this]() {
+        const auto idx = m_view->currentIndex();
+        if (idx.column() == COLUMN_FILE) {
+            const auto fname = idx.data().toString();
+            if (!fname.isEmpty()) {
+                auto job = new KIO::OpenUrlJob(QUrl(fname), QStringLiteral("application/vnd.oasis.opendocument.text"));
+                job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, window()));
+                job->start();
+            }
+        }
+    });
 
 //     createOptionAction();
 }
@@ -361,7 +412,7 @@ void ReportsGeneratorView::setupGui()
 
 void ReportsGeneratorView::slotOptions()
 {
-    debugPlan;
+    debugPlanReport;
 //     SplitItemViewSettupDialog *dlg = new SplitItemViewSettupDialog(this, m_view, this);
 //     dlg->addPrintingOptions();
 //     connect(dlg, SIGNAL(finished(int)), SLOT(slotOptionsFinished(int)));
@@ -372,24 +423,24 @@ void ReportsGeneratorView::slotOptions()
 
 void ReportsGeneratorView::slotAddReport()
 {
-    debugPlan;
+    debugPlanReport;
     QAbstractItemModel *m = m_view->model();
     int row = m->rowCount();
     m->insertRow(row);
-    QModelIndex idx = m->index(row, 0);
+    QModelIndex idx = m->index(row, COLUMN_NAME);
     m->setData(idx, i18n("New report"));
-    QModelIndex add = m->index(row, 3);
+    QModelIndex add = m->index(row, COLUMN_ADD);
     m->setData(add, ReportsGeneratorView::addOptions().at(0));
     m->setData(add, ReportsGeneratorView::addTags().at(0), Qt::UserRole);
 
     m_view->selectionModel()->setCurrentIndex(idx, QItemSelectionModel::Rows | QItemSelectionModel::ClearAndSelect);
     m_view->edit(idx);
-    emit optionsModified();
+    Q_EMIT optionsModified();
 }
 
 void ReportsGeneratorView::slotRemoveReport()
 {
-    debugPlan<<selectedRows();
+    debugPlanReport<<selectedRows();
     QAbstractItemModel *m = m_view->model();
     QModelIndexList lst = selectedRows();
     if (lst.isEmpty()) {
@@ -405,46 +456,58 @@ void ReportsGeneratorView::slotRemoveReport()
         Q_ASSERT(!idx.parent().isValid()); // must be flat
         m->removeRow(idx.row(), idx.parent());
     }
-    emit optionsModified();
+    Q_EMIT optionsModified();
 }
 
 void ReportsGeneratorView::slotGenerateReport()
 {
-    debugPlan;
+    debugPlanReport;
     QAbstractItemModel *model = m_view->model();
-    foreach(const QModelIndex &idx, selectedRows()) {
-        QString name = model->index(idx.row(), 0).data().toString();
-        QString tmp = model->index(idx.row(), 1).data(FULLPATHROLE).toString();
-        QString file = model->index(idx.row(), 2).data().toString();
+    const QModelIndexList indexes = selectedRows();
+    for (const QModelIndex &idx : indexes) {
+        QString name = model->index(idx.row(), COLUMN_NAME).data().toString();
+        QString tmp = model->index(idx.row(), COLUMN_TEMPLATE).data(FULLPATHROLE).toString();
+        QString file = QUrl::fromUserInput(model->index(idx.row(), COLUMN_FILE).data().toString()).toLocalFile(); // get rid of possible scheme
         if (tmp.isEmpty()) {
             QMessageBox::information(this, xi18nc("@title:window", "Generate Report"),
-                                     i18n("Failed to generate %1."
-                                          "\nTemplate file name is empty.", name));
+                                     xi18n("Failed to generate %1."
+                                          "<nl/>Template file name is empty.", name));
+            continue;
+        }
+        if (!QFile::exists(tmp)) {
+            QMessageBox::information(this, xi18nc("@title:window", "Generate Report"),
+                                     xi18n("Failed to generate %1."
+                                          "<nl/>Template file does not exist:<nl/>%2", name, tmp));
             continue;
         }
         if (file.isEmpty()) {
-            debugPlan<<"No files for report:"<<name<<tmp<<file;
+            debugPlanReport<<"No files for report:"<<name<<tmp<<file;
             QMessageBox::information(this, xi18nc("@title:window", "Generate Report"),
-                                     i18n("Failed to generate %1."
-                                          "\nReport file name is empty.", name));
+                                     xi18n("Failed to generate %1."
+                                          "<nl/>Report file name is empty.", name));
             continue;
         }
-        QString addition = model->index(idx.row(), 3).data(Qt::UserRole).toString();
-        if (addition == "Date") {
-            int dotpos = file.lastIndexOf('.');
+        QString addition = model->index(idx.row(), COLUMN_ADD).data(Qt::UserRole).toString();
+        if (addition == QStringLiteral("Date")) {
+            int dotpos = file.lastIndexOf(QLatin1Char('.'));
             QString date = QDate::currentDate().toString();
-            file = file.insert(dotpos, date.prepend('-'));
-        } else if (addition == "Number") {
-            int dotpos = file.lastIndexOf('.');
+            file = file.insert(dotpos, date.prepend(QLatin1Char('-')));
+        } else if (addition == QStringLiteral("Number")) {
+            int dotpos = file.lastIndexOf(QLatin1Char('.'));
             QString fn = file;
             for (int i = 1; QFile::exists(fn); ++i) {
-                fn = file.insert(dotpos, QString::number(i).prepend('-'));
+                fn.insert(dotpos, QString::number(i).prepend(QLatin1Char('-')));
+                if (!QFile::exists(fn)) {
+                    file = fn;
+                    break;
+                }
+                fn = file;
             }
-            file = fn;
         }
         // warn if file exists
-        if (QFile::exists(QUrl(file).path())) {
-            if (QMessageBox::question(this, i18n("Report Generation"), i18n("File exists. Continue?")) == QMessageBox::No) {
+        if (QFile::exists(file)) {
+            auto ret = KMessageBox::warningContinueCancel(this, xi18nc("@info", "File exists:<nl/>%1", file), i18nc("@title:window", "Report Generation"));
+            if (ret != KMessageBox::Continue) {
                 return;
             }
         }
@@ -454,38 +517,43 @@ void ReportsGeneratorView::slotGenerateReport()
 
 bool ReportsGeneratorView::generateReport(const QString &templateFile, const QString &file)
 {
-    ReportGenerator rg;
-    rg.setReportType("odt"); // TODO: handle different report types
-    rg.setTemplateFile(templateFile);
-    rg.setReportFile(file);
-    rg.setProject(project());
-    rg.setScheduleManager(scheduleManager());
-    if (!rg.open()) {
-        debugPlan<<"Failed to open report generator";
-        QMessageBox::warning(this, i18n("Failed to open report generator"), rg.lastError());
+    ReportGeneratorFactory rgf;
+    QScopedPointer<ReportGenerator> rg(rgf.createReportGenerator(QStringLiteral("odt")));
+    rg->setTemplateFile(templateFile);
+    rg->setReportFile(file);
+    rg->setProject(project());
+    rg->setScheduleManager(scheduleManager());
+    if (!rg->initiate()) {
+        debugPlanReport<<"Failed to initiate report generator";
+        QMessageBox::warning(this, i18n("Failed to open report generator"), rg->lastError());
         return false;
     }
-    if (!rg.createReport()) {
-        QMessageBox::warning(this, i18n("Failed to create report"), rg.lastError());
+    if (!rg->createReport()) {
+        QMessageBox::warning(this, i18n("Failed to create report"), rg->lastError());
         return false;
     }
     if (QMessageBox::question(this, xi18nc("@title:window", "Report Generation"), xi18nc("@info", "Report file generated:<nl/><filename>%1</filename>", file), QMessageBox::Open|QMessageBox::Close, QMessageBox::Close) == QMessageBox::Open) {
-        return KRun::runUrl(QUrl(file), "application/vnd.oasis.opendocument.text", window(), (KRun::RunFlags)0);
+        QUrl url(file);
+        url.setScheme(QStringLiteral("file"));
+        debugPlanReport<<"open:"<<url;
+        auto job = new KIO::OpenUrlJob(url, QStringLiteral("application/vnd.oasis.opendocument.text"));
+        job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, window()));
+        job->start();
     }
     return true;
 }
 
 bool ReportsGeneratorView::loadContext(const KoXmlElement &context)
 {
-    debugPlan;
-    m_view->header()->setStretchLastSection((bool)(context.attribute("stretch-last-column", "1").toInt()));
+    debugPlanReport;
+    m_view->header()->setStretchLastSection((bool)(context.attribute(QStringLiteral("stretch-last-column"), QString::number(1)).toInt()));
     KoXmlElement e = context.namedItem("sections").toElement();
     if (!e.isNull()) {
         QHeaderView *h = m_view->header();
-        QString s("section-%1");
+        QString s = QString::fromLatin1("section-%1");
         for (int i = 0; i < h->count(); ++i) {
             if (e.hasAttribute(s.arg(i))) {
-                int index = e.attribute(s.arg(i), "-1").toInt();
+                int index = e.attribute(s.arg(i), QString::number(-1)).toInt();
                 if (index >= 0 && index < h->count()) {
                     h->moveSection(h->visualIndex(index), i);
                 }
@@ -494,11 +562,11 @@ bool ReportsGeneratorView::loadContext(const KoXmlElement &context)
     }
     KoXmlElement parent = context.namedItem("data").toElement();
     if (!parent.isNull()) {
-        debugPlan<<"Load data";
+        debugPlanReport<<"Load data";
         int row = 0;
         QAbstractItemModel *model = m_view->model();
         forEachElement(e, parent) {
-            if (e.tagName() != "row") {
+            if (e.tagName() != QStringLiteral("row")) {
                 continue;
             }
             model->insertRow(row);
@@ -506,15 +574,15 @@ bool ReportsGeneratorView::loadContext(const KoXmlElement &context)
             QString tmp = e.attribute("template");
             QString file = e.attribute("file");
             QString add = e.attribute("add");
-            QModelIndex idx = model->index(row, 0);
+            QModelIndex idx = model->index(row, COLUMN_NAME);
             model->setData(idx, name);
-            idx = model->index(row, 1);
+            idx = model->index(row, COLUMN_TEMPLATE);
             model->setData(idx, tmp, FULLPATHROLE);
             model->setData(idx, tmp, Qt::ToolTipRole);
             model->setData(idx, QUrl(tmp).fileName());
-            idx = model->index(row, 2);
+            idx = model->index(row, COLUMN_FILE);
             model->setData(idx, file);
-            idx = model->index(row, 3);
+            idx = model->index(row, COLUMN_ADD);
             model->setData(idx, add, Qt::UserRole);
             model->setData(idx, ReportsGeneratorView::addOptions().value(ReportsGeneratorView::addTags().indexOf(add)));
             ++row;
@@ -530,31 +598,28 @@ bool ReportsGeneratorView::loadContext(const KoXmlElement &context)
 
 void ReportsGeneratorView::saveContext(QDomElement &context) const
 {
-    debugPlan;
-    context.setAttribute("stretch-last-column", QString::number(m_view->header()->stretchLastSection()));
-    QDomElement e = context.ownerDocument().createElement("sections");
+    debugPlanReport;
+    context.setAttribute(QStringLiteral("stretch-last-column"), QString::number(m_view->header()->stretchLastSection()));
+    QDomElement e = context.ownerDocument().createElement(QStringLiteral("sections"));
     context.appendChild(e);
     QHeaderView *h = m_view->header();
     for (int i = 0; i < h->count(); ++i) {
-        e.setAttribute(QString("section-%1").arg(i), h->logicalIndex(i));
+        e.setAttribute(QStringLiteral("section-%1").arg(i), h->logicalIndex(i));
     }
-    QDomElement data = context.ownerDocument().createElement("data");
+    QDomElement data = context.ownerDocument().createElement(QStringLiteral("data"));
     context.appendChild(data);
     const QAbstractItemModel *model = m_view->model();
     for (int row = 0; row < model->rowCount(); ++row) {
-        e = data.ownerDocument().createElement("row");
+        e = data.ownerDocument().createElement(QStringLiteral("row"));
         data.appendChild(e);
-        QModelIndex idx = model->index(row, 0);
-        e.setAttribute("name", idx.data().toString());
-        idx = model->index(row, 1);
-        e.setAttribute("template", idx.data(FULLPATHROLE).toString());
-        idx = model->index(row, 2);
-        e.setAttribute("file", idx.data().toString());
-        idx = model->index(row, 3);
-        e.setAttribute("add", idx.data(Qt::UserRole).toString());
+        QModelIndex idx = model->index(row, COLUMN_NAME);
+        e.setAttribute(QStringLiteral("name"), idx.data().toString());
+        idx = model->index(row, COLUMN_TEMPLATE);
+        e.setAttribute(QStringLiteral("template"), idx.data(FULLPATHROLE).toString());
+        idx = model->index(row, COLUMN_FILE);
+        e.setAttribute(QStringLiteral("file"), idx.data().toString());
+        idx = model->index(row, COLUMN_ADD);
+        e.setAttribute(QStringLiteral("add"), idx.data(Qt::UserRole).toString());
     }
     ViewBase::saveContext(context);
 }
-
-
-} // namespace KPlato
