@@ -1,23 +1,10 @@
 /*  This file is part of the KDE Libraries
- *  Copyright (C) 1998 Thomas Tanghus (tanghus@earthling.net)
+ *  SPDX-FileCopyrightText: 1998 Thomas Tanghus (tanghus@earthling.net)
  *  Additions 1999-2000 by Espen Sand (espen@kde.org)
  *                      by Holger Freyther <freyther@kde.org>
  *            2005-2009 by Olivier Goffart (ogoffart at kde.org)
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 // clazy:excludeall=qstring-arg
@@ -25,7 +12,6 @@
 #include "KoDialog_p.h"
 
 #include <QApplication>
-#include <QDesktopWidget>
 #include <QDialogButtonBox>
 #include <QHBoxLayout>
 #include <QHideEvent>
@@ -37,14 +23,14 @@
 #include <QDebug>
 #include <QPushButton>
 
-#include <kconfig.h>
-#include <klocalizedstring.h>
+#include <KConfig>
+#include <KLocalizedString>
 
-#include <kseparator.h>
-#include <kstandardguiitem.h>
-#include <khelpclient.h>
-#include <kurllabel.h>
-#include <kwindowconfig.h>
+#include <KSeparator>
+#include <KStandardGuiItem>
+#include <KHelpClient>
+#include <KUrlLabel>
+#include <KWindowConfig>
 
 void KoDialogPrivate::setupLayout()
 {
@@ -67,7 +53,7 @@ void KoDialogPrivate::queuedLayoutUpdate()
 
     // Don't lose the focus widget when re-creating the layout.
     // Testcase: KOrganizer's "Select Categories" dialog
-    QPointer<QWidget> focusWidget = mMainWidget ? mMainWidget->focusWidget() : 0;
+    QPointer<QWidget> focusWidget = mMainWidget ? mMainWidget->focusWidget() : nullptr;
 
     if (q->layout() && q->layout() != mTopLayout) {
         qWarning() << q->metaObject()->className() << "created with a layout; don't do that, KoDialog takes care of it, use mainWidget or setMainWidget instead";
@@ -129,16 +115,10 @@ void KoDialogPrivate::appendButton(KoDialog::ButtonCode key, const KGuiItem &ite
         role = QDialogButtonBox::ApplyRole;
         break;
     case KoDialog::Try:
-    case KoDialog::Yes:
-        role = QDialogButtonBox::YesRole;
-        break;
     case KoDialog::Close:
     case KoDialog::Cancel:
         role = QDialogButtonBox::RejectRole;
         break;
-    case KoDialog::No:
-        role = QDialogButtonBox::NoRole;
-        break;
     case KoDialog::User1:
     case KoDialog::User2:
     case KoDialog::User3:
@@ -178,7 +158,7 @@ void KoDialogPrivate::init(KoDialog *q)
     q->setButtons(KoDialog::Ok | KoDialog::Cancel);
     q->setDefaultButton(KoDialog::Ok);
 
-    q->connect(&mButtonSignalMapper, SIGNAL(mapped(int)), q, SLOT(slotButtonClicked(int)));
+    q->connect(&mButtonSignalMapper, &QSignalMapper::mappedInt, q, &KoDialog::slotButtonClicked);
 
     q->setPlainCaption(qApp->applicationDisplayName()); // set appropriate initial window title for case it gets not set later
 }
@@ -214,7 +194,7 @@ void KoDialog::setButtons(ButtonCodes buttonMask)
         d->mButtonList.clear();
 
         delete d->mButtonBox;
-        d->mButtonBox = 0;
+        d->mButtonBox = nullptr;
     }
 
     if (buttonMask & Cancel) {
@@ -270,14 +250,8 @@ void KoDialog::setButtons(ButtonCodes buttonMask)
     if (buttonMask & Close) {
         d->appendButton(Close, KStandardGuiItem::close());
     }
-    if (buttonMask & Yes) {
-        d->appendButton(Yes, KStandardGuiItem::yes());
-    }
-    if (buttonMask & No) {
-        d->appendButton(No, KStandardGuiItem::no());
-    }
     if (buttonMask & Details) {
-        d->appendButton(Details, KGuiItem(QString(), "help-about"));
+        d->appendButton(Details, KGuiItem(QString(), QStringLiteral("help-about")));
         setDetailsWidgetVisible(false);
     }
 
@@ -329,7 +303,7 @@ void KoDialog::setDefaultButton(ButtonCode newDefaultButton)
         QPushButton *b = button(newDefaultButton);
         if (b) {
             b->setDefault(true);
-            if (focusWidget() == 0 || oldDefaultHadFocus) {
+            if (focusWidget() == nullptr || oldDefaultHadFocus) {
                 // No widget had focus yet, or the old default button had
                 // -> ok to give focus to the new default button, so that it's
                 // really default (Enter triggers it).
@@ -366,7 +340,7 @@ void KoDialog::setMainWidget(QWidget *widget)
     d->mMainWidget = widget;
     if (d->mMainWidget && d->mMainWidget->layout()) {
         // Avoid double-margin problem
-        d->mMainWidget->layout()->setMargin(0);
+        d->mMainWidget->layout()->setContentsMargins(0, 0, 0, 0);
     }
     d->setupLayout();
 }
@@ -450,21 +424,6 @@ void KoDialog::keyPressEvent(QKeyEvent *event)
     QDialog::keyPressEvent(event);
 }
 
-int KoDialog::marginHint()
-{
-    return QApplication::style()->pixelMetric(QStyle::PM_DefaultChildMargin);
-}
-
-int KoDialog::spacingHint()
-{
-    return QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
-}
-
-int KoDialog::groupSpacingHint()
-{
-    return QApplication::fontMetrics().lineSpacing();
-}
-
 QString KoDialog::makeStandardCaption(const QString &userCaption,
                                      QWidget *window,
                                      CaptionFlags flags)
@@ -526,7 +485,7 @@ void KoDialog::resizeLayout(QWidget *widget, int margin, int spacing)   //static
 
     if (widget->children().count() > 0) {
         const QList<QObject *> list = widget->children();
-        foreach (QObject *object, list) {
+        for (QObject *object : list) {
             if (object->isWidgetType()) {
                 resizeLayout((QWidget *)object, margin, spacing);
             }
@@ -548,108 +507,15 @@ void KoDialog::resizeLayout(QLayout *layout, int margin, int spacing)   //static
     }
 
     if (layout->layout()) {
-        layout->layout()->setMargin(margin);
+        layout->layout()->setContentsMargins(margin, margin, margin, margin);
         layout->layout()->setSpacing(spacing);
     }
 }
 
-static QRect screenRect(QWidget *widget, int screen)
-{
-    QDesktopWidget *desktop = QApplication::desktop();
-    KConfig gc("kdeglobals", KConfig::NoGlobals);
-    KConfigGroup cg(&gc, "Windows");
-    if (desktop->isVirtualDesktop() &&
-            cg.readEntry("XineramaEnabled", true) &&
-            cg.readEntry("XineramaPlacementEnabled", true)) {
-
-        if (screen < 0 || screen >= desktop->numScreens()) {
-            if (screen == -1) {
-                screen = desktop->primaryScreen();
-            } else if (screen == -3) {
-                screen = desktop->screenNumber(QCursor::pos());
-            } else {
-                screen = desktop->screenNumber(widget);
-            }
-        }
-
-        return desktop->availableGeometry(screen);
-    } else {
-        return desktop->geometry();
-    }
-}
-
-void KoDialog::centerOnScreen(QWidget *widget, int screen)
-{
-    if (!widget) {
-        return;
-    }
-
-    QRect rect = screenRect(widget, screen);
-
-    widget->move(rect.center().x() - widget->width() / 2,
-                 rect.center().y() - widget->height() / 2);
-}
-
-bool KoDialog::avoidArea(QWidget *widget, const QRect &area, int screen)
-{
-    if (!widget) {
-        return false;
-    }
-
-    QRect fg = widget->frameGeometry();
-    if (!fg.intersects(area)) {
-        return true;    // nothing to do.
-    }
-
-    const QRect scr = screenRect(widget, screen);
-    QRect avoid(area);   // let's add some margin
-    avoid.translate(-5, -5);
-    avoid.setRight(avoid.right() + 10);
-    avoid.setBottom(avoid.bottom() + 10);
-
-    if (qMax(fg.top(), avoid.top()) <= qMin(fg.bottom(), avoid.bottom())) {
-        // We need to move the widget up or down
-        int spaceAbove = qMax(0, avoid.top() - scr.top());
-        int spaceBelow = qMax(0, scr.bottom() - avoid.bottom());
-        if (spaceAbove > spaceBelow)   // where's the biggest side?
-            if (fg.height() <= spaceAbove) { // big enough?
-                fg.setY(avoid.top() - fg.height());
-            } else {
-                return false;
-            }
-        else if (fg.height() <= spaceBelow) { // big enough?
-            fg.setY(avoid.bottom());
-        } else {
-            return false;
-        }
-    }
-
-    if (qMax(fg.left(), avoid.left()) <= qMin(fg.right(), avoid.right())) {
-        // We need to move the widget left or right
-        const int spaceLeft = qMax(0, avoid.left() - scr.left());
-        const int spaceRight = qMax(0, scr.right() - avoid.right());
-        if (spaceLeft > spaceRight)   // where's the biggest side?
-            if (fg.width() <= spaceLeft) { // big enough?
-                fg.setX(avoid.left() - fg.width());
-            } else {
-                return false;
-            }
-        else if (fg.width() <= spaceRight) { // big enough?
-            fg.setX(avoid.right());
-        } else {
-            return false;
-        }
-    }
-
-    widget->move(fg.x(), fg.y());
-
-    return true;
-}
-
 void KoDialog::showButtonSeparator(bool state)
 {
     Q_D(KoDialog);
-    if ((d->mActionSeparator != 0) == state) {
+    if ((d->mActionSeparator != nullptr) == state) {
         return;
     }
     if (state) {
@@ -661,7 +527,7 @@ void KoDialog::showButtonSeparator(bool state)
         d->mActionSeparator->setOrientation(d->mButtonOrientation);
     } else {
         delete d->mActionSeparator;
-        d->mActionSeparator = 0;
+        d->mActionSeparator = nullptr;
     }
 
     d->setupLayout();
@@ -682,7 +548,7 @@ void KoDialog::incrementInitialSize(const QSize &size)
 QPushButton *KoDialog::button(ButtonCode id) const
 {
     Q_D(const KoDialog);
-    return d->mButtonList.value(id, 0);
+    return d->mButtonList.value(id, nullptr);
 }
 
 void KoDialog::enableButton(ButtonCode id, bool state)
@@ -867,8 +733,8 @@ void KoDialog::setDetailsWidgetVisible(bool visible)
     d->mSettingDetails = true;
     d->mDetailsVisible = visible;
     if (d->mDetailsVisible) {
-        emit aboutToShowDetails();
-        setButtonText(Details, d->mDetailsButtonText + " <<");
+        Q_EMIT aboutToShowDetails();
+        setButtonText(Details, d->mDetailsButtonText + QStringLiteral(" <<"));
         if (d->mDetailsWidget) {
             if (layout()) {
                 layout()->setEnabled(false);
@@ -884,7 +750,7 @@ void KoDialog::setDetailsWidgetVisible(bool visible)
             }
         }
     } else {
-        setButtonText(Details, d->mDetailsButtonText + " >>");
+        setButtonText(Details, d->mDetailsButtonText + QStringLiteral(" >>"));
         if (d->mDetailsWidget) {
             d->mDetailsWidget->hide();
         }
@@ -911,55 +777,47 @@ void KoDialog::delayedDestruct()
 void KoDialog::slotButtonClicked(int button)
 {
     Q_D(KoDialog);
-    emit buttonClicked(static_cast<KoDialog::ButtonCode>(button));
+    Q_EMIT buttonClicked(static_cast<KoDialog::ButtonCode>(button));
 
     switch (button) {
     case Ok:
-        emit okClicked();
+        Q_EMIT okClicked();
         accept();
         break;
     case Apply:
-        emit applyClicked();
+        Q_EMIT applyClicked();
         break;
     case Try:
-        emit tryClicked();
+        Q_EMIT tryClicked();
         break;
     case User3:
-        emit user3Clicked();
+        Q_EMIT user3Clicked();
         break;
     case User2:
-        emit user2Clicked();
+        Q_EMIT user2Clicked();
         break;
     case User1:
-        emit user1Clicked();
-        break;
-    case Yes:
-        emit yesClicked();
-        done(Yes);
-        break;
-    case No:
-        emit noClicked();
-        done(No);
+        Q_EMIT user1Clicked();
         break;
     case Cancel:
-        emit cancelClicked();
+        Q_EMIT cancelClicked();
         reject();
         break;
     case Close:
-        emit closeClicked();
+        Q_EMIT closeClicked();
         done(Close); // KDE5: call reject() instead; more QDialog-like.
         break;
     case Help:
-        emit helpClicked();
+        Q_EMIT helpClicked();
         if (!d->mAnchor.isEmpty() || !d->mHelpApp.isEmpty()) {
             KHelpClient::invokeHelp(d->mAnchor, d->mHelpApp);
         }
         break;
     case Default:
-        emit defaultClicked();
+        Q_EMIT defaultClicked();
         break;
     case Reset:
-        emit resetClicked();
+        Q_EMIT resetClicked();
         break;
     case Details:
         setDetailsWidgetVisible(!d->mDetailsVisible);
@@ -976,7 +834,7 @@ void KoDialog::slotButtonClicked(int button)
 void KoDialog::enableLinkedHelp(bool state)
 {
     Q_D(KoDialog);
-    if ((d->mUrlHelp != 0) == state) {
+    if ((d->mUrlHelp != nullptr) == state) {
         return;
     }
     if (state) {
@@ -988,13 +846,13 @@ void KoDialog::enableLinkedHelp(bool state)
         d->mUrlHelp->setText(helpLinkText());
         d->mUrlHelp->setFloatEnabled(true);
         d->mUrlHelp->setUnderline(true);
-        d->mUrlHelp->setMinimumHeight(fontMetrics().height() + marginHint());
+        d->mUrlHelp->setMinimumHeight(fontMetrics().height() + QApplication::style()->pixelMetric(QStyle::PM_LayoutTopMargin));
         connect(d->mUrlHelp, SIGNAL(leftClickedUrl()), SLOT(helpLinkClicked()));
 
         d->mUrlHelp->show();
     } else {
         delete d->mUrlHelp;
-        d->mUrlHelp = 0;
+        d->mUrlHelp = nullptr;
     }
 
     d->setupLayout();
@@ -1028,11 +886,8 @@ void KoDialog::updateGeometry()
 
 void KoDialog::hideEvent(QHideEvent *event)
 {
-    emit hidden();
-
-    if (!event->spontaneous()) {
-        emit finished();
-    }
+    Q_UNUSED(event)
+    Q_EMIT hidden();
 }
 
 void KoDialog::closeEvent(QCloseEvent *event)
