@@ -1,25 +1,13 @@
 /* This file is part of the KDE project
-   Copyright (c) 2000 Simon Hausmann <hausmann@kde.org>
+   SPDX-FileCopyrightText: 2000 Simon Hausmann <hausmann@kde.org>
                  2006 Martin Pfeiffer <hubipete@gmx.net>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 // clazy:excludeall=qstring-arg
 #include "KoDocumentInfoDlg.h"
+#include "WidgetsDebug.h"
 
 #include "ui_koDocumentInfoAboutWidget.h"
 #include "ui_koDocumentInfoAuthorWidget.h"
@@ -34,11 +22,11 @@
 //#include <KoDocumentRdfBase.h>
 #include <KoIcon.h>
 
-#include <klocalizedstring.h>
-#include <kiconloader.h>
+#include <KLocalizedString>
+#include <KIconLoader>
 
-#include <kmessagebox.h>
-#include <kmainwindow.h>
+#include <KMessageBox>
+#include <KMainWindow>
 #include <KoDialog.h>
 
 #include <QUrl>
@@ -49,8 +37,7 @@
 
 
 // see KoIcon.h
-#define koSmallIcon(name) (SmallIcon(QStringLiteral(name)))
-
+#define koSmallPixmap(name) KIconLoader::global()->loadIcon(QStringLiteral(name), KIconLoader::Small)
 
 class KoPageWidgetItemAdapter : public KPageWidgetItem
 {
@@ -128,7 +115,7 @@ KoDocumentInfoDlg::KoDocumentInfoDlg(QWidget* parent, KoDocumentInfo* docInfo)
     KoDocumentBase* doc = dynamic_cast< KoDocumentBase* >(d->info->parent());
     if (doc) {
         QMimeDatabase db;
-        QMimeType mime = db.mimeTypeForName(doc->mimeType());
+        QMimeType mime = db.mimeTypeForName(QString::fromLatin1(doc->mimeType()));
         if (mime.isValid()) {
             page->setIcon(QIcon::fromTheme(mime.iconName()));
         }
@@ -167,7 +154,7 @@ KoDocumentInfoDlg::~KoDocumentInfoDlg()
 void KoDocumentInfoDlg::accept()
 {
     // check if any pages veto the close
-    foreach(KPageWidgetItem* item, d->pages) {
+    for (KPageWidgetItem* item : std::as_const(d->pages)) {
         KoPageWidgetItemAdapter *page = dynamic_cast<KoPageWidgetItemAdapter*>(item);
         if (page) {
             if (page->shouldDialogCloseBeVetoed()) {
@@ -178,7 +165,7 @@ void KoDocumentInfoDlg::accept()
 
     // all fine, go and apply
     saveAboutData();
-    foreach(KPageWidgetItem* item, d->pages) {
+    for (KPageWidgetItem* item : std::as_const(d->pages)) {
         KoPageWidgetItemAdapter *page = dynamic_cast<KoPageWidgetItemAdapter*>(item);
         if (page) {
             page->apply();
@@ -213,7 +200,7 @@ void KoDocumentInfoDlg::initAboutTab()
     d->aboutUi->meComments->setPlainText(d->info->aboutInfo("description"));
     if (doc && !doc->mimeType().isEmpty()) {
         QMimeDatabase db;
-        QMimeType docmime = db.mimeTypeForName(doc->mimeType());
+        QMimeType docmime = db.mimeTypeForName(QLatin1String(doc->mimeType()));
         if (docmime.isValid())
             d->aboutUi->lblType->setText(docmime.comment());
     }
@@ -221,14 +208,14 @@ void KoDocumentInfoDlg::initAboutTab()
         QDateTime t = QDateTime::fromString(d->info->aboutInfo("creation-date"),
                                             Qt::ISODate);
         QString s = QLocale().toString(t);
-        d->aboutUi->lblCreated->setText(s + ", " +
+        d->aboutUi->lblCreated->setText(s + QStringLiteral(", ") +
                                         d->info->aboutInfo("initial-creator"));
     }
 
     if (!d->info->aboutInfo("date").isEmpty()) {
         QDateTime t = QDateTime::fromString(d->info->aboutInfo("date"), Qt::ISODate);
         QString s = QLocale().toString(t);
-        d->aboutUi->lblModified->setText(s + ", " + d->info->authorInfo("creator"));
+        d->aboutUi->lblModified->setText(s + QStringLiteral(", ") + d->info->authorInfo("creator"));
     }
 
     d->aboutUi->lblRevision->setText(d->info->aboutInfo("editing-cycles"));
@@ -237,21 +224,21 @@ void KoDocumentInfoDlg::initAboutTab()
         if (doc->specialOutputFlag() == KoDocumentBase::SaveEncrypted) {
             if (d->toggleEncryption) {
                 d->aboutUi->lblEncrypted->setText(i18n("This document will be decrypted"));
-                d->aboutUi->lblEncryptedPic->setPixmap(koSmallIcon("object-unlocked"));
+                d->aboutUi->lblEncryptedPic->setPixmap(koSmallPixmap("object-unlocked"));
                 d->aboutUi->pbEncrypt->setText(i18n("Do not decrypt"));
             } else {
                 d->aboutUi->lblEncrypted->setText(i18n("This document is encrypted"));
-                d->aboutUi->lblEncryptedPic->setPixmap(koSmallIcon("object-locked"));
+                d->aboutUi->lblEncryptedPic->setPixmap(koSmallPixmap("object-locked"));
                 d->aboutUi->pbEncrypt->setText(i18n("D&ecrypt"));
             }
         } else {
             if (d->toggleEncryption) {
                 d->aboutUi->lblEncrypted->setText(i18n("This document will be encrypted."));
-                d->aboutUi->lblEncryptedPic->setPixmap(koSmallIcon("object-locked"));
+                d->aboutUi->lblEncryptedPic->setPixmap(koSmallPixmap("object-locked"));
                 d->aboutUi->pbEncrypt->setText(i18n("Do not encrypt"));
             } else {
                 d->aboutUi->lblEncrypted->setText(i18n("This document is not encrypted"));
-                d->aboutUi->lblEncryptedPic->setPixmap(koSmallIcon("object-unlocked"));
+                d->aboutUi->lblEncryptedPic->setPixmap(koSmallPixmap("object-unlocked"));
                 d->aboutUi->pbEncrypt->setText(i18n("&Encrypt"));
             }
         }
@@ -309,14 +296,14 @@ void KoDocumentInfoDlg::slotResetMetaData()
         QDateTime t = QDateTime::fromString(d->info->aboutInfo("creation-date"),
                                             Qt::ISODate);
         QString s = QLocale().toString(t);
-        d->aboutUi->lblCreated->setText(s + ", " +
+        d->aboutUi->lblCreated->setText(s + QStringLiteral(", ") +
                                         d->info->aboutInfo("initial-creator"));
     }
 
     if (!d->info->aboutInfo("date").isEmpty()) {
         QDateTime t = QDateTime::fromString(d->info->aboutInfo("date"), Qt::ISODate);
         QString s = QLocale().toString(t);
-        d->aboutUi->lblModified->setText(s + ", " + d->info->authorInfo("creator"));
+        d->aboutUi->lblModified->setText(s + QStringLiteral(", ") + d->info->authorInfo("creator"));
     }
 
     d->aboutUi->lblRevision->setText(d->info->aboutInfo("editing-cycles"));
@@ -333,21 +320,21 @@ void KoDocumentInfoDlg::slotToggleEncryption()
     if (doc->specialOutputFlag() == KoDocumentBase::SaveEncrypted) {
         if (d->toggleEncryption) {
             d->aboutUi->lblEncrypted->setText(i18n("This document will be decrypted"));
-            d->aboutUi->lblEncryptedPic->setPixmap(koSmallIcon("object-unlocked"));
+            d->aboutUi->lblEncryptedPic->setPixmap(koSmallPixmap("object-unlocked"));
             d->aboutUi->pbEncrypt->setText(i18n("Do not decrypt"));
         } else {
             d->aboutUi->lblEncrypted->setText(i18n("This document is encrypted"));
-            d->aboutUi->lblEncryptedPic->setPixmap(koSmallIcon("object-locked"));
+            d->aboutUi->lblEncryptedPic->setPixmap(koSmallPixmap("object-locked"));
             d->aboutUi->pbEncrypt->setText(i18n("D&ecrypt"));
         }
     } else {
         if (d->toggleEncryption) {
             d->aboutUi->lblEncrypted->setText(i18n("This document will be encrypted."));
-            d->aboutUi->lblEncryptedPic->setPixmap(koSmallIcon("object-locked"));
+            d->aboutUi->lblEncryptedPic->setPixmap(koSmallPixmap("object-locked"));
             d->aboutUi->pbEncrypt->setText(i18n("Do not encrypt"));
         } else {
             d->aboutUi->lblEncrypted->setText(i18n("This document is not encrypted"));
-            d->aboutUi->lblEncryptedPic->setPixmap(koSmallIcon("object-unlocked"));
+            d->aboutUi->lblEncryptedPic->setPixmap(koSmallPixmap("object-unlocked"));
             d->aboutUi->pbEncrypt->setText(i18n("&Encrypt"));
         }
     }
@@ -363,7 +350,7 @@ void KoDocumentInfoDlg::saveEncryption()
         return;
 
     KMainWindow* mainWindow = dynamic_cast< KMainWindow* >(parent());
-
+    bool saveas = false;
     if (doc->specialOutputFlag() == KoDocumentBase::SaveEncrypted) {
         // Decrypt
         if (KMessageBox::warningContinueCancel(
@@ -373,7 +360,7 @@ void KoDocumentInfoDlg::saveEncryption()
                     i18n("Confirm Decrypt"),
                     KGuiItem(i18n("Decrypt")),
                     KStandardGuiItem::cancel(),
-                    "DecryptConfirmation"
+                    QStringLiteral("DecryptConfirmation")
                     ) != KMessageBox::Continue) {
             return;
         }
@@ -385,35 +372,35 @@ void KoDocumentInfoDlg::saveEncryption()
                         i18n("<qt>Your document could not be saved automatically."
                              "<p>To complete the decryption, please save the document.</qt>"),
                         i18n("Save Document"),
-                        "DecryptSaveMessage");
+                        QStringLiteral("DecryptSaveMessage"));
             return;
         }
-        if (modified && KMessageBox::questionYesNo(
+        if (modified && KMessageBox::questionTwoActions(
                     this,
                     i18n("<qt>The document has been changed since it was opened. To complete the decryption the document needs to be saved."
                          "<p>Do you want to save the document now?</qt>"),
                     i18n("Save Document"),
                     KStandardGuiItem::save(),
                     KStandardGuiItem::dontSave(),
-                    "DecryptSaveConfirmation"
-                    ) != KMessageBox::Yes) {
+                    QStringLiteral("DecryptSaveConfirmation")
+                    ) != KMessageBox::PrimaryAction) {
             return;
         }
-    } else {
-        // Encrypt
+    } else if (doc->mimeType().startsWith("application/vnd.oasis.opendocument.")) {
+        // Encrypt oasis document
         bool modified = doc->isModified();
-        if (!doc->url().isEmpty() && !(doc->mimeType().startsWith("application/vnd.oasis.opendocument.") && doc->specialOutputFlag() == 0)) {
+        if (!doc->url().isEmpty() && doc->specialOutputFlag() == 0) {
             QMimeDatabase db;
-            QMimeType mime = db.mimeTypeForName(doc->mimeType());
+            QMimeType mime = db.mimeTypeForName(QString::fromLatin1(doc->mimeType()));
             QString comment = mime.isValid() ? mime.comment() : i18n("%1 (unknown file type)", QString::fromLatin1(doc->mimeType()));
             if (KMessageBox::warningContinueCancel(
                         this,
                         i18n("<qt>The document is currently saved as %1. The document needs to be changed to <b>OASIS OpenDocument</b> to be encrypted."
-                             "<p>Do you want to change the file to OASIS OpenDocument?</qt>", QString("<b>%1</b>").arg(comment)),
+                             "<p>Do you want to change the file to OASIS OpenDocument?</qt>", QStringLiteral("<b>%1</b>").arg(comment)),
                         i18n("Change Filetype"),
                         KGuiItem(i18n("Change")),
                         KStandardGuiItem::cancel(),
-                        "EncryptChangeFiletypeConfirmation"
+                        QStringLiteral("EncryptChangeFiletypeConfirmation")
                         ) != KMessageBox::Continue) {
                 return;
             }
@@ -427,27 +414,93 @@ void KoDocumentInfoDlg::saveEncryption()
                         i18n("<qt>Your document could not be saved automatically."
                              "<p>To complete the encryption, please save the document.</qt>"),
                         i18n("Save Document"),
-                        "EncryptSaveMessage");
+                        QStringLiteral("EncryptSaveMessage"));
             return;
         }
-        if (modified && KMessageBox::questionYesNo(
+        if (modified && KMessageBox::questionTwoActions(
                     this,
                     i18n("<qt>The document has been changed since it was opened. To complete the encryption the document needs to be saved."
                          "<p>Do you want to save the document now?</qt>"),
                     i18n("Save Document"),
                     KStandardGuiItem::save(),
                     KStandardGuiItem::dontSave(),
-                    "EncryptSaveConfirmation"
-                    ) != KMessageBox::Yes) {
+                    QStringLiteral("EncryptSaveConfirmation")
+                    ) != KMessageBox::PrimaryAction) {
+            return;
+        }
+    } else {
+        // Encrypt non-oasis document
+        bool modified = doc->isModified();
+        saveas = doc->outputMimeType().isEmpty();
+        if (!doc->url().isEmpty() && doc->specialOutputFlag() == 0) {
+            QMimeDatabase db;
+            QMimeType mime = db.mimeTypeForName(QString::fromLatin1(doc->mimeType()));
+            if (!doc->mimeType().isEmpty() && doc->mimeType() != doc->nativeFormatMimeType()) {
+                QString comment = mime.isValid() ? mime.comment() : i18n("%1 (unknown file type)", QString::fromLatin1(doc->mimeType()));
+                QString native = db.mimeTypeForName(QString::fromLatin1(doc->nativeFormatMimeType())).comment();
+                if (KMessageBox::warningContinueCancel(
+                            this,
+                            i18n("<qt>The document is currently saved as %1. The document needs to be changed to <b>%2</b> to be encrypted."
+                                "<p>Do you want to change the file to %2?</qt>", QStringLiteral("<b>%1</b>").arg(comment), native),
+                            i18n("Change Filetype"),
+                            KGuiItem(i18n("Change")),
+                            KStandardGuiItem::cancel(),
+                            QStringLiteral("EncryptChangeFiletypeConfirmation")
+                            ) != KMessageBox::Continue) {
+                    return;
+                }
+                // Replace the current extension with our native one.
+                // If the current extension is an unknown mimetype,
+                // we just add our native extension. Maybe not ideal
+                // but should not happen in normal cases,
+                // and the user can always correct it in the save dialog.
+                auto patterns = mime.globPatterns();
+                auto url = doc->url().url();
+                for (auto p : patterns) {
+                    p.remove(QLatin1Char('*'));
+                    if (url.endsWith(p)) {
+                        url = url.left(url.lastIndexOf(p));
+                    }
+                }
+                if (!url.isEmpty()) {
+                    const auto nativePattern = db.mimeTypeForName(QString::fromLatin1(doc->nativeFormatMimeType())).globPatterns().value(0).remove(QLatin1Char('*'));
+                    url.append(nativePattern);
+                }
+                doc->setUrl(QUrl(url));
+                saveas = true;
+                debugWidgets<<"document mimetype changed:"<<doc->url()<<patterns;
+            }
+        }
+        doc->setMimeType(doc->nativeFormatMimeType());
+        doc->setOutputMimeType(doc->nativeFormatMimeType(), KoDocumentBase::SaveEncrypted);
+        if (!mainWindow) {
+            KMessageBox::information(
+                        this,
+                        i18n("<qt>Your document could not be saved automatically."
+                            "<p>To complete the encryption, please save the document.</qt>"),
+                        i18n("Save Document"),
+                        QStringLiteral("EncryptSaveMessage"));
+            return;
+        }
+        if (modified && KMessageBox::questionTwoActions(
+                    this,
+                    i18n("<qt>The document has been changed since it was opened. To complete the encryption the document needs to be saved."
+                        "<p>Do you want to save the document now?</qt>"),
+                    i18n("Save Document"),
+                    KStandardGuiItem::save(),
+                    KStandardGuiItem::dontSave(),
+                    QStringLiteral("EncryptSaveConfirmation")
+                    ) != KMessageBox::PrimaryAction) {
             return;
         }
     }
-    // Why do the dirty work ourselves?
-    emit saveRequested();
+    // Let KoMainWindow handle save
+    Q_EMIT saveRequested(saveas, false, doc->specialOutputFlag());
     d->toggleEncryption = false;
     d->applyToggleEncryption = false;
-    // Detects when the user cancelled saving
-    d->documentSaved = !doc->url().isEmpty();
+    // Detects when the user cancelled saving of an unsaved document
+    // FIXME: Should this be tracked in the document?
+    d->documentSaved = !doc->url().scheme().isEmpty();
 }
 
 QList<KPageWidgetItem*> KoDocumentInfoDlg::pages() const
@@ -459,11 +512,13 @@ void KoDocumentInfoDlg::setReadOnly(bool ro)
 {
     d->aboutUi->meComments->setReadOnly(ro);
 
-    Q_FOREACH(KPageWidgetItem* page, d->pages) {
-        Q_FOREACH(QLineEdit* le, page->widget()->findChildren<QLineEdit *>()) {
+    for (KPageWidgetItem* page : std::as_const(d->pages)) {
+        const QList<QLineEdit*> lineEdits = page->widget()->findChildren<QLineEdit *>();
+        for (QLineEdit* le : lineEdits) {
             le->setReadOnly(ro);
         }
-        Q_FOREACH(QPushButton* le, page->widget()->findChildren<QPushButton *>()) {
+        const QList<QPushButton*> buttons = page->widget()->findChildren<QPushButton *>();
+        for (QPushButton* le : buttons ) {
             le->setDisabled(ro);
         }
     }
