@@ -1,21 +1,8 @@
 /* This file is part of the KDE project
-   Copyright (C) 2001 David Faure <faure@kde.org>
-   Copyright 2003 Nicolas GOUTTE <goutte@kde.org>
+   SPDX-FileCopyrightText: 2001 David Faure <faure@kde.org>
+   SPDX-FileCopyrightText: 2003 Nicolas GOUTTE <goutte@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 // clazy:excludeall=qstring-arg
@@ -31,10 +18,10 @@
 #include <QGlobalStatic>
 
 #include <WidgetsDebug.h>
-#include <kconfiggroup.h>
-#include <klocalizedstring.h>
-#include <ksharedconfig.h>
-#include <kconfig.h>
+#include <KConfigGroup>
+#include <KLocalizedString>
+#include <KSharedConfig>
+#include <KConfig>
 
 Q_GLOBAL_STATIC(KoGlobal, s_instance)
 
@@ -45,7 +32,7 @@ KoGlobal* KoGlobal::self()
 
 KoGlobal::KoGlobal()
     : m_pointSize(-1)
-    , m_planConfig(0)
+    , m_planConfig(nullptr)
 {
     // Fixes a bug where values from some config files are not picked up
     // due to  KSharedConfig::openConfig() being initialized before paths have been set up above.
@@ -90,7 +77,7 @@ QStringList KoGlobal::_listOfLanguages()
 
 void KoGlobal::createListOfLanguages()
 {
-    KConfig config("all_languages", KConfig::NoGlobals);
+    KConfig config(QStringLiteral("all_languages"), KConfig::NoGlobals);
 
     QMap<QString, bool> seenLanguages;
     const QStringList langlist = config.groupList();
@@ -117,15 +104,15 @@ void KoGlobal::createListOfLanguages()
             it != translationList.end(); ++it) {
         // Extract the language tag from the directory name
         QString tag = *it;
-        int index = tag.lastIndexOf('/');
+        int index = tag.lastIndexOf(QLatin1Char('/'));
         tag = tag.left(index);
-        index = tag.lastIndexOf('/');
+        index = tag.lastIndexOf(QLatin1Char('/'));
         tag = tag.mid(index + 1);
 
         if (seenLanguages.find(tag) == seenLanguages.end()) {
             KConfig entry(*it, KConfig::SimpleConfig);
 
-            const QString name = entry.group("KCM Locale").readEntry("Name", tag);
+            const QString name = entry.group(QStringLiteral("KCM Locale")).readEntry("Name", tag);
             // e.g. name is "US English" and tag is "en_US"
             m_langMap.insert(name, tag);
 
@@ -165,7 +152,7 @@ QString KoGlobal::languageFromTag(const QString &langTag)
 KConfig* KoGlobal::_planConfig()
 {
     if (!m_planConfig) {
-        m_planConfig = new KConfig("calligraplanrc");
+        m_planConfig = new KConfig(QStringLiteral("calligraplanrc"));
     }
     return m_planConfig;
 }
