@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
-   Copyright (C) 2013 - 2014 Yue Liu <yue.liu@mail.com>
+   SPDX-FileCopyrightText: 2013-2014 Yue Liu <yue.liu@mail.com>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 // clazy:excludeall=qstring-arg
@@ -25,9 +12,9 @@
 #include <QImageReader>
 #include <QClipboard>
 
-#include <kconfiggroup.h>
-#include <ksharedconfig.h>
-#include <klocalizedstring.h>
+#include <KConfigGroup>
+#include <KSharedConfig>
+#include <KLocalizedString>
 
 #include <QUrl>
 #include <QMimeDatabase>
@@ -106,7 +93,7 @@ public:
 KoFileDialog::KoFileDialog(QWidget *parent,
                            KoFileDialog::DialogType type,
                            const QString &dialogName)
-    : d(new Private(parent, type, "", getUsedDir(dialogName), dialogName))
+    : d(new Private(parent, type, QString(), getUsedDir(dialogName).toString(QUrl::FullyEncoded), dialogName))
 {
 }
 
@@ -148,7 +135,8 @@ void KoFileDialog::setOverrideDir(const QString &overrideDir)
 void KoFileDialog::setImageFilters()
 {
     QStringList imageMimeTypes;
-    foreach(const QByteArray &mimeType, QImageReader::supportedMimeTypes()) {
+    const QList<QByteArray> types = QImageReader::supportedMimeTypes();
+    for (const QByteArray &mimeType : types) {
         imageMimeTypes << QLatin1String(mimeType);
     }
     setMimeTypeFilters(imageMimeTypes);
@@ -174,7 +162,7 @@ void KoFileDialog::setNameFilters(const QStringList &filterList,
 
     if (d->type == KoFileDialog::SaveFile) {
         QStringList mimeList;
-        foreach(const QString &filter, filterList) {
+        for (const QString &filter : filterList) {
             d->filterList << splitNameFilter(filter, &mimeList);
         }
 
@@ -233,13 +221,13 @@ QString KoFileDialog::selectedMimeType() const
         return d->mimeType.name();
     }
     else {
-        return "";
+        return QString();
     }
 }
 
 void KoFileDialog::createFileDialog()
 {
-    d->fileDialog.reset(new QFileDialog(d->parent, d->caption, d->defaultDirectory));
+    d->fileDialog.reset(new QFileDialog(d->parent, d->caption, directory().toString()));
 
     if (d->type == SaveFile) {
         d->fileDialog->setAcceptMode(QFileDialog::AcceptSave);
@@ -288,7 +276,8 @@ void KoFileDialog::createFileDialog()
 
 QString KoFileDialog::filename()
 {
-    QString url;
+    QUrl url;
+    auto directory = this->directory();
     if (!d->useStaticForNative) {
 
         if (!d->fileDialog) {
@@ -296,51 +285,51 @@ QString KoFileDialog::filename()
         }
 
         if (d->fileDialog->exec() == QDialog::Accepted) {
-            url = d->fileDialog->selectedFiles().first();
+            url = d->fileDialog->selectedUrls().first();
         }
     }
     else {
         switch (d->type) {
         case OpenFile:
         {
-            url = QFileDialog::getOpenFileName(d->parent,
+            url = QFileDialog::getOpenFileUrl(d->parent,
                                                d->caption,
-                                               d->defaultDirectory,
-                                               d->filterList.join(";;"),
+                                               directory,
+                                               d->filterList.join(QStringLiteral(";;")),
                                                &d->defaultFilter);
             break;
         }
         case OpenDirectory:
         {
-            url = QFileDialog::getExistingDirectory(d->parent,
+            url = QUrl::fromUserInput(QFileDialog::getExistingDirectory(d->parent,
                                                     d->caption,
-                                                    d->defaultDirectory,
-                                                    QFileDialog::ShowDirsOnly);
+                                                    directory.toString(),
+                                                    QFileDialog::ShowDirsOnly));
             break;
         }
         case ImportFile:
         {
-            url = QFileDialog::getOpenFileName(d->parent,
+            url = QFileDialog::getOpenFileUrl(d->parent,
                                                d->caption,
-                                               d->defaultDirectory,
-                                               d->filterList.join(";;"),
+                                               directory,
+                                               d->filterList.join(QStringLiteral(";;")),
                                                &d->defaultFilter);
             break;
         }
         case ImportDirectory:
         {
-            url = QFileDialog::getExistingDirectory(d->parent,
+            url = QUrl::fromUserInput(QFileDialog::getExistingDirectory(d->parent,
                                                     d->caption,
-                                                    d->defaultDirectory,
-                                                    QFileDialog::ShowDirsOnly);
+                                                    directory.toString(),
+                                                    QFileDialog::ShowDirsOnly));
             break;
         }
         case SaveFile:
         {
-            url = QFileDialog::getSaveFileName(d->parent,
+            url = QFileDialog::getSaveFileUrl(d->parent,
                                                d->caption,
-                                               d->defaultDirectory,
-                                               d->filterList.join(";;"),
+                                               directory,
+                                               d->filterList.join(QStringLiteral(";;")),
                                                &d->defaultFilter);
             break;
         }
@@ -349,33 +338,24 @@ QString KoFileDialog::filename()
         }
     }
 
-    if (!url.isEmpty()) {
-
-        if (d->type == SaveFile && QFileInfo(url).suffix().isEmpty()) {
-            int start = d->defaultFilter.lastIndexOf("*.") + 1;
-            int end = d->defaultFilter.lastIndexOf(")");
-            int n = end - start;
-            QString extension = d->defaultFilter.mid(start, n);
-            url.append(extension);
-        }
-
+    if (url.isValid()) {
         QMimeDatabase db;
-        d->mimeType = db.mimeTypeForFile(url);
-        saveUsedDir(url, d->dialogName);
+        d->mimeType = db.mimeTypeForUrl(url);
+        saveUsedDir(url.toString(QUrl::FullyEncoded), d->dialogName);
     }
-    return url;
+    return url.toString(QUrl::FullyEncoded);
 }
 
-QStringList KoFileDialog::filenames()
+QList<QUrl> KoFileDialog::filenames()
 {
-    QStringList urls;
+    QList<QUrl> urls;
 
     if (!d->useStaticForNative) {
         if (!d->fileDialog) {
             createFileDialog();
         }
         if (d->fileDialog->exec() == QDialog::Accepted) {
-            urls = d->fileDialog->selectedFiles();
+            urls = d->fileDialog->selectedUrls();
         }
     }
     else {
@@ -383,10 +363,10 @@ QStringList KoFileDialog::filenames()
         case OpenFiles:
         case ImportFiles:
         {
-            urls = QFileDialog::getOpenFileNames(d->parent,
+            urls = QFileDialog::getOpenFileUrls(d->parent,
                                                  d->caption,
-                                                 d->defaultDirectory,
-                                                 d->filterList.join(";;"),
+                                                 directory(),
+                                                 d->filterList.join(QStringLiteral(";;")),
                                                  &d->defaultFilter);
             break;
         }
@@ -394,8 +374,8 @@ QStringList KoFileDialog::filenames()
             ;
         }
     }
-    if (urls.size() > 0) {
-        saveUsedDir(urls.first(), d->dialogName);
+    if (!urls.isEmpty()) {
+        saveUsedDir(urls.first().toString(QUrl::FullyEncoded), d->dialogName);
     }
     return urls;
 }
@@ -403,8 +383,8 @@ QStringList KoFileDialog::filenames()
 void KoFileDialog::filterSelected(const QString &filter)
 {
     // "Windows BMP image (*.bmp)";
-    int start = filter.lastIndexOf("*.") + 2;
-    int end = filter.lastIndexOf(")");
+    int start = filter.lastIndexOf(QStringLiteral("*.")) + 2;
+    int end = filter.lastIndexOf(QLatin1Char(')'));
     int n = end - start;
     QString extension = filter.mid(start, n);
     d->defaultFilter = filter;
@@ -418,27 +398,27 @@ QStringList KoFileDialog::splitNameFilter(const QString &nameFilter, QStringList
     QStringList filters;
     QString description;
 
-    if (nameFilter.contains("(")) {
-        description = nameFilter.left(nameFilter.indexOf("(") -1).trimmed();
+    if (nameFilter.contains(QLatin1Char('('))) {
+        description = nameFilter.left(nameFilter.indexOf(QLatin1Char('(')) -1).trimmed();
     }
 
-    QStringList entries = nameFilter.mid(nameFilter.indexOf("(") + 1).split(" ",QString::SkipEmptyParts);
+    const QStringList entries = nameFilter.mid(nameFilter.indexOf(QLatin1Char('(')) + 1).split(QLatin1Char(' '),Qt::SkipEmptyParts);
 
-    foreach(QString entry, entries) {
+    for (QString entry : entries) {
 
-        entry = entry.remove("*");
-        entry = entry.remove(")");
+        entry = entry.remove(QLatin1Char('*'));
+        entry = entry.remove(QLatin1Char(')'));
 
         QMimeDatabase db;
-        QMimeType mime = db.mimeTypeForName("bla" + entry);
-        if (mime.name() != "application/octet-stream") {
+        QMimeType mime = db.mimeTypeForName(QStringLiteral("bla") + entry);
+        if (mime.name() != QStringLiteral("application/octet-stream")) {
             if (!mimeList->contains(mime.name())) {
                 mimeList->append(mime.name());
-                filters.append(mime.comment() + " (*" + entry + ")");
+                filters.append(mime.comment() + QStringLiteral(" (*") + entry + QLatin1Char(')'));
             }
         }
         else {
-            filters.append(entry.remove(".").toUpper() + " " + description + " (*." + entry + ")");
+            filters.append(entry.remove(QLatin1Char('.')).toUpper() + QLatin1Char(' ') + description + QStringLiteral(" (*.") + entry + QLatin1Char(')'));
         }
     }
 
@@ -468,36 +448,45 @@ const QStringList KoFileDialog::getFilterStringListFromMime(const QStringList &m
             QStringList::ConstIterator jt;
             for (jt = patterns.constBegin(); jt != patterns.constEnd(); ++jt) {
                 if (d->swapExtensionOrder) {
-                    oneFilter.prepend(*jt + " ");
+                    oneFilter.prepend(*jt + QLatin1Char(' '));
                     if (withAllSupportedEntry) {
-                        ret[0].prepend(*jt + " ");
+                        ret[0].prepend(*jt + QLatin1Char(' '));
                     }
                 }
                 else {
-                    oneFilter.append(*jt + " ");
+                    oneFilter.append(*jt + QLatin1Char(' '));
                     if (withAllSupportedEntry) {
-                        ret[0].append(*jt + " ");
+                        ret[0].append(*jt + QLatin1Char(' '));
                     }
                 }
             }
-            oneFilter = mimeType.comment() + " (" + oneFilter + ")";
+            oneFilter = mimeType.comment() + QStringLiteral(" (") + oneFilter + QLatin1Char(')');
             ret << oneFilter;
             mimeSeen << mimeType.name();
         }
     }
 
     if (withAllSupportedEntry) {
-        ret[0] = i18n("All supported formats") + " (" + ret[0] + (")");
+        ret[0] = i18n("All supported formats") + QStringLiteral(" (") + ret[0] + QLatin1Char(')');
     }
     return ret;
 }
 
-QString KoFileDialog::getUsedDir(const QString &dialogName)
+QUrl KoFileDialog::directory()
 {
-    if (dialogName.isEmpty()) return "";
+    auto url = getUsedDir(d->dialogName);
+    if (!url.isValid()) {
+        url = QUrl::fromUserInput(d->defaultDirectory);
+    }
+    return url;
+}
 
-    KConfigGroup group =  KSharedConfig::openConfig()->group("File Dialogs");
-    QString dir = group.readEntry(dialogName);
+QUrl KoFileDialog::getUsedDir(const QString &dialogName)
+{
+    if (dialogName.isEmpty()) return QUrl();
+
+    KConfigGroup group =  KSharedConfig::openConfig()->group(QStringLiteral("File Dialogs"));
+    QUrl dir = QUrl::fromUserInput(group.readEntry(dialogName));
 
     return dir;
 }
@@ -505,13 +494,14 @@ QString KoFileDialog::getUsedDir(const QString &dialogName)
 void KoFileDialog::saveUsedDir(const QString &fileName,
                                const QString &dialogName)
 {
-
-    if (dialogName.isEmpty()) return;
-
-    QFileInfo fileInfo(fileName);
-    KConfigGroup group =  KSharedConfig::openConfig()->group("File Dialogs");
-    group.writeEntry(dialogName, fileInfo.absolutePath());
-
+    if (dialogName.isEmpty()) {
+        return;
+    }
+    const auto url = QUrl::fromUserInput(fileName);
+    if (url.isValid()) {
+        KConfigGroup group = KSharedConfig::openConfig()->group(QStringLiteral("File Dialogs"));
+        group.writeEntry(dialogName, url.adjusted(QUrl::RemoveFilename).toString(QUrl::FullyEncoded));
+    }
 }
 
 void KoFileDialog::setVisible(bool value)
