@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006
  * by Chris Schlaeger <cs@kde.org>
- * Copyright (c) 2011 Dag Andersen <danders@get2net.dk>
+ * SPDX-FileCopyrightText: 2011 Dag Andersen <dag.andersen@kdemail.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of version 2 of the GNU General Public License as
@@ -68,7 +68,7 @@ Project::Project() :
 //     currencyFormat("(", ")", ",", ".", 0),
     priority(500),
     minEffort(0.0),
-    resourceLimits(0),
+    resourceLimits(nullptr),
     rate(0.0),
     dailyWorkingHours(8.0),
     yearlyWorkingDays(260.714),
@@ -95,9 +95,10 @@ Project::Project() :
 //     reports(),
 //     interactiveReports(),
     sourceFiles(),
-    breakFlag(false)
+    breakFlag(false),
+    cancelSchedulingFlag(false)
 {
-    qDebug()<<"Project:"<<this;
+    //qDebug()<<"Project:"<<this;
     /* Pick some reasonable initial number since we don't know the
      * project time frame yet. */
     initUtility(20000);
@@ -108,13 +109,13 @@ Project::Project() :
 //     resourceAttributes.setAutoDelete(true);
 //     reports.setAutoDelete(true);
 
-    new Scenario(this, "plan", "Plan", 0);
+    new Scenario(this, "plan", "Plan", nullptr);
     scenarioList.createIndex(true);
     scenarioList.createIndex(false);
-    foreach(CoreAttributes *s, scenarioList) {
-        qDebug()<<"Project:"<<static_cast<CoreAttributes*>(s)<<static_cast<CoreAttributes*>(s)->getName()<<static_cast<CoreAttributes*>(s)->getSequenceNo();
-    }
-    setNow(time(0));
+//     for (CoreAttributes *s : std::as_const(scenarioList)) {
+//         qDebug()<<"Project:"<<static_cast<CoreAttributes*>(s)<<static_cast<CoreAttributes*>(s)->getName()<<static_cast<CoreAttributes*>(s)->getSequenceNo();
+//     }
+    setNow(time(nullptr));
 
     /* Initialize working hours with default values that match the Monday -
      * Friday 9 - 6 (with 1 hour lunch break) pattern used by many western
@@ -138,7 +139,7 @@ Project::Project() :
 
 Project::~Project()
 {
-    qDebug()<<"~Project:"<<this;
+    //qDebug()<<"~Project:"<<this<<">>>";
     taskList.deleteContents();
     resourceList.deleteContents();
     Resource::deleteStaticData();
@@ -160,7 +161,7 @@ Project::~Project()
     }
     exitUtility();
 
-    qDebug()<<"~Project:"<<this;
+    //qDebug()<<"~Project:"<<this<<"<<<";
 }
 
 // void
@@ -179,19 +180,19 @@ Project::~Project()
 void
 Project::setProgressInfo(const QString& i)
 {
-    emit updateProgressInfo(i);
+    Q_EMIT updateProgressInfo(i);
 }
 
 void
 Project::setProgressBar(int i, int of)
 {
-    emit updateProgressBar(i, of);
+    Q_EMIT updateProgressBar(i, of);
 }
 
 bool
 Project::setTimeZone(const QString& tz)
 {
-    if (!setTimezone(tz.toLocal8Bit()))
+    if (!setTimezone(tz.toLocal8Bit().constData()))
         return false;
 
     timeZone = tz;
@@ -242,7 +243,7 @@ Project::setWorkingHours(int day, const QList< Interval* >& l)
     // Create a deep copy of the interval list.
     workingHours[day] = new QList<Interval*>;
 //     workingHours[day]->setAutoDelete(true);
-    foreach(Interval *i, l) {
+    for (Interval *i : l) {
         workingHours[day]->append(new Interval(*i));
 
     }
@@ -352,7 +353,7 @@ Project::deleteShift(Shift* s)
 void
 Project::addResource(Resource* r)
 {
-    qDebug()<<"Project::addResource:"<<r<<resourceList;
+    //qDebug()<<"Project::addResource:"<<r<<resourceList;
     resourceList.append(r);
 }
 
@@ -425,7 +426,8 @@ Project::isWorkingTime(time_t wd) const
         return false;
 
     int dow = dayOfWeek(wd, false);
-    foreach (Interval *i, *getWorkingHours(dow)) {
+    const auto lst = *getWorkingHours(dow);
+    for (Interval *i : lst) {
         if (i->contains(secondsOfDay(wd)))
             return true;
     }
@@ -439,8 +441,8 @@ Project::isWorkingTime(const Interval& iv) const
         return false;
 
     int dow = dayOfWeek(iv.getStart(), false);
-    foreach (Interval *i, *(workingHours[dow]))
-    {
+    const auto lst = *(workingHours[dow]);
+    for (Interval *i : lst) {
         if (i->contains(Interval(secondsOfDay(iv.getStart()),
                                   secondsOfDay(iv.getEnd()))))
             return true;
@@ -489,11 +491,11 @@ Project::pass2(bool noDepCheck)
         TJMH.errorMessage(xi18nc("@info/plain", "The project does not contain any tasks."));
         return false;
     }
-    qDebug()<<"pass2 task info:";
-    foreach (CoreAttributes *a, taskList) {
-        Task *t = static_cast<Task*>(a);
-        qDebug()<<t->getName()<<t->getDuration(0)<<t->getPrecedes()<<t->getDepends();
-    }
+//     qDebug()<<"pass2 task info:";
+//     for (CoreAttributes *a : std::as_const(taskList)) {
+//         Task *t = static_cast<Task*>(a);
+//         qDebug()<<t->getName()<<t->getDuration(0)<<t->getPrecedes()<<t->getDepends();
+//     }
     QMap<QString, Task*> idHash;
 
     /* The optimum size for the localtime hash is twice the number of time
@@ -510,15 +512,15 @@ Project::pass2(bool noDepCheck)
     srand((int) start);
 
     // Create hash to map task IDs to pointers.
-    foreach (CoreAttributes *t, taskList)
+    for (CoreAttributes *t : std::as_const(taskList))
     {
         idHash.insert(static_cast<Task*>(t)->getId(), static_cast<Task*>(t));
     }
     // Create cross links from dependency lists.
-    foreach (CoreAttributes *t, taskList)
+    for (CoreAttributes *t : std::as_const(taskList))
         static_cast<Task*>(t)->xRef(idHash);
 
-    foreach (CoreAttributes *t, taskList)
+    for (CoreAttributes *t : std::as_const(taskList))
     {
         // Set dates according to implicit dependencies
         static_cast<Task*>(t)->implicitXRef();
@@ -531,7 +533,7 @@ Project::pass2(bool noDepCheck)
     }
 
     // Save a copy of all manually booked resources.
-    foreach (CoreAttributes *r, resourceList)
+    for (CoreAttributes *r : std::as_const(resourceList))
         static_cast<Resource*>(r)->saveSpecifiedBookings();
 
     /* Now we can copy the missing values from the plan scenario to the other
@@ -547,8 +549,8 @@ Project::pass2(bool noDepCheck)
     // Now check that all tasks have sufficient data to be scheduled.
     setProgressInfo(QString("Checking scheduling data..."));
     bool error = false;
-    foreach (CoreAttributes *s, scenarioList) {
-        foreach (CoreAttributes *t, taskList) {
+    for (CoreAttributes *s : std::as_const(scenarioList)) {
+        for (CoreAttributes *t : std::as_const(taskList)) {
             if (!static_cast<Task*>(t)->preScheduleOk(static_cast<Scenario*>(s)->getSequenceNo() - 1))
             {
                 error = true;
@@ -565,7 +567,7 @@ Project::pass2(bool noDepCheck)
             tjDebug("Searching for dependency loops ...");
         // Check all tasks for dependency loops.
         LDIList chkedTaskList;
-        foreach (CoreAttributes *t, taskList) {
+        for (CoreAttributes *t : std::as_const(taskList)) {
             if (static_cast<Task*>(t)->loopDetector(chkedTaskList))
                 return false;
         }
@@ -573,8 +575,8 @@ Project::pass2(bool noDepCheck)
         setProgressInfo(QString("Searching for underspecified tasks ..."));
         if (DEBUGPS(1))
             tjDebug("Searching for underspecified tasks ...");
-        foreach (CoreAttributes *s, scenarioList) {
-            foreach (CoreAttributes *t, taskList) {
+        for (CoreAttributes *s : std::as_const(scenarioList)) {
+            for (CoreAttributes *t : std::as_const(taskList)) {
                 if (!static_cast<Task*>(t)->checkDetermination(static_cast<Scenario*>(s)->getSequenceNo() - 1))
                     error = true;
             }
@@ -586,7 +588,7 @@ Project::pass2(bool noDepCheck)
     TJ::TaskList starts;
     TJ::TaskList ends;
     QStringList tl;
-    foreach (TJ::CoreAttributes *t, taskList) {
+    for (TJ::CoreAttributes *t : std::as_const(taskList)) {
         tl << t->getName();
         if (! static_cast<TJ::Task*>(t)->hasPrevious()) {
             starts << static_cast<TJ::Task*>(t);
@@ -598,7 +600,7 @@ Project::pass2(bool noDepCheck)
         }
     }
     tl.clear();
-    foreach (TJ::CoreAttributes *t, taskList) {
+    for (TJ::CoreAttributes *t : std::as_const(taskList)) {
         tl << t->getName();
         if (! static_cast<TJ::Task*>(t)->hasPrevious()) {
             starts << static_cast<TJ::Task*>(t);
@@ -613,7 +615,7 @@ Project::pass2(bool noDepCheck)
         qDebug()<<"Tasks:"<<tl;
         qDebug()<<"Depends/precedes: -------------------";
         tl.clear();
-        foreach (TJ::CoreAttributes *t, taskList) {
+        for (TJ::CoreAttributes *t : std::as_const(taskList)) {
             tl << t->getName() + (static_cast<TJ::Task*>(t)->getScheduling() == TJ::Task::ASAP ? " (ASAP)" : " (ALAP)") + " depends: ";
             for (QListIterator<TJ::TaskDependency*> it = static_cast<TJ::Task*>(t)->getDependsIterator(); it.hasNext();) {
                 const TJ::Task *a = it.next()->getTaskRef();
@@ -631,7 +633,7 @@ Project::pass2(bool noDepCheck)
         }
         qDebug()<<"Followers/previous: -------------------";
         tl.clear();
-        foreach (TJ::CoreAttributes *t, taskList) {
+        for (TJ::CoreAttributes *t : std::as_const(taskList)) {
             tl << t->getName() + (static_cast<TJ::Task*>(t)->getScheduling() == TJ::Task::ASAP ? " (ASAP)" : " (ALAP)") + " followers: ";
             for (TJ::TaskListIterator it = static_cast<TJ::Task*>(t)->getFollowersIterator(); it.hasNext();) {
                 const TJ::Task *a = static_cast<TJ::Task*>(it.next());
@@ -649,16 +651,18 @@ Project::pass2(bool noDepCheck)
         }
         qDebug()<<"Successors/predecessors: -------------------";
         tl.clear();
-        foreach (TJ::CoreAttributes *c, taskList) {
+        for (TJ::CoreAttributes *c : std::as_const(taskList)) {
             tl << c->getName() + (static_cast<TJ::Task*>(c)->getScheduling() == TJ::Task::ASAP ? " (ASAP)" : " (ALAP)") + " successors: ";
-            foreach (TJ::CoreAttributes *t, static_cast<TJ::Task*>(c)->getSuccessors()) {
+            const auto succs = static_cast<TJ::Task*>(c)->getSuccessors();
+            for (TJ::CoreAttributes *t : succs) {
                 TJ::Task *a = static_cast<TJ::Task*>(t);
                 QString s = a->getName() + (a->getScheduling() == TJ::Task::ASAP ? " (ASAP)" : " (ALAP)");
                 tl << s;
             }
             qDebug()<<tl; tl.clear();
             tl << c->getName() + (static_cast<TJ::Task*>(c)->getScheduling() == TJ::Task::ASAP ? " (ASAP)" : " (ALAP)") + " predecessors: ";
-            foreach (TJ::CoreAttributes *t, static_cast<TJ::Task*>(c)->getPredecessors()) {
+            const auto preds = static_cast<TJ::Task*>(c)->getPredecessors();
+            for (TJ::CoreAttributes *t : preds) {
                 TJ::Task *a = static_cast<TJ::Task*>(t);
                 QString s = a->getName() + (a->getScheduling() == TJ::Task::ASAP ? " (ASAP)" : " (ALAP)");
                 tl << s;
@@ -688,7 +692,7 @@ Project::scheduleScenario(Scenario* sc)
     }
     finishScenario(scIdx);
 
-    foreach (CoreAttributes *r, resourceList)
+    for (CoreAttributes *r : std::as_const(resourceList))
     {
         if (!static_cast<Resource*>(r)->bookingsOk(scIdx))
             break;
@@ -700,7 +704,7 @@ Project::scheduleScenario(Scenario* sc)
 void
 Project::completeBuffersAndIndices()
 {
-    foreach (CoreAttributes *t, taskList) {
+    for (CoreAttributes *t : std::as_const(taskList)) {
         static_cast<Task*>(t)->computeBuffers();
     }
     /* Create indices for all lists according to their default sorting
@@ -715,7 +719,7 @@ bool
 Project::scheduleAllScenarios()
 {
     bool schedulingOk = true;
-    foreach (CoreAttributes *s, scenarioList) {
+    for (CoreAttributes *s : std::as_const(scenarioList)) {
         if (static_cast<Scenario*>(s)->getEnabled())
         {
             if (DEBUGPS(1))
@@ -736,10 +740,11 @@ Project::scheduleAllScenarios()
 void
 Project::overlayScenario(int base, int sc)
 {
-    foreach (CoreAttributes *t, taskList) {
+    for (CoreAttributes *t : std::as_const(taskList)) {
         static_cast<Task*>(t)->overlayScenario(base, sc);
     }
-    foreach (CoreAttributes *s, scenarioList[sc]->getSubList()) {
+    const auto lst = scenarioList[sc]->getSubList();
+    for (CoreAttributes *s : lst) {
         overlayScenario(sc, static_cast<Scenario*>(s)->getSequenceNo() - 1);
     }
 }
@@ -747,39 +752,39 @@ Project::overlayScenario(int base, int sc)
 void
 Project::prepareScenario(int sc)
 {
-    foreach (CoreAttributes *r, resourceList) {
+    for (CoreAttributes *r : std::as_const(resourceList)) {
         static_cast<Resource*>(r)->prepareScenario(sc);
     }
-    foreach (CoreAttributes *t, taskList) {
+    for (CoreAttributes *t : std::as_const(taskList)) {
         static_cast<Task*>(t)->prepareScenario(sc);
     }
 
     /* First we compute the criticalness of the individual task without their
      * dependency context. */
-    foreach (CoreAttributes *t, taskList) {
+    for (CoreAttributes *t : std::as_const(taskList)) {
         static_cast<Task*>(t)->computeCriticalness(sc);
     }
     /* Then we compute the path criticalness that represents the criticalness
      * of a task taking their dependency context into account. */
-    foreach (CoreAttributes *t, taskList) {
+    for (CoreAttributes *t : std::as_const(taskList)) {
         static_cast<Task*>(t)->computePathCriticalness(sc);
     }
 
-    foreach (CoreAttributes *t, taskList) {
+    for (CoreAttributes *t : std::as_const(taskList)) {
         static_cast<Task*>(t)->propagateInitialValues(sc);
     }
 
     if (DEBUGTS(4))
     {
         tjDebug("Allocation probabilities for the resources:");
-        foreach (CoreAttributes *r, resourceList) {
+        for (CoreAttributes *r : std::as_const(resourceList)) {
             qDebug()<<QString("Resource %1: %2%")
                    .arg(static_cast<Resource*>(r)->getName())
                    .arg(static_cast<Resource*>(r)->getAllocationProbability(sc));
         }
         tjDebug("Criticalnesses of the tasks with respect to resource "
                "availability:");
-        foreach (CoreAttributes *t, taskList) {
+        for (CoreAttributes *t : std::as_const(taskList)) {
             qDebug()<<QString("Task %1: %2 %3").arg(static_cast<Task*>(t)->getName())
                    .arg(static_cast<Task*>(t)->getCriticalness(sc))
                    .arg(static_cast<Task*>(t)->getPathCriticalness(sc));
@@ -787,19 +792,25 @@ Project::prepareScenario(int sc)
     }
 }
 
+void
+Project::cancelScheduling()
+{
+    cancelSchedulingFlag = true;
+}
+
 void
 Project::finishScenario(int sc)
 {
-    foreach (CoreAttributes *r, resourceList) {
+    for (CoreAttributes *r : std::as_const(resourceList)) {
         static_cast<Resource*>(r)->finishScenario(sc);
     }
-    foreach (CoreAttributes *t, taskList) {
+    for (CoreAttributes *t : std::as_const(taskList)) {
         static_cast<Task*>(t)->finishScenario(sc);
     }
 #if 0
     /* We need to have finished the scenario for all tasks before we can
      * calculate the completion degree. */
-    foreach (CoreAttributes *t, taskList) {
+    for (CoreAttributes *t : std::as_const(taskList)) {
         static_cast<Task*>(t)->calcCompletionDegree(sc);
     }
 #endif
@@ -811,11 +822,11 @@ Project::finishScenario(int sc)
         /* The critical path detector needs to know the end of the last task.
          * So we have to find this out first. */
         time_t maxEnd = 0;
-        foreach (CoreAttributes *t, taskList) {
+        for (CoreAttributes *t : std::as_const(taskList)) {
             if (maxEnd < static_cast<Task*>(t)->getEnd(sc))
                 maxEnd = static_cast<Task*>(t)->getEnd(sc);
         }
-        foreach (CoreAttributes *t, taskList) {
+        for (CoreAttributes *t : std::as_const(taskList)) {
             static_cast<Task*>(t)->checkAndMarkCriticalPath
                 (sc, getScenario(sc)->getMinSlackRate(), maxEnd);
         }
@@ -825,17 +836,17 @@ Project::finishScenario(int sc)
 TaskList Project::tasksReadyToBeScheduled(int sc, const TaskList& allLeafTasks)
 {
     TaskList workItems;
-    foreach (CoreAttributes *t, allLeafTasks) {
+    for (CoreAttributes *t : std::as_const(allLeafTasks)) {
         if (static_cast<Task*>(t)->isReadyForScheduling())
             workItems.append(static_cast<Task*>(t));
     }
     if (workItems.isEmpty()) {
-        foreach (CoreAttributes *t, allLeafTasks) {
+        for (CoreAttributes *t : std::as_const(allLeafTasks)) {
             if (!static_cast<Task*>(t)->isSchedulingDone() && !static_cast<Task*>(t)->isReadyForScheduling()) {
                 TJMH.debugMessage("Not ready to be scheduled", t);
             }
         }
-        foreach (CoreAttributes *c, allLeafTasks) {
+        for (CoreAttributes *c : std::as_const(allLeafTasks)) {
             Task *t = static_cast<Task*>(c);
             if (!t->isSchedulingDone() /*&& !t->isRunaway()*/) {
                 if (t->getScheduling() == Task::ASAP) {
@@ -862,7 +873,7 @@ TaskList Project::tasksReadyToBeScheduled(int sc, const TaskList& allLeafTasks)
             }
             if (workItems.isEmpty()) {
                 TaskList lst;
-                foreach (CoreAttributes *c, allLeafTasks) {
+                for (CoreAttributes *c : std::as_const(allLeafTasks)) {
                     Task *t = static_cast<Task*>(c);
                     if (!t->isSchedulingDone()) {
                         lst << t;
@@ -880,27 +891,27 @@ TaskList Project::tasksReadyToBeScheduled(int sc, const TaskList& allLeafTasks)
         }
     }
 /*    if (workItems.isEmpty() && getTask("TJ::StartJob")->getScheduling() == Task::ASAP) {
-        foreach (CoreAttributes *c, allLeafTasks) {
+        for (CoreAttributes *c : std::as_const(allLeafTasks)) {
         }
     }                                                                                                                                                                                                                                                                                                                                                                                               */
     if (workItems.isEmpty() && getTask("TJ::StartJob")->getScheduling() == Task::ALAP) {
         qDebug()<<"tasksReadyToSchedule:"<<"backward, try really hard";
-        foreach (CoreAttributes *c, allLeafTasks) {
+        for (CoreAttributes *c : std::as_const(allLeafTasks)) {
             Task *task = static_cast<Task*>(c);
             if (!task->isSchedulingDone()) {
                 continue;
             }
             qDebug()<<"tasksReadyToSchedule:"<<"scheduled task:"<<task<<time2ISO(task->start)<<time2ISO(task->end);
-            Task *predecessor = 0;
+            Task *predecessor = nullptr;
             long gapLength = 0;
             long gapDuration = 0;
-            foreach (CoreAttributes *c, task->previous) {
+            for (CoreAttributes *c : std::as_const(task->previous)) {
                 Task *t = static_cast<Task*>(c);
                 if (t->isSchedulingDone()) {
                     continue;
                 }
                 // get the dependency/longest gap
-                foreach (TaskDependency *d, t->precedes) {
+                for (TaskDependency *d : std::as_const(t->precedes)) {
                     if (d->getTaskRef() == task) {
                         predecessor = t;
                         gapLength = qMax(gapLength, d->getGapLength(sc));
@@ -908,7 +919,7 @@ TaskList Project::tasksReadyToBeScheduled(int sc, const TaskList& allLeafTasks)
                     }
                 }
             }
-            if (predecessor == 0) {
+            if (predecessor == nullptr) {
                 continue;
             }
             time_t potentialDate = task->start - 1;
@@ -942,7 +953,7 @@ Project::schedule(int sc)
     // are scheduled automatically when all their children are scheduled. So
     // we create a task list that only contains leaf tasks.
     TaskList allLeafTasks;
-    foreach (CoreAttributes *t, taskList) {
+    for (CoreAttributes *t : std::as_const(taskList)) {
         if (!static_cast<Task*>(t)->hasSubs()) {
             allLeafTasks.append(static_cast<Task*>(t));
 //             TJMH.debugMessage("Leaf task", t);
@@ -955,7 +966,7 @@ Project::schedule(int sc)
     allLeafTasks.sort();
     maxProgress = allLeafTasks.count();
     int sortedTasks = 0;
-    foreach (CoreAttributes *t, allLeafTasks) {
+    for (CoreAttributes *t : std::as_const(allLeafTasks)) {
         if (static_cast<Task*>(t)->isSchedulingDone())
             sortedTasks++;
     }
@@ -982,13 +993,21 @@ Project::schedule(int sc)
         double pathCriticalness = 0.0;
         Task::SchedulingInfo schedulingInfo = Task::ASAP;
 
+        // helpers to avoid updating workItems list inside loop
+        bool updateList = false;
+        TaskList temp;
+
         /* The task list is sorted by priority. The priority decreases towards
          * the end of the list. We iterate through the list and look for a
          * task that can be scheduled. It the determines the time slot that
          * will be scheduled during this run for all subsequent tasks as well.
          */
-        foreach (CoreAttributes *t, workItems) {
+        for (CoreAttributes *t : std::as_const(workItems)) {
+            if (cancelSchedulingFlag) {
+                break;
+            }
 //            TJMH.debugMessage(QString("'%1' schedule for slot: %2, (%3 -%4)").arg(static_cast<Task*>(t)->getName()).arg(time2ISO(slot)).arg(time2ISO(start)).arg(time2ISO(end)));
+
             if (slot == 0)
             {
                 /* No time slot has been set yet. Check if this task can be
@@ -1015,9 +1034,9 @@ Project::schedule(int sc)
                 {
                     if (!static_cast<Task*>(t)->isRunaway()) {
                         if (slot < start) {
-                            static_cast<Task*>(t)->warningMessage(i18n("Attempt to schedule task to start before project target time"));
+                            static_cast<Task*>(t)->warningMessage(i18n("Attempt to schedule task at %1 to start before project target start time: %2", formatTime(slot), formatTime(start)));
                         } else {
-                            static_cast<Task*>(t)->warningMessage(i18n("Attempt to schedule task to end after project target time"));
+                            static_cast<Task*>(t)->warningMessage(i18n("Attempt to schedule task at %1 to end after project target end time: %2", formatTime(slot), formatTime(end)));
                         }
                         static_cast<Task*>(t)->setRunaway();
                     }
@@ -1056,10 +1075,11 @@ Project::schedule(int sc)
             // Schedule this task for the current time slot.
             if (static_cast<Task*>(t)->schedule(sc, slot, scheduleGranularity))
             {
-                workItems = tasksReadyToBeScheduled(sc, allLeafTasks);
+                temp = tasksReadyToBeScheduled(sc, allLeafTasks);
+                updateList = true;
                 int oldSortedTasks = sortedTasks;
                 sortedTasks = 0;
-                foreach (CoreAttributes *t, allLeafTasks) {
+                for (CoreAttributes *t : std::as_const(allLeafTasks)) {
                     if (static_cast<Task*>(t)->isSchedulingDone())
                         sortedTasks++;
                 }
@@ -1072,8 +1092,18 @@ Project::schedule(int sc)
                 }
             }
         }
-    } while (!done && !breakFlag);
+        if (updateList) {
+            workItems = temp;
+        }
+    } while (!done && !breakFlag && !cancelSchedulingFlag);
 
+    if (cancelSchedulingFlag)
+    {
+        setProgressInfo("");
+        setProgressBar(100, 0);
+        TJMH.infoMessage(xi18nc("@info/plain", "Scheduling aborted on user request"));
+        return false;
+    }
     if (breakFlag)
     {
         setProgressInfo("");
@@ -1082,7 +1112,7 @@ Project::schedule(int sc)
         return false;
     }
 //    if (runAwayFound) {
-//        foreach (CoreAttributes *t, taskList) {
+//        for (CoreAttributes *t : std::as_const(taskList)) {
 //            if (static_cast<Task*>(t)->isRunaway()) {
 //                if (static_cast<Task*>(t)->getScheduling() == Task::ASAP) {
 //                    TJMH.errorMessage(xi18nc("@info/plain", "Cannot meet the projects target finish time. Try using a later project end date.", t->getName()), t);
@@ -1114,10 +1144,10 @@ bool
 Project::checkSchedule(int sc) const
 {
     int oldErrors = TJMH.getErrors();
-    foreach (CoreAttributes *t, taskList) {
+    for (CoreAttributes *t : std::as_const(taskList)) {
         /* Only check top-level tasks, since they recursively check their sub
          * tasks. */
-        if (static_cast<Task*>(t)->getParent() == 0)
+        if (static_cast<Task*>(t)->getParent() == nullptr)
             static_cast<Task*>(t)->scheduleOk(sc);
         if (maxErrors > 0 && TJMH.getErrors() >= maxErrors)
         {
