@@ -1,7 +1,7 @@
 /*
  * ShiftSelection.cpp - TaskJuggler
  *
- * Copyright (c) 2001, 2002, 2003, 2004 by Chris Schlaeger <cs@kde.org>
+ * SPDX-FileCopyrightText: 2001, 2002, 2003, 2004 Chris Schlaeger <cs@kde.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of version 2 of the GNU General Public License as
@@ -31,3 +31,14 @@ ShiftSelection::isVacationDay(time_t day) const
 
 } // namespace TJ
 
+QDebug operator<<(QDebug dbg, const TJ::ShiftSelection &s)
+{
+    return dbg << &s;
+}
+QDebug operator<<(QDebug dbg, const TJ::ShiftSelection *s)
+{
+    dbg << "ShiftSelection[";
+    if (s) dbg << s->getPeriod() << s->getShift();
+    else dbg << (void*)s;
+    return dbg << ']';
+}
