@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006
  * Chris Schlaeger <cs@kde.org>
- * Copyright (c) 2011 by Dag Andersen <danders@get2net.dk>
+ * SPDX-FileCopyrightText: 2011 Dag Andersen <dag.andersen@kdemail.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of version 2 of the GNU General Public License as
@@ -164,7 +164,11 @@ public:
     void setSpecifiedStart(int sc, time_t s)
     {
         scenarios[sc].specifiedStart = s;
-        qDebug()<<"Task::setSpecifiedStart:"<<id<<":"<<sc<<s<<scenarios[sc].specifiedStart;
+        //qDebug()<<"Task::setSpecifiedStart:"<<id<<":"<<sc<<s<<scenarios[sc].specifiedStart;
+    }
+    time_t getSpecifiedStart(int sc) const
+    {
+        return scenarios[sc].specifiedStart;
     }
     void setStart(int sc, time_t s) { scenarios[sc].start = s; }
     time_t getStart(int sc) const { return scenarios[sc].start; }
@@ -275,12 +279,12 @@ public:
     double getCompletedLoad(int sc) const;
     double getRemainingLoad(int sc) const;
 
-    double getLoad(int sc, const Interval& period, const Resource* resource = 0)
+    double getLoad(int sc, const Interval& period, const Resource* resource = nullptr)
         const;
     long getAllocatedTime(int sc, const Interval& period,
-                          const Resource* resource = 0) const;
+                          const Resource* resource = nullptr) const;
     double getAllocatedTimeLoad(int sc, const Interval& period,
-                                const Resource* resource = 0) const;
+                                const Resource* resource = nullptr) const;
 
     void addBookedResource(int sc, Resource* r)
     {
@@ -401,8 +405,8 @@ private:
                        bool fromOutside) const;
     bool checkPathForLoops(LDIList& list, bool atEnd) const;
     bool scheduleContainer(int sc);
-    Task* subFirst() { return 0/*(Task*) sub->first()*/; }
-    Task* subNext() { return 0/*(Task*) sub->next()*/; }
+    Task* subFirst() { return nullptr/*(Task*) sub->first()*/; }
+    Task* subNext() { return nullptr/*(Task*) sub->next()*/; }
     /// Returns the availability of @p resource and its required resources (if any)
     int isAvailable(Allocation *allocation, Resource *resource, time_t slot) const;
     /// Book resource @p r if it (and its required resources) is available
