@@ -1,7 +1,7 @@
 /*
  * TaskList.cpp - TaskJuggler
  *
- * Copyright (c) 2001, 2002, 2003, 2004 by Chris Schlaeger <cs@kde.org>
+ * SPDX-FileCopyrightText: 2001, 2002, 2003, 2004 Chris Schlaeger <cs@kde.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of version 2 of the GNU General Public License as
@@ -19,11 +19,11 @@ namespace TJ
 Task*
 TaskList::getTask(const QString& id) const
 {
-    for (TaskListIterator tli(*this); *tli != 0; ++tli)
+    for (TaskListIterator tli(*this); *tli != nullptr; ++tli)
         if ((*tli)->getId() == id)
             return *tli;
 
-    return 0;
+    return nullptr;
 }
 
 bool
