@@ -1,26 +1,14 @@
 /* This file is part of the KDE project
-  Copyright (C) 2007 - 2009, 2012 Dag Andersen <danders@get2net.dk>
+  SPDX-FileCopyrightText: 2007-2009, 2012 Dag Andersen <dag.andersen@kdemail.net>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-* Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 // clazy:excludeall=qstring-arg
 #include "taskworkpackageview.h"
 #include "taskworkpackagemodel.h"
 #include "workpackage.h"
+#include "view.h"
 
 #include "part.h"
 #include "kptglobal.h"
@@ -51,8 +39,6 @@
 
 #include "debugarea.h"
 
-using namespace KPlato;
-
 namespace KPlatoWork
 {
 
@@ -124,43 +110,44 @@ TaskWorkPackageModel *TaskWorkPackageTreeView::itemModel() const
     return static_cast<TaskWorkPackageModel*>(static_cast<QSortFilterProxyModel*>(model())->sourceModel());
 }
 
-Project *TaskWorkPackageTreeView::project() const
+KPlato::Project *TaskWorkPackageTreeView::project() const
 {
     return itemModel()->project();
 }
 
-Document *TaskWorkPackageTreeView::currentDocument() const
+KPlato::Document *TaskWorkPackageTreeView::currentDocument() const
 {
     QSortFilterProxyModel *sf = qobject_cast<QSortFilterProxyModel*>(model());
     Q_ASSERT(sf);
-    if (sf == 0) {
-        return 0;
+    if (sf == nullptr) {
+        return nullptr;
     }
     return itemModel()->documentForIndex(sf->mapToSource(selectionModel()->currentIndex()));
 }
 
-Node *TaskWorkPackageTreeView::currentNode() const
+KPlato::Node *TaskWorkPackageTreeView::currentNode() const
 {
     QSortFilterProxyModel *sf = qobject_cast<QSortFilterProxyModel*>(model());
     Q_ASSERT(sf);
-    if (sf == 0) {
-        return 0;
+    if (sf == nullptr) {
+        return nullptr;
     }
     return itemModel()->nodeForIndex(sf->mapToSource(selectionModel()->currentIndex()));
 }
 
-QList<Node*> TaskWorkPackageTreeView::selectedNodes() const
+QList<KPlato::Node*> TaskWorkPackageTreeView::selectedNodes() const
 {
-    QList<Node*> lst;
+    QList<KPlato::Node*> lst;
     QSortFilterProxyModel *sf = qobject_cast<QSortFilterProxyModel*>(model());
     Q_ASSERT(sf);
-    if (sf == 0) {
+    if (sf == nullptr) {
         return lst;
     }
-    foreach(const QModelIndex &idx, selectionModel()->selectedIndexes()) {
+    const QList<QModelIndex> indexes = selectionModel()->selectedIndexes();
+    for(const QModelIndex &idx : indexes) {
         QModelIndex i = sf->mapToSource(idx);
         Q_ASSERT(i.isValid() && i.model() == itemModel());
-        Node *n = itemModel()->nodeForIndex(i);
+        KPlato::Node *n = itemModel()->nodeForIndex(i);
         if (n && ! lst.contains(n)) {
             lst << n;
         }
@@ -168,7 +155,7 @@ QList<Node*> TaskWorkPackageTreeView::selectedNodes() const
     return lst;
 }
 
-void TaskWorkPackageTreeView::setProject(Project *project)
+void TaskWorkPackageTreeView::setProject(KPlato::Project *project)
 {
     itemModel()->setProject(project);
 }
@@ -178,8 +165,9 @@ void TaskWorkPackageTreeView::slotActivated(const QModelIndex &index)
     debugPlanWork<<index.column();
 }
 
-void TaskWorkPackageTreeView::dragMoveEvent(QDragMoveEvent */*event*/)
+void TaskWorkPackageTreeView::dragMoveEvent(QDragMoveEvent *event)
 {
+    Q_UNUSED(event)
 /*    if (dragDropMode() == InternalMove
         && (event->source() != this || !(event->possibleActions() & Qt::MoveAction)))
         return;
@@ -195,7 +183,7 @@ void TaskWorkPackageTreeView::dragMoveEvent(QDragMoveEvent */*event*/)
         event->accept();
         return; // always ok to drop on main project
     }
-    Node *dn = model()->node(index);
+    KPlato::Node *dn = model()->node(index);
     if (dn == 0) {
         errorPlanWork<<"no node to drop on!"
         return; // hmmm
@@ -231,19 +219,19 @@ void AbstractView::updateReadWrite(bool /*rw*/)
 {
 }
 
-QList<Node*> AbstractView::selectedNodes() const
+QList<KPlato::Node*> AbstractView::selectedNodes() const
 {
-    return QList<Node*>();
+    return QList<KPlato::Node*>();
 }
 
-Node *AbstractView::currentNode() const
+KPlato::Node *AbstractView::currentNode() const
 {
-    return 0;
+    return nullptr;
 }
 
-Document *AbstractView::currentDocument() const
+KPlato::Document *AbstractView::currentDocument() const
 {
-    return 0;
+    return nullptr;
 }
 
 
@@ -261,19 +249,19 @@ void AbstractView::slotContextMenuRequested(const QModelIndex &/*index*/, const
     return slotHeaderContextMenuRequested(pos);
 }
 
-void AbstractView::slotContextMenuRequested(Node *node, const QPoint& pos)
+void AbstractView::slotContextMenuRequested(KPlato::Node *node, const QPoint& pos)
 {
     debugPlanWork<<node->name()<<" :"<<pos;
     QString name;
     switch (node->type()) {
-        case Node::Type_Task:
-            name = "taskstatus_popup";
+        case KPlato::Node::Type_Task:
+            name = QStringLiteral("taskstatus_popup");
             break;
-        case Node::Type_Milestone:
-            name = "taskview_milestone_popup";
+        case KPlato::Node::Type_Milestone:
+            name = QStringLiteral("taskview_milestone_popup");
             break;
-        case Node::Type_Summarytask:
-            name = "taskview_summary_popup";
+        case KPlato::Node::Type_Summarytask:
+            name = QStringLiteral("taskview_summary_popup");
             break;
         default:
             break;
@@ -283,19 +271,19 @@ void AbstractView::slotContextMenuRequested(Node *node, const QPoint& pos)
         slotHeaderContextMenuRequested(pos);
         return;
     }
-    emit requestPopupMenu(name, pos);
+    Q_EMIT requestPopupMenu(name, pos);
 }
 
-void AbstractView::slotContextMenuRequested(Document *doc, const QPoint& pos)
+void AbstractView::slotContextMenuRequested(KPlato::Document *doc, const QPoint& pos)
 {
     debugPlanWork<<doc->url()<<" :"<<pos;
     QString name;
     switch (doc->type()) {
-        case Document::Type_Product:
-            name = "editdocument_popup";
+        case KPlato::Document::Type_Product:
+            name = QStringLiteral("editdocument_popup");
             break;
         default:
-            name = "viewdocument_popup";
+            name = QStringLiteral("viewdocument_popup");
             break;
     }
     debugPlanWork<<name;
@@ -303,7 +291,7 @@ void AbstractView::slotContextMenuRequested(Document *doc, const QPoint& pos)
         slotHeaderContextMenuRequested(pos);
         return;
     }
-    emit requestPopupMenu(name, pos);
+    Q_EMIT requestPopupMenu(name, pos);
 }
 
 void AbstractView::sectionsMoved()
@@ -321,7 +309,7 @@ void AbstractView::saveContext()
 
 KoPrintJob *AbstractView::createPrintJob()
 {
-    return 0;
+    return nullptr;
 }
 
 //-----------------------------------
@@ -330,14 +318,14 @@ TaskWorkPackageView::TaskWorkPackageView(Part *part, QWidget *parent)
 {
     debugPlanWork<<"-------------------- creating TaskWorkPackageView -------------------";
     QVBoxLayout * l = new QVBoxLayout(this);
-    l->setMargin(0);
+    l->setContentsMargins(0, 0, 0, 0);
     m_view = new TaskWorkPackageTreeView(part, this);
     l->addWidget(m_view);
     setupGui();
 
     connect(itemModel(), &KPlato::ItemModelBase::executeCommand, part, &Part::addCommand);
 
-    connect(m_view, SIGNAL(contextMenuRequested(QModelIndex,QPoint,QModelIndexList)), SLOT(slotContextMenuRequested(QModelIndex,QPoint)));
+    connect(m_view, &KPlato::DoubleTreeViewBase::contextMenuRequested, this, QOverload<const QModelIndex&, const QPoint&>::of(&TaskWorkPackageView::slotContextMenuRequested));
 
     connect(m_view, &KPlato::DoubleTreeViewBase::headerContextMenuRequested, this, &TaskWorkPackageView::slotHeaderContextMenuRequested);
 
@@ -360,20 +348,20 @@ void TaskWorkPackageView::updateReadWrite(bool rw)
 
 void TaskWorkPackageView::slotSelectionChanged(const QModelIndexList &/*lst*/)
 {
-    emit selectionChanged();
+    Q_EMIT selectionChanged();
 }
 
-QList<Node*> TaskWorkPackageView::selectedNodes() const
+QList<KPlato::Node*> TaskWorkPackageView::selectedNodes() const
 {
     return m_view->selectedNodes();
 }
 
-Node *TaskWorkPackageView::currentNode() const
+KPlato::Node *TaskWorkPackageView::currentNode() const
 {
     return m_view->currentNode();
 }
 
-Document *TaskWorkPackageView::currentDocument() const
+KPlato::Document *TaskWorkPackageView::currentDocument() const
 {
     return m_view->currentDocument();
 }
@@ -387,7 +375,7 @@ void TaskWorkPackageView::slotContextMenuRequested(const QModelIndex &index, con
     }
     QSortFilterProxyModel *sf = qobject_cast<QSortFilterProxyModel*>(m_view->model());
     Q_ASSERT(sf);
-    if (sf == 0) {
+    if (sf == nullptr) {
         return;
     }
     QModelIndex idx = sf->mapToSource(index);
@@ -396,11 +384,11 @@ void TaskWorkPackageView::slotContextMenuRequested(const QModelIndex &index, con
         return;
     }
 
-    Node *node = itemModel()->nodeForIndex(idx);
+    KPlato::Node *node = itemModel()->nodeForIndex(idx);
     if (node) {
         return slotContextMenuRequested(node, pos);
     }
-    Document *doc = itemModel()->documentForIndex(idx);
+    KPlato::Document *doc = itemModel()->documentForIndex(idx);
     if (doc) {
         return slotContextMenuRequested(doc, pos);
     }
@@ -428,7 +416,7 @@ void TaskWorkPackageView::slotSplitView()
 void TaskWorkPackageView::slotOptions()
 {
     debugPlanWork;
-    QPointer<SplitItemViewSettupDialog> dlg = new SplitItemViewSettupDialog(0, m_view, this);
+    QPointer<KPlato::SplitItemViewSettupDialog> dlg = new KPlato::SplitItemViewSettupDialog(nullptr, m_view, this);
     dlg->exec();
     delete dlg;
 }
@@ -448,12 +436,12 @@ bool TaskWorkPackageView::loadContext()
 
 void TaskWorkPackageView::saveContext()
 {
-    QDomDocument doc ("TaskWorkPackageView");
-    QDomElement context = doc.createElement("TaskWorkPackageViewSettings");
+    QDomDocument doc(QStringLiteral("TaskWorkPackageView"));
+    QDomElement context = doc.createElement(QStringLiteral("TaskWorkPackageViewSettings"));
     doc.appendChild(context);
     m_view->saveContext(itemModel()->columnMap(), context);
     PlanWorkSettings::self()->setTaskWorkPackageView(doc.toString());
-    debugPlanWork<<"saved context:"<<endl<<doc.toString();
+    debugPlanWork<<"saved context:"<<'\n'<<doc.toString();
 }
 
 //-------------------------------------------
@@ -474,7 +462,8 @@ GanttItemDelegate::GanttItemDelegate(QObject *parent)
     showSchedulingError = false;
     showStatus = true;
 
-    QLinearGradient b(0., 0., 0., QApplication::fontMetrics().height());
+    QFontMetricsF metrics(QApplication::font());
+    QLinearGradient b(0., 0., 0., metrics.height());
     b.setColorAt(0., Qt::green);
     b.setColorAt(1., Qt::darkGreen);
     m_brushes.insert(Brush_Normal, QBrush(b));
@@ -518,7 +507,7 @@ void GanttItemDelegate::paintGanttItem(QPainter* painter, const KGantt::StyleOpt
 
     QRectF textRect = itemRect;
     if (! txt.isEmpty()) {
-        int tw = opt.fontMetrics.width(txt) + static_cast<int>(itemRect.height()/1.5);
+        int tw = opt.fontMetrics.horizontalAdvance(txt) + static_cast<int>(itemRect.height()/1.5);
         switch(opt.displayPosition) {
             case KGantt::StyleOptionGanttItem::Left:
                 textRect.adjust(-tw, 0.0, 0.0, 0.0);
@@ -550,37 +539,37 @@ void GanttItemDelegate::paintGanttItem(QPainter* painter, const KGantt::StyleOpt
             bool normal = true;
             if (showStatus) {
                 int state = data(idx, TaskWorkPackageModel::NodeStatus, Qt::EditRole).toInt();
-                if (state & Node::State_NotScheduled) {
+                if (state & KPlato::Node::State_NotScheduled) {
                     painter->setBrush(m_brushes[ Brush_NotScheduled ]);
                     normal = false;
-                } else if (state & Node::State_Finished) {
+                } else if (state & KPlato::Node::State_Finished) {
                     painter->setBrush(m_brushes[ Brush_Finished ]);
                     normal = false;
-                } else if (state & Node::State_Started) {
-                    if (state & Node::State_Late) {
+                } else if (state & KPlato::Node::State_Started) {
+                    if (state & KPlato::Node::State_Late) {
                         painter->setBrush(m_brushes[ Brush_Late ]);
                         normal = false;
                     }
                 } else  {
                     // scheduled, not started, not finished
-                    if (state & Node::State_Late) {
+                    if (state & KPlato::Node::State_Late) {
                         painter->setBrush(m_brushes[ Brush_Late ]);
                         normal = false;
-                    } else if (state & Node::State_NotReadyToStart) {
+                    } else if (state & KPlato::Node::State_NotReadyToStart) {
                         painter->setBrush(m_brushes[ Brush_NotReadyToStart ]);
                         normal = false;
-                    } else if (state & Node::State_ReadyToStart) {
+                    } else if (state & KPlato::Node::State_ReadyToStart) {
                         painter->setBrush(m_brushes[ Brush_ReadyToStart ]);
                         normal = false;
                     }
                 }
             } else if (showCriticalTasks) {
-                bool critical = data(idx, NodeModel::NodeCritical, Qt::DisplayRole).toBool();
+                bool critical = data(idx, KPlato::NodeModel::NodeCritical, Qt::DisplayRole).toBool();
                 if (! critical && showCriticalPath) {
-                    critical = data(idx, NodeModel::NodeCriticalPath, Qt::DisplayRole).toBool();
+                    critical = data(idx, KPlato::NodeModel::NodeCriticalPath, Qt::DisplayRole).toBool();
                 }
                 if (critical) {
-                    QVariant br = data(idx, NodeModel::NodeCritical, Role::Foreground);
+                    QVariant br = data(idx, KPlato::NodeModel::NodeCritical, KPlato::Role::Foreground);
                     painter->setBrush(br.isValid() ? br.value<QBrush>() : m_criticalBrush);
                     normal = false;
                 }
@@ -671,9 +660,9 @@ QString GanttItemDelegate::toolTip(const QModelIndex &index) const
     }
     // Planned
     KGantt::StyleOptionGanttItem opt;
-    int typ = data(idx, NodeModel::NodeType, Qt::EditRole).toInt();
+    int typ = data(idx, KPlato::NodeModel::NodeType, Qt::EditRole).toInt();
     switch (typ) {
-        case Node::Type_Task:
+        case KPlato::Node::Type_Task:
             return xi18nc("@info:tooltip",
                           "Task: %1<nl/>"
                           "Planned: %2 - %3<nl/>"
@@ -692,14 +681,13 @@ QString GanttItemDelegate::toolTip(const QModelIndex &index) const
 GanttView::GanttView(Part *part, QWidget *parent)
     : KPlato::GanttViewBase(parent),
       m_part(part),
-      m_project(0),
       m_ganttdelegate(new GanttItemDelegate(this)),
       m_itemmodel(new TaskWorkPackageModel(part, this))
 {
     debugPlanWork<<"------------------- create GanttView -----------------------";
-    m_itemmodel->setObjectName("Gantt model");
+    m_itemmodel->setObjectName(QStringLiteral("Gantt model"));
     graphicsView()->setItemDelegate(m_ganttdelegate);
-    GanttTreeView *tv = new GanttTreeView(this);
+    KPlato::GanttTreeView *tv = new KPlato::GanttTreeView(this);
     tv->setSortingEnabled(true);
     tv->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
     tv->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
@@ -709,6 +697,14 @@ GanttView::GanttView(Part *part, QWidget *parent)
     setRowController(m_rowController);
     tv->header()->setStretchLastSection(true);
 
+    // Set workdays so freedays can be indicated
+    const auto weekdays = QLocale().weekdays();
+    for (const auto w : weekdays) {
+        auto day = m_calendar.weekday(w);
+        day->setState(KPlato::CalendarDay::Working);
+    }
+    setCalendar(2, &m_calendar);
+
     QSortFilterProxyModel *sf = new QSortFilterProxyModel(tv);
     sf->setSortRole(Qt::EditRole);
     sf->setSourceModel(m_itemmodel);
@@ -765,7 +761,7 @@ GanttView::~GanttView()
 
 void GanttView::slotSelectionChanged(const QItemSelection &selected, const QItemSelection&)
 {
-    emit selectionChanged(selected.indexes());
+    Q_EMIT selectionChanged(selected.indexes());
 }
 
 void GanttView::slotRowsInserted(const QModelIndex &parent, int start, int end)
@@ -784,7 +780,7 @@ void GanttView::slotRowsRemoved(const QModelIndex &/*parent*/, int /*start*/, in
     QDateTime newStart;
     for (int i = 0; i < m_part->workPackageCount(); ++i) {
         WorkPackage *wp = m_part->workPackage(i);
-        Task *task = static_cast<Task*>(wp->project()->childNode(0));
+        KPlato::Task *task = static_cast<KPlato::Task*>(wp->project()->childNode(0));
         if (!newStart.isValid() || newStart > task->startTime()) {
             newStart = task->startTime();
         }
@@ -800,8 +796,8 @@ void GanttView::updateDateTimeGrid(WorkPackage *wp)
     if (! wp || ! wp->project() || ! wp->project()->childNode(0)) {
         return;
     }
-    Task *task = static_cast<Task*>(wp->project()->childNode(0));
-    DateTime st = task->startTime();
+    KPlato::Task *task = static_cast<KPlato::Task*>(wp->project()->childNode(0));
+    KPlato::DateTime st = task->startTime();
     if (! st.isValid() && task->completion().startTime().isValid()) {
         st = qMin(st, task->completion().startTime());
     }
@@ -821,27 +817,28 @@ TaskWorkPackageModel *GanttView::itemModel() const
     return m_itemmodel;
 }
 
-void GanttView::setProject(Project *project)
+void GanttView::setProject(KPlato::Project *project)
 {
     itemModel()->setProject(project);
     m_project = project;
 }
 
-QList<Node*> GanttView::selectedNodes() const
+QList<KPlato::Node*> GanttView::selectedNodes() const
 {
-    QList<Node*> nodes;
-    foreach(const QModelIndex &idx, treeView()->selectionModel()->selectedRows()) {
+    QList<KPlato::Node*> nodes;
+    const QList<QModelIndex> rows = treeView()->selectionModel()->selectedRows();
+    for(const QModelIndex &idx : rows) {
         nodes << itemModel()->nodeForIndex(idx);
     }
     return nodes;
 }
 
-Node *GanttView::currentNode() const
+KPlato::Node *GanttView::currentNode() const
 {
     return itemModel()->nodeForIndex(treeView()->selectionModel()->currentIndex());
 }
 
-Document *GanttView::currentDocument() const
+KPlato::Document *GanttView::currentDocument() const
 {
     return itemModel()->documentForIndex(treeView()->selectionModel()->currentIndex());
 }
@@ -861,10 +858,10 @@ bool GanttView::loadContext(const KoXmlElement &context)
 
 void GanttView::saveContext(QDomElement &context) const
 {
-    QDomElement e = context.ownerDocument().createElement("itemview");
+    QDomElement e = context.ownerDocument().createElement(QStringLiteral("itemview"));
     context.appendChild(e);
     treeView()->saveContext(itemModel()->columnMap(), e);
-    e = context.ownerDocument().createElement("ganttview");
+    e = context.ownerDocument().createElement(QStringLiteral("ganttview"));
     context.appendChild(e);
     KPlato::GanttViewBase::saveContext(e);
 }
@@ -875,7 +872,7 @@ TaskWPGanttView::TaskWPGanttView(Part *part, QWidget *parent)
 {
     debugPlanWork<<"-------------------- creating TaskWPGanttView -------------------";
     QVBoxLayout * l = new QVBoxLayout(this);
-    l->setMargin(0);
+    l->setContentsMargins(0, 0, 0, 0);
     m_view = new GanttView(part, this);
     l->addWidget(m_view);
 
@@ -883,7 +880,6 @@ TaskWPGanttView::TaskWPGanttView(Part *part, QWidget *parent)
 
     connect(itemModel(), &KPlato::ItemModelBase::executeCommand, part, &Part::addCommand);
 
-    connect(m_view, SIGNAL(contextMenuRequested(QModelIndex,QPoint)), SLOT(slotContextMenuRequested(QModelIndex,QPoint)));
     connect(m_view, &GanttView::headerContextMenuRequested, this, &TaskWPGanttView::slotHeaderContextMenuRequested);
 
     connect(m_view, &GanttView::selectionChanged, this, &TaskWPGanttView::slotSelectionChanged);
@@ -898,20 +894,20 @@ TaskWPGanttView::~TaskWPGanttView()
 
 void TaskWPGanttView::slotSelectionChanged(const QModelIndexList& /*lst*/)
 {
-    emit selectionChanged();
+    Q_EMIT selectionChanged();
 }
 
-QList<Node*> TaskWPGanttView::selectedNodes() const
+QList<KPlato::Node*> TaskWPGanttView::selectedNodes() const
 {
     return m_view->selectedNodes();
 }
 
-Node *TaskWPGanttView::currentNode() const
+KPlato::Node *TaskWPGanttView::currentNode() const
 {
     return m_view->currentNode();
 }
 
-Document *TaskWPGanttView::currentDocument() const
+KPlato::Document *TaskWPGanttView::currentDocument() const
 {
     return m_view->currentDocument();
 }
@@ -923,11 +919,11 @@ void TaskWPGanttView::slotContextMenuRequested(const QModelIndex &idx, const QPo
         slotHeaderContextMenuRequested(pos);
         return;
     }
-    Node *node = itemModel()->nodeForIndex(idx);
+    KPlato::Node *node = itemModel()->nodeForIndex(idx);
     if (node) {
         return slotContextMenuRequested(node, pos);
     }
-    Document *doc = itemModel()->documentForIndex(idx);
+    KPlato::Document *doc = itemModel()->documentForIndex(idx);
     if (doc) {
         return slotContextMenuRequested(doc, pos);
     }
@@ -944,7 +940,7 @@ void TaskWPGanttView::setupGui()
 void TaskWPGanttView::slotOptions()
 {
     debugPlanWork;
-    QPointer<ItemViewSettupDialog> dlg = new ItemViewSettupDialog(0, m_view->treeView(), true, this);
+    QPointer<KPlato::ItemViewSettupDialog> dlg = new KPlato::ItemViewSettupDialog(nullptr, m_view->treeView(), true, this);
     dlg->exec();
     delete dlg;
 }
@@ -963,12 +959,12 @@ bool TaskWPGanttView::loadContext()
 
 void TaskWPGanttView::saveContext()
 {
-    QDomDocument doc ("TaskWPGanttView");
-    QDomElement context = doc.createElement("TaskWPGanttViewSettings");
+    QDomDocument doc (QStringLiteral("TaskWPGanttView"));
+    QDomElement context = doc.createElement(QStringLiteral("TaskWPGanttViewSettings"));
     doc.appendChild(context);
     m_view->saveContext(context);
     PlanWorkSettings::self()->setTaskWPGanttView(doc.toString());
-    debugPlanWork<<endl<<doc.toString();
+    debugPlanWork<<'\n'<<doc.toString();
 }
 
 } // namespace KPlatoWork
