@@ -1,22 +1,9 @@
 /* This file is part of the KDE project
-  Copyright (C) 1998, 1999, 2000 Torben Weis <weis@kde.org>
-  Copyright (C) 2002 - 2009, 2011, 2012 Dag Andersen <danders@get2net.dk>
-  Copyright (C) 2019 Dag Andersen <danders@get2net.dk>
+  SPDX-FileCopyrightText: 1998, 1999, 2000 Torben Weis <weis@kde.org>
+  SPDX-FileCopyrightText: 2002-2009, 2011, 2012 Dag Andersen <dag.andersen@kdemail.net>
+  SPDX-FileCopyrightText: 2019 Dag Andersen <dag.andersen@kdemail.net>
   
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-* Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 // clazy:excludeall=qstring-arg
@@ -45,16 +32,18 @@
 #include <QPointer>
 #include <QMenu>
 #include <QAction>
+#include <QActionGroup>
 
 #include <KLocalizedString>
-#include <ktoolbar.h>
+#include <KToolBar>
 
-#include <kxmlguifactory.h>
-#include <ktoolinvocation.h>
-#include <kactioncollection.h>
+#include <KXMLGUIFactory>
+#include <KEMailClientLauncherJob>
+#include <KDialogJobUiDelegate>
+#include <KActionCollection>
 #include <QTemporaryFile>
 
-#include <kmessagebox.h>
+#include <KMessageBox>
 
 #include <KoIcon.h>
 
@@ -83,7 +72,7 @@ View::View(Part *part,  QWidget *parent, KActionCollection *collection)
     : QStackedWidget(parent),
     m_part(part),
     m_scheduleActionGroup(new QActionGroup(this)),
-    m_manager(0)
+    m_manager(nullptr)
 {
     m_readWrite = part->isReadWrite();
     debugPlanWork<<m_readWrite;
@@ -94,56 +83,51 @@ View::View(Part *part,  QWidget *parent, KActionCollection *collection)
     // The menu items
     // ------ Edit
     actionRemoveSelectedPackages  = new QAction(koIcon("edit-delete"), i18n("Remove Packages"), this);
-    collection->addAction("package_remove_selected", actionRemoveSelectedPackages);
+    collection->addAction(QStringLiteral("package_remove_selected"), actionRemoveSelectedPackages);
     connect(actionRemoveSelectedPackages, &QAction::triggered, this, &View::slotRemoveSelectedPackages);
 
     actionRemoveCurrentPackage  = new QAction(koIcon("edit-delete"), i18n("Remove Package"), this);
-    collection->addAction("package_remove_current", actionRemoveCurrentPackage);
+    collection->addAction(QStringLiteral("package_remove_current"), actionRemoveCurrentPackage);
     connect(actionRemoveCurrentPackage, &QAction::triggered, this, &View::slotRemoveCurrentPackage);
 
     actionViewList  = new QAction(koIcon("view-list-tree"), i18n("List"), this);
     actionViewList->setToolTip(i18nc("@info:tooltip", "Select task list"));
-    collection->addAction("view_list", actionViewList);
+    collection->addAction(QStringLiteral("view_list"), actionViewList);
     connect(actionViewList, &QAction::triggered, this, &View::slotViewList);
 
     actionViewGantt  = new QAction(koIcon("view-time-schedule"), i18n("Gantt"), this);
     actionViewGantt->setToolTip(i18nc("@info:tooltip", "Select timeline"));
-    collection->addAction("view_gantt", actionViewGantt);
+    collection->addAction(QStringLiteral("view_gantt"), actionViewGantt);
     connect(actionViewGantt, &QAction::triggered, this, &View::slotViewGantt);
 
-//     actionTaskProgress  = new QAction(koIcon("document-edit"), i18n("Progress..."), this);
-//     collection->addAction("task_progress", actionTaskProgress);
-//     connect(actionTaskProgress, SIGNAL(triggered(bool)), SLOT(slotTaskProgress()));
-
     //------ Settings
     actionConfigure  = new QAction(koIcon("configure"), i18n("Configure PlanWork..."), this);
-    collection->addAction("configure", actionConfigure);
+    collection->addAction(QStringLiteral("configure"), actionConfigure);
     connect(actionConfigure, &QAction::triggered, this, &View::slotConfigure);
 
     //------ Popups
     actionEditDocument  = new QAction(koIcon("document-edit"), i18n("Edit..."), this);
-    collection->addAction("edit_document", actionEditDocument);
-    connect(actionEditDocument, SIGNAL(triggered(bool)), SLOT(slotEditDocument()));
+    collection->addAction(QStringLiteral("edit_document"), actionEditDocument);
+    connect(actionEditDocument, &QAction::triggered, this, QOverload<>::of(&View::slotEditDocument));
 
     actionViewDocument  = new QAction(koIcon("document-preview"), i18nc("@verb", "View..."), this);
-    collection->addAction("view_document", actionViewDocument);
+    collection->addAction(QStringLiteral("view_document"), actionViewDocument);
     connect(actionViewDocument, &QAction::triggered, this, &View::slotViewDocument);
 
-    // FIXME remove UndoText::removeDocument() when string freeze is lifted
-    actionRemoveDocument = new QAction(koIcon("list-remove"), UndoText::removeDocument().toString(), this);
-    collection->addAction("remove_document", actionRemoveDocument);
+    actionRemoveDocument = new QAction(koIcon("list-remove"), i18n("Remove document"), this);
+    collection->addAction(QStringLiteral("remove_document"), actionRemoveDocument);
     connect(actionRemoveDocument, &QAction::triggered, this, &View::slotRemoveDocument);
 
     actionSendPackage  = new QAction(koIcon("mail-send"), i18n("Send Package..."), this);
-    collection->addAction("edit_sendpackage", actionSendPackage);
+    collection->addAction(QStringLiteral("edit_sendpackage"), actionSendPackage);
     connect(actionSendPackage, &QAction::triggered, this, &View::slotSendPackage);
 
     actionTaskCompletion  = new QAction(koIcon("document-edit"), i18n("Edit Progress..."), this);
-    collection->addAction("task_progress", actionTaskCompletion);
+    collection->addAction(QStringLiteral("task_progress"), actionTaskCompletion);
     connect(actionTaskCompletion, &QAction::triggered, this, &View::slotTaskCompletion);
 
     actionViewDescription  = new QAction(/*koIcon("document_view"),*/ i18n("View Description..."), this);
-    collection->addAction("task_description", actionViewDescription);
+    collection->addAction(QStringLiteral("task_description"), actionViewDescription);
     connect(actionViewDescription, &QAction::triggered, this, &View::slotTaskDescription);
 
 
@@ -252,7 +236,7 @@ void View::slotConfigure()
 {
 }
 
-ScheduleManager *View::currentScheduleManager() const
+KPlato::ScheduleManager *View::currentScheduleManager() const
 {
     WorkPackage *wp = m_part->findWorkPackage(currentNode());
     return wp ? wp->project()->scheduleManagers().value(0) : nullptr;
@@ -265,7 +249,7 @@ void View::updateReadWrite(bool readwrite)
 
 //    actionTaskProgress->setEnabled(readwrite);
 
-    emit sigUpdateReadWrite(readwrite);
+    Q_EMIT sigUpdateReadWrite(readwrite);
 }
 
 Part *View::part() const
@@ -277,11 +261,11 @@ void View::slotPopupMenu(const QString& name, const QPoint & pos)
 {
     debugPlanWork<<name;
     Q_ASSERT(m_part->factory());
-    if (m_part->factory() == 0) {
+    if (m_part->factory() == nullptr) {
         return;
     }
     QMenu *menu = ((QMenu*) m_part->factory() ->container(name, m_part));
-    if (menu == 0) {
+    if (menu == nullptr) {
         return;
     }
     QList<QAction*> lst;
@@ -291,13 +275,13 @@ void View::slotPopupMenu(const QString& name, const QPoint & pos)
         debugPlanWork<<lst;
         if (! lst.isEmpty()) {
             menu->addSeparator();
-            foreach (QAction *a, lst) {
+            for (QAction *a : std::as_const(lst)) {
                 menu->addAction(a);
             }
         }
     }
     menu->exec(pos);
-    foreach (QAction *a, lst) {
+    for (QAction *a : std::as_const(lst)) {
         menu->removeAction(a);
     }
 }
@@ -321,15 +305,15 @@ void View::slotEditDocument()
     slotEditDocument(currentDocument());
 }
 
-void View::slotEditDocument(Document *doc)
+void View::slotEditDocument(KPlato::Document *doc)
 {
     debugPlanWork<<doc;
-    if (doc == 0) {
+    if (doc == nullptr) {
         debugPlanWork<<"No document";
         return;
     }
-    if (doc->type() != Document::Type_Product) {
-        KMessageBox::error(0, i18n("This file is not editable"));
+    if (doc->type() != KPlato::Document::Type_Product) {
+        KMessageBox::error(nullptr, i18n("This file is not editable"));
         return;
     }
     part()->editWorkpackageDocument(doc);
@@ -337,7 +321,7 @@ void View::slotEditDocument(Document *doc)
 
 void View::slotViewDocument()
 {
-    emit viewDocument(currentDocument());
+    Q_EMIT viewDocument(currentDocument());
 }
 
 void View::slotRemoveDocument()
@@ -347,66 +331,69 @@ void View::slotRemoveDocument()
 
 void View::slotSendPackage()
 {
-    Node *node = currentNode();
-    if (node == 0) {
-        KMessageBox::error(0, i18n("No work package is selected"));
+    KPlato::Node *node = currentNode();
+    if (node == nullptr) {
+        KMessageBox::error(nullptr, i18n("No work package is selected"));
         return;
     }
     debugPlanWork<<node->name();
     WorkPackage *wp = part()->findWorkPackage(node);
-    if (wp == 0) {
-        KMessageBox::error(0, i18n("Cannot find work package"));
+    if (wp == nullptr) {
+        KMessageBox::error(nullptr, i18n("Cannot find work package"));
         return;
     }
 /*    if (wp->isModified()) {
-        int r = KMessageBox::questionYesNoCancel(0, i18n("This work package has been modified.\nDo you want to save it before sending?"), node->name());
+        int r = KMessageBox::questionTwoActionsCancel(0, i18n("This work package has been modified.\nDo you want to save it before sending?"), node->name());
         switch (r) {
             case KMessageBox::Cancel: return;
-            case KMessageBox::Yes: wp->saveToProjects(part()); break;
+            case KMessageBox::PrimaryAction: wp->saveToProjects(part()); break;
             default: break;
         }
     }*/
 
     bool wasmodified = wp->isModified();
     if (wp->sendUrl().isValid()) {
-        QTemporaryFile temp(wp->sendUrl().toLocalFile() + QLatin1String("/calligraplanwork_XXXXXX") + QLatin1String(".planwork"));
+        QTemporaryFile temp(wp->sendUrl().toLocalFile() + QStringLiteral("/calligraplanwork_XXXXXX") + QStringLiteral(".planwork"));
         temp.setAutoRemove(false);
         if (! temp.open()) {
-            KMessageBox::error(0, i18n("Could not open file. Sending is aborted."));
+            KMessageBox::error(nullptr, i18n("Could not open file. Sending is aborted."));
             return;
         }
         wp->saveNativeFormat(part(), temp.fileName());
     } else {
-        QTemporaryFile temp(QDir::tempPath() + QLatin1String("/calligraplanwork_XXXXXX") + QLatin1String(".planwork"));
+        QTemporaryFile temp(QDir::tempPath() + QStringLiteral("/calligraplanwork_XXXXXX") + QStringLiteral(".planwork"));
         temp.setAutoRemove(false);
         if (! temp.open()) {
-            KMessageBox::error(0, i18n("Could not open temporary file. Sending is aborted."));
+            KMessageBox::error(nullptr, i18n("Could not open temporary file. Sending is aborted."));
             return;
         }
         wp->saveNativeFormat(part(), temp.fileName());
 
-        QStringList attachURLs;
-        attachURLs << temp.fileName();
+        QList<QUrl> attachURLs;
+        attachURLs << QUrl::fromUserInput(temp.fileName());
 
         QString to = node->projectNode()->leader();
-        QString cc;
-        QString bcc;
         QString subject = i18n("Work Package: %1", node->name());
         QString body = node->projectNode()->name();
-        QString messageFile;
 
-        KToolInvocation::invokeMailer(to, cc, bcc, subject, body, messageFile, attachURLs);
+        auto job = new KEMailClientLauncherJob();
+        job->setTo(QStringList()<<to);
+        job->setSubject(subject);
+        job->setBody(body);
+        job->setAttachments(attachURLs);
+        job->setUiDelegate(new KDialogJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+        job->start();
     }
     wp->setModified(wasmodified);
 }
 
 void View::slotTaskDescription()
 {
-    Task *node = qobject_cast<Task*>(currentNode());
-    if (node == 0) {
+    KPlato::Task *node = qobject_cast<KPlato::Task*>(currentNode());
+    if (node == nullptr) {
         return;
     }
-    QPointer<TaskDescriptionDialog> dlg = new TaskDescriptionDialog(*node, this, true);
+    QPointer<KPlato::TaskDescriptionDialog> dlg = new KPlato::TaskDescriptionDialog(*node, this, true);
     dlg->exec();
     delete dlg;
 }
@@ -416,27 +403,27 @@ AbstractView *View::currentView() const
     return qobject_cast<AbstractView*>(currentWidget());
 }
 
-Node *View::currentNode() const
+KPlato::Node *View::currentNode() const
 {
     AbstractView *v = currentView();
-    return v ? v->currentNode() : 0;
+    return v ? v->currentNode() : nullptr;
 }
 
-Document *View::currentDocument() const
+KPlato::Document *View::currentDocument() const
 {
     AbstractView *v = currentView();
-    return v ? v->currentDocument() : 0;
+    return v ? v->currentDocument() : nullptr;
 }
 
 void View::slotTaskProgress()
 {
     debugPlanWork;
-    Task *n = qobject_cast<Task*>(currentNode());
-    if (n == 0) {
+    KPlato::Task *n = qobject_cast<KPlato::Task*>(currentNode());
+    if (n == nullptr) {
         return;
     }
-    StandardWorktime *w = qobject_cast<Project*>(n->projectNode())->standardWorktime();
-    QPointer<TaskProgressDialog> dlg = new TaskProgressDialog(*n, currentScheduleManager(), w, this);
+    KPlato::StandardWorktime *w = qobject_cast<KPlato::Project*>(n->projectNode())->standardWorktime();
+    QPointer<KPlato::TaskProgressDialog> dlg = new KPlato::TaskProgressDialog(*n, currentScheduleManager(), w, this);
     if (dlg->exec() == QDialog::Accepted && dlg) {
         KUndo2Command *cmd = dlg->buildCommand();
         if (cmd) {
@@ -449,7 +436,7 @@ void View::slotTaskCompletion()
 {
     debugPlanWork;
     WorkPackage *wp = m_part->findWorkPackage(currentNode());
-    if (wp == 0) {
+    if (wp == nullptr) {
         return;
     }
     QPointer<TaskCompletionDialog> dlg = new TaskCompletionDialog(*wp, currentScheduleManager(), this);
@@ -465,7 +452,7 @@ void View::slotTaskCompletion()
 void View::slotRemoveSelectedPackages()
 {
     debugPlanWork;
-    QList<Node*> lst = currentView()->selectedNodes();
+    QList<KPlato::Node*> lst = currentView()->selectedNodes();
     if (lst.isEmpty()) {
         return;
     }
@@ -475,8 +462,8 @@ void View::slotRemoveSelectedPackages()
 void View::slotRemoveCurrentPackage()
 {
     debugPlanWork;
-    Node *n = currentNode();
-    if (n == 0) {
+    KPlato::Node *n = currentNode();
+    if (n == nullptr) {
         return;
     }
     m_part->removeWorkPackage(n);
