@@ -1,27 +1,14 @@
 /* This file is part of the KDE project
- Copyright (C) 2009, 2012 Dag Andersen <danders@get2net.dk>
- Copyright (C) 2019 Dag Andersen <danders@get2net.dk>
+ SPDX-FileCopyrightText: 2009, 2012 Dag Andersen <dag.andersen@kdemail.net>
+ SPDX-FileCopyrightText: 2019 Dag Andersen <dag.andersen@kdemail.net>
  
- This library is free software; you can redistribute it and/or
- modify it under the terms of the GNU Library General Public
- License as published by the Free Software Foundation; either
- version 2 of the License, or (at your option) any later version.
-
- This library is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- Library General Public License for more details.
-
- You should have received a copy of the GNU Library General Public License
- along with this library; see the file COPYING.LIB.  If not, write to
- the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- Boston, MA 02110-1301, USA.
+ SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 // clazy:excludeall=qstring-arg
 #include "workpackage.h"
 
-#include "KPlatoXmlLoader.h" //NOTE: this file should probably be moved
+#include "plan/KPlatoXmlLoader.h" //NOTE: this file should probably be moved
 
 #include "part.h"
 #include "kptglobal.h"
@@ -34,6 +21,9 @@
 #include "kptconfigbase.h"
 #include "kptcommonstrings.h"
 
+#include <ProjectLoaderBase.h>
+#include <MimeTypes.h>
+
 #include <KoStore.h>
 #include <KoXmlReader.h>
 #include <KoStoreDevice.h>
@@ -45,28 +35,28 @@
 #include <QDateTime>
 #include <QDomDocument>
 
-#include <kmessagebox.h>
+#include <KMessageBox>
 
 
 #include "debugarea.h"
 
-using namespace KPlato;
-
 namespace KPlatoWork
 {
 
 WorkPackage::WorkPackage(bool fromProjectStore)
-    : m_project(new Project()),
+    : m_project(new KPlato::Project()),
     m_fromProjectStore(fromProjectStore),
-    m_modified(false)
+    m_modified(false),
+    m_nogui(false)
 {
     m_project->setConfig(&m_config);
 }
 
-WorkPackage::WorkPackage(Project *project, bool fromProjectStore)
+WorkPackage::WorkPackage(KPlato::Project *project, bool fromProjectStore)
     : m_project(project),
     m_fromProjectStore(fromProjectStore),
-    m_modified(false)
+    m_modified(false),
+    m_nogui(false)
 {
     Q_ASSERT(project);
     Q_ASSERT (project->childNode(0));
@@ -75,7 +65,7 @@ WorkPackage::WorkPackage(Project *project, bool fromProjectStore)
 
     if (! project->scheduleManagers().isEmpty()) {
         // should be only one manager, so just get the first
-        const QList<ScheduleManager*> &lst = m_project->scheduleManagers();
+        const QList<KPlato::ScheduleManager*> &lst = m_project->scheduleManagers();
         project->setCurrentSchedule(lst.first()->scheduleId());
     }
     connect(project, &KPlato::Project::projectChanged, this, &WorkPackage::projectChanged);
@@ -88,7 +78,7 @@ WorkPackage::~WorkPackage()
     qDeleteAll(m_childdocs);
 }
 
-void WorkPackage::setSettings(const WorkPackageSettings &settings)
+void WorkPackage::setSettings(const KPlato::WorkPackageSettings &settings)
 {
     if (m_settings != settings) {
         m_settings = settings;
@@ -103,12 +93,15 @@ void WorkPackage::projectChanged()
     setModified(true);
 }
 
-bool WorkPackage::addChild(Part */*part*/, const Document *doc)
+bool WorkPackage::addChild(Part *part, const KPlato::Document *doc)
 {
+    Q_UNUSED(part)
     DocumentChild *ch = findChild(doc);
     if (ch) {
         if (ch->isOpen()) {
-            KMessageBox::error(0, i18n("Document is already open"));
+            if (!m_nogui) {
+                KMessageBox::error(nullptr, i18n("Document is already open"));
+            }
             return false;
         }
     } else {
@@ -132,8 +125,8 @@ bool WorkPackage::addChild(Part */*part*/, const Document *doc)
 void WorkPackage::slotChildModified(bool mod)
 {
     debugPlanWork<<mod;
-    emit modified(isModified());
-    emit saveWorkPackage(this);
+    Q_EMIT modified(isModified());
+    Q_EMIT saveWorkPackage(this);
 }
 
 void WorkPackage::removeChild(DocumentChild *child)
@@ -150,90 +143,68 @@ void WorkPackage::removeChild(DocumentChild *child)
     }
 }
 
-bool WorkPackage::contains(const Document *doc) const
+bool WorkPackage::contains(const KPlato::Document *doc) const
 {
     return node() ? node()->documents().contains(doc) : false;
 }
 
-DocumentChild *WorkPackage::findChild(const Document *doc) const
+DocumentChild *WorkPackage::findChild(const KPlato::Document *doc) const
 {
-    foreach (DocumentChild *c, m_childdocs) {
+    for (DocumentChild *c : std::as_const(m_childdocs)) {
         if (c->doc() == doc) {
             return c;
         }
     }
-    return 0;
+    return nullptr;
 }
 
-bool WorkPackage::loadXML(const KoXmlElement &element, XMLLoaderObject &status)
+bool WorkPackage::loadXML(const KoXmlElement &element, KPlato::XMLLoaderObject &status)
 {
-    bool ok = false;
-    QString wbsCode = "Unknown";
-    KoXmlNode n = element.firstChild();
-    for (; ! n.isNull(); n = n.nextSibling()) {
-        if (! n.isElement()) {
-            continue;
+    QString wbsCode = QStringLiteral("Unknown");
+    bool ok = status.loadProject(m_project, element.ownerDocument());
+    if (!ok) {
+        warnPlanXml<<"Failed to load project";
+        status.addMsg(KPlato::XMLLoaderObject::Errors, QStringLiteral("Loading of work package failed"));
+        if (!m_nogui) {
+            KMessageBox::error(nullptr, i18n("Failed to load project: %1" , m_project->name()));
         }
-        KoXmlElement e = n.toElement();
-        debugPlanWork<<e.tagName();
-        if (e.tagName() == "project") {
-            status.setProject(m_project);
-            debugPlanWork<<"loading new project";
-            if (! (ok = m_project->load(e, status))) {
-                status.addMsg(XMLLoaderObject::Errors, "Loading of work package failed");
-                KMessageBox::error(0, i18n("Failed to load project: %1" , m_project->name()));
-            } else {
-                KoXmlElement te = e.namedItem("task").toElement();
-                if (!te.isNull()) {
-                    wbsCode = te.attribute("wbs", "empty");
-                }
-            }
+    } else {
+        KoXmlElement te = element.namedItem("task").toElement();
+        if (!te.isNull()) {
+            wbsCode = te.attribute("wbs", QStringLiteral("empty"));
         }
     }
     if (ok) {
-        KoXmlNode n = element.firstChild();
-        for (; ! n.isNull(); n = n.nextSibling()) {
-            if (! n.isElement()) {
-                continue;
-            }
-            KoXmlElement e = n.toElement();
-            debugPlanWork<<e.tagName();
-            if (e.tagName() == "workpackage") {
-                Task *t = static_cast<Task*>(m_project->childNode(0));
-                t->workPackage().setOwnerName(e.attribute("owner"));
-                t->workPackage().setOwnerId(e.attribute("owner-id"));
-                m_sendUrl = QUrl(e.attribute("save-url"));
-                m_fetchUrl = QUrl(e.attribute("load-url"));
-                m_wbsCode = wbsCode;
+        KoXmlElement e = element.namedItem(QStringLiteral("workpackage")).toElement();
+        debugPlanWork<<e.tagName();
+        if (e.tagName() == QStringLiteral("workpackage")) {
+            KPlato::Task *t = static_cast<KPlato::Task*>(m_project->childNode(0));
+            t->workPackage().setOwnerName(e.attribute("owner"));
+            t->workPackage().setOwnerId(e.attribute("owner-id"));
+            m_sendUrl = QUrl(e.attribute("save-url"));
+            m_fetchUrl = QUrl(e.attribute("load-url"));
+            m_wbsCode = wbsCode;
 
-                Resource *r = m_project->findResource(t->workPackage().ownerId());
-                if (r == 0) {
-                    debugPlanWork<<"Cannot find resource id!!"<<t->workPackage().ownerId()<<t->workPackage().ownerName();
-                }
-                debugPlanWork<<"is this me?"<<t->workPackage().ownerName();
-                KoXmlNode ch = e.firstChild();
-                for (; ! ch.isNull(); ch = ch.nextSibling()) {
-                    if (! ch.isElement()) {
-                        continue;
-                    }
-                    KoXmlElement el = ch.toElement();
-                    debugPlanWork<<el.tagName();
-                    if (el.tagName() == "settings") {
-                        m_settings.loadXML(el);
-                    }
-                }
+            KPlato::Resource *r = m_project->findResource(t->workPackage().ownerId());
+            if (r == nullptr) {
+                warnPlanWork<<"Cannot find resource id!"<<t->workPackage().ownerId()<<t->workPackage().ownerName();
+            }
+            debugPlanWork<<"is this me?"<<t->workPackage().ownerName();
+            auto ch = e.namedItem(QStringLiteral("settings")).toElement();
+            if (!ch.isNull()) {
+                m_settings.loadXML(ch);
             }
         }
     }
     if (! m_project->scheduleManagers().isEmpty()) {
         // should be only one manager
-        const QList<ScheduleManager*> &lst = m_project->scheduleManagers();
+        const QList<KPlato::ScheduleManager*> &lst = m_project->scheduleManagers();
         m_project->setCurrentSchedule(lst.first()->scheduleId());
     }
     return ok;
 }
 
-bool WorkPackage::loadKPlatoXML(const KoXmlElement &element, XMLLoaderObject &status)
+bool WorkPackage::loadKPlatoXML(const KoXmlElement &element, KPlato::XMLLoaderObject &status)
 {
     bool ok = false;
     KoXmlNode n = element.firstChild();
@@ -243,13 +214,15 @@ bool WorkPackage::loadKPlatoXML(const KoXmlElement &element, XMLLoaderObject &st
         }
         KoXmlElement e = n.toElement();
         debugPlanWork<<e.tagName();
-        if (e.tagName() == "project") {
+        if (e.tagName() == QStringLiteral("project")) {
             status.setProject(m_project);
-            KPlatoXmlLoader loader(status, m_project);
+            KPlato::KPlatoXmlLoader loader(status, m_project);
             debugPlanWork<<"loading new project";
             if (! (ok = loader.load(m_project, e, status))) {
-                status.addMsg(XMLLoaderObject::Errors, "Loading of work package failed");
-                KMessageBox::error(0, i18n("Failed to load project: %1" , m_project->name()));
+                status.addMsg(KPlato::XMLLoaderObject::Errors, QStringLiteral("Loading of work package failed"));
+                if (!m_nogui) {
+                    KMessageBox::error(nullptr, i18n("Failed to load project: %1" , m_project->name()));
+                }
             }
         }
     }
@@ -261,13 +234,13 @@ bool WorkPackage::loadKPlatoXML(const KoXmlElement &element, XMLLoaderObject &st
             }
             KoXmlElement e = n.toElement();
             debugPlanWork<<e.tagName();
-            if (e.tagName() == "workpackage") {
-                Task *t = static_cast<Task*>(m_project->childNode(0));
+            if (e.tagName() == QStringLiteral("workpackage")) {
+                KPlato::Task *t = static_cast<KPlato::Task*>(m_project->childNode(0));
                 t->workPackage().setOwnerName(e.attribute("owner"));
                 t->workPackage().setOwnerId(e.attribute("owner-id"));
 
-                Resource *r = m_project->findResource(t->workPackage().ownerId());
-                if (r == 0) {
+                KPlato::Resource *r = m_project->findResource(t->workPackage().ownerId());
+                if (r == nullptr) {
                     debugPlanWork<<"Cannot find resource id!!"<<t->workPackage().ownerId()<<t->workPackage().ownerName();
                 }
                 debugPlanWork<<"is this me?"<<t->workPackage().ownerName();
@@ -278,7 +251,7 @@ bool WorkPackage::loadKPlatoXML(const KoXmlElement &element, XMLLoaderObject &st
                     }
                     KoXmlElement el = ch.toElement();
                     debugPlanWork<<el.tagName();
-                    if (el.tagName() == "settings") {
+                    if (el.tagName() == QStringLiteral("settings")) {
                         m_settings.loadXML(el);
                     }
                 }
@@ -287,7 +260,7 @@ bool WorkPackage::loadKPlatoXML(const KoXmlElement &element, XMLLoaderObject &st
     }
     if (! m_project->scheduleManagers().isEmpty()) {
         // should be only one manager
-        const QList<ScheduleManager*> &lst = m_project->scheduleManagers();
+        const QList<KPlato::ScheduleManager*> &lst = m_project->scheduleManagers();
         m_project->setCurrentSchedule(lst.first()->scheduleId());
     }
     return ok;
@@ -305,16 +278,21 @@ bool WorkPackage::saveToStream(QIODevice * dev)
     return nwritten == (int)s.size();
 }
 
-bool WorkPackage::saveNativeFormat(Part */*part*/, const QString &path)
+bool WorkPackage::saveNativeFormat(Part *part, const QString &path)
 {
+    Q_UNUSED(part)
     if (path.isEmpty()) {
-        KMessageBox::error(0, i18n("Cannot save to empty filename"));
+        if (!m_nogui) {
+            KMessageBox::error(nullptr, i18n("Cannot save to empty filename"));
+        }
         return false;
     }
     debugPlanWork<<node()->name()<<path;
     KoStore* store = KoStore::createStore(path, KoStore::Write, "application/x-vnd.kde.plan.work", KoStore::Auto);
     if (store->bad()) {
-        KMessageBox::error(0, i18n("Could not create the file for saving"));
+        if (!m_nogui) {
+            KMessageBox::error(nullptr, i18n("Could not create the file for saving"));
+        }
         delete store;
         return false;
     }
@@ -326,7 +304,9 @@ bool WorkPackage::saveNativeFormat(Part */*part*/, const QString &path)
             return false;
         }
     } else {
-        KMessageBox::error(0, i18n("Not able to write '%1'. Partition full?", QString("maindoc.xml")));
+        if (!m_nogui) {
+            KMessageBox::error(nullptr, i18n("Not able to write '%1'. Partition full?", QStringLiteral("maindoc.xml")));
+        }
         delete store;
         return false;
     }
@@ -348,26 +328,29 @@ bool WorkPackage::saveNativeFormat(Part */*part*/, const QString &path)
 bool WorkPackage::completeSaving(KoStore *store)
 {
     debugPlanWork;
-    KoStore *oldstore = KoStore::createStore(filePath(), KoStore::Read, "", KoStore::Zip);
+    KoStore *oldstore = KoStore::createStore(filePath(), KoStore::Read, QByteArray(""), KoStore::Zip);
     if (oldstore->bad()) {
-        KMessageBox::error(0, i18n("Failed to open store:\n %1", filePath()));
+        if (!m_nogui) {
+            KMessageBox::error(nullptr, i18n("Failed to open store:\n %1", filePath()));
+        }
         return false;
     }
     if (oldstore->hasFile("documentinfo.xml")) {
-        copyFile(oldstore, store, "documentinfo.xml");
+        copyFile(oldstore, store, QStringLiteral("documentinfo.xml"));
     }
     if (oldstore->hasFile("preview.png")) {
-        copyFile(oldstore, store, "preview.png");
+        copyFile(oldstore, store, QStringLiteral("preview.png"));
     }
 
     // First get all open documents
     debugPlanWork<<m_childdocs.count();
-    foreach (DocumentChild *cd, m_childdocs) {
+    for (DocumentChild *cd : std::as_const(m_childdocs)) {
         if (! cd->saveToStore(store)) {
         }
     }
     // Then get new files
-    foreach (const Document *doc,  node()->documents().documents()) {
+    const QList<KPlato::Document*> documents = node()->documents().documents();
+    for (const KPlato::Document *doc : documents) {
         if (m_newdocs.contains(doc)) {
             store->addLocalFile(m_newdocs[ doc ].path(), doc->url().fileName());
             m_newdocs.remove(doc);
@@ -375,8 +358,8 @@ bool WorkPackage::completeSaving(KoStore *store)
         }
     }
     // Then get files from the old store copied to the new store
-    foreach (Document *doc,  node()->documents().documents()) {
-        if (doc->sendAs() != Document::SendAs_Copy) {
+    for (KPlato::Document *doc : documents) {
+        if (doc->sendAs() != KPlato::Document::SendAs_Copy) {
             continue;
         }
         if (! store->hasFile(doc->url().fileName())) {
@@ -389,20 +372,20 @@ bool WorkPackage::completeSaving(KoStore *store)
 QString WorkPackage::fileName(const Part *part) const
 {
     Q_UNUSED(part);
-    if (m_project == 0) {
+    if (m_project == nullptr) {
         warnPlanWork<<"No project in this package";
         return QString();
     }
-    Node *n = node();
-    if (n == 0) {
+    KPlato::Node *n = node();
+    if (n == nullptr) {
         warnPlanWork<<"No node in this project";
         return QString();
     }
-    QString projectName = m_project->name().remove(' ');
-    // FIXME: workaround: KoResourcePaths::saveLocation("projects", projectName + '/');
-    const QString path = KoResourcePaths::saveLocation("appdata", "projects/" + projectName + '/');
+    QString projectName = m_project->name().remove(QLatin1Char(' '));
+    // FIXME: workaround: KoResourcePaths::saveLocation("projects", QStringLiteral(projectName) + QLatin1Char('/'));
+    const QString path = KoResourcePaths::saveLocation("appdata", QStringLiteral("projects/") + projectName + QLatin1Char('/'));
     QString wpName = n->name();
-    wpName = QString(wpName.remove(' ').replace('/', '_') + '_' + n->id() + ".planwork");
+    wpName = QString(wpName.remove(QLatin1Char(' ')).replace(QLatin1Char('/'), QLatin1Char('_')) + QLatin1Char('_') + n->id() + QStringLiteral(".planwork"));
     return path + wpName;
 }
 
@@ -425,7 +408,9 @@ void WorkPackage::saveToProjects(Part *part)
         m_fromProjectStore = true;
         m_filePath = path;
     } else {
-        KMessageBox::error(0, i18n("Cannot save to projects store:\n%1" , path));
+        if (!m_nogui) {
+            KMessageBox::error(nullptr, i18n("Cannot save to projects store:\n%1" , path));
+        }
     }
     return;
 }
@@ -435,7 +420,7 @@ bool WorkPackage::isModified() const
     if (m_modified) {
         return true;
     }
-    foreach (DocumentChild *ch, m_childdocs) {
+    for (DocumentChild *ch : std::as_const(m_childdocs)) {
         if (ch->isModified() || ch->isFileModified()) {
             return true;
         }
@@ -445,29 +430,29 @@ bool WorkPackage::isModified() const
 
 QString WorkPackage::name() const
 {
-    Task *t = task();
+    KPlato::Task *t = task();
     return t ? t->name() : QString();
 }
 
-Node *WorkPackage::node() const
+KPlato::Node *WorkPackage::node() const
 {
-    return m_project == 0 ? 0 : m_project->childNode(0);
+    return m_project == nullptr ? nullptr : m_project->childNode(0);
 }
 
-Task *WorkPackage::task() const
+KPlato::Task *WorkPackage::task() const
 {
-    Task *task = qobject_cast<Task*>(node());
+    KPlato::Task *task = qobject_cast<KPlato::Task*>(node());
     Q_ASSERT(task);
     return task;
 }
 
-bool WorkPackage::removeDocument(Part *part, Document *doc)
+bool WorkPackage::removeDocument(Part *part, KPlato::Document *doc)
 {
-    Node *n = node();
-    if (n == 0) {
+    KPlato::Node *n = node();
+    if (n == nullptr) {
         return false;
     }
-    part->addCommand(new DocumentRemoveCmd(n->documents(), doc, UndoText::removeDocument()));
+    part->addCommand(new KPlato::DocumentRemoveCmd(n->documents(), doc, kundo2_i18n("Remove document")));
     return true;
 }
 
@@ -475,11 +460,15 @@ bool WorkPackage::copyFile(KoStore *from, KoStore *to, const QString &filename)
 {
     QByteArray data;
     if (! from->extractFile(filename , data)) {
-        KMessageBox::error(0, i18n("Failed read file:\n %1", filename));
+        if (!m_nogui) {
+            KMessageBox::error(nullptr, i18n("Failed read file:\n %1", filename));
+        }
         return false;
     }
     if (! to->addDataToFile(data, filename)) {
-        KMessageBox::error(0, i18n("Failed write file:\n %1", filename));
+        if (!m_nogui) {
+            KMessageBox::error(nullptr, i18n("Failed write file:\n %1", filename));
+        }
         return false;
     }
     debugPlanWork<<"Copied file:"<<filename;
@@ -489,128 +478,141 @@ bool WorkPackage::copyFile(KoStore *from, KoStore *to, const QString &filename)
 QDomDocument WorkPackage::saveXML()
 {
     debugPlanWork;
-    QDomDocument document("plan-workpackage");
+    QDomDocument document(QStringLiteral("plan-workpackage"));
 
     document.appendChild(document.createProcessingInstruction(
-                              "xml",
-                              "version=\"1.0\" encoding=\"UTF-8\""));
+                              QStringLiteral("xml"),
+                              QStringLiteral("version=\"1.0\" encoding=\"UTF-8\"")));
 
-    QDomElement doc = document.createElement("planwork");
-    doc.setAttribute("editor", "PlanWork");
-    doc.setAttribute("mime", "application/x-vnd.kde.plan.work");
-    doc.setAttribute("version", PLANWORK_FILE_SYNTAX_VERSION);
-    doc.setAttribute("plan-version", PLAN_FILE_SYNTAX_VERSION);
+    QDomElement doc = document.createElement(QStringLiteral("planwork"));
+    doc.setAttribute(QStringLiteral("editor"), QStringLiteral("PlanWork"));
+    doc.setAttribute(QStringLiteral("mime"), PLANWORK_MIME_TYPE);
+    doc.setAttribute(QStringLiteral("version"), PLAN_FILE_SYNTAX_VERSION);
+    doc.setAttribute(QStringLiteral("plan-version"), PLAN_FILE_SYNTAX_VERSION);
     document.appendChild(doc);
 
     // Work package info
-    QDomElement wp = document.createElement("workpackage");
-    wp.setAttribute("time-tag", QDateTime::currentDateTime().toString(Qt::ISODate));
+    QDomElement wp = document.createElement(QStringLiteral("workpackage"));
+    wp.setAttribute(QStringLiteral("time-tag"), QDateTime::currentDateTime().toString(Qt::ISODate));
     m_settings.saveXML(wp);
-    Task *t = qobject_cast<Task*>(node());
+    KPlato::Task *t = qobject_cast<KPlato::Task*>(node());
     if (t) {
-        wp.setAttribute("owner", t->workPackage().ownerName());
-        wp.setAttribute("owner-id", t->workPackage().ownerId());
+        wp.setAttribute(QStringLiteral("owner"), t->workPackage().ownerName());
+        wp.setAttribute(QStringLiteral("owner-id"), t->workPackage().ownerId());
     }
     doc.appendChild(wp);
-    m_project->save(doc, XmlSaveContext());
+    m_project->save(doc, KPlato::XmlSaveContext());
     return document;
 }
 
 void WorkPackage::merge(Part *part, const WorkPackage *wp, KoStore *store)
 {
     debugPlanWork;
-    const Node *from = wp->node();
-    Node *to = node();
+    const KPlato::Node *from = wp->node();
+    KPlato::Node *to = node();
 
-    MacroCommand *m = new MacroCommand(kundo2_i18n("Merge data"));
+    KPlato::MacroCommand *m = new KPlato::MacroCommand(kundo2_i18n("Merge data"));
     if (m_wbsCode != wp->wbsCode()) {
+        debugPlanWork<<"wbs code:"<<wp->wbsCode();
         m->addCommand(new ModifyWbsCodeCmd(this, wp->wbsCode()));
     }
     if (to->name() != from->name()) {
-        m->addCommand(new NodeModifyNameCmd(*to, from->name()));
+        debugPlanWork<<"name:"<<from->name();
+        m->addCommand(new KPlato::NodeModifyNameCmd(*to, from->name()));
     }
     if (to->description() != from->description()) {
-        m->addCommand(new NodeModifyDescriptionCmd(*to, from->description()));
+        debugPlanWork<<"description:"<<from->description();
+        m->addCommand(new KPlato::NodeModifyDescriptionCmd(*to, from->description()));
     }
     if (to->startTime() != from->startTime() && from->startTime().isValid()) {
-        m->addCommand(new NodeModifyStartTimeCmd(*to, from->startTime()));
+        debugPlanWork<<"start time:"<<from->startTime();
+        m->addCommand(new KPlato::NodeModifyStartTimeCmd(*to, from->startTime()));
     }
     if (to->endTime() != from->endTime() && from->endTime().isValid()) {
-        m->addCommand(new NodeModifyEndTimeCmd(*to, from->endTime()));
+        debugPlanWork<<"end time:"<<from->endTime();
+        m->addCommand(new KPlato::NodeModifyEndTimeCmd(*to, from->endTime()));
     }
     if (to->leader() != from->leader()) {
-        m->addCommand(new NodeModifyLeaderCmd(*to, from->leader()));
+        debugPlanWork<<"leader:"<<from->leader();
+        m->addCommand(new KPlato::NodeModifyLeaderCmd(*to, from->leader()));
     }
 
-    if (from->type() == Node::Type_Task && from->type() == Node::Type_Task) {
-        if (static_cast<Task*>(to)->workPackage().ownerId() != static_cast<const Task*>(from)->workPackage().ownerId()) {
-            debugPlanWork<<"merge:"<<"different owners"<<static_cast<const Task*>(from)->workPackage().ownerName()<<static_cast<Task*>(to)->workPackage().ownerName();
-            if (static_cast<Task*>(to)->workPackage().ownerId().isEmpty()) {
+    if (from->type() == KPlato::Node::Type_Task && from->type() == KPlato::Node::Type_Task) {
+        if (static_cast<KPlato::Task*>(to)->workPackage().ownerId() != static_cast<const KPlato::Task*>(from)->workPackage().ownerId()) {
+            debugPlanWork<<"merge:"<<"different owners"<<static_cast<const KPlato::Task*>(from)->workPackage().ownerName()<<static_cast<KPlato::Task*>(to)->workPackage().ownerName();
+            if (static_cast<KPlato::Task*>(to)->workPackage().ownerId().isEmpty()) {
                 //TODO cmd
-                static_cast<Task*>(to)->workPackage().setOwnerId(static_cast<const Task*>(from)->workPackage().ownerId());
-                static_cast<Task*>(to)->workPackage().setOwnerName(static_cast<const Task*>(from)->workPackage().ownerName());
+                static_cast<KPlato::Task*>(to)->workPackage().setOwnerId(static_cast<const KPlato::Task*>(from)->workPackage().ownerId());
+                static_cast<KPlato::Task*>(to)->workPackage().setOwnerName(static_cast<const KPlato::Task*>(from)->workPackage().ownerName());
             }
         }
-        foreach (Document *doc,  from->documents().documents()) {
-            Document *org = to->documents().findDocument(doc->url());
+        const QList<KPlato::Document*> documents = from->documents().documents();
+        for (KPlato::Document *doc : documents) {
+            KPlato::Document *org = to->documents().findDocument(doc->url());
             if (org) {
                 // TODO: also handle modified type, sendas
                 // update ? what if open, modified ...
-                if (doc->type() == Document::Type_Product) {
+                if (doc->type() == KPlato::Document::Type_Product) {
                     //### FIXME. user feedback
                     warnPlanWork<<"We do not update existing deliverables (except name change)";
                     if (doc->name() != org->name()) {
-                        m->addCommand(new DocumentModifyNameCmd(org, doc->name()));
+                        m->addCommand(new KPlato::DocumentModifyNameCmd(org, doc->name()));
                     }
                 } else {
                     if (doc->name() != org->name()) {
-                        m->addCommand(new DocumentModifyNameCmd(org, doc->name()));
+                        m->addCommand(new KPlato::DocumentModifyNameCmd(org, doc->name()));
                     }
                     if (doc->sendAs() != org->sendAs()) {
-                        m->addCommand(new DocumentModifySendAsCmd(org, doc->sendAs()));
+                        m->addCommand(new KPlato::DocumentModifySendAsCmd(org, doc->sendAs()));
                     }
-                    if (doc->sendAs() == Document::SendAs_Copy) {
+                    if (doc->sendAs() == KPlato::Document::SendAs_Copy) {
                         debugPlanWork<<"Update existing doc:"<<org->url();
                         openNewDocument(org, store);
                     }
                 }
             } else {
                 debugPlanWork<<"new document:"<<doc->typeToString(doc->type())<<doc->url();
-                Document *newdoc = new Document(*doc);
-                m->addCommand(new DocumentAddCmd(to->documents(), newdoc));
-                if (doc->sendAs() == Document::SendAs_Copy) {
+                KPlato::Document *newdoc = new KPlato::Document(*doc);
+                m->addCommand(new KPlato::DocumentAddCmd(to->documents(), newdoc));
+                if (doc->sendAs() == KPlato::Document::SendAs_Copy) {
                     debugPlanWork<<"Copy file";
                     openNewDocument(newdoc, store);
                 }
             }
         }
     }
-    const Project *fromProject = wp->project();
-    Project *toProject = m_project;
-    const ScheduleManager *fromSm = fromProject->scheduleManagers().value(0);
+    const KPlato::Project *fromProject = wp->project();
+    KPlato::Project *toProject = m_project;
+    const KPlato::ScheduleManager *fromSm = fromProject->scheduleManagers().value(0);
     Q_ASSERT(fromSm);
-    ScheduleManager *toSm = toProject->scheduleManagers().value(0);
-    Q_ASSERT(toSm);
-    if (fromSm->managerId() != toSm->managerId() || fromSm->scheduleId() != toSm->scheduleId()) {
+    KPlato::ScheduleManager *toSm = toProject->scheduleManagers().value(0);
+
+    if (!toSm || fromSm->managerId() != toSm->managerId() || fromSm->scheduleId() != toSm->scheduleId()) {
         // rescheduled, update schedules
+        debugPlanWork<<"schedules:"<<fromSm;
         m->addCommand(new CopySchedulesCmd(*fromProject, *toProject));
     }
     if (m->isEmpty()) {
+        debugPlanWork<<"Nothing to merge";
         delete m;
     } else {
         part->addCommand(m);
     }
 }
 
-void WorkPackage::openNewDocument(const Document *doc, KoStore *store)
+void WorkPackage::openNewDocument(const KPlato::Document *doc, KoStore *store)
 {
     const QUrl url = extractFile(doc, store);
     if (url.url().isEmpty()) {
-        KMessageBox::error(0, i18n("Could not extract document from storage:<br>%1", doc->url().path()));
+        if (!m_nogui) {
+            KMessageBox::error(nullptr, i18n("Could not extract document from storage:<br>%1", doc->url().path()));
+        }
         return;
     }
     if (! url.isValid()) {
-        KMessageBox::error(0, i18n("Invalid URL:<br>%1", url.path()));
+        if (!m_nogui) {
+            KMessageBox::error(nullptr, i18n("Invalid URL:<br>%1", url.path()));
+        }
         return;
     }
     m_newdocs.insert(doc, url);
@@ -622,21 +624,23 @@ int WorkPackage::queryClose(Part *part)
     QString name = node()->name();
     QStringList lst;
     if (! m_childdocs.isEmpty()) {
-        foreach (DocumentChild *ch, m_childdocs) {
-            if (ch->isOpen() && ch->doc()->sendAs() == Document::SendAs_Copy) {
+        for (DocumentChild *ch : std::as_const(m_childdocs)) {
+            if (ch->isOpen() && ch->doc()->sendAs() == KPlato::Document::SendAs_Copy) {
                 lst << ch->doc()->url().fileName();
             }
         }
     }
     if (! lst.isEmpty()) {
-        KMessageBox::ButtonCode result = KMessageBox::warningContinueCancelList(0,
+        KMessageBox::ButtonCode result = KMessageBox::Continue;
+        if (!m_nogui) {
+            result = KMessageBox::warningContinueCancelList(nullptr,
                     i18np(
                         "<p>The work package <b>'%2'</b> has an open document.</p><p>Data may be lost if you continue.</p>",
                         "<p>The work package <b>'%2'</b> has open documents.</p><p>Data may be lost if you continue.</p>",
                         lst.count(),
                         name),
                     lst);
-
+        }
         switch (result) {
             case KMessageBox::Continue: {
                 debugPlanWork<<"Continue";
@@ -649,21 +653,23 @@ int WorkPackage::queryClose(Part *part)
         }
     }
     if (! isModified()) {
-        return KMessageBox::Yes;
+        return KMessageBox::PrimaryAction;
     }
-    KMessageBox::ButtonCode res = KMessageBox::warningYesNoCancel(0,
+    KMessageBox::ButtonCode res = KMessageBox::PrimaryAction;
+    if (!m_nogui) {
+        res = KMessageBox::warningTwoActionsCancel(nullptr,
                 i18n("<p>The work package <b>'%1'</b> has been modified.</p><p>Do you want to save it?</p>", name),
                 QString(),
                 KStandardGuiItem::save(),
                 KStandardGuiItem::discard());
-
+    }
     switch (res) {
-        case KMessageBox::Yes: {
+        case KMessageBox::PrimaryAction: {
             debugPlanWork<<"Yes";
             saveToProjects(part);
             break;
         }
-        case KMessageBox::No:
+        case KMessageBox::SecondaryAction:
             debugPlanWork<<"No";
             break;
         default: // case KMessageBox::Cancel :
@@ -673,12 +679,14 @@ int WorkPackage::queryClose(Part *part)
     return res;
 }
 
-QUrl WorkPackage::extractFile(const Document *doc)
+QUrl WorkPackage::extractFile(const KPlato::Document *doc)
 {
     KoStore *store = KoStore::createStore(m_filePath, KoStore::Read, "", KoStore::Zip);
     if (store->bad())
     {
-        KMessageBox::error(0, i18n("<p>Work package <b>'%1'</b></p><p>Could not open store:</p><p>%2</p>", node()->name(), m_filePath));
+        if (!m_nogui) {
+            KMessageBox::error(nullptr, i18n("<p>Work package <b>'%1'</b></p><p>Could not open store:</p><p>%2</p>", node()->name(), m_filePath));
+        }
         delete store;
         return QUrl();
     }
@@ -687,14 +695,16 @@ QUrl WorkPackage::extractFile(const Document *doc)
     return url;
 }
 
-QUrl WorkPackage::extractFile(const Document *doc, KoStore *store)
+QUrl WorkPackage::extractFile(const KPlato::Document *doc, KoStore *store)
 {
     //FIXME: should use a special tmp dir
     QString tmp = QDir::tempPath() + QLatin1Char('/') + doc->url().fileName();
     const QUrl url = QUrl::fromLocalFile(tmp);
     debugPlanWork<<"Extract: "<<doc->url().fileName()<<" -> "<<url.path();
     if (! store->extractFile(doc->url().fileName(), url.path())) {
-        KMessageBox::error(0, i18n("<p>Work package <b>'%1'</b></p><p>Could not extract file:</p><p>%2</p>", node()->name(), doc->url().fileName()));
+        if (!m_nogui) {
+            KMessageBox::error(nullptr, i18n("<p>Work package <b>'%1'</b></p><p>Could not extract file:</p><p>%2</p>", node()->name(), doc->url().fileName()));
+        }
         return QUrl();
     }
     return url;
@@ -709,6 +719,11 @@ QString WorkPackage::id() const
     return id;
 }
 
+void WorkPackage::setNoGui(bool nogui)
+{
+    m_nogui = nogui;
+}
+
 //--------------------------------
 PackageRemoveCmd::PackageRemoveCmd(Part *part, WorkPackage *value, const KUndo2MagicString& name)
     : NamedCommand(name),
@@ -736,20 +751,20 @@ void PackageRemoveCmd::unexecute()
 }
 
 //---------------------
-CopySchedulesCmd::CopySchedulesCmd(const Project &fromProject, Project &toProject, const KUndo2MagicString &name)
-    : NamedCommand(name),
+CopySchedulesCmd::CopySchedulesCmd(const KPlato::Project &fromProject, KPlato::Project &toProject, const KUndo2MagicString &name)
+    : KPlato::NamedCommand(name),
       m_project(toProject)
 {
     QDomDocument olddoc;
-    QDomElement e = olddoc.createElement("old");
+    QDomElement e = olddoc.createElement(QStringLiteral("old"));
     olddoc.appendChild(e);
-    toProject.save(e, XmlSaveContext());
+    toProject.save(e, KPlato::XmlSaveContext());
     m_olddoc = olddoc.toString();
 
     QDomDocument newdoc;
-    e = newdoc.createElement("new");
+    e = newdoc.createElement(QStringLiteral("new"));
     newdoc.appendChild(e);
-    fromProject.save(e, XmlSaveContext());
+    fromProject.save(e, KPlato::XmlSaveContext());
     m_newdoc = newdoc.toString();
 }
 void CopySchedulesCmd::execute()
@@ -769,19 +784,28 @@ void CopySchedulesCmd::load(const QString &doc)
     d.setContent(doc);
     KoXmlElement proj = d.documentElement().namedItem("project").toElement();
     Q_ASSERT(! proj.isNull());
-    KoXmlElement task = proj.namedItem("task").toElement();
-    Q_ASSERT(! task.isNull());
-    KoXmlElement ts = task.namedItem("schedules").namedItem("schedule").toElement();
-    Q_ASSERT(! ts.isNull());
-    KoXmlElement ps = proj.namedItem("schedules").namedItem("plan").toElement();
-    Q_ASSERT(! ps.isNull());
+    KoXmlElement tasks = proj.namedItem("tasks").toElement();
+    if (tasks.isNull()) {
+        return;
+    }
+    KoXmlElement task = tasks.namedItem("task").toElement();
+    if (task.isNull()) {
+        return;
+    }
+    KoXmlElement ts = task.namedItem("task-schedules").namedItem("task-schedule").toElement();
+    if (ts.isNull()) {
+        return;
+    }
+    KoXmlElement ps = proj.namedItem("project-schedules").namedItem("schedule-management").toElement();
 
-    XMLLoaderObject status;
+    KPlato::XMLLoaderObject status;
     status.setProject(&m_project);
     status.setVersion(PLAN_FILE_SYNTAX_VERSION);
+    status.setMimetype(PLAN_MIME_TYPE);
+    const auto loader = status.loader();
     // task first
-    NodeSchedule *ns = new NodeSchedule();
-    if (ns->loadXML(ts, status)) {
+    KPlato::NodeSchedule *ns = new KPlato::NodeSchedule();
+    if (loader->loadNodeSchedule(ns, ts, status)) {
         debugPlanWork<<ns->name()<<ns->type()<<ns->id();
         ns->setNode(m_project.childNode(0));
         m_project.childNode(0)->addSchedule(ns);
@@ -789,34 +813,39 @@ void CopySchedulesCmd::load(const QString &doc)
         Q_ASSERT(false);
         delete ns;
     }
-    // schedule manager next (includes main schedule and resource schedule)
-    ScheduleManager *sm = new ScheduleManager(m_project);
-    if (sm->loadXML(ps, status)) {
-        m_project.addScheduleManager(sm);
-    } else {
-        Q_ASSERT(false);
-        delete sm;
-    }
-    if (sm) {
-        m_project.setCurrentSchedule(sm->scheduleId());
+    if (!ps.isNull()) {
+        // schedule manager next (includes main schedule and resource schedule)
+        KPlato::ScheduleManager *sm = new KPlato::ScheduleManager(m_project);
+        if (loader->load(sm, ps, status)) {
+            m_project.addScheduleManager(sm);
+        } else {
+            Q_ASSERT(false);
+            delete sm;
+        }
+        if (sm) {
+            m_project.setCurrentSchedule(sm->scheduleId());
+        }
     }
     m_project.childNode(0)->changed();
 }
 
 void CopySchedulesCmd::clearSchedules()
 {
-    foreach (Schedule *s, m_project.schedules()) {
+    const QList<KPlato::Schedule*> schedules = m_project.childNode(0)->schedules().values();
+    for (KPlato::Schedule *s : schedules) {
         m_project.takeSchedule(s);
     }
-    foreach (Schedule *s, m_project.childNode(0)->schedules()) {
-        foreach (Appointment *a, s->appointments()) {
+    for (KPlato::Schedule *s : schedules) {
+        const QList<KPlato::Appointment*> appointments = s->appointments();
+        for (KPlato::Appointment *a : appointments) {
             if (a->resource() && a->resource()->resource()) {
                 a->resource()->resource()->takeSchedule(a->resource());
             }
         }
         m_project.childNode(0)->takeSchedule(s);
     }
-    foreach (ScheduleManager *sm,  m_project.scheduleManagers()) {
+    const QList<KPlato::ScheduleManager*> managers = m_project.scheduleManagers();
+    for (KPlato::ScheduleManager *sm : managers) {
         m_project.takeScheduleManager(sm);
         delete sm;
     }
@@ -853,9 +882,10 @@ QDebug operator<<(QDebug dbg, const KPlatoWork::WorkPackage *wp)
 
 QDebug operator<<(QDebug dbg, const KPlatoWork::WorkPackage &wp)
 {
-    dbg.noquote() << "WorkPackage[";
-    dbg << wp.id();
-    dbg << wp.name();
+    dbg.noquote().nospace() << "WorkPackage[";
+    dbg << "Project: " << wp.project()->name();
+    dbg << " Task: " << wp.name();
+    dbg << " Docs: " << wp.childDocs().count();
     dbg << ']';
     return dbg;
 }
